-- Demo module database dump
-- Version 1.1
-- http://drupal.org/project/demo
--
-- Database: theme822
-- Date: Fri, 09/13/2013 - 13:46
-- Server version: 5.5.24-log
-- PHP version: 5.4.3
-- Drupal version: 7.23

SET SQL_MODE="NO_AUTO_VALUE_ON_ZERO";
SET FOREIGN_KEY_CHECKS = 0;

SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT;
SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS;
SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION;
SET NAMES utf8;

--
-- Table structure for table 'accesslog'
--

CREATE TABLE IF NOT EXISTS `accesslog` (
  `aid` int(11) NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique accesslog ID.',
  `sid` varchar(128) NOT NULL DEFAULT '' COMMENT 'Browser session ID of user that visited page.',
  `title` varchar(255) DEFAULT NULL COMMENT 'Title of page visited.',
  `path` varchar(255) DEFAULT NULL COMMENT 'Internal path to page visited (relative to Drupal root.)',
  `url` text COMMENT 'Referrer URI.',
  `hostname` varchar(128) DEFAULT NULL COMMENT 'Hostname of user that visited the page.',
  `uid` int(10) unsigned DEFAULT '0' COMMENT 'User users.uid that visited the page.',
  `timer` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'Time in milliseconds that the page took to load.',
  `timestamp` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'Timestamp of when the page was visited.',
  PRIMARY KEY (`aid`),
  KEY `accesslog_timestamp` (`timestamp`),
  KEY `uid` (`uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores site access information for statistics.';

--
-- Dumping data for table 'accesslog'
--

/*!40000 ALTER TABLE accesslog DISABLE KEYS */;
/*!40000 ALTER TABLE accesslog ENABLE KEYS */;

--
-- Table structure for table 'actions'
--

CREATE TABLE IF NOT EXISTS `actions` (
  `aid` varchar(255) NOT NULL DEFAULT '0' COMMENT 'Primary Key: Unique actions ID.',
  `type` varchar(32) NOT NULL DEFAULT '' COMMENT 'The object that that action acts on (node, user, comment, system or custom types.)',
  `callback` varchar(255) NOT NULL DEFAULT '' COMMENT 'The callback function that executes when the action runs.',
  `parameters` longblob NOT NULL COMMENT 'Parameters to be passed to the callback function.',
  `label` varchar(255) NOT NULL DEFAULT '0' COMMENT 'Label of the action.',
  PRIMARY KEY (`aid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores action information.';

--
-- Dumping data for table 'actions'
--

/*!40000 ALTER TABLE actions DISABLE KEYS */;
INSERT INTO `actions` VALUES
('comment_publish_action', 'comment', 'comment_publish_action', '', 'Publish comment'),
('comment_save_action', 'comment', 'comment_save_action', '', 'Save comment'),
('comment_unpublish_action', 'comment', 'comment_unpublish_action', '', 'Unpublish comment'),
('node_make_sticky_action', 'node', 'node_make_sticky_action', '', 'Make content sticky'),
('node_make_unsticky_action', 'node', 'node_make_unsticky_action', '', 'Make content unsticky'),
('node_promote_action', 'node', 'node_promote_action', '', 'Promote content to front page'),
('node_publish_action', 'node', 'node_publish_action', '', 'Publish content'),
('node_save_action', 'node', 'node_save_action', '', 'Save content'),
('node_unpromote_action', 'node', 'node_unpromote_action', '', 'Remove content from front page'),
('node_unpublish_action', 'node', 'node_unpublish_action', '', 'Unpublish content'),
('system_block_ip_action', 'user', 'system_block_ip_action', '', 'Ban IP address of current user'),
('user_block_user_action', 'user', 'user_block_user_action', '', 'Block current user');
/*!40000 ALTER TABLE actions ENABLE KEYS */;

--
-- Table structure for table 'aggregator_category'
--

CREATE TABLE IF NOT EXISTS `aggregator_category` (
  `cid` int(11) NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique aggregator category ID.',
  `title` varchar(255) NOT NULL DEFAULT '' COMMENT 'Title of the category.',
  `description` longtext NOT NULL COMMENT 'Description of the category',
  `block` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'The number of recent items to show within the category block.',
  PRIMARY KEY (`cid`),
  UNIQUE KEY `title` (`title`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores categories for aggregator feeds and feed items.';

--
-- Dumping data for table 'aggregator_category'
--

/*!40000 ALTER TABLE aggregator_category DISABLE KEYS */;
/*!40000 ALTER TABLE aggregator_category ENABLE KEYS */;

--
-- Table structure for table 'aggregator_category_feed'
--

CREATE TABLE IF NOT EXISTS `aggregator_category_feed` (
  `fid` int(11) NOT NULL DEFAULT '0' COMMENT 'The feed’s aggregator_feed.fid.',
  `cid` int(11) NOT NULL DEFAULT '0' COMMENT 'The aggregator_category.cid to which the feed is being assigned.',
  PRIMARY KEY (`cid`,`fid`),
  KEY `fid` (`fid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Bridge table; maps feeds to categories.';

--
-- Dumping data for table 'aggregator_category_feed'
--

/*!40000 ALTER TABLE aggregator_category_feed DISABLE KEYS */;
/*!40000 ALTER TABLE aggregator_category_feed ENABLE KEYS */;

--
-- Table structure for table 'aggregator_category_item'
--

CREATE TABLE IF NOT EXISTS `aggregator_category_item` (
  `iid` int(11) NOT NULL DEFAULT '0' COMMENT 'The feed item’s aggregator_item.iid.',
  `cid` int(11) NOT NULL DEFAULT '0' COMMENT 'The aggregator_category.cid to which the feed item is being assigned.',
  PRIMARY KEY (`cid`,`iid`),
  KEY `iid` (`iid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Bridge table; maps feed items to categories.';

--
-- Dumping data for table 'aggregator_category_item'
--

/*!40000 ALTER TABLE aggregator_category_item DISABLE KEYS */;
/*!40000 ALTER TABLE aggregator_category_item ENABLE KEYS */;

--
-- Table structure for table 'aggregator_feed'
--

CREATE TABLE IF NOT EXISTS `aggregator_feed` (
  `fid` int(11) NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique feed ID.',
  `title` varchar(255) NOT NULL DEFAULT '' COMMENT 'Title of the feed.',
  `url` text NOT NULL COMMENT 'URL to the feed.',
  `refresh` int(11) NOT NULL DEFAULT '0' COMMENT 'How often to check for new feed items, in seconds.',
  `checked` int(11) NOT NULL DEFAULT '0' COMMENT 'Last time feed was checked for new items, as Unix timestamp.',
  `queued` int(11) NOT NULL DEFAULT '0' COMMENT 'Time when this feed was queued for refresh, 0 if not queued.',
  `link` text NOT NULL COMMENT 'The parent website of the feed; comes from the <link> element in the feed.',
  `description` longtext NOT NULL COMMENT 'The parent website’s description; comes from the <description> element in the feed.',
  `image` longtext NOT NULL COMMENT 'An image representing the feed.',
  `hash` varchar(64) NOT NULL DEFAULT '' COMMENT 'Calculated hash of the feed data, used for validating cache.',
  `etag` varchar(255) NOT NULL DEFAULT '' COMMENT 'Entity tag HTTP response header, used for validating cache.',
  `modified` int(11) NOT NULL DEFAULT '0' COMMENT 'When the feed was last modified, as a Unix timestamp.',
  `block` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'Number of items to display in the feed’s block.',
  PRIMARY KEY (`fid`),
  UNIQUE KEY `title` (`title`),
  KEY `queued` (`queued`),
  KEY `url` (`url`(255))
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores feeds to be parsed by the aggregator.';

--
-- Dumping data for table 'aggregator_feed'
--

/*!40000 ALTER TABLE aggregator_feed DISABLE KEYS */;
/*!40000 ALTER TABLE aggregator_feed ENABLE KEYS */;

--
-- Table structure for table 'aggregator_item'
--

CREATE TABLE IF NOT EXISTS `aggregator_item` (
  `iid` int(11) NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique ID for feed item.',
  `fid` int(11) NOT NULL DEFAULT '0' COMMENT 'The aggregator_feed.fid to which this item belongs.',
  `title` varchar(255) NOT NULL DEFAULT '' COMMENT 'Title of the feed item.',
  `link` text NOT NULL COMMENT 'Link to the feed item.',
  `author` varchar(255) NOT NULL DEFAULT '' COMMENT 'Author of the feed item.',
  `description` longtext NOT NULL COMMENT 'Body of the feed item.',
  `timestamp` int(11) DEFAULT NULL COMMENT 'Posted date of the feed item, as a Unix timestamp.',
  `guid` text NOT NULL COMMENT 'Unique identifier for the feed item.',
  PRIMARY KEY (`iid`),
  KEY `fid` (`fid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores the individual items imported from feeds.';

--
-- Dumping data for table 'aggregator_item'
--

/*!40000 ALTER TABLE aggregator_item DISABLE KEYS */;
/*!40000 ALTER TABLE aggregator_item ENABLE KEYS */;

--
-- Table structure for table 'authmap'
--

CREATE TABLE IF NOT EXISTS `authmap` (
  `aid` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique authmap ID.',
  `uid` int(11) NOT NULL DEFAULT '0' COMMENT 'User’s users.uid.',
  `authname` varchar(128) NOT NULL DEFAULT '' COMMENT 'Unique authentication name.',
  `module` varchar(128) NOT NULL DEFAULT '' COMMENT 'Module which is controlling the authentication.',
  PRIMARY KEY (`aid`),
  UNIQUE KEY `authname` (`authname`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores distributed authentication mapping.';

--
-- Dumping data for table 'authmap'
--

/*!40000 ALTER TABLE authmap DISABLE KEYS */;
/*!40000 ALTER TABLE authmap ENABLE KEYS */;

--
-- Table structure for table 'batch'
--

CREATE TABLE IF NOT EXISTS `batch` (
  `bid` int(10) unsigned NOT NULL COMMENT 'Primary Key: Unique batch ID.',
  `token` varchar(64) NOT NULL COMMENT 'A string token generated against the current user’s session id and the batch id, used to ensure that only the user who submitted the batch can effectively access it.',
  `timestamp` int(11) NOT NULL COMMENT 'A Unix timestamp indicating when this batch was submitted for processing. Stale batches are purged at cron time.',
  `batch` longblob COMMENT 'A serialized array containing the processing data for the batch.',
  PRIMARY KEY (`bid`),
  KEY `token` (`token`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores details about batches (processes that run in...';

--
-- Dumping data for table 'batch'
--

/*!40000 ALTER TABLE batch DISABLE KEYS */;
INSERT INTO `batch` VALUES
('165', 'fYm5PpLrPyXcN57deAc668absO5bE-qxE2H1dB7LSBk', '1378903920', 'a:13:{s:4:"sets";a:1:{i:0;a:15:{s:7:"sandbox";a:0:{}s:7:"results";a:1:{s:8:"projects";a:4:{s:11:"block_class";s:63:"http://ftp.drupal.org/files/projects/block_class-7.x-2.1.tar.gz";s:10:"flexslider";s:69:"http://ftp.drupal.org/files/projects/flexslider-7.x-2.0-alpha3.tar.gz";s:12:"getlocations";s:64:"http://ftp.drupal.org/files/projects/getlocations-7.x-1.9.tar.gz";s:13:"module_filter";s:65:"http://ftp.drupal.org/files/projects/module_filter-7.x-1.8.tar.gz";}}s:7:"success";b:1;s:5:"start";d:1378903926.962318897247314453125;s:7:"elapsed";d:26704.639999999999417923390865325927734375;s:5:"title";s:19:"Downloading updates";s:12:"init_message";s:49:"Preparing to download selected updates<br/>&nbsp;";s:8:"finished";s:38:"update_manager_download_batch_finished";s:4:"file";s:33:"modules/update/update.manager.inc";s:16:"progress_message";s:29:"Completed @current of @total.";s:13:"error_message";s:22:"An error has occurred.";s:3:"css";a:0:{}s:5:"total";i:4;s:5:"count";i:0;s:5:"queue";a:2:{s:4:"name";s:18:"drupal_batch:165:0";s:5:"class";s:10:"BatchQueue";}}}s:16:"has_form_submits";b:0;s:10:"form_state";a:3:{s:10:"programmed";b:0;s:7:"rebuild";b:0;s:8:"redirect";N;}s:11:"progressive";b:1;s:11:"current_set";i:0;s:3:"url";s:5:"batch";s:11:"url_options";a:0:{}s:10:"source_url";s:28:"admin/reports/updates/update";s:8:"redirect";N;s:5:"theme";s:5:"seven";s:17:"redirect_callback";s:11:"drupal_goto";s:2:"id";s:3:"165";s:13:"error_message";s:122:"Please continue to <a href="/2013/09_September/theme822.freesample/?q=batch&amp;id=165&amp;op=finished">the error page</a>";}');
/*!40000 ALTER TABLE batch ENABLE KEYS */;

--
-- Table structure for table 'block'
--

CREATE TABLE IF NOT EXISTS `block` (
  `bid` int(11) NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique block ID.',
  `module` varchar(64) NOT NULL DEFAULT '' COMMENT 'The module from which the block originates; for example, ’user’ for the Who’s Online block, and ’block’ for any custom blocks.',
  `delta` varchar(32) NOT NULL DEFAULT '0' COMMENT 'Unique ID for block within a module.',
  `theme` varchar(64) NOT NULL DEFAULT '' COMMENT 'The theme under which the block settings apply.',
  `status` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'Block enabled status. (1 = enabled, 0 = disabled)',
  `weight` int(11) NOT NULL DEFAULT '0' COMMENT 'Block weight within region.',
  `region` varchar(64) NOT NULL DEFAULT '' COMMENT 'Theme region within which the block is set.',
  `custom` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'Flag to indicate how users may control visibility of the block. (0 = Users cannot control, 1 = On by default, but can be hidden, 2 = Hidden by default, but can be shown)',
  `visibility` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'Flag to indicate how to show blocks on pages. (0 = Show on all pages except listed pages, 1 = Show only on listed pages, 2 = Use custom PHP code to determine visibility)',
  `pages` text NOT NULL COMMENT 'Contents of the `Pages` block; contains either a list of paths on which to include/exclude the block or PHP code, depending on `visibility` setting.',
  `title` varchar(64) NOT NULL DEFAULT '' COMMENT 'Custom title for the block. (Empty string will use block default title, <none> will remove the title, text will cause block to use specified title.)',
  `cache` tinyint(4) NOT NULL DEFAULT '1' COMMENT 'Binary flag to indicate block cache mode. (-2: Custom cache, -1: Do not cache, 1: Cache per role, 2: Cache per user, 4: Cache per page, 8: Block cache global) See DRUPAL_CACHE_* constants in ../includes/common.inc for more detailed information.',
  `css_class` varchar(255) NOT NULL DEFAULT '' COMMENT 'String containing the classes for the block.',
  PRIMARY KEY (`bid`),
  UNIQUE KEY `tmd` (`theme`,`module`,`delta`),
  KEY `list` (`theme`,`status`,`region`,`weight`,`module`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores block settings, such as region and visibility...';

--
-- Dumping data for table 'block'
--

/*!40000 ALTER TABLE block DISABLE KEYS */;
INSERT INTO `block` VALUES
('1', 'system', 'main', 'bartik', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('2', 'search', 'form', 'bartik', '1', '-1', 'sidebar_first', '0', '0', '', '', '-1', ''),
('3', 'node', 'recent', 'seven', '0', '10', '-1', '0', '0', '', '', '-1', ''),
('4', 'user', 'login', 'bartik', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('5', 'system', 'navigation', 'bartik', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('6', 'system', 'powered-by', 'bartik', '1', '10', 'footer', '0', '0', '', '', '-1', ''),
('7', 'system', 'help', 'bartik', '1', '0', 'help', '0', '0', '', '', '-1', ''),
('8', 'system', 'main', 'seven', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('9', 'system', 'help', 'seven', '1', '0', 'help', '0', '0', '', '', '-1', ''),
('10', 'user', 'login', 'seven', '1', '10', 'content', '0', '0', '', '', '-1', ''),
('11', 'user', 'new', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('12', 'search', 'form', 'seven', '0', '-10', '-1', '0', '0', '', '', '-1', ''),
('13', 'comment', 'recent', 'bartik', '0', '1', '-1', '0', '0', '', '', '1', ''),
('14', 'node', 'syndicate', 'bartik', '0', '4', '-1', '0', '0', '', '', '-1', ''),
('15', 'node', 'recent', 'bartik', '0', '2', '-1', '0', '0', '', '', '1', ''),
('16', 'shortcut', 'shortcuts', 'bartik', '0', '3', '-1', '0', '0', '', '', '-1', ''),
('17', 'system', 'management', 'bartik', '0', '-6', '-1', '0', '0', '', '', '-1', ''),
('18', 'system', 'user-menu', 'bartik', '0', '5', '-1', '0', '0', '', '<none>', '-1', ''),
('19', 'system', 'main-menu', 'bartik', '0', '-7', '-1', '0', '0', '', '', '-1', ''),
('20', 'user', 'new', 'bartik', '0', '6', '-1', '0', '0', '', '', '1', ''),
('21', 'user', 'online', 'bartik', '0', '7', '-1', '0', '0', '', '', '-1', ''),
('22', 'comment', 'recent', 'seven', '0', '0', '-1', '0', '0', '', '', '1', ''),
('23', 'node', 'syndicate', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('24', 'shortcut', 'shortcuts', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('25', 'system', 'powered-by', 'seven', '0', '10', '-1', '0', '0', '', '', '-1', ''),
('26', 'system', 'navigation', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('27', 'system', 'management', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('28', 'system', 'user-menu', 'seven', '0', '0', '-1', '0', '0', '', '<none>', '-1', ''),
('29', 'system', 'main-menu', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('30', 'user', 'online', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('31', 'blog', 'recent', 'bartik', '0', '0', '-1', '0', '0', '', '', '1', ''),
('32', 'book', 'navigation', 'bartik', '0', '-13', '-1', '0', '0', '', '', '5', ''),
('33', 'locale', 'language', 'bartik', '0', '-8', '-1', '0', '0', '', '', '-1', ''),
('34', 'poll', 'recent', 'bartik', '0', '-5', '-1', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('35', 'forum', 'active', 'bartik', '0', '-14', '-1', '0', '0', '', '', '-2', ''),
('36', 'forum', 'new', 'bartik', '0', '-4', '-1', '0', '0', '', '', '-2', ''),
('37', 'blog', 'recent', 'seven', '0', '0', '-1', '0', '0', '', '', '1', ''),
('38', 'book', 'navigation', 'seven', '0', '0', '-1', '0', '0', '', '', '5', ''),
('39', 'locale', 'language', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('40', 'poll', 'recent', 'seven', '0', '0', '-1', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('41', 'forum', 'active', 'seven', '0', '0', '-1', '0', '0', '', '', '-2', ''),
('42', 'forum', 'new', 'seven', '0', '0', '-1', '0', '0', '', '', '-2', ''),
('43', 'blog', 'recent', 'theme551', '1', '-4', 'sidebar_first', '0', '0', '', '', '1', ''),
('44', 'book', 'navigation', 'theme551', '1', '1', 'sidebar_first', '0', '0', '', '', '5', ''),
('45', 'comment', 'recent', 'theme551', '1', '-5', 'sidebar_first', '0', '0', '', '', '1', ''),
('46', 'forum', 'active', 'theme551', '1', '2', 'sidebar_first', '0', '0', '', '', '-2', ''),
('47', 'forum', 'new', 'theme551', '1', '-3', 'sidebar_first', '0', '0', '', '', '-2', ''),
('48', 'locale', 'language', 'theme551', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('49', 'node', 'recent', 'theme551', '1', '-6', 'sidebar_first', '0', '0', '', '', '1', ''),
('50', 'node', 'syndicate', 'theme551', '1', '-8', 'sidebar_first', '0', '0', '', '', '-1', ''),
('51', 'poll', 'recent', 'theme551', '1', '-2', 'sidebar_first', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('52', 'search', 'form', 'theme551', '1', '-1', 'search', '0', '0', '', '', '-1', ''),
('53', 'shortcut', 'shortcuts', 'theme551', '1', '-7', 'sidebar_first', '0', '0', '', '', '-1', ''),
('54', 'system', 'help', 'theme551', '1', '0', 'help', '0', '0', '', '', '-1', ''),
('55', 'system', 'main', 'theme551', '1', '-11', 'content', '0', '0', '', '', '-1', ''),
('56', 'system', 'main-menu', 'theme551', '1', '-1', 'sidebar_first', '0', '0', '', '', '-1', ''),
('57', 'system', 'management', 'theme551', '1', '-7', 'sidebar_first', '0', '0', '', '', '-1', ''),
('58', 'system', 'navigation', 'theme551', '1', '3', 'sidebar_first', '0', '0', '', '', '-1', ''),
('59', 'system', 'powered-by', 'theme551', '0', '-11', '-1', '0', '0', '', '', '-1', ''),
('60', 'system', 'user-menu', 'theme551', '1', '-9', 'sidebar_first', '0', '0', '', '<none>', '-1', ''),
('61', 'user', 'login', 'theme551', '1', '4', 'sidebar_first', '0', '0', '', '', '-1', ''),
('62', 'user', 'new', 'theme551', '1', '-10', 'sidebar_first', '0', '0', '', '', '1', ''),
('63', 'user', 'online', 'theme551', '1', '-11', 'sidebar_first', '0', '0', '', '', '-1', ''),
('64', 'superfish', '1', 'bartik', '0', '-15', '-1', '0', '0', '', '<none>', '-1', ''),
('65', 'superfish', '2', 'bartik', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('66', 'superfish', '3', 'bartik', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('67', 'superfish', '4', 'bartik', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('68', 'superfish', '1', 'seven', '0', '0', '-1', '0', '0', '', '<none>', '-1', ''),
('69', 'superfish', '2', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('70', 'superfish', '3', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('71', 'superfish', '4', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('72', 'superfish', '1', 'theme551', '1', '0', 'menu', '0', '0', '', '<none>', '-1', ''),
('73', 'superfish', '2', 'theme551', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('74', 'superfish', '3', 'theme551', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('75', 'superfish', '4', 'theme551', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('76', 'block', '1', 'bartik', '0', '-3', '-1', '0', '1', 'contact', 'Our Location', '-1', ''),
('77', 'block', '1', 'seven', '0', '0', '-1', '0', '1', 'contact', 'Our Location', '-1', ''),
('78', 'block', '1', 'theme551', '1', '0', 'sidebar_second', '0', '1', 'contact', 'Our Location', '-1', ''),
('88', 'block', '5', 'bartik', '0', '-9', '-1', '0', '0', '', '', '-1', ''),
('89', 'block', '5', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('90', 'block', '5', 'theme551', '1', '0', 'footer', '0', '0', '', '', '-1', ''),
('91', 'block', '1', 'theme557', '1', '0', 'sidebar_second', '0', '1', 'contact', 'Our Location', '-1', ''),
('95', 'block', '5', 'theme557', '1', '0', 'footer', '0', '0', '', '', '-1', ''),
('96', 'blog', 'recent', 'theme557', '1', '-4', 'sidebar_first', '0', '0', '', '', '1', ''),
('97', 'book', 'navigation', 'theme557', '1', '1', 'sidebar_first', '0', '0', '', '', '5', ''),
('98', 'comment', 'recent', 'theme557', '1', '-5', 'sidebar_first', '0', '0', '', '', '1', ''),
('99', 'forum', 'active', 'theme557', '1', '2', 'sidebar_first', '0', '0', '', '', '-2', ''),
('100', 'forum', 'new', 'theme557', '1', '-3', 'sidebar_first', '0', '0', '', '', '-2', ''),
('101', 'locale', 'language', 'theme557', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('102', 'node', 'recent', 'theme557', '1', '-6', 'sidebar_first', '0', '0', '', '', '1', ''),
('103', 'node', 'syndicate', 'theme557', '1', '-8', 'sidebar_first', '0', '0', '', '', '-1', ''),
('104', 'poll', 'recent', 'theme557', '1', '-2', 'sidebar_first', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('105', 'search', 'form', 'theme557', '1', '-1', 'search', '0', '0', '', '', '-1', ''),
('106', 'shortcut', 'shortcuts', 'theme557', '1', '-7', 'sidebar_first', '0', '0', '', '', '-1', ''),
('107', 'superfish', '1', 'theme557', '1', '0', 'menu', '0', '0', '', '<none>', '-1', ''),
('108', 'superfish', '2', 'theme557', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('109', 'superfish', '3', 'theme557', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('110', 'superfish', '4', 'theme557', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('111', 'system', 'help', 'theme557', '1', '0', 'help', '0', '0', '', '', '-1', ''),
('112', 'system', 'main', 'theme557', '1', '-11', 'content', '0', '0', '', '', '-1', ''),
('113', 'system', 'main-menu', 'theme557', '1', '-1', 'sidebar_first', '0', '0', '', '', '-1', ''),
('114', 'system', 'management', 'theme557', '1', '-7', 'sidebar_first', '0', '0', '', '', '-1', ''),
('115', 'system', 'navigation', 'theme557', '1', '3', 'sidebar_first', '0', '0', '', '', '-1', ''),
('116', 'system', 'powered-by', 'theme557', '0', '-11', '-1', '0', '0', '', '', '-1', ''),
('117', 'system', 'user-menu', 'theme557', '1', '-9', 'sidebar_first', '0', '0', '', '<none>', '-1', ''),
('118', 'user', 'login', 'theme557', '1', '4', 'sidebar_first', '0', '0', '', '', '-1', ''),
('119', 'user', 'new', 'theme557', '1', '-10', 'sidebar_first', '0', '0', '', '', '1', ''),
('120', 'user', 'online', 'theme557', '1', '-11', 'sidebar_first', '0', '0', '', '', '-1', ''),
('121', 'demo_reset', 'reset', 'bartik', '1', '0', 'sidebar_second', '0', '0', '', '', '-1', ''),
('122', 'demo_reset', 'reset', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('123', 'demo_reset', 'reset', 'theme557', '1', '0', 'sidebar_second', '0', '0', '', '', '-1', ''),
('124', 'block', '1', 'zentropy', '1', '-17', 'sidebar_first_wide', '0', '1', 'contact', 'Our Location', '-1', ''),
('128', 'block', '5', 'zentropy', '1', '-16', 'footer', '0', '0', '', '', '-1', ''),
('129', 'blog', 'recent', 'zentropy', '1', '-3', 'sidebar_first_wide', '0', '0', '', '', '1', ''),
('130', 'book', 'navigation', 'zentropy', '1', '3', 'sidebar_first_wide', '0', '0', '', '', '5', ''),
('131', 'comment', 'recent', 'zentropy', '1', '-4', 'sidebar_first_wide', '0', '0', '', '', '1', ''),
('132', 'demo_reset', 'reset', 'zentropy', '0', '-13', '-1', '0', '0', '', '', '-1', ''),
('133', 'forum', 'active', 'zentropy', '1', '4', 'sidebar_first_wide', '0', '0', '', '', '-2', ''),
('134', 'forum', 'new', 'zentropy', '1', '-2', 'sidebar_first_wide', '0', '0', '', '', '-2', ''),
('135', 'locale', 'language', 'zentropy', '1', '2', 'sidebar_first_wide', '0', '0', '', '', '-1', ''),
('136', 'node', 'recent', 'zentropy', '1', '-5', 'sidebar_first_wide', '0', '0', '', '', '1', ''),
('137', 'node', 'syndicate', 'zentropy', '1', '-9', 'sidebar_first_wide', '0', '0', '', '', '-1', ''),
('138', 'poll', 'recent', 'zentropy', '1', '-1', 'sidebar_first_wide', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('139', 'search', 'form', 'zentropy', '1', '-16', 'sidebar_first_wide', '0', '0', '', '', '-1', ''),
('140', 'shortcut', 'shortcuts', 'zentropy', '1', '-7', 'sidebar_first_wide', '0', '0', '', '', '-1', ''),
('141', 'superfish', '1', 'zentropy', '1', '-17', 'menu', '0', '0', '', '<none>', '-1', ''),
('142', 'superfish', '2', 'zentropy', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('143', 'superfish', '3', 'zentropy', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('144', 'superfish', '4', 'zentropy', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('145', 'system', 'help', 'zentropy', '1', '0', 'help', '0', '0', '', '', '-1', ''),
('146', 'system', 'main', 'zentropy', '1', '-16', 'content', '0', '0', '', '', '-1', ''),
('147', 'system', 'main-menu', 'zentropy', '1', '1', 'sidebar_first_wide', '0', '0', '', '', '-1', ''),
('148', 'system', 'management', 'zentropy', '1', '0', 'sidebar_first_wide', '0', '0', '', '', '-1', ''),
('149', 'system', 'navigation', 'zentropy', '1', '5', 'sidebar_first_wide', '0', '0', '', '', '-1', ''),
('150', 'system', 'powered-by', 'zentropy', '1', '-10', 'sidebar_first_wide', '0', '0', '', '', '-1', ''),
('151', 'system', 'user-menu', 'zentropy', '1', '-11', 'user_menu', '0', '0', '', '<none>', '-1', ''),
('152', 'user', 'login', 'zentropy', '1', '-15', 'sidebar_first_wide', '0', '0', '', '', '-1', ''),
('153', 'user', 'new', 'zentropy', '1', '-13', 'sidebar_first_wide', '0', '0', '', '', '1', ''),
('154', 'user', 'online', 'zentropy', '1', '-11', 'sidebar_first_wide', '0', '0', '', '', '-1', ''),
('155', 'block', '1', 'basic', '0', '0', '-1', '0', '1', 'contact', 'Our Location', '-1', ''),
('159', 'block', '5', 'basic', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('160', 'blog', 'recent', 'basic', '0', '0', '-1', '0', '0', '', '', '1', ''),
('161', 'book', 'navigation', 'basic', '0', '0', '-1', '0', '0', '', '', '5', ''),
('162', 'comment', 'recent', 'basic', '0', '0', '-1', '0', '0', '', '', '1', ''),
('163', 'demo_reset', 'reset', 'basic', '1', '0', 'sidebar_second', '0', '0', '', '', '-1', ''),
('164', 'forum', 'active', 'basic', '0', '0', '-1', '0', '0', '', '', '-2', ''),
('165', 'forum', 'new', 'basic', '0', '0', '-1', '0', '0', '', '', '-2', ''),
('166', 'locale', 'language', 'basic', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('167', 'node', 'recent', 'basic', '0', '0', '-1', '0', '0', '', '', '1', ''),
('168', 'node', 'syndicate', 'basic', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('169', 'poll', 'recent', 'basic', '0', '0', '-1', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('170', 'search', 'form', 'basic', '1', '-1', 'sidebar_first', '0', '0', '', '', '-1', ''),
('171', 'shortcut', 'shortcuts', 'basic', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('172', 'superfish', '1', 'basic', '0', '0', '-1', '0', '0', '', '<none>', '-1', ''),
('173', 'superfish', '2', 'basic', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('174', 'superfish', '3', 'basic', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('175', 'superfish', '4', 'basic', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('176', 'system', 'help', 'basic', '1', '0', 'help', '0', '0', '', '', '-1', ''),
('177', 'system', 'main', 'basic', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('178', 'system', 'main-menu', 'basic', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('179', 'system', 'management', 'basic', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('180', 'system', 'navigation', 'basic', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('181', 'system', 'powered-by', 'basic', '1', '10', 'footer', '0', '0', '', '', '-1', ''),
('182', 'system', 'user-menu', 'basic', '0', '0', '-1', '0', '0', '', '<none>', '-1', ''),
('183', 'user', 'login', 'basic', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('184', 'user', 'new', 'basic', '0', '0', '-1', '0', '0', '', '', '1', ''),
('185', 'user', 'online', 'basic', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('186', 'block', '1', 'framework', '0', '1', '-1', '0', '1', 'contact', 'Our Location', '-1', ''),
('190', 'block', '5', 'framework', '0', '-5', '-1', '0', '0', '', '', '-1', ''),
('191', 'blog', 'recent', 'framework', '0', '4', '-1', '0', '0', '', '', '1', ''),
('192', 'book', 'navigation', 'framework', '0', '-19', '-1', '0', '0', '', '', '5', ''),
('193', 'comment', 'recent', 'framework', '0', '5', '-1', '0', '0', '', '', '1', ''),
('194', 'demo_reset', 'reset', 'framework', '1', '0', 'sidebar_second', '0', '0', '', '', '-1', ''),
('195', 'forum', 'active', 'framework', '0', '-21', '-1', '0', '0', '', '', '-2', ''),
('196', 'forum', 'new', 'framework', '0', '0', '-1', '0', '0', '', '', '-2', ''),
('197', 'locale', 'language', 'framework', '0', '-4', '-1', '0', '0', '', '', '-1', ''),
('198', 'node', 'recent', 'framework', '0', '7', '-1', '0', '0', '', '', '1', ''),
('199', 'node', 'syndicate', 'framework', '0', '9', '-1', '0', '0', '', '', '-1', ''),
('200', 'poll', 'recent', 'framework', '0', '-1', '-1', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('201', 'search', 'form', 'framework', '1', '-23', 'menu', '0', '0', '', '', '-1', ''),
('202', 'shortcut', 'shortcuts', 'framework', '0', '8', '-1', '0', '0', '', '', '-1', ''),
('203', 'superfish', '1', 'framework', '1', '-24', 'menu', '0', '0', '', '<none>', '-1', ''),
('204', 'superfish', '2', 'framework', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('205', 'superfish', '3', 'framework', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('206', 'superfish', '4', 'framework', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('207', 'system', 'help', 'framework', '1', '0', 'help', '0', '0', '', '', '-1', ''),
('208', 'system', 'main', 'framework', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('209', 'system', 'main-menu', 'framework', '0', '-3', '-1', '0', '0', '', '', '-1', ''),
('210', 'system', 'management', 'framework', '0', '-2', '-1', '0', '0', '', '', '-1', ''),
('211', 'system', 'navigation', 'framework', '1', '-23', 'sidebar_first', '0', '0', '', '', '-1', ''),
('212', 'system', 'powered-by', 'framework', '1', '10', 'footer', '0', '0', '', '', '-1', ''),
('213', 'system', 'user-menu', 'framework', '0', '13', '-1', '0', '0', '', '<none>', '-1', ''),
('214', 'user', 'login', 'framework', '1', '-22', 'sidebar_first', '0', '0', '', '', '-1', ''),
('215', 'user', 'new', 'framework', '0', '14', '-1', '0', '0', '', '', '1', ''),
('216', 'user', 'online', 'framework', '0', '15', '-1', '0', '0', '', '', '-1', ''),
('217', 'block', '1', 'genesis', '0', '0', '-1', '0', '1', 'contact', 'Our Location', '-1', ''),
('221', 'block', '5', 'genesis', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('222', 'blog', 'recent', 'genesis', '0', '0', '-1', '0', '0', '', '', '1', ''),
('223', 'book', 'navigation', 'genesis', '0', '0', '-1', '0', '0', '', '', '5', ''),
('224', 'comment', 'recent', 'genesis', '0', '0', '-1', '0', '0', '', '', '1', ''),
('225', 'demo_reset', 'reset', 'genesis', '1', '0', 'sidebar_second', '0', '0', '', '', '-1', ''),
('226', 'forum', 'active', 'genesis', '0', '0', '-1', '0', '0', '', '', '-2', ''),
('227', 'forum', 'new', 'genesis', '0', '0', '-1', '0', '0', '', '', '-2', ''),
('228', 'locale', 'language', 'genesis', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('229', 'node', 'recent', 'genesis', '0', '0', '-1', '0', '0', '', '', '1', ''),
('230', 'node', 'syndicate', 'genesis', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('231', 'poll', 'recent', 'genesis', '0', '0', '-1', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('232', 'search', 'form', 'genesis', '1', '-1', 'sidebar_first', '0', '0', '', '', '-1', ''),
('233', 'shortcut', 'shortcuts', 'genesis', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('234', 'superfish', '1', 'genesis', '0', '0', '-1', '0', '0', '', '<none>', '-1', ''),
('235', 'superfish', '2', 'genesis', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('236', 'superfish', '3', 'genesis', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('237', 'superfish', '4', 'genesis', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('238', 'system', 'help', 'genesis', '1', '0', 'help', '0', '0', '', '', '-1', ''),
('239', 'system', 'main', 'genesis', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('240', 'system', 'main-menu', 'genesis', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('241', 'system', 'management', 'genesis', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('242', 'system', 'navigation', 'genesis', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('243', 'system', 'powered-by', 'genesis', '1', '10', 'footer', '0', '0', '', '', '-1', ''),
('244', 'system', 'user-menu', 'genesis', '0', '0', '-1', '0', '0', '', '<none>', '-1', ''),
('245', 'user', 'login', 'genesis', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('246', 'user', 'new', 'genesis', '0', '0', '-1', '0', '0', '', '', '1', ''),
('247', 'user', 'online', 'genesis', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('248', 'block', '1', 'genesis_SUBTHEME', '0', '0', '-1', '0', '1', 'contact', 'Our Location', '-1', ''),
('252', 'block', '5', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('253', 'blog', 'recent', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '1', ''),
('254', 'book', 'navigation', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '5', ''),
('255', 'comment', 'recent', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '1', ''),
('256', 'demo_reset', 'reset', 'genesis_SUBTHEME', '1', '0', 'sidebar_second', '0', '0', '', '', '-1', ''),
('257', 'forum', 'active', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '-2', ''),
('258', 'forum', 'new', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '-2', ''),
('259', 'locale', 'language', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('260', 'node', 'recent', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '1', ''),
('261', 'node', 'syndicate', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('262', 'poll', 'recent', 'genesis_SUBTHEME', '0', '0', '-1', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('263', 'search', 'form', 'genesis_SUBTHEME', '1', '-1', 'sidebar_first', '0', '0', '', '', '-1', ''),
('264', 'shortcut', 'shortcuts', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('265', 'superfish', '1', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '<none>', '-1', ''),
('266', 'superfish', '2', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('267', 'superfish', '3', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('268', 'superfish', '4', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('269', 'system', 'help', 'genesis_SUBTHEME', '1', '0', 'help', '0', '0', '', '', '-1', ''),
('270', 'system', 'main', 'genesis_SUBTHEME', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('271', 'system', 'main-menu', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('272', 'system', 'management', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('273', 'system', 'navigation', 'genesis_SUBTHEME', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('274', 'system', 'powered-by', 'genesis_SUBTHEME', '1', '10', 'footer', '0', '0', '', '', '-1', ''),
('275', 'system', 'user-menu', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '<none>', '-1', ''),
('276', 'user', 'login', 'genesis_SUBTHEME', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('277', 'user', 'new', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '1', ''),
('278', 'user', 'online', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('279', 'block', '1', 'ninesixty', '0', '-5', '-1', '0', '1', 'contact', 'Our Location', '-1', ''),
('283', 'block', '5', 'ninesixty', '0', '-12', '-1', '0', '0', '', '', '-1', ''),
('284', 'blog', 'recent', 'ninesixty', '0', '-4', '-1', '0', '0', '', '', '1', ''),
('285', 'book', 'navigation', 'ninesixty', '0', '-13', '-1', '0', '0', '', '', '5', ''),
('286', 'comment', 'recent', 'ninesixty', '0', '-3', '-1', '0', '0', '', '', '1', ''),
('287', 'demo_reset', 'reset', 'ninesixty', '1', '0', 'sidebar_second', '0', '0', '', '', '-1', ''),
('288', 'forum', 'active', 'ninesixty', '0', '-14', '-1', '0', '0', '', '', '-2', ''),
('289', 'forum', 'new', 'ninesixty', '0', '-6', '-1', '0', '0', '', '', '-2', ''),
('290', 'locale', 'language', 'ninesixty', '0', '-11', '-1', '0', '0', '', '', '-1', ''),
('291', 'node', 'recent', 'ninesixty', '0', '-2', '-1', '0', '0', '', '', '1', ''),
('292', 'node', 'syndicate', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('293', 'poll', 'recent', 'ninesixty', '0', '-7', '-1', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('294', 'search', 'form', 'ninesixty', '1', '-1', 'sidebar_first', '0', '0', '', '', '-1', ''),
('295', 'shortcut', 'shortcuts', 'ninesixty', '0', '-1', '-1', '0', '0', '', '', '-1', ''),
('296', 'superfish', '1', 'ninesixty', '1', '0', 'header', '0', '0', '', '<none>', '-1', ''),
('297', 'superfish', '2', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('298', 'superfish', '3', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('299', 'superfish', '4', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('300', 'system', 'help', 'ninesixty', '1', '0', 'help', '0', '0', '', '', '-1', ''),
('301', 'system', 'main', 'ninesixty', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('302', 'system', 'main-menu', 'ninesixty', '0', '-10', '-1', '0', '0', '', '', '-1', ''),
('303', 'system', 'management', 'ninesixty', '0', '-9', '-1', '0', '0', '', '', '-1', ''),
('304', 'system', 'navigation', 'ninesixty', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('305', 'system', 'powered-by', 'ninesixty', '1', '10', 'footer', '0', '0', '', '', '-1', ''),
('306', 'system', 'user-menu', 'ninesixty', '0', '2', '-1', '0', '0', '', '<none>', '-1', ''),
('307', 'user', 'login', 'ninesixty', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('308', 'user', 'new', 'ninesixty', '0', '3', '-1', '0', '0', '', '', '1', ''),
('309', 'user', 'online', 'ninesixty', '0', '4', '-1', '0', '0', '', '', '-1', ''),
('310', 'block', '1', 'alpha', '0', '-5', '-1', '0', '1', 'contact', 'Our Location', '-1', ''),
('314', 'block', '5', 'alpha', '0', '-12', '-1', '0', '0', '', '', '-1', ''),
('315', 'blog', 'recent', 'alpha', '0', '-4', '-1', '0', '0', '', '', '1', ''),
('316', 'book', 'navigation', 'alpha', '0', '-13', '-1', '0', '0', '', '', '5', ''),
('317', 'comment', 'recent', 'alpha', '0', '-3', '-1', '0', '0', '', '', '1', ''),
('318', 'demo_reset', 'reset', 'alpha', '1', '0', 'sidebar_second', '0', '0', '', '', '-1', ''),
('319', 'forum', 'active', 'alpha', '0', '-14', '-1', '0', '0', '', '', '-2', ''),
('320', 'forum', 'new', 'alpha', '0', '-6', '-1', '0', '0', '', '', '-2', ''),
('321', 'locale', 'language', 'alpha', '0', '-11', '-1', '0', '0', '', '', '-1', ''),
('322', 'node', 'recent', 'alpha', '0', '-2', '-1', '0', '0', '', '', '1', ''),
('323', 'node', 'syndicate', 'alpha', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('324', 'poll', 'recent', 'alpha', '0', '-7', '-1', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('325', 'search', 'form', 'alpha', '1', '-1', 'sidebar_first', '0', '0', '', '', '-1', ''),
('326', 'shortcut', 'shortcuts', 'alpha', '0', '-1', '-1', '0', '0', '', '', '-1', ''),
('327', 'superfish', '1', 'alpha', '1', '0', 'header', '0', '0', '', '<none>', '-1', ''),
('328', 'superfish', '2', 'alpha', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('329', 'superfish', '3', 'alpha', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('330', 'superfish', '4', 'alpha', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('331', 'system', 'help', 'alpha', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('332', 'system', 'main', 'alpha', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('333', 'system', 'main-menu', 'alpha', '0', '-10', '-1', '0', '0', '', '', '-1', ''),
('334', 'system', 'management', 'alpha', '0', '-9', '-1', '0', '0', '', '', '-1', ''),
('335', 'system', 'navigation', 'alpha', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('336', 'system', 'powered-by', 'alpha', '1', '10', 'footer', '0', '0', '', '', '-1', ''),
('337', 'system', 'user-menu', 'alpha', '0', '2', '-1', '0', '0', '', '<none>', '-1', ''),
('338', 'user', 'login', 'alpha', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('339', 'user', 'new', 'alpha', '0', '3', '-1', '0', '0', '', '', '1', ''),
('340', 'user', 'online', 'alpha', '0', '4', '-1', '0', '0', '', '', '-1', ''),
('341', 'block', '1', 'fusion_core', '0', '-5', '-1', '0', '1', 'contact', 'Our Location', '-1', ''),
('345', 'block', '5', 'fusion_core', '0', '-12', '-1', '0', '0', '', '', '-1', ''),
('346', 'blog', 'recent', 'fusion_core', '0', '-4', '-1', '0', '0', '', '', '1', ''),
('347', 'book', 'navigation', 'fusion_core', '0', '-13', '-1', '0', '0', '', '', '5', ''),
('348', 'comment', 'recent', 'fusion_core', '0', '-3', '-1', '0', '0', '', '', '1', ''),
('349', 'demo_reset', 'reset', 'fusion_core', '1', '-14', 'sidebar_second', '0', '0', '', '', '-1', ''),
('350', 'forum', 'active', 'fusion_core', '0', '-14', '-1', '0', '0', '', '', '-2', ''),
('351', 'forum', 'new', 'fusion_core', '0', '-6', '-1', '0', '0', '', '', '-2', ''),
('352', 'locale', 'language', 'fusion_core', '0', '-11', '-1', '0', '0', '', '', '-1', ''),
('353', 'node', 'recent', 'fusion_core', '0', '-2', '-1', '0', '0', '', '', '1', ''),
('354', 'node', 'syndicate', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('355', 'poll', 'recent', 'fusion_core', '0', '-7', '-1', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('356', 'search', 'form', 'fusion_core', '1', '-1', 'sidebar_first', '0', '0', '', '', '-1', ''),
('357', 'shortcut', 'shortcuts', 'fusion_core', '0', '-1', '-1', '0', '0', '', '', '-1', ''),
('358', 'superfish', '1', 'fusion_core', '1', '0', 'header', '0', '0', '', '<none>', '-1', ''),
('359', 'superfish', '2', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('360', 'superfish', '3', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('361', 'superfish', '4', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('362', 'system', 'help', 'fusion_core', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('363', 'system', 'main', 'fusion_core', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('364', 'system', 'main-menu', 'fusion_core', '1', '-10', 'sidebar_second', '0', '0', '', '', '-1', ''),
('365', 'system', 'management', 'fusion_core', '0', '-9', '-1', '0', '0', '', '', '-1', ''),
('366', 'system', 'navigation', 'fusion_core', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('367', 'system', 'powered-by', 'fusion_core', '1', '10', 'footer', '0', '0', '', '', '-1', ''),
('368', 'system', 'user-menu', 'fusion_core', '0', '2', '-1', '0', '0', '', '<none>', '-1', ''),
('369', 'user', 'login', 'fusion_core', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('370', 'user', 'new', 'fusion_core', '0', '3', '-1', '0', '0', '', '', '1', ''),
('371', 'user', 'online', 'fusion_core', '0', '4', '-1', '0', '0', '', '', '-1', ''),
('372', 'block', '1', 'fusion_starter', '0', '-5', '-1', '0', '1', 'contact', 'Our Location', '-1', ''),
('376', 'block', '5', 'fusion_starter', '0', '-12', '-1', '0', '0', '', '', '-1', ''),
('377', 'blog', 'recent', 'fusion_starter', '0', '-4', '-1', '0', '0', '', '', '1', ''),
('378', 'book', 'navigation', 'fusion_starter', '0', '-13', '-1', '0', '0', '', '', '5', ''),
('379', 'comment', 'recent', 'fusion_starter', '0', '-3', '-1', '0', '0', '', '', '1', ''),
('380', 'demo_reset', 'reset', 'fusion_starter', '1', '0', 'sidebar_second', '0', '0', '', '', '-1', ''),
('381', 'forum', 'active', 'fusion_starter', '0', '-14', '-1', '0', '0', '', '', '-2', ''),
('382', 'forum', 'new', 'fusion_starter', '0', '-6', '-1', '0', '0', '', '', '-2', ''),
('383', 'locale', 'language', 'fusion_starter', '0', '-11', '-1', '0', '0', '', '', '-1', ''),
('384', 'node', 'recent', 'fusion_starter', '0', '-2', '-1', '0', '0', '', '', '1', ''),
('385', 'node', 'syndicate', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('386', 'poll', 'recent', 'fusion_starter', '0', '-7', '-1', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('387', 'search', 'form', 'fusion_starter', '1', '-1', 'sidebar_first', '0', '0', '', '', '-1', ''),
('388', 'shortcut', 'shortcuts', 'fusion_starter', '0', '-1', '-1', '0', '0', '', '', '-1', ''),
('389', 'superfish', '1', 'fusion_starter', '1', '0', 'header', '0', '0', '', '<none>', '-1', ''),
('390', 'superfish', '2', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('391', 'superfish', '3', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('392', 'superfish', '4', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('393', 'system', 'help', 'fusion_starter', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('394', 'system', 'main', 'fusion_starter', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('395', 'system', 'main-menu', 'fusion_starter', '0', '-10', '-1', '0', '0', '', '', '-1', ''),
('396', 'system', 'management', 'fusion_starter', '0', '-9', '-1', '0', '0', '', '', '-1', ''),
('397', 'system', 'navigation', 'fusion_starter', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('398', 'system', 'powered-by', 'fusion_starter', '1', '10', 'footer', '0', '0', '', '', '-1', ''),
('399', 'system', 'user-menu', 'fusion_starter', '0', '2', '-1', '0', '0', '', '<none>', '-1', ''),
('400', 'user', 'login', 'fusion_starter', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('401', 'user', 'new', 'fusion_starter', '0', '3', '-1', '0', '0', '', '', '1', ''),
('402', 'user', 'online', 'fusion_starter', '0', '4', '-1', '0', '0', '', '', '-1', ''),
('403', 'block', '1', 'omega', '0', '-5', '-1', '0', '1', 'contact', 'Our Location', '-1', ''),
('407', 'block', '5', 'omega', '0', '-12', '-1', '0', '0', '', '', '-1', ''),
('408', 'blog', 'recent', 'omega', '0', '-4', '-1', '0', '0', '', '', '1', ''),
('409', 'book', 'navigation', 'omega', '0', '-13', '-1', '0', '0', '', '', '5', ''),
('410', 'comment', 'recent', 'omega', '0', '-3', '-1', '0', '0', '', '', '1', ''),
('411', 'demo_reset', 'reset', 'omega', '1', '0', 'sidebar_second', '0', '0', '', '', '-1', ''),
('412', 'forum', 'active', 'omega', '0', '-14', '-1', '0', '0', '', '', '-2', ''),
('413', 'forum', 'new', 'omega', '0', '-6', '-1', '0', '0', '', '', '-2', ''),
('414', 'locale', 'language', 'omega', '0', '-11', '-1', '0', '0', '', '', '-1', ''),
('415', 'node', 'recent', 'omega', '0', '-2', '-1', '0', '0', '', '', '1', ''),
('416', 'node', 'syndicate', 'omega', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('417', 'poll', 'recent', 'omega', '0', '-7', '-1', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('418', 'search', 'form', 'omega', '1', '-1', 'sidebar_first', '0', '0', '', '', '-1', ''),
('419', 'shortcut', 'shortcuts', 'omega', '0', '-1', '-1', '0', '0', '', '', '-1', ''),
('420', 'superfish', '1', 'omega', '1', '0', 'content', '0', '0', '', '<none>', '-1', ''),
('421', 'superfish', '2', 'omega', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('422', 'superfish', '3', 'omega', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('423', 'superfish', '4', 'omega', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('424', 'system', 'help', 'omega', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('425', 'system', 'main', 'omega', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('426', 'system', 'main-menu', 'omega', '0', '-10', '-1', '0', '0', '', '', '-1', ''),
('427', 'system', 'management', 'omega', '0', '-9', '-1', '0', '0', '', '', '-1', ''),
('428', 'system', 'navigation', 'omega', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('429', 'system', 'powered-by', 'omega', '1', '10', 'content', '0', '0', '', '', '-1', ''),
('430', 'system', 'user-menu', 'omega', '0', '2', '-1', '0', '0', '', '<none>', '-1', ''),
('431', 'user', 'login', 'omega', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('432', 'user', 'new', 'omega', '0', '3', '-1', '0', '0', '', '', '1', ''),
('433', 'user', 'online', 'omega', '0', '4', '-1', '0', '0', '', '', '-1', ''),
('434', 'block', '1', 'tm_framefork', '0', '-5', '-1', '0', '1', 'contact', 'Our Location', '-1', ''),
('438', 'block', '5', 'tm_framefork', '0', '-12', '-1', '0', '0', '', '', '-1', ''),
('439', 'blog', 'recent', 'tm_framefork', '0', '-4', '-1', '0', '0', '', '', '1', ''),
('440', 'book', 'navigation', 'tm_framefork', '0', '-13', '-1', '0', '0', '', '', '5', ''),
('441', 'comment', 'recent', 'tm_framefork', '0', '-3', '-1', '0', '0', '', '', '1', ''),
('442', 'demo_reset', 'reset', 'tm_framefork', '1', '0', 'sidebar_second', '0', '0', '', '', '-1', ''),
('443', 'forum', 'active', 'tm_framefork', '0', '-14', '-1', '0', '0', '', '', '-2', ''),
('444', 'forum', 'new', 'tm_framefork', '0', '-6', '-1', '0', '0', '', '', '-2', ''),
('445', 'locale', 'language', 'tm_framefork', '0', '-11', '-1', '0', '0', '', '', '-1', ''),
('446', 'node', 'recent', 'tm_framefork', '0', '-2', '-1', '0', '0', '', '', '1', ''),
('447', 'node', 'syndicate', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('448', 'poll', 'recent', 'tm_framefork', '0', '-7', '-1', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('449', 'search', 'form', 'tm_framefork', '1', '-1', 'sidebar_first', '0', '0', '', '', '-1', ''),
('450', 'shortcut', 'shortcuts', 'tm_framefork', '0', '-1', '-1', '0', '0', '', '', '-1', ''),
('451', 'superfish', '1', 'tm_framefork', '1', '0', 'content', '0', '0', '', '<none>', '-1', ''),
('452', 'superfish', '2', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('453', 'superfish', '3', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('454', 'superfish', '4', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('455', 'system', 'help', 'tm_framefork', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('456', 'system', 'main', 'tm_framefork', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('457', 'system', 'main-menu', 'tm_framefork', '0', '-10', '-1', '0', '0', '', '', '-1', ''),
('458', 'system', 'management', 'tm_framefork', '0', '-9', '-1', '0', '0', '', '', '-1', ''),
('459', 'system', 'navigation', 'tm_framefork', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('460', 'system', 'powered-by', 'tm_framefork', '1', '10', 'content', '0', '0', '', '', '-1', ''),
('461', 'system', 'user-menu', 'tm_framefork', '0', '2', '-1', '0', '0', '', '<none>', '-1', ''),
('462', 'user', 'login', 'tm_framefork', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('463', 'user', 'new', 'tm_framefork', '0', '3', '-1', '0', '0', '', '', '1', ''),
('464', 'user', 'online', 'tm_framefork', '0', '4', '-1', '0', '0', '', '', '-1', ''),
('465', 'demo_reset', 'reset', 'corolla', '0', '-13', '-1', '0', '0', '', '', '-1', ''),
('466', 'system', 'powered-by', 'corolla', '0', '-13', '-1', '0', '0', '', '', '-1', ''),
('467', 'superfish', '2', 'corolla', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('468', 'superfish', '3', 'corolla', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('469', 'superfish', '4', 'corolla', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('470', 'system', 'main', 'corolla', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('471', 'block', '5', 'corolla', '1', '7', 'header_menu', '0', '0', '', '', '-1', ''),
('472', 'system', 'help', 'corolla', '1', '0', 'help', '0', '0', '', '', '-1', ''),
('473', 'superfish', '1', 'corolla', '1', '0', 'header_menu', '0', '0', '', '<none>', '-1', ''),
('474', 'search', 'form', 'corolla', '1', '-13', 'sidebar_first', '0', '0', '', '', '-1', ''),
('475', 'user', 'login', 'corolla', '1', '-12', 'sidebar_first', '0', '0', '', '', '-1', ''),
('476', 'user', 'new', 'corolla', '1', '-11', 'sidebar_first', '0', '0', '', '', '1', ''),
('477', 'user', 'online', 'corolla', '1', '-10', 'sidebar_first', '0', '0', '', '', '-1', ''),
('478', 'system', 'user-menu', 'corolla', '1', '-9', 'sidebar_first', '0', '0', '', '<none>', '-1', ''),
('479', 'node', 'syndicate', 'corolla', '1', '-8', 'sidebar_first', '0', '0', '', '', '-1', ''),
('480', 'shortcut', 'shortcuts', 'corolla', '1', '-7', 'sidebar_first', '0', '0', '', '', '-1', ''),
('481', 'node', 'recent', 'corolla', '1', '-6', 'sidebar_first', '0', '0', '', '', '1', ''),
('482', 'comment', 'recent', 'corolla', '1', '-5', 'sidebar_first', '0', '0', '', '', '1', ''),
('483', 'blog', 'recent', 'corolla', '1', '-4', 'sidebar_first', '0', '0', '', '', '1', ''),
('484', 'forum', 'new', 'corolla', '1', '-3', 'sidebar_first', '0', '0', '', '', '-2', ''),
('485', 'poll', 'recent', 'corolla', '1', '-2', 'sidebar_first', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('486', 'system', 'management', 'corolla', '1', '-1', 'sidebar_first', '0', '0', '', '', '-1', ''),
('487', 'system', 'main-menu', 'corolla', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('488', 'locale', 'language', 'corolla', '1', '1', 'sidebar_first', '0', '0', '', '', '-1', ''),
('489', 'book', 'navigation', 'corolla', '1', '2', 'sidebar_first', '0', '0', '', '', '5', ''),
('490', 'forum', 'active', 'corolla', '1', '3', 'sidebar_first', '0', '0', '', '', '-2', ''),
('491', 'system', 'navigation', 'corolla', '1', '4', 'sidebar_first', '0', '0', '', '', '-1', ''),
('492', 'block', '1', 'corolla', '1', '-5', 'sidebar_second', '0', '1', 'contact', 'Our Location', '-1', ''),
('493', 'demo_reset', 'reset', 'koi', '0', '-13', '-1', '0', '0', '', '', '-1', ''),
('494', 'system', 'powered-by', 'koi', '0', '-13', '-1', '0', '0', '', '', '-1', ''),
('495', 'superfish', '2', 'koi', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('496', 'superfish', '3', 'koi', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('497', 'superfish', '4', 'koi', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('498', 'system', 'main', 'koi', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('499', 'superfish', '1', 'koi', '1', '0', 'header_menu', '0', '0', '', '<none>', '-1', ''),
('500', 'block', '5', 'koi', '1', '7', 'header_menu', '0', '0', '', '', '-1', ''),
('501', 'system', 'help', 'koi', '1', '0', 'help', '0', '0', '', '', '-1', ''),
('502', 'search', 'form', 'koi', '1', '-13', 'sidebar_first', '0', '0', '', '', '-1', ''),
('503', 'user', 'login', 'koi', '1', '-12', 'sidebar_first', '0', '0', '', '', '-1', ''),
('504', 'user', 'new', 'koi', '1', '-11', 'sidebar_first', '0', '0', '', '', '1', ''),
('505', 'user', 'online', 'koi', '1', '-10', 'sidebar_first', '0', '0', '', '', '-1', ''),
('506', 'system', 'user-menu', 'koi', '1', '-9', 'sidebar_first', '0', '0', '', '<none>', '-1', ''),
('507', 'node', 'syndicate', 'koi', '1', '-8', 'sidebar_first', '0', '0', '', '', '-1', ''),
('508', 'shortcut', 'shortcuts', 'koi', '1', '-7', 'sidebar_first', '0', '0', '', '', '-1', ''),
('509', 'node', 'recent', 'koi', '1', '-6', 'sidebar_first', '0', '0', '', '', '1', ''),
('510', 'comment', 'recent', 'koi', '1', '-5', 'sidebar_first', '0', '0', '', '', '1', ''),
('511', 'blog', 'recent', 'koi', '1', '-4', 'sidebar_first', '0', '0', '', '', '1', ''),
('512', 'forum', 'new', 'koi', '1', '-3', 'sidebar_first', '0', '0', '', '', '-2', ''),
('513', 'poll', 'recent', 'koi', '1', '-2', 'sidebar_first', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('514', 'system', 'management', 'koi', '1', '-1', 'sidebar_first', '0', '0', '', '', '-1', ''),
('515', 'system', 'main-menu', 'koi', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('516', 'locale', 'language', 'koi', '1', '1', 'sidebar_first', '0', '0', '', '', '-1', ''),
('517', 'book', 'navigation', 'koi', '1', '2', 'sidebar_first', '0', '0', '', '', '5', ''),
('518', 'forum', 'active', 'koi', '1', '3', 'sidebar_first', '0', '0', '', '', '-2', ''),
('519', 'system', 'navigation', 'koi', '1', '4', 'sidebar_first', '0', '0', '', '', '-1', ''),
('520', 'block', '1', 'koi', '1', '-5', 'sidebar_second', '0', '1', 'contact', 'Our Location', '-1', ''),
('521', 'demo_reset', 'reset', 'marinelli', '0', '-13', '-1', '0', '0', '', '', '-1', ''),
('522', 'system', 'powered-by', 'marinelli', '0', '-13', '-1', '0', '0', '', '', '-1', ''),
('523', 'superfish', '2', 'marinelli', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('524', 'superfish', '3', 'marinelli', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('525', 'superfish', '4', 'marinelli', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('526', 'system', 'main', 'marinelli', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('527', 'superfish', '1', 'marinelli', '1', '0', 'topbar', '0', '0', '', '<none>', '-1', ''),
('528', 'block', '5', 'marinelli', '1', '7', 'topbar', '0', '0', '', '', '-1', ''),
('529', 'system', 'help', 'marinelli', '1', '0', 'topbar', '0', '0', '', '', '-1', ''),
('530', 'search', 'form', 'marinelli', '1', '-13', 'sidebar_first', '0', '0', '', '', '-1', ''),
('531', 'user', 'login', 'marinelli', '1', '-12', 'sidebar_first', '0', '0', '', '', '-1', ''),
('532', 'user', 'new', 'marinelli', '1', '-11', 'sidebar_first', '0', '0', '', '', '1', ''),
('533', 'user', 'online', 'marinelli', '1', '-10', 'sidebar_first', '0', '0', '', '', '-1', ''),
('534', 'system', 'user-menu', 'marinelli', '1', '-9', 'sidebar_first', '0', '0', '', '<none>', '-1', ''),
('535', 'node', 'syndicate', 'marinelli', '1', '-8', 'sidebar_first', '0', '0', '', '', '-1', ''),
('536', 'shortcut', 'shortcuts', 'marinelli', '1', '-7', 'sidebar_first', '0', '0', '', '', '-1', ''),
('537', 'node', 'recent', 'marinelli', '1', '-6', 'sidebar_first', '0', '0', '', '', '1', ''),
('538', 'comment', 'recent', 'marinelli', '1', '-5', 'sidebar_first', '0', '0', '', '', '1', ''),
('539', 'blog', 'recent', 'marinelli', '1', '-4', 'sidebar_first', '0', '0', '', '', '1', ''),
('540', 'forum', 'new', 'marinelli', '1', '-3', 'sidebar_first', '0', '0', '', '', '-2', ''),
('541', 'poll', 'recent', 'marinelli', '1', '-2', 'sidebar_first', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('542', 'system', 'management', 'marinelli', '1', '-1', 'sidebar_first', '0', '0', '', '', '-1', ''),
('543', 'system', 'main-menu', 'marinelli', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('544', 'locale', 'language', 'marinelli', '1', '1', 'sidebar_first', '0', '0', '', '', '-1', ''),
('545', 'book', 'navigation', 'marinelli', '1', '2', 'sidebar_first', '0', '0', '', '', '5', ''),
('546', 'forum', 'active', 'marinelli', '1', '3', 'sidebar_first', '0', '0', '', '', '-2', ''),
('547', 'system', 'navigation', 'marinelli', '1', '4', 'sidebar_first', '0', '0', '', '', '-1', ''),
('548', 'block', '1', 'marinelli', '1', '-5', 'sidebar_second', '0', '1', 'contact', 'Our Location', '-1', ''),
('549', 'demo_reset', 'reset', 'mayo', '0', '-13', '-1', '0', '0', '', '', '-1', ''),
('550', 'system', 'powered-by', 'mayo', '0', '-13', '-1', '0', '0', '', '', '-1', ''),
('551', 'superfish', '2', 'mayo', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('552', 'superfish', '3', 'mayo', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('553', 'superfish', '4', 'mayo', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('554', 'system', 'main', 'mayo', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('555', 'superfish', '1', 'mayo', '1', '0', 'header', '0', '0', '', '<none>', '-1', ''),
('556', 'block', '5', 'mayo', '1', '7', 'header', '0', '0', '', '', '-1', ''),
('557', 'system', 'help', 'mayo', '1', '0', 'help', '0', '0', '', '', '-1', ''),
('558', 'search', 'form', 'mayo', '1', '-13', 'sidebar_first', '0', '0', '', '', '-1', ''),
('559', 'user', 'login', 'mayo', '1', '-12', 'sidebar_first', '0', '0', '', '', '-1', ''),
('560', 'user', 'new', 'mayo', '1', '-11', 'sidebar_first', '0', '0', '', '', '1', ''),
('561', 'user', 'online', 'mayo', '1', '-10', 'sidebar_first', '0', '0', '', '', '-1', ''),
('562', 'system', 'user-menu', 'mayo', '1', '-9', 'sidebar_first', '0', '0', '', '<none>', '-1', ''),
('563', 'node', 'syndicate', 'mayo', '1', '-8', 'sidebar_first', '0', '0', '', '', '-1', ''),
('564', 'shortcut', 'shortcuts', 'mayo', '1', '-7', 'sidebar_first', '0', '0', '', '', '-1', ''),
('565', 'node', 'recent', 'mayo', '1', '-6', 'sidebar_first', '0', '0', '', '', '1', ''),
('566', 'comment', 'recent', 'mayo', '1', '-5', 'sidebar_first', '0', '0', '', '', '1', ''),
('567', 'blog', 'recent', 'mayo', '1', '-4', 'sidebar_first', '0', '0', '', '', '1', ''),
('568', 'forum', 'new', 'mayo', '1', '-3', 'sidebar_first', '0', '0', '', '', '-2', ''),
('569', 'poll', 'recent', 'mayo', '1', '-2', 'sidebar_first', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('570', 'system', 'management', 'mayo', '1', '-1', 'sidebar_first', '0', '0', '', '', '-1', ''),
('571', 'system', 'main-menu', 'mayo', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('572', 'locale', 'language', 'mayo', '1', '1', 'sidebar_first', '0', '0', '', '', '-1', ''),
('573', 'book', 'navigation', 'mayo', '1', '2', 'sidebar_first', '0', '0', '', '', '5', ''),
('574', 'forum', 'active', 'mayo', '1', '3', 'sidebar_first', '0', '0', '', '', '-2', ''),
('575', 'system', 'navigation', 'mayo', '1', '4', 'sidebar_first', '0', '0', '', '', '-1', ''),
('576', 'block', '1', 'mayo', '1', '-5', 'sidebar_second', '0', '1', 'contact', 'Our Location', '-1', ''),
('577', 'demo_reset', 'reset', 'newswire', '0', '-13', '-1', '0', '0', '', '', '-1', ''),
('578', 'system', 'powered-by', 'newswire', '0', '-13', '-1', '0', '0', '', '', '-1', ''),
('579', 'superfish', '2', 'newswire', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('580', 'superfish', '3', 'newswire', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('581', 'superfish', '4', 'newswire', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('582', 'system', 'main', 'newswire', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('583', 'superfish', '1', 'newswire', '1', '0', 'leaderboard', '0', '0', '', '<none>', '-1', ''),
('584', 'block', '5', 'newswire', '1', '7', 'leaderboard', '0', '0', '', '', '-1', ''),
('585', 'system', 'help', 'newswire', '1', '0', 'help', '0', '0', '', '', '-1', ''),
('586', 'search', 'form', 'newswire', '1', '-13', 'sidebar_first', '0', '0', '', '', '-1', ''),
('587', 'user', 'login', 'newswire', '1', '-12', 'sidebar_first', '0', '0', '', '', '-1', ''),
('588', 'user', 'new', 'newswire', '1', '-11', 'sidebar_first', '0', '0', '', '', '1', ''),
('589', 'user', 'online', 'newswire', '1', '-10', 'sidebar_first', '0', '0', '', '', '-1', ''),
('590', 'system', 'user-menu', 'newswire', '1', '-9', 'sidebar_first', '0', '0', '', '<none>', '-1', ''),
('591', 'node', 'syndicate', 'newswire', '1', '-8', 'sidebar_first', '0', '0', '', '', '-1', ''),
('592', 'shortcut', 'shortcuts', 'newswire', '1', '-7', 'sidebar_first', '0', '0', '', '', '-1', ''),
('593', 'node', 'recent', 'newswire', '1', '-6', 'sidebar_first', '0', '0', '', '', '1', ''),
('594', 'comment', 'recent', 'newswire', '1', '-5', 'sidebar_first', '0', '0', '', '', '1', ''),
('595', 'blog', 'recent', 'newswire', '1', '-4', 'sidebar_first', '0', '0', '', '', '1', ''),
('596', 'forum', 'new', 'newswire', '1', '-3', 'sidebar_first', '0', '0', '', '', '-2', ''),
('597', 'poll', 'recent', 'newswire', '1', '-2', 'sidebar_first', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('598', 'system', 'management', 'newswire', '1', '-1', 'sidebar_first', '0', '0', '', '', '-1', ''),
('599', 'system', 'main-menu', 'newswire', '1', '0', 'sidebar_first', '0', '0', '', '', '-1', ''),
('600', 'locale', 'language', 'newswire', '1', '1', 'sidebar_first', '0', '0', '', '', '-1', ''),
('601', 'book', 'navigation', 'newswire', '1', '2', 'sidebar_first', '0', '0', '', '', '5', ''),
('602', 'forum', 'active', 'newswire', '1', '3', 'sidebar_first', '0', '0', '', '', '-2', ''),
('603', 'system', 'navigation', 'newswire', '1', '4', 'sidebar_first', '0', '0', '', '', '-1', ''),
('604', 'block', '1', 'newswire', '1', '-5', 'sidebar_second', '0', '1', 'contact', 'Our Location', '-1', '');
INSERT INTO `block` VALUES
('605', 'demo_reset', 'reset', 'typebased', '0', '-13', '-1', '0', '0', '', '', '-1', ''),
('606', 'system', 'powered-by', 'typebased', '0', '-13', '-1', '0', '0', '', '', '-1', ''),
('607', 'superfish', '2', 'typebased', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('608', 'superfish', '3', 'typebased', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('609', 'superfish', '4', 'typebased', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('610', 'system', 'main', 'typebased', '1', '0', 'content', '0', '0', '', '', '-1', ''),
('611', 'superfish', '1', 'typebased', '1', '0', 'header_menu', '0', '0', '', '<none>', '-1', ''),
('612', 'block', '5', 'typebased', '1', '7', 'header_menu', '0', '0', '', '', '-1', ''),
('613', 'system', 'help', 'typebased', '1', '0', 'help', '0', '0', '', '', '-1', ''),
('614', 'search', 'form', 'typebased', '1', '-13', 'header_menu', '0', '0', '', '', '-1', ''),
('615', 'user', 'login', 'typebased', '1', '-12', 'header_menu', '0', '0', '', '', '-1', ''),
('616', 'user', 'new', 'typebased', '1', '-11', 'header_menu', '0', '0', '', '', '1', ''),
('617', 'user', 'online', 'typebased', '1', '-10', 'header_menu', '0', '0', '', '', '-1', ''),
('618', 'system', 'user-menu', 'typebased', '1', '-9', 'header_menu', '0', '0', '', '<none>', '-1', ''),
('619', 'node', 'syndicate', 'typebased', '1', '-8', 'header_menu', '0', '0', '', '', '-1', ''),
('620', 'shortcut', 'shortcuts', 'typebased', '1', '-7', 'header_menu', '0', '0', '', '', '-1', ''),
('621', 'node', 'recent', 'typebased', '1', '-6', 'header_menu', '0', '0', '', '', '1', ''),
('622', 'comment', 'recent', 'typebased', '1', '-5', 'header_menu', '0', '0', '', '', '1', ''),
('623', 'blog', 'recent', 'typebased', '1', '-4', 'header_menu', '0', '0', '', '', '1', ''),
('624', 'forum', 'new', 'typebased', '1', '-3', 'header_menu', '0', '0', '', '', '-2', ''),
('625', 'poll', 'recent', 'typebased', '1', '-2', 'header_menu', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('626', 'system', 'management', 'typebased', '1', '-1', 'header_menu', '0', '0', '', '', '-1', ''),
('627', 'system', 'main-menu', 'typebased', '1', '0', 'header_menu', '0', '0', '', '', '-1', ''),
('628', 'locale', 'language', 'typebased', '1', '1', 'header_menu', '0', '0', '', '', '-1', ''),
('629', 'book', 'navigation', 'typebased', '1', '2', 'header_menu', '0', '0', '', '', '5', ''),
('630', 'forum', 'active', 'typebased', '1', '3', 'header_menu', '0', '0', '', '', '-2', ''),
('631', 'system', 'navigation', 'typebased', '1', '4', 'header_menu', '0', '0', '', '', '-1', ''),
('632', 'block', '1', 'typebased', '1', '-5', 'header_menu', '0', '1', 'contact', 'Our Location', '-1', ''),
('633', 'faq', 'faq_categories', 'bartik', '0', '-12', '-1', '0', '0', '', '', '1', ''),
('634', 'faq', 'faq_recent', 'bartik', '0', '-1', '-1', '0', '0', '', '', '1', ''),
('635', 'faq', 'faq_random', 'bartik', '0', '-2', '-1', '0', '0', '', '', '1', ''),
('636', 'faq', 'faq_categories', 'basic', '0', '0', '-1', '0', '0', '', '', '1', ''),
('637', 'faq', 'faq_recent', 'basic', '0', '0', '-1', '0', '0', '', '', '1', ''),
('638', 'faq', 'faq_random', 'basic', '0', '0', '-1', '0', '0', '', '', '1', ''),
('639', 'faq', 'faq_categories', 'corolla', '0', '0', '-1', '0', '0', '', '', '1', ''),
('640', 'faq', 'faq_recent', 'corolla', '0', '0', '-1', '0', '0', '', '', '1', ''),
('641', 'faq', 'faq_random', 'corolla', '0', '0', '-1', '0', '0', '', '', '1', ''),
('642', 'faq', 'faq_categories', 'framework', '0', '-16', '-1', '0', '0', '', '', '1', ''),
('643', 'faq', 'faq_recent', 'framework', '0', '3', '-1', '0', '0', '', '', '1', ''),
('644', 'faq', 'faq_random', 'framework', '0', '2', '-1', '0', '0', '', '', '1', ''),
('645', 'faq', 'faq_categories', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '1', ''),
('646', 'faq', 'faq_recent', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '1', ''),
('647', 'faq', 'faq_random', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '1', ''),
('648', 'faq', 'faq_categories', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '1', ''),
('649', 'faq', 'faq_recent', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '1', ''),
('650', 'faq', 'faq_random', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '1', ''),
('651', 'faq', 'faq_categories', 'genesis', '0', '0', '-1', '0', '0', '', '', '1', ''),
('652', 'faq', 'faq_recent', 'genesis', '0', '0', '-1', '0', '0', '', '', '1', ''),
('653', 'faq', 'faq_random', 'genesis', '0', '0', '-1', '0', '0', '', '', '1', ''),
('654', 'faq', 'faq_categories', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '1', ''),
('655', 'faq', 'faq_recent', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '1', ''),
('656', 'faq', 'faq_random', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '1', ''),
('657', 'faq', 'faq_categories', 'koi', '0', '0', '-1', '0', '0', '', '', '1', ''),
('658', 'faq', 'faq_recent', 'koi', '0', '0', '-1', '0', '0', '', '', '1', ''),
('659', 'faq', 'faq_random', 'koi', '0', '0', '-1', '0', '0', '', '', '1', ''),
('660', 'faq', 'faq_categories', 'marinelli', '0', '0', '-1', '0', '0', '', '', '1', ''),
('661', 'faq', 'faq_recent', 'marinelli', '0', '0', '-1', '0', '0', '', '', '1', ''),
('662', 'faq', 'faq_random', 'marinelli', '0', '0', '-1', '0', '0', '', '', '1', ''),
('663', 'faq', 'faq_categories', 'mayo', '0', '0', '-1', '0', '0', '', '', '1', ''),
('664', 'faq', 'faq_recent', 'mayo', '0', '0', '-1', '0', '0', '', '', '1', ''),
('665', 'faq', 'faq_random', 'mayo', '0', '0', '-1', '0', '0', '', '', '1', ''),
('666', 'faq', 'faq_categories', 'newswire', '0', '0', '-1', '0', '0', '', '', '1', ''),
('667', 'faq', 'faq_recent', 'newswire', '0', '0', '-1', '0', '0', '', '', '1', ''),
('668', 'faq', 'faq_random', 'newswire', '0', '0', '-1', '0', '0', '', '', '1', ''),
('669', 'faq', 'faq_categories', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '1', ''),
('670', 'faq', 'faq_recent', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '1', ''),
('671', 'faq', 'faq_random', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '1', ''),
('672', 'faq', 'faq_categories', 'seven', '0', '0', '-1', '0', '0', '', '', '1', ''),
('673', 'faq', 'faq_recent', 'seven', '0', '0', '-1', '0', '0', '', '', '1', ''),
('674', 'faq', 'faq_random', 'seven', '0', '0', '-1', '0', '0', '', '', '1', ''),
('675', 'faq', 'faq_categories', 'theme557', '0', '0', '-1', '0', '0', '', '', '1', ''),
('676', 'faq', 'faq_recent', 'theme557', '0', '0', '-1', '0', '0', '', '', '1', ''),
('677', 'faq', 'faq_random', 'theme557', '0', '0', '-1', '0', '0', '', '', '1', ''),
('678', 'faq', 'faq_categories', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '1', ''),
('679', 'faq', 'faq_recent', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '1', ''),
('680', 'faq', 'faq_random', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '1', ''),
('681', 'faq', 'faq_categories', 'typebased', '0', '0', '-1', '0', '0', '', '', '1', ''),
('682', 'faq', 'faq_recent', 'typebased', '0', '0', '-1', '0', '0', '', '', '1', ''),
('683', 'faq', 'faq_random', 'typebased', '0', '0', '-1', '0', '0', '', '', '1', ''),
('684', 'faq', 'faq_categories', 'zentropy', '1', '-14', 'sidebar_first_wide', '0', '0', '', '', '1', ''),
('685', 'faq', 'faq_recent', 'zentropy', '0', '-11', '-1', '0', '0', '', '', '1', ''),
('686', 'faq', 'faq_random', 'zentropy', '0', '-12', '-1', '0', '0', '', '', '1', ''),
('687', 'follow', 'site', 'bartik', '0', '-11', '-1', '0', '0', '', '<none>', '1', ''),
('688', 'follow', 'user', 'bartik', '0', '-10', '-1', '0', '0', '', '', '2', ''),
('689', 'follow', 'site', 'basic', '0', '0', '-1', '0', '0', '', '<none>', '1', ''),
('690', 'follow', 'user', 'basic', '0', '0', '-1', '0', '0', '', '', '2', ''),
('691', 'follow', 'site', 'corolla', '0', '0', '-1', '0', '0', '', '<none>', '1', ''),
('692', 'follow', 'user', 'corolla', '0', '0', '-1', '0', '0', '', '', '2', ''),
('693', 'follow', 'site', 'framework', '0', '-7', '-1', '0', '0', '', '<none>', '1', ''),
('694', 'follow', 'user', 'framework', '0', '-6', '-1', '0', '0', '', '', '2', ''),
('695', 'follow', 'site', 'fusion_core', '0', '0', '-1', '0', '0', '', '<none>', '1', ''),
('696', 'follow', 'user', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '2', ''),
('697', 'follow', 'site', 'fusion_starter', '0', '0', '-1', '0', '0', '', '<none>', '1', ''),
('698', 'follow', 'user', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '2', ''),
('699', 'follow', 'site', 'genesis', '0', '0', '-1', '0', '0', '', '<none>', '1', ''),
('700', 'follow', 'user', 'genesis', '0', '0', '-1', '0', '0', '', '', '2', ''),
('701', 'follow', 'site', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '<none>', '1', ''),
('702', 'follow', 'user', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '2', ''),
('703', 'follow', 'site', 'koi', '0', '0', '-1', '0', '0', '', '<none>', '1', ''),
('704', 'follow', 'user', 'koi', '0', '0', '-1', '0', '0', '', '', '2', ''),
('705', 'follow', 'site', 'marinelli', '0', '0', '-1', '0', '0', '', '<none>', '1', ''),
('706', 'follow', 'user', 'marinelli', '0', '0', '-1', '0', '0', '', '', '2', ''),
('707', 'follow', 'site', 'mayo', '0', '0', '-1', '0', '0', '', '<none>', '1', ''),
('708', 'follow', 'user', 'mayo', '0', '0', '-1', '0', '0', '', '', '2', ''),
('709', 'follow', 'site', 'newswire', '0', '0', '-1', '0', '0', '', '<none>', '1', ''),
('710', 'follow', 'user', 'newswire', '0', '0', '-1', '0', '0', '', '', '2', ''),
('711', 'follow', 'site', 'ninesixty', '0', '0', '-1', '0', '0', '', '<none>', '1', ''),
('712', 'follow', 'user', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '2', ''),
('713', 'follow', 'site', 'seven', '0', '0', '-1', '0', '0', '', '<none>', '1', ''),
('714', 'follow', 'user', 'seven', '0', '0', '-1', '0', '0', '', '', '2', ''),
('715', 'follow', 'site', 'theme557', '0', '0', '-1', '0', '0', '', '<none>', '1', ''),
('716', 'follow', 'user', 'theme557', '0', '0', '-1', '0', '0', '', '', '2', ''),
('717', 'follow', 'site', 'tm_framefork', '0', '0', '-1', '0', '0', '', '<none>', '1', ''),
('718', 'follow', 'user', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '2', ''),
('719', 'follow', 'site', 'typebased', '0', '0', '-1', '0', '0', '', '<none>', '1', ''),
('720', 'follow', 'user', 'typebased', '0', '0', '-1', '0', '0', '', '', '2', ''),
('721', 'follow', 'site', 'zentropy', '1', '-17', 'footer', '0', '0', '', '<none>', '1', ''),
('722', 'follow', 'user', 'zentropy', '1', '-12', 'sidebar_first_wide', '0', '0', '', '', '2', ''),
('723', 'views', 'sldier-block', 'bartik', '1', '0', 'header', '0', '1', 'node', '<none>', '-1', ''),
('724', 'views', 'sldier-block', 'basic', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('725', 'views', 'sldier-block', 'corolla', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('726', 'views', 'sldier-block', 'framework', '1', '16', 'header', '0', '1', 'node', '<none>', '-1', ''),
('727', 'views', 'sldier-block', 'fusion_core', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('728', 'views', 'sldier-block', 'fusion_starter', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('729', 'views', 'sldier-block', 'genesis', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('730', 'views', 'sldier-block', 'genesis_SUBTHEME', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('731', 'views', 'sldier-block', 'koi', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('732', 'views', 'sldier-block', 'marinelli', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('733', 'views', 'sldier-block', 'mayo', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('734', 'views', 'sldier-block', 'newswire', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('735', 'views', 'sldier-block', 'ninesixty', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('736', 'views', 'sldier-block', 'seven', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('737', 'views', 'sldier-block', 'theme557', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('738', 'views', 'sldier-block', 'tm_framefork', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('739', 'views', 'sldier-block', 'typebased', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('740', 'views', 'sldier-block', 'zentropy', '1', '-17', 'header', '0', '1', 'node', '<none>', '-1', ''),
('741', 'quicktabs', 'default_tabs', 'zentropy', '0', '-17', '-1', '0', '1', 'node', '<none>', '1', ''),
('742', 'quicktabs', 'default_tabs', 'seven', '0', '0', '-1', '0', '1', 'node', '<none>', '1', ''),
('743', 'quicktabs', 'accordion', 'zentropy', '0', '-18', '-1', '0', '1', 'node', '', '1', ''),
('744', 'quicktabs', 'accordion', 'bartik', '0', '0', '-1', '0', '1', 'node', '', '1', ''),
('745', 'quicktabs', 'accordion', 'basic', '0', '0', '-1', '0', '1', 'node', '', '1', ''),
('746', 'quicktabs', 'accordion', 'corolla', '0', '0', '-1', '0', '1', 'node', '', '1', ''),
('747', 'quicktabs', 'accordion', 'framework', '0', '-22', '-1', '0', '1', 'node', '', '1', ''),
('748', 'quicktabs', 'accordion', 'fusion_core', '0', '0', '-1', '0', '1', 'node', '', '1', ''),
('749', 'quicktabs', 'accordion', 'fusion_starter', '0', '0', '-1', '0', '1', 'node', '', '1', ''),
('750', 'quicktabs', 'accordion', 'genesis', '0', '0', '-1', '0', '1', 'node', '', '1', ''),
('751', 'quicktabs', 'accordion', 'genesis_SUBTHEME', '0', '0', '-1', '0', '1', 'node', '', '1', ''),
('752', 'quicktabs', 'accordion', 'koi', '0', '0', '-1', '0', '1', 'node', '', '1', ''),
('753', 'quicktabs', 'accordion', 'marinelli', '0', '0', '-1', '0', '1', 'node', '', '1', ''),
('754', 'quicktabs', 'accordion', 'mayo', '0', '0', '-1', '0', '1', 'node', '', '1', ''),
('755', 'quicktabs', 'accordion', 'newswire', '0', '0', '-1', '0', '1', 'node', '', '1', ''),
('756', 'quicktabs', 'accordion', 'ninesixty', '0', '0', '-1', '0', '1', 'node', '', '1', ''),
('757', 'quicktabs', 'accordion', 'seven', '0', '0', '-1', '0', '1', 'node', '', '1', ''),
('758', 'quicktabs', 'accordion', 'theme557', '0', '0', '-1', '0', '1', 'node', '', '1', ''),
('759', 'quicktabs', 'accordion', 'tm_framefork', '0', '0', '-1', '0', '1', 'node', '', '1', ''),
('760', 'quicktabs', 'accordion', 'typebased', '0', '0', '-1', '0', '1', 'node', '', '1', ''),
('761', 'quicktabs', 'default_tabs', 'bartik', '0', '0', '-1', '0', '1', 'node', '<none>', '1', ''),
('762', 'quicktabs', 'default_tabs', 'basic', '0', '0', '-1', '0', '1', 'node', '<none>', '1', ''),
('763', 'quicktabs', 'default_tabs', 'corolla', '0', '0', '-1', '0', '1', 'node', '<none>', '1', ''),
('764', 'quicktabs', 'default_tabs', 'framework', '0', '-17', '-1', '0', '1', 'node', '<none>', '1', ''),
('765', 'quicktabs', 'default_tabs', 'fusion_core', '0', '0', '-1', '0', '1', 'node', '<none>', '1', ''),
('766', 'quicktabs', 'default_tabs', 'fusion_starter', '0', '0', '-1', '0', '1', 'node', '<none>', '1', ''),
('767', 'quicktabs', 'default_tabs', 'genesis', '0', '0', '-1', '0', '1', 'node', '<none>', '1', ''),
('768', 'quicktabs', 'default_tabs', 'genesis_SUBTHEME', '0', '0', '-1', '0', '1', 'node', '<none>', '1', ''),
('769', 'quicktabs', 'default_tabs', 'koi', '0', '0', '-1', '0', '1', 'node', '<none>', '1', ''),
('770', 'quicktabs', 'default_tabs', 'marinelli', '0', '0', '-1', '0', '1', 'node', '<none>', '1', ''),
('771', 'quicktabs', 'default_tabs', 'mayo', '0', '0', '-1', '0', '1', 'node', '<none>', '1', ''),
('772', 'quicktabs', 'default_tabs', 'newswire', '0', '0', '-1', '0', '1', 'node', '<none>', '1', ''),
('773', 'quicktabs', 'default_tabs', 'ninesixty', '0', '0', '-1', '0', '1', 'node', '<none>', '1', ''),
('774', 'quicktabs', 'default_tabs', 'theme557', '0', '0', '-1', '0', '1', 'node', '<none>', '1', ''),
('775', 'quicktabs', 'default_tabs', 'tm_framefork', '0', '0', '-1', '0', '1', 'node', '<none>', '1', ''),
('776', 'quicktabs', 'default_tabs', 'typebased', '0', '0', '-1', '0', '1', 'node', '<none>', '1', ''),
('777', 'views', 'Carousel-block', 'bartik', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('778', 'views', 'Carousel-block', 'basic', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('779', 'views', 'Carousel-block', 'corolla', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('780', 'views', 'Carousel-block', 'framework', '0', '-18', '-1', '0', '1', 'node', '<none>', '-1', ''),
('781', 'views', 'Carousel-block', 'fusion_core', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('782', 'views', 'Carousel-block', 'fusion_starter', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('783', 'views', 'Carousel-block', 'genesis', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('784', 'views', 'Carousel-block', 'genesis_SUBTHEME', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('785', 'views', 'Carousel-block', 'koi', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('786', 'views', 'Carousel-block', 'marinelli', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('787', 'views', 'Carousel-block', 'mayo', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('788', 'views', 'Carousel-block', 'newswire', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('789', 'views', 'Carousel-block', 'ninesixty', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('790', 'views', 'Carousel-block', 'seven', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('791', 'views', 'Carousel-block', 'theme557', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('792', 'views', 'Carousel-block', 'tm_framefork', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('793', 'views', 'Carousel-block', 'typebased', '0', '0', '-1', '0', '1', 'node', '<none>', '-1', ''),
('794', 'views', 'Carousel-block', 'zentropy', '1', '-16', 'header_bottom', '0', '1', 'node', '<none>', '-1', ''),
('795', 'views', 'archive-block', 'zentropy', '1', '6', 'sidebar_first_wide', '0', '0', '', '', '-1', ''),
('796', 'views', 'comments_recent-block', 'zentropy', '1', '9', 'sidebar_first_wide', '0', '0', '', '', '-1', ''),
('797', 'views', 'archive-block', 'bartik', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('798', 'views', 'comments_recent-block', 'bartik', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('799', 'views', 'archive-block', 'basic', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('800', 'views', 'comments_recent-block', 'basic', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('801', 'views', 'archive-block', 'corolla', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('802', 'views', 'comments_recent-block', 'corolla', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('803', 'views', 'archive-block', 'framework', '0', '-20', '-1', '0', '0', '', '', '-1', ''),
('804', 'views', 'comments_recent-block', 'framework', '0', '6', '-1', '0', '0', '', '', '-1', ''),
('805', 'views', 'archive-block', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('806', 'views', 'comments_recent-block', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('807', 'views', 'archive-block', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('808', 'views', 'comments_recent-block', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('809', 'views', 'archive-block', 'genesis', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('810', 'views', 'comments_recent-block', 'genesis', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('811', 'views', 'archive-block', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('812', 'views', 'comments_recent-block', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('813', 'views', 'archive-block', 'koi', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('814', 'views', 'comments_recent-block', 'koi', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('815', 'views', 'archive-block', 'marinelli', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('816', 'views', 'comments_recent-block', 'marinelli', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('817', 'views', 'archive-block', 'mayo', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('818', 'views', 'comments_recent-block', 'mayo', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('819', 'views', 'archive-block', 'newswire', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('820', 'views', 'comments_recent-block', 'newswire', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('821', 'views', 'archive-block', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('822', 'views', 'comments_recent-block', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('823', 'views', 'archive-block', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('824', 'views', 'comments_recent-block', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('825', 'views', 'archive-block', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('826', 'views', 'comments_recent-block', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('827', 'views', 'archive-block', 'typebased', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('828', 'views', 'comments_recent-block', 'typebased', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('829', 'flickr', '0', 'bartik', '0', '0', '-1', '0', '0', '', '', '1', ''),
('830', 'flickr', '1', 'bartik', '0', '0', '-1', '0', '0', '', '', '1', ''),
('831', 'flickr', '2', 'bartik', '0', '0', '-1', '0', '0', '', '', '1', ''),
('832', 'flickr', '3', 'bartik', '0', '0', '-1', '0', '0', '', '', '1', ''),
('833', 'flickr', '4', 'bartik', '0', '0', '-1', '0', '0', '', '', '1', ''),
('834', 'flickr', '5', 'bartik', '0', '0', '-1', '0', '0', '', '', '1', ''),
('835', 'flickr', '6', 'bartik', '0', '0', '-1', '0', '0', '', '', '1', ''),
('836', 'flickr', '7', 'bartik', '0', '0', '-1', '0', '0', '', '', '1', ''),
('837', 'flickr', '0', 'basic', '0', '0', '-1', '0', '0', '', '', '1', ''),
('838', 'flickr', '1', 'basic', '0', '0', '-1', '0', '0', '', '', '1', ''),
('839', 'flickr', '2', 'basic', '0', '0', '-1', '0', '0', '', '', '1', ''),
('840', 'flickr', '3', 'basic', '0', '0', '-1', '0', '0', '', '', '1', ''),
('841', 'flickr', '4', 'basic', '0', '0', '-1', '0', '0', '', '', '1', ''),
('842', 'flickr', '5', 'basic', '0', '0', '-1', '0', '0', '', '', '1', ''),
('843', 'flickr', '6', 'basic', '0', '0', '-1', '0', '0', '', '', '1', ''),
('844', 'flickr', '7', 'basic', '0', '0', '-1', '0', '0', '', '', '1', ''),
('845', 'flickr', '0', 'corolla', '0', '0', '-1', '0', '0', '', '', '1', ''),
('846', 'flickr', '1', 'corolla', '0', '0', '-1', '0', '0', '', '', '1', ''),
('847', 'flickr', '2', 'corolla', '0', '0', '-1', '0', '0', '', '', '1', ''),
('848', 'flickr', '3', 'corolla', '0', '0', '-1', '0', '0', '', '', '1', ''),
('849', 'flickr', '4', 'corolla', '0', '0', '-1', '0', '0', '', '', '1', ''),
('850', 'flickr', '5', 'corolla', '0', '0', '-1', '0', '0', '', '', '1', ''),
('851', 'flickr', '6', 'corolla', '0', '0', '-1', '0', '0', '', '', '1', ''),
('852', 'flickr', '7', 'corolla', '0', '0', '-1', '0', '0', '', '', '1', ''),
('853', 'flickr', '0', 'framework', '0', '-8', '-1', '0', '0', '', '', '1', ''),
('854', 'flickr', '1', 'framework', '0', '-10', '-1', '0', '0', '', '', '1', ''),
('855', 'flickr', '2', 'framework', '0', '-9', '-1', '0', '0', '', '', '1', ''),
('856', 'flickr', '3', 'framework', '0', '-12', '-1', '0', '0', '', '', '1', ''),
('857', 'flickr', '4', 'framework', '0', '-11', '-1', '0', '0', '', '', '1', ''),
('858', 'flickr', '5', 'framework', '0', '-13', '-1', '0', '0', '', '', '1', ''),
('859', 'flickr', '6', 'framework', '0', '-15', '-1', '0', '0', '', '', '1', ''),
('860', 'flickr', '7', 'framework', '0', '-14', '-1', '0', '0', '', '', '1', ''),
('861', 'flickr', '0', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '1', ''),
('862', 'flickr', '1', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '1', ''),
('863', 'flickr', '2', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '1', ''),
('864', 'flickr', '3', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '1', ''),
('865', 'flickr', '4', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '1', ''),
('866', 'flickr', '5', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '1', ''),
('867', 'flickr', '6', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '1', ''),
('868', 'flickr', '7', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '1', ''),
('869', 'flickr', '0', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '1', ''),
('870', 'flickr', '1', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '1', ''),
('871', 'flickr', '2', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '1', ''),
('872', 'flickr', '3', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '1', ''),
('873', 'flickr', '4', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '1', ''),
('874', 'flickr', '5', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '1', ''),
('875', 'flickr', '6', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '1', ''),
('876', 'flickr', '7', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '1', ''),
('877', 'flickr', '0', 'genesis', '0', '0', '-1', '0', '0', '', '', '1', ''),
('878', 'flickr', '1', 'genesis', '0', '0', '-1', '0', '0', '', '', '1', ''),
('879', 'flickr', '2', 'genesis', '0', '0', '-1', '0', '0', '', '', '1', ''),
('880', 'flickr', '3', 'genesis', '0', '0', '-1', '0', '0', '', '', '1', ''),
('881', 'flickr', '4', 'genesis', '0', '0', '-1', '0', '0', '', '', '1', ''),
('882', 'flickr', '5', 'genesis', '0', '0', '-1', '0', '0', '', '', '1', ''),
('883', 'flickr', '6', 'genesis', '0', '0', '-1', '0', '0', '', '', '1', ''),
('884', 'flickr', '7', 'genesis', '0', '0', '-1', '0', '0', '', '', '1', ''),
('885', 'flickr', '0', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '1', ''),
('886', 'flickr', '1', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '1', ''),
('887', 'flickr', '2', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '1', ''),
('888', 'flickr', '3', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '1', ''),
('889', 'flickr', '4', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '1', ''),
('890', 'flickr', '5', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '1', ''),
('891', 'flickr', '6', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '1', ''),
('892', 'flickr', '7', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '1', ''),
('893', 'flickr', '0', 'koi', '0', '0', '-1', '0', '0', '', '', '1', ''),
('894', 'flickr', '1', 'koi', '0', '0', '-1', '0', '0', '', '', '1', ''),
('895', 'flickr', '2', 'koi', '0', '0', '-1', '0', '0', '', '', '1', ''),
('896', 'flickr', '3', 'koi', '0', '0', '-1', '0', '0', '', '', '1', ''),
('897', 'flickr', '4', 'koi', '0', '0', '-1', '0', '0', '', '', '1', ''),
('898', 'flickr', '5', 'koi', '0', '0', '-1', '0', '0', '', '', '1', ''),
('899', 'flickr', '6', 'koi', '0', '0', '-1', '0', '0', '', '', '1', ''),
('900', 'flickr', '7', 'koi', '0', '0', '-1', '0', '0', '', '', '1', ''),
('901', 'flickr', '0', 'marinelli', '0', '0', '-1', '0', '0', '', '', '1', ''),
('902', 'flickr', '1', 'marinelli', '0', '0', '-1', '0', '0', '', '', '1', ''),
('903', 'flickr', '2', 'marinelli', '0', '0', '-1', '0', '0', '', '', '1', ''),
('904', 'flickr', '3', 'marinelli', '0', '0', '-1', '0', '0', '', '', '1', ''),
('905', 'flickr', '4', 'marinelli', '0', '0', '-1', '0', '0', '', '', '1', ''),
('906', 'flickr', '5', 'marinelli', '0', '0', '-1', '0', '0', '', '', '1', ''),
('907', 'flickr', '6', 'marinelli', '0', '0', '-1', '0', '0', '', '', '1', ''),
('908', 'flickr', '7', 'marinelli', '0', '0', '-1', '0', '0', '', '', '1', ''),
('909', 'flickr', '0', 'mayo', '0', '0', '-1', '0', '0', '', '', '1', ''),
('910', 'flickr', '1', 'mayo', '0', '0', '-1', '0', '0', '', '', '1', ''),
('911', 'flickr', '2', 'mayo', '0', '0', '-1', '0', '0', '', '', '1', ''),
('912', 'flickr', '3', 'mayo', '0', '0', '-1', '0', '0', '', '', '1', ''),
('913', 'flickr', '4', 'mayo', '0', '0', '-1', '0', '0', '', '', '1', ''),
('914', 'flickr', '5', 'mayo', '0', '0', '-1', '0', '0', '', '', '1', ''),
('915', 'flickr', '6', 'mayo', '0', '0', '-1', '0', '0', '', '', '1', ''),
('916', 'flickr', '7', 'mayo', '0', '0', '-1', '0', '0', '', '', '1', ''),
('917', 'flickr', '0', 'newswire', '0', '0', '-1', '0', '0', '', '', '1', ''),
('918', 'flickr', '1', 'newswire', '0', '0', '-1', '0', '0', '', '', '1', ''),
('919', 'flickr', '2', 'newswire', '0', '0', '-1', '0', '0', '', '', '1', ''),
('920', 'flickr', '3', 'newswire', '0', '0', '-1', '0', '0', '', '', '1', ''),
('921', 'flickr', '4', 'newswire', '0', '0', '-1', '0', '0', '', '', '1', ''),
('922', 'flickr', '5', 'newswire', '0', '0', '-1', '0', '0', '', '', '1', ''),
('923', 'flickr', '6', 'newswire', '0', '0', '-1', '0', '0', '', '', '1', ''),
('924', 'flickr', '7', 'newswire', '0', '0', '-1', '0', '0', '', '', '1', ''),
('925', 'flickr', '0', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '1', ''),
('926', 'flickr', '1', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '1', ''),
('927', 'flickr', '2', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '1', ''),
('928', 'flickr', '3', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '1', ''),
('929', 'flickr', '4', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '1', ''),
('930', 'flickr', '5', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '1', ''),
('931', 'flickr', '6', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '1', ''),
('932', 'flickr', '7', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '1', ''),
('933', 'flickr', '0', 'seven', '0', '0', '-1', '0', '0', '', '', '1', ''),
('934', 'flickr', '1', 'seven', '0', '0', '-1', '0', '0', '', '', '1', ''),
('935', 'flickr', '2', 'seven', '0', '0', '-1', '0', '0', '', '', '1', ''),
('936', 'flickr', '3', 'seven', '0', '0', '-1', '0', '0', '', '', '1', ''),
('937', 'flickr', '4', 'seven', '0', '0', '-1', '0', '0', '', '', '1', ''),
('938', 'flickr', '5', 'seven', '0', '0', '-1', '0', '0', '', '', '1', ''),
('939', 'flickr', '6', 'seven', '0', '0', '-1', '0', '0', '', '', '1', ''),
('940', 'flickr', '7', 'seven', '0', '0', '-1', '0', '0', '', '', '1', ''),
('941', 'flickr', '0', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '1', ''),
('942', 'flickr', '1', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '1', ''),
('943', 'flickr', '2', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '1', ''),
('944', 'flickr', '3', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '1', ''),
('945', 'flickr', '4', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '1', ''),
('946', 'flickr', '5', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '1', ''),
('947', 'flickr', '6', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '1', ''),
('948', 'flickr', '7', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '1', ''),
('949', 'flickr', '0', 'typebased', '0', '0', '-1', '0', '0', '', '', '1', ''),
('950', 'flickr', '1', 'typebased', '0', '0', '-1', '0', '0', '', '', '1', ''),
('951', 'flickr', '2', 'typebased', '0', '0', '-1', '0', '0', '', '', '1', ''),
('952', 'flickr', '3', 'typebased', '0', '0', '-1', '0', '0', '', '', '1', ''),
('953', 'flickr', '4', 'typebased', '0', '0', '-1', '0', '0', '', '', '1', ''),
('954', 'flickr', '5', 'typebased', '0', '0', '-1', '0', '0', '', '', '1', ''),
('955', 'flickr', '6', 'typebased', '0', '0', '-1', '0', '0', '', '', '1', ''),
('956', 'flickr', '7', 'typebased', '0', '0', '-1', '0', '0', '', '', '1', ''),
('957', 'flickr', '0', 'zentropy', '0', '-15', '-1', '0', '0', '', '', '1', ''),
('958', 'flickr', '1', 'zentropy', '0', '-17', '-1', '0', '0', '', '', '1', ''),
('959', 'flickr', '2', 'zentropy', '0', '-16', '-1', '0', '0', '', '', '1', ''),
('960', 'flickr', '3', 'zentropy', '0', '-19', '-1', '0', '0', '', '', '1', ''),
('961', 'flickr', '4', 'zentropy', '0', '-18', '-1', '0', '0', '', '', '1', ''),
('962', 'flickr', '5', 'zentropy', '0', '-20', '-1', '0', '0', '', '', '1', ''),
('963', 'flickr', '6', 'zentropy', '0', '-22', '-1', '0', '0', '', '', '1', ''),
('964', 'flickr', '7', 'zentropy', '0', '-21', '-1', '0', '0', '', '', '1', ''),
('965', 'tagadelic', '2', 'bartik', '0', '0', '-1', '0', '0', '', '', '8', ''),
('966', 'tagadelic', '3', 'bartik', '0', '0', '-1', '0', '0', '', '', '8', ''),
('967', 'tagadelic', '1', 'bartik', '0', '0', '-1', '0', '0', '', '', '8', ''),
('968', 'tagadelic', '2', 'basic', '0', '0', '-1', '0', '0', '', '', '8', ''),
('969', 'tagadelic', '3', 'basic', '0', '0', '-1', '0', '0', '', '', '8', ''),
('970', 'tagadelic', '1', 'basic', '0', '0', '-1', '0', '0', '', '', '8', ''),
('971', 'tagadelic', '2', 'corolla', '0', '0', '-1', '0', '0', '', '', '8', ''),
('972', 'tagadelic', '3', 'corolla', '0', '0', '-1', '0', '0', '', '', '8', ''),
('973', 'tagadelic', '1', 'corolla', '0', '0', '-1', '0', '0', '', '', '8', ''),
('974', 'tagadelic', '2', 'framework', '0', '10', '-1', '0', '0', '', '', '8', ''),
('975', 'tagadelic', '3', 'framework', '0', '11', '-1', '0', '0', '', '', '8', ''),
('976', 'tagadelic', '1', 'framework', '0', '12', '-1', '0', '0', '', '', '8', ''),
('977', 'tagadelic', '2', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '8', ''),
('978', 'tagadelic', '3', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '8', ''),
('979', 'tagadelic', '1', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '8', ''),
('980', 'tagadelic', '2', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '8', ''),
('981', 'tagadelic', '3', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '8', ''),
('982', 'tagadelic', '1', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '8', ''),
('983', 'tagadelic', '2', 'genesis', '0', '0', '-1', '0', '0', '', '', '8', ''),
('984', 'tagadelic', '3', 'genesis', '0', '0', '-1', '0', '0', '', '', '8', ''),
('985', 'tagadelic', '1', 'genesis', '0', '0', '-1', '0', '0', '', '', '8', ''),
('986', 'tagadelic', '2', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '8', ''),
('987', 'tagadelic', '3', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '8', ''),
('988', 'tagadelic', '1', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '8', ''),
('989', 'tagadelic', '2', 'koi', '0', '0', '-1', '0', '0', '', '', '8', ''),
('990', 'tagadelic', '3', 'koi', '0', '0', '-1', '0', '0', '', '', '8', ''),
('991', 'tagadelic', '1', 'koi', '0', '0', '-1', '0', '0', '', '', '8', ''),
('992', 'tagadelic', '2', 'marinelli', '0', '0', '-1', '0', '0', '', '', '8', ''),
('993', 'tagadelic', '3', 'marinelli', '0', '0', '-1', '0', '0', '', '', '8', ''),
('994', 'tagadelic', '1', 'marinelli', '0', '0', '-1', '0', '0', '', '', '8', ''),
('995', 'tagadelic', '2', 'mayo', '0', '0', '-1', '0', '0', '', '', '8', ''),
('996', 'tagadelic', '3', 'mayo', '0', '0', '-1', '0', '0', '', '', '8', ''),
('997', 'tagadelic', '1', 'mayo', '0', '0', '-1', '0', '0', '', '', '8', ''),
('998', 'tagadelic', '2', 'newswire', '0', '0', '-1', '0', '0', '', '', '8', ''),
('999', 'tagadelic', '3', 'newswire', '0', '0', '-1', '0', '0', '', '', '8', ''),
('1000', 'tagadelic', '1', 'newswire', '0', '0', '-1', '0', '0', '', '', '8', ''),
('1001', 'tagadelic', '2', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '8', ''),
('1002', 'tagadelic', '3', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '8', ''),
('1003', 'tagadelic', '1', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '8', ''),
('1004', 'tagadelic', '2', 'seven', '0', '0', '-1', '0', '0', '', '', '8', ''),
('1005', 'tagadelic', '3', 'seven', '0', '0', '-1', '0', '0', '', '', '8', ''),
('1006', 'tagadelic', '1', 'seven', '0', '0', '-1', '0', '0', '', '', '8', ''),
('1007', 'tagadelic', '2', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '8', ''),
('1008', 'tagadelic', '3', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '8', ''),
('1009', 'tagadelic', '1', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '8', ''),
('1010', 'tagadelic', '2', 'typebased', '0', '0', '-1', '0', '0', '', '', '8', ''),
('1011', 'tagadelic', '3', 'typebased', '0', '0', '-1', '0', '0', '', '', '8', ''),
('1012', 'tagadelic', '1', 'typebased', '0', '0', '-1', '0', '0', '', '', '8', ''),
('1013', 'tagadelic', '2', 'zentropy', '1', '-6', 'sidebar_first', '0', '0', '', '', '8', ''),
('1014', 'tagadelic', '3', 'zentropy', '1', '-24', 'sidebar_first', '0', '0', '', '', '8', ''),
('1015', 'tagadelic', '1', 'zentropy', '1', '-22', 'sidebar_first', '0', '0', '', '', '8', ''),
('1016', 'views', 'our_team-block', 'bartik', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1017', 'views', 'our_team-block', 'basic', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1018', 'views', 'our_team-block', 'corolla', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1019', 'views', 'our_team-block', 'framework', '0', '16', '-1', '0', '0', '', '', '-1', ''),
('1020', 'views', 'our_team-block', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1021', 'views', 'our_team-block', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1022', 'views', 'our_team-block', 'genesis', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1023', 'views', 'our_team-block', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1024', 'views', 'our_team-block', 'koi', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1025', 'views', 'our_team-block', 'marinelli', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1026', 'views', 'our_team-block', 'mayo', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1027', 'views', 'our_team-block', 'newswire', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1028', 'views', 'our_team-block', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1029', 'views', 'our_team-block', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1030', 'views', 'our_team-block', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1031', 'views', 'our_team-block', 'typebased', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1032', 'views', 'our_team-block', 'zentropy', '1', '8', 'sidebar_first_wide', '0', '0', '', '', '-1', ''),
('1033', 'social_share', 'social_share', 'zentropy', '1', '0', 'header', '0', '1', '', '', '1', ''),
('1034', 'addthis', 'addthis', 'bartik', '0', '0', '-1', '0', '0', '', '', '4', ''),
('1035', 'addtoany', 'addtoany_button', 'bartik', '0', '0', '-1', '0', '0', '', '', '1', ''),
('1036', 'social_share', 'social_share', 'bartik', '1', '0', 'header', '0', '1', '', '', '1', ''),
('1037', 'addthis', 'addthis', 'basic', '0', '0', '-1', '0', '0', '', '', '4', ''),
('1038', 'addtoany', 'addtoany_button', 'basic', '0', '0', '-1', '0', '0', '', '', '1', ''),
('1039', 'social_share', 'social_share', 'basic', '1', '0', 'header', '0', '1', '', '', '1', ''),
('1040', 'addthis', 'addthis', 'corolla', '0', '0', '-1', '0', '0', '', '', '4', ''),
('1041', 'addtoany', 'addtoany_button', 'corolla', '0', '0', '-1', '0', '0', '', '', '1', ''),
('1042', 'social_share', 'social_share', 'corolla', '0', '0', '-1', '0', '1', '', '', '1', ''),
('1043', 'addthis', 'addthis', 'framework', '0', '0', '-1', '0', '0', '', '', '4', ''),
('1044', 'addtoany', 'addtoany_button', 'framework', '0', '0', '-1', '0', '0', '', '', '1', ''),
('1045', 'social_share', 'social_share', 'framework', '0', '-24', '-1', '0', '1', '', '', '1', ''),
('1046', 'addthis', 'addthis', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '4', ''),
('1047', 'addtoany', 'addtoany_button', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '1', ''),
('1048', 'social_share', 'social_share', 'fusion_core', '1', '0', 'header', '0', '1', '', '', '1', ''),
('1049', 'addthis', 'addthis', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '4', ''),
('1050', 'addtoany', 'addtoany_button', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '1', ''),
('1051', 'social_share', 'social_share', 'fusion_starter', '1', '0', 'header', '0', '1', '', '', '1', ''),
('1052', 'addthis', 'addthis', 'genesis', '0', '0', '-1', '0', '0', '', '', '4', ''),
('1053', 'addtoany', 'addtoany_button', 'genesis', '0', '0', '-1', '0', '0', '', '', '1', ''),
('1054', 'social_share', 'social_share', 'genesis', '1', '0', 'header', '0', '1', '', '', '1', ''),
('1055', 'addthis', 'addthis', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '4', ''),
('1056', 'addtoany', 'addtoany_button', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '1', ''),
('1057', 'social_share', 'social_share', 'genesis_SUBTHEME', '1', '0', 'header', '0', '1', '', '', '1', ''),
('1058', 'addthis', 'addthis', 'koi', '0', '0', '-1', '0', '0', '', '', '4', ''),
('1059', 'addtoany', 'addtoany_button', 'koi', '0', '0', '-1', '0', '0', '', '', '1', ''),
('1060', 'social_share', 'social_share', 'koi', '0', '0', '-1', '0', '1', '', '', '1', ''),
('1061', 'addthis', 'addthis', 'marinelli', '0', '0', '-1', '0', '0', '', '', '4', ''),
('1062', 'addtoany', 'addtoany_button', 'marinelli', '0', '0', '-1', '0', '0', '', '', '1', ''),
('1063', 'social_share', 'social_share', 'marinelli', '0', '0', '-1', '0', '1', '', '', '1', ''),
('1064', 'addthis', 'addthis', 'mayo', '0', '0', '-1', '0', '0', '', '', '4', ''),
('1065', 'addtoany', 'addtoany_button', 'mayo', '0', '0', '-1', '0', '0', '', '', '1', ''),
('1066', 'social_share', 'social_share', 'mayo', '1', '0', 'header', '0', '1', '', '', '1', ''),
('1067', 'addthis', 'addthis', 'newswire', '0', '0', '-1', '0', '0', '', '', '4', ''),
('1068', 'addtoany', 'addtoany_button', 'newswire', '0', '0', '-1', '0', '0', '', '', '1', ''),
('1069', 'social_share', 'social_share', 'newswire', '1', '0', 'header', '0', '1', '', '', '1', ''),
('1070', 'addthis', 'addthis', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '4', ''),
('1071', 'addtoany', 'addtoany_button', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '1', ''),
('1072', 'social_share', 'social_share', 'ninesixty', '1', '0', 'header', '0', '1', '', '', '1', ''),
('1073', 'addthis', 'addthis', 'seven', '0', '0', '-1', '0', '0', '', '', '4', ''),
('1074', 'addtoany', 'addtoany_button', 'seven', '0', '0', '-1', '0', '0', '', '', '1', ''),
('1075', 'social_share', 'social_share', 'seven', '0', '0', '-1', '0', '1', '', '', '1', ''),
('1076', 'addthis', 'addthis', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '4', ''),
('1077', 'addtoany', 'addtoany_button', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '1', ''),
('1078', 'social_share', 'social_share', 'tm_framefork', '0', '0', '-1', '0', '1', '', '', '1', ''),
('1079', 'addthis', 'addthis', 'typebased', '0', '0', '-1', '0', '0', '', '', '4', ''),
('1080', 'addtoany', 'addtoany_button', 'typebased', '0', '0', '-1', '0', '0', '', '', '1', ''),
('1081', 'social_share', 'social_share', 'typebased', '0', '0', '-1', '0', '1', '', '', '1', ''),
('1082', 'addthis', 'addthis', 'zentropy', '0', '0', '-1', '0', '0', '', '', '4', ''),
('1083', 'addtoany', 'addtoany_button', 'zentropy', '0', '0', '-1', '0', '0', '', '', '1', ''),
('1084', 'views', 'faq-faq_recent', 'bartik', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1085', 'views', 'faq-faq_random', 'bartik', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1086', 'views', 'faq-faq_recent', 'basic', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1087', 'views', 'faq-faq_random', 'basic', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1088', 'views', 'faq-faq_recent', 'corolla', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1089', 'views', 'faq-faq_random', 'corolla', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1090', 'views', 'faq-faq_recent', 'framework', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1091', 'views', 'faq-faq_random', 'framework', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1092', 'views', 'faq-faq_recent', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1093', 'views', 'faq-faq_random', 'fusion_core', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1094', 'views', 'faq-faq_recent', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1095', 'views', 'faq-faq_random', 'fusion_starter', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1096', 'views', 'faq-faq_recent', 'genesis', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1097', 'views', 'faq-faq_random', 'genesis', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1098', 'views', 'faq-faq_recent', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1099', 'views', 'faq-faq_random', 'genesis_SUBTHEME', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1100', 'views', 'faq-faq_recent', 'koi', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1101', 'views', 'faq-faq_random', 'koi', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1102', 'views', 'faq-faq_recent', 'marinelli', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1103', 'views', 'faq-faq_random', 'marinelli', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1104', 'views', 'faq-faq_recent', 'mayo', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1105', 'views', 'faq-faq_random', 'mayo', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1106', 'views', 'faq-faq_recent', 'newswire', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1107', 'views', 'faq-faq_random', 'newswire', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1108', 'views', 'faq-faq_recent', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1109', 'views', 'faq-faq_random', 'ninesixty', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1110', 'views', 'faq-faq_recent', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1111', 'views', 'faq-faq_random', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1112', 'views', 'faq-faq_recent', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1113', 'views', 'faq-faq_random', 'tm_framefork', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1114', 'views', 'faq-faq_recent', 'typebased', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1115', 'views', 'faq-faq_random', 'typebased', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1116', 'views', 'faq-faq_recent', 'zentropy', '1', '-6', 'sidebar_first_wide', '0', '0', '', '', '-1', ''),
('1117', 'views', 'faq-faq_random', 'zentropy', '1', '-8', 'sidebar_first_wide', '0', '0', '', '', '-1', ''),
('1118', 'views', 'slider-block', 'zentropy', '1', '0', 'header', '0', '1', '<front>', '', '-1', 'slider-wide'),
('1119', 'views', 'slider-block', 'bartik', '0', '0', '-1', '0', '1', '<front>', '', '-1', 'slider-wide'),
('1120', 'views', 'slider-block', 'seven', '0', '0', '-1', '0', '1', '<front>', '', '-1', 'slider-wide'),
('1121', 'addthis', 'addthis_block', 'bartik', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1122', 'addthis', 'addthis_block', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1123', 'addthis', 'addthis_block', 'zentropy', '1', '7', 'sidebar_first_wide', '0', '0', '', '', '-1', ''),
('1124', 'views', 'categories-block', 'zentropy', '1', '-18', 'sidebar_first_wide', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '-1', ''),
('1125', 'views', 'categories-block', 'bartik', '0', '0', '-1', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '-1', ''),
('1126', 'views', 'categories-block', 'seven', '0', '0', '-1', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '-1', ''),
('1127', 'views', 'portfolio_filter-block', 'bartik', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1128', 'views', 'portfolio_filter-block', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1129', 'views', 'portfolio_filter-block', 'zentropy', '1', '0', 'sidebar_first_wide', '0', '0', '', '', '-1', ''),
('1130', 'menu', 'devel', 'bartik', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1131', 'devel', 'execute_php', 'bartik', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1132', 'devel', 'switch_user', 'bartik', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1133', 'menu', 'devel', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1134', 'devel', 'execute_php', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1135', 'devel', 'switch_user', 'seven', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1136', 'menu', 'devel', 'zentropy', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1137', 'devel', 'execute_php', 'zentropy', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1138', 'devel', 'switch_user', 'zentropy', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1139', 'addthis', 'addthis', 'theme813', '0', '0', '-1', '0', '0', '', '', '4', ''),
('1140', 'addthis', 'addthis_block', 'theme813', '0', '7', '-1', '0', '0', '', '', '-1', ''),
('1141', 'addtoany', 'addtoany_button', 'theme813', '0', '0', '-1', '0', '0', '', '', '1', ''),
('1142', 'block', '1', 'theme813', '0', '-17', '-1', '0', '1', 'contact', 'Our Location', '-1', ''),
('1143', 'block', '5', 'theme813', '1', '-16', 'footer', '0', '0', '', '', '-1', ''),
('1144', 'blog', 'recent', 'theme813', '0', '-3', '-1', '0', '0', '', '', '1', ''),
('1145', 'book', 'navigation', 'theme813', '0', '3', '-1', '0', '0', '', '', '5', ''),
('1146', 'comment', 'recent', 'theme813', '0', '-4', '-1', '0', '0', '', '', '1', ''),
('1147', 'demo_reset', 'reset', 'theme813', '0', '-13', '-1', '0', '0', '', '', '-1', ''),
('1148', 'devel', 'execute_php', 'theme813', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1149', 'devel', 'switch_user', 'theme813', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1150', 'faq', 'faq_categories', 'theme813', '0', '-14', '-1', '0', '0', '', '', '1', ''),
('1151', 'faq', 'faq_random', 'theme813', '0', '-12', '-1', '0', '0', '', '', '1', ''),
('1152', 'faq', 'faq_recent', 'theme813', '0', '-11', '-1', '0', '0', '', '', '1', ''),
('1153', 'flickr', '0', 'theme813', '0', '-15', '-1', '0', '0', '', '', '1', ''),
('1154', 'flickr', '1', 'theme813', '0', '-17', '-1', '0', '0', '', '', '1', ''),
('1155', 'flickr', '2', 'theme813', '0', '-16', '-1', '0', '0', '', '', '1', ''),
('1156', 'flickr', '3', 'theme813', '0', '-19', '-1', '0', '0', '', '', '1', ''),
('1157', 'flickr', '4', 'theme813', '0', '-18', '-1', '0', '0', '', '', '1', ''),
('1158', 'flickr', '5', 'theme813', '0', '-20', '-1', '0', '0', '', '', '1', ''),
('1159', 'flickr', '6', 'theme813', '0', '-22', '-1', '0', '0', '', '', '1', ''),
('1160', 'flickr', '7', 'theme813', '0', '-21', '-1', '0', '0', '', '', '1', ''),
('1161', 'follow', 'site', 'theme813', '1', '-17', 'footer', '0', '0', '', '<none>', '1', ''),
('1162', 'follow', 'user', 'theme813', '0', '-12', '-1', '0', '0', '', '', '2', ''),
('1163', 'forum', 'active', 'theme813', '0', '4', '-1', '0', '0', '', '', '-2', ''),
('1164', 'forum', 'new', 'theme813', '0', '-2', '-1', '0', '0', '', '', '-2', ''),
('1165', 'locale', 'language', 'theme813', '0', '2', '-1', '0', '0', '', '', '-1', ''),
('1166', 'menu', 'devel', 'theme813', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1167', 'node', 'recent', 'theme813', '0', '-5', '-1', '0', '0', '', '', '1', ''),
('1168', 'node', 'syndicate', 'theme813', '0', '-9', '-1', '0', '0', '', '', '-1', ''),
('1169', 'poll', 'recent', 'theme813', '1', '-1', 'sidebar_second_narrow', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('1170', 'quicktabs', 'accordion', 'theme813', '0', '-18', '-1', '0', '1', 'node', '', '1', ''),
('1171', 'quicktabs', 'default_tabs', 'theme813', '0', '-17', '-1', '0', '1', 'node', '<none>', '1', ''),
('1172', 'search', 'form', 'theme813', '0', '-16', '-1', '0', '0', '', '', '-1', ''),
('1173', 'shortcut', 'shortcuts', 'theme813', '0', '-7', '-1', '0', '0', '', '', '-1', ''),
('1174', 'social_share', 'social_share', 'theme813', '1', '0', 'header', '0', '1', '', '', '1', ''),
('1175', 'superfish', '1', 'theme813', '1', '-17', 'menu', '0', '0', '', '<none>', '-1', '');
INSERT INTO `block` VALUES
('1176', 'superfish', '2', 'theme813', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1177', 'superfish', '3', 'theme813', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1178', 'superfish', '4', 'theme813', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1179', 'system', 'help', 'theme813', '1', '0', 'help', '0', '0', '', '', '-1', ''),
('1180', 'system', 'main', 'theme813', '1', '-22', 'content', '0', '0', '', '', '-1', ''),
('1181', 'system', 'main-menu', 'theme813', '0', '1', '-1', '0', '0', '', '', '-1', ''),
('1182', 'system', 'management', 'theme813', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1183', 'system', 'navigation', 'theme813', '0', '5', '-1', '0', '0', '', '', '-1', ''),
('1184', 'system', 'powered-by', 'theme813', '0', '-10', '-1', '0', '0', '', '', '-1', ''),
('1185', 'system', 'user-menu', 'theme813', '0', '-11', '-1', '0', '0', '', '<none>', '-1', ''),
('1186', 'tagadelic', '1', 'theme813', '1', '-22', 'header', '0', '0', '', '', '8', ''),
('1187', 'tagadelic', '2', 'theme813', '1', '-6', 'header', '0', '0', '', '', '8', ''),
('1188', 'tagadelic', '3', 'theme813', '1', '-24', 'header', '0', '0', '', '', '8', ''),
('1189', 'user', 'login', 'theme813', '0', '-15', '-1', '0', '0', '', '', '-1', ''),
('1190', 'user', 'new', 'theme813', '0', '-13', '-1', '0', '0', '', '', '1', ''),
('1191', 'user', 'online', 'theme813', '0', '-11', '-1', '0', '0', '', '', '-1', ''),
('1192', 'views', 'archive-block', 'theme813', '0', '6', '-1', '0', '0', '', '', '-1', ''),
('1193', 'views', 'Carousel-block', 'theme813', '1', '-16', 'header_bottom', '0', '1', 'node', '<none>', '-1', ''),
('1194', 'views', 'categories-block', 'theme813', '1', '-18', 'sidebar_second_narrow', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '-1', ''),
('1195', 'views', 'comments_recent-block', 'theme813', '0', '9', '-1', '0', '0', '', '', '-1', ''),
('1196', 'views', 'faq-faq_random', 'theme813', '0', '-8', '-1', '0', '0', '', '', '-1', ''),
('1197', 'views', 'faq-faq_recent', 'theme813', '0', '-6', '-1', '0', '0', '', '', '-1', ''),
('1198', 'views', 'our_team-block', 'theme813', '0', '8', '-1', '0', '0', '', '', '-1', ''),
('1199', 'views', 'portfolio_filter-block', 'theme813', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1200', 'views', 'sldier-block', 'theme813', '1', '-17', 'header', '0', '1', 'node', '<none>', '-1', ''),
('1201', 'views', 'slider-block', 'theme813', '1', '0', 'header', '0', '1', '<front>', '', '-1', 'slider-wide'),
('1202', 'block', '6', 'bartik', '0', '0', '-1', '0', '0', '', '<none>', '-1', 'header-phone'),
('1203', 'block', '6', 'seven', '0', '0', '-1', '0', '0', '', '<none>', '-1', 'header-phone'),
('1204', 'block', '6', 'theme813', '1', '0', 'header_top', '0', '0', '', '<none>', '-1', 'header-phone'),
('1205', 'views', 'services-block', 'theme813', '1', '0', 'header_bottom', '0', '1', '<front>', '', '-1', 'service-block'),
('1206', 'views', 'services-block', 'bartik', '0', '0', '-1', '0', '0', '<front>', '', '-1', 'service-block'),
('1207', 'views', 'services-block', 'seven', '0', '0', '-1', '0', '0', '<front>', '', '-1', 'service-block'),
('1208', 'views', 'areas_of_practice-block', 'theme813', '1', '-18', 'content', '0', '1', '<front>', '', '-1', 'grid-4 omega title-list-block'),
('1209', 'views', 'areas_of_practice-block', 'bartik', '0', '0', '-1', '0', '1', '<front>', '', '-1', 'grid-4 omega title-list-block'),
('1210', 'views', 'areas_of_practice-block', 'seven', '0', '0', '-1', '0', '1', '<front>', '', '-1', 'grid-4 omega title-list-block'),
('1211', 'views', 'popular_services-block', 'theme813', '1', '-17', 'content', '0', '1', 'services', '', '-1', 'block-container'),
('1212', 'views', 'popular_services-block', 'bartik', '0', '0', '-1', '0', '1', 'services', '', '-1', 'block-container'),
('1213', 'views', 'popular_services-block', 'seven', '0', '0', '-1', '0', '1', 'services', '', '-1', 'block-container'),
('1214', 'views', 'latest_news-block', 'theme813', '1', '-19', 'content', '0', '1', '<front>', '', '-1', 'grid-4 news-block'),
('1215', 'views', 'latest_news-block', 'bartik', '0', '0', '-1', '0', '1', '<front>', '', '-1', 'grid-4 news-block'),
('1216', 'views', 'latest_news-block', 'seven', '0', '0', '-1', '0', '1', '<front>', '', '-1', 'grid-4 news-block'),
('1220', 'views', 'testimonials-block', 'theme813', '1', '-21', 'content', '0', '1', '<front>', '', '-1', 'grid-4 alpha testimonials-wrap'),
('1221', 'views', 'testimonials-block', 'bartik', '0', '0', '-1', '0', '1', '<front>', '', '-1', 'grid-4 alpha testimonials-wrap'),
('1222', 'views', 'testimonials-block', 'seven', '0', '0', '-1', '0', '1', '<front>', '', '-1', 'grid-4 alpha testimonials-wrap'),
('1223', 'addthis', 'addthis', 'theme822', '0', '0', '-1', '0', '0', '', '', '4', ''),
('1224', 'addthis', 'addthis_block', 'theme822', '0', '7', '-1', '0', '0', '', '', '-1', ''),
('1225', 'addtoany', 'addtoany_button', 'theme822', '0', '0', '-1', '0', '0', '', '', '1', ''),
('1226', 'block', '1', 'theme822', '0', '-17', '-1', '0', '1', 'contact', 'Our Location', '-1', ''),
('1227', 'block', '5', 'theme822', '1', '-16', 'footer', '0', '0', '', '', '-1', ''),
('1228', 'block', '6', 'theme822', '1', '0', 'header_top', '0', '0', '', '<none>', '-1', 'header-phone'),
('1229', 'blog', 'recent', 'theme822', '0', '-3', '-1', '0', '0', '', '', '1', ''),
('1230', 'book', 'navigation', 'theme822', '0', '3', '-1', '0', '0', '', '', '5', ''),
('1231', 'comment', 'recent', 'theme822', '0', '-4', '-1', '0', '0', '', '', '1', ''),
('1232', 'demo_reset', 'reset', 'theme822', '0', '-13', '-1', '0', '0', '', '', '-1', ''),
('1233', 'devel', 'execute_php', 'theme822', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1234', 'devel', 'switch_user', 'theme822', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1235', 'faq', 'faq_categories', 'theme822', '0', '-14', '-1', '0', '0', '', '', '1', ''),
('1236', 'faq', 'faq_random', 'theme822', '0', '-12', '-1', '0', '0', '', '', '1', ''),
('1237', 'faq', 'faq_recent', 'theme822', '0', '-11', '-1', '0', '0', '', '', '1', ''),
('1238', 'flickr', '0', 'theme822', '0', '-15', '-1', '0', '0', '', '', '1', ''),
('1239', 'flickr', '1', 'theme822', '0', '-17', '-1', '0', '0', '', '', '1', ''),
('1240', 'flickr', '2', 'theme822', '0', '-16', '-1', '0', '0', '', '', '1', ''),
('1241', 'flickr', '3', 'theme822', '0', '-19', '-1', '0', '0', '', '', '1', ''),
('1242', 'flickr', '4', 'theme822', '0', '-18', '-1', '0', '0', '', '', '1', ''),
('1243', 'flickr', '5', 'theme822', '0', '-20', '-1', '0', '0', '', '', '1', ''),
('1244', 'flickr', '6', 'theme822', '0', '-22', '-1', '0', '0', '', '', '1', ''),
('1245', 'flickr', '7', 'theme822', '0', '-21', '-1', '0', '0', '', '', '1', ''),
('1246', 'follow', 'site', 'theme822', '1', '-17', 'footer', '0', '0', '', '<none>', '1', ''),
('1247', 'follow', 'user', 'theme822', '0', '-12', '-1', '0', '0', '', '', '2', ''),
('1248', 'forum', 'active', 'theme822', '0', '4', '-1', '0', '0', '', '', '-2', ''),
('1249', 'forum', 'new', 'theme822', '0', '-2', '-1', '0', '0', '', '', '-2', ''),
('1250', 'locale', 'language', 'theme822', '0', '2', '-1', '0', '0', '', '', '-1', ''),
('1251', 'menu', 'devel', 'theme822', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1252', 'node', 'recent', 'theme822', '0', '-5', '-1', '0', '0', '', '', '1', ''),
('1253', 'node', 'syndicate', 'theme822', '0', '-9', '-1', '0', '0', '', '', '-1', ''),
('1254', 'poll', 'recent', 'theme822', '1', '-1', 'sidebar_second_narrow', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '1', ''),
('1255', 'quicktabs', 'accordion', 'theme822', '0', '-18', '-1', '0', '1', 'node', '', '1', ''),
('1256', 'quicktabs', 'default_tabs', 'theme822', '0', '-17', '-1', '0', '1', 'node', '<none>', '1', ''),
('1257', 'search', 'form', 'theme822', '0', '-16', '-1', '0', '0', '', '', '-1', ''),
('1258', 'shortcut', 'shortcuts', 'theme822', '0', '-7', '-1', '0', '0', '', '', '-1', ''),
('1259', 'social_share', 'social_share', 'theme822', '1', '0', 'header', '0', '1', '', '', '1', ''),
('1260', 'superfish', '1', 'theme822', '1', '-17', 'menu', '0', '0', '', '<none>', '-1', ''),
('1261', 'superfish', '2', 'theme822', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1262', 'superfish', '3', 'theme822', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1263', 'superfish', '4', 'theme822', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1264', 'system', 'help', 'theme822', '1', '0', 'help', '0', '0', '', '', '-1', ''),
('1265', 'system', 'main', 'theme822', '1', '-22', 'content', '0', '0', '', '', '-1', ''),
('1266', 'system', 'main-menu', 'theme822', '0', '1', '-1', '0', '0', '', '', '-1', ''),
('1267', 'system', 'management', 'theme822', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1268', 'system', 'navigation', 'theme822', '0', '5', '-1', '0', '0', '', '', '-1', ''),
('1269', 'system', 'powered-by', 'theme822', '0', '-10', '-1', '0', '0', '', '', '-1', ''),
('1270', 'system', 'user-menu', 'theme822', '0', '-11', '-1', '0', '0', '', '<none>', '-1', ''),
('1271', 'tagadelic', '1', 'theme822', '1', '-22', 'header', '0', '0', '', '', '8', ''),
('1272', 'tagadelic', '2', 'theme822', '1', '-6', 'header', '0', '0', '', '', '8', ''),
('1273', 'tagadelic', '3', 'theme822', '1', '-24', 'header', '0', '0', '', '', '8', ''),
('1274', 'user', 'login', 'theme822', '0', '-15', '-1', '0', '0', '', '', '-1', ''),
('1275', 'user', 'new', 'theme822', '0', '-13', '-1', '0', '0', '', '', '1', ''),
('1276', 'user', 'online', 'theme822', '0', '-11', '-1', '0', '0', '', '', '-1', ''),
('1277', 'views', 'archive-block', 'theme822', '0', '6', '-1', '0', '0', '', '', '-1', ''),
('1278', 'views', 'areas_of_practice-block', 'theme822', '1', '-18', 'content', '0', '1', '<front>', '', '-1', 'grid-4 omega title-list-block'),
('1279', 'views', 'Carousel-block', 'theme822', '1', '-16', 'header_bottom', '0', '1', 'node', '<none>', '-1', ''),
('1280', 'views', 'categories-block', 'theme822', '1', '-18', 'sidebar_second_narrow', '0', '1', 'blog\r\nblog/*\r\nnode/*', '', '-1', ''),
('1281', 'views', 'comments_recent-block', 'theme822', '0', '9', '-1', '0', '0', '', '', '-1', ''),
('1282', 'views', 'faq-faq_random', 'theme822', '0', '-8', '-1', '0', '0', '', '', '-1', ''),
('1283', 'views', 'faq-faq_recent', 'theme822', '0', '-6', '-1', '0', '0', '', '', '-1', ''),
('1284', 'views', 'latest_news-block', 'theme822', '1', '-19', 'content', '0', '1', '<front>', '', '-1', 'grid-4 news-block'),
('1285', 'views', 'our_team-block', 'theme822', '0', '8', '-1', '0', '0', '', '', '-1', ''),
('1286', 'views', 'popular_services-block', 'theme822', '1', '-17', 'content', '0', '1', 'services', '', '-1', 'block-container'),
('1287', 'views', 'portfolio_filter-block', 'theme822', '0', '0', '-1', '0', '0', '', '', '-1', ''),
('1288', 'views', 'services-block', 'theme822', '1', '0', 'header_bottom', '0', '1', '<front>', '', '-1', 'service-block'),
('1289', 'views', 'sldier-block', 'theme822', '1', '-17', 'header', '0', '1', 'node', '<none>', '-1', ''),
('1290', 'views', 'slider-block', 'theme822', '1', '0', 'header', '0', '1', '<front>', '', '-1', 'slider-wide'),
('1291', 'views', 'testimonials-block', 'theme822', '1', '-21', 'content', '0', '1', '<front>', '', '-1', 'grid-4 alpha testimonials-wrap');
/*!40000 ALTER TABLE block ENABLE KEYS */;

--
-- Table structure for table 'block_custom'
--

CREATE TABLE IF NOT EXISTS `block_custom` (
  `bid` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'The block’s block.bid.',
  `body` longtext COMMENT 'Block contents.',
  `info` varchar(128) NOT NULL DEFAULT '' COMMENT 'Block description.',
  `format` varchar(255) DEFAULT NULL COMMENT 'The filter_format.format of the block body.',
  PRIMARY KEY (`bid`),
  UNIQUE KEY `info` (`info`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores contents of custom-made blocks.';

--
-- Dumping data for table 'block_custom'
--

/*!40000 ALTER TABLE block_custom DISABLE KEYS */;
INSERT INTO `block_custom` VALUES
('1', '[gmap markers=blue::41.902277040963696,-87.6708984375 |zoom=16 |center=41.902277040963696,-87.6708984375 |width=280px |height=200px |control=Small |type=Map]\r\n<br />\r\nThe Company Name Inc.<br />\r\n8901 Marmora Road, Glasgow, D04 89GR.<br />\r\n<br />\r\nFreephone:           +1 800 559 6580<br />\r\nTelephone:          +1 800 603 6035<br />\r\nFAX:                         +1 800 889 9898 <br />\r\nE-mail: <a href="#">mail@demolink.org</a>', 'Our Location', 'gmap'),
('5', '<span><?php $site_name =  variable_get(''site_name'', ''Drupal''); print $site_name; ?></span> &copy; <?php echo date(''Y'') ?> | <a href="?q=node/79">Privacy Policy</a>', 'Footer-text', 'php_code'),
('6', '<div>Give Us A Call: <span>+1 800 567 45 56</span></div>', 'Header top', 'full_html');
/*!40000 ALTER TABLE block_custom ENABLE KEYS */;

--
-- Table structure for table 'block_node_type'
--

CREATE TABLE IF NOT EXISTS `block_node_type` (
  `module` varchar(64) NOT NULL COMMENT 'The block’s origin module, from block.module.',
  `delta` varchar(32) NOT NULL COMMENT 'The block’s unique delta within module, from block.delta.',
  `type` varchar(32) NOT NULL COMMENT 'The machine-readable name of this type from node_type.type.',
  PRIMARY KEY (`module`,`delta`,`type`),
  KEY `type` (`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Sets up display criteria for blocks based on content types';

--
-- Dumping data for table 'block_node_type'
--

/*!40000 ALTER TABLE block_node_type DISABLE KEYS */;
/*!40000 ALTER TABLE block_node_type ENABLE KEYS */;

--
-- Table structure for table 'block_role'
--

CREATE TABLE IF NOT EXISTS `block_role` (
  `module` varchar(64) NOT NULL COMMENT 'The block’s origin module, from block.module.',
  `delta` varchar(32) NOT NULL COMMENT 'The block’s unique delta within module, from block.delta.',
  `rid` int(10) unsigned NOT NULL COMMENT 'The user’s role ID from users_roles.rid.',
  PRIMARY KEY (`module`,`delta`,`rid`),
  KEY `rid` (`rid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Sets up access permissions for blocks based on user roles';

--
-- Dumping data for table 'block_role'
--

/*!40000 ALTER TABLE block_role DISABLE KEYS */;
/*!40000 ALTER TABLE block_role ENABLE KEYS */;

--
-- Table structure for table 'blocked_ips'
--

CREATE TABLE IF NOT EXISTS `blocked_ips` (
  `iid` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: unique ID for IP addresses.',
  `ip` varchar(40) NOT NULL DEFAULT '' COMMENT 'IP address',
  PRIMARY KEY (`iid`),
  KEY `blocked_ip` (`ip`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores blocked IP addresses.';

--
-- Dumping data for table 'blocked_ips'
--

/*!40000 ALTER TABLE blocked_ips DISABLE KEYS */;
/*!40000 ALTER TABLE blocked_ips ENABLE KEYS */;

--
-- Table structure for table 'book'
--

CREATE TABLE IF NOT EXISTS `book` (
  `mlid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The book page’s menu_links.mlid.',
  `nid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The book page’s node.nid.',
  `bid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The book ID is the book.nid of the top-level page.',
  PRIMARY KEY (`mlid`),
  UNIQUE KEY `nid` (`nid`),
  KEY `bid` (`bid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores book outline information. Uniquely connects each...';

--
-- Dumping data for table 'book'
--

/*!40000 ALTER TABLE book DISABLE KEYS */;
/*!40000 ALTER TABLE book ENABLE KEYS */;

--
-- Table structure for table 'cache'
--

CREATE TABLE IF NOT EXISTS `cache` (
  `cid` varchar(255) NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or 0 for never.',
  `created` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry was created.',
  `serialized` smallint(6) NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Generic cache table for caching things not separated out...';

--
-- Table structure for table 'cache_admin_menu'
--

CREATE TABLE IF NOT EXISTS `cache_admin_menu` (
  `cid` varchar(255) NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or 0 for never.',
  `created` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry was created.',
  `serialized` smallint(6) NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Cache table for Administration menu to store client-side...';

--
-- Table structure for table 'cache_block'
--

CREATE TABLE IF NOT EXISTS `cache_block` (
  `cid` varchar(255) NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or 0 for never.',
  `created` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry was created.',
  `serialized` smallint(6) NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Cache table for the Block module to store already built...';

--
-- Table structure for table 'cache_bootstrap'
--

CREATE TABLE IF NOT EXISTS `cache_bootstrap` (
  `cid` varchar(255) NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or 0 for never.',
  `created` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry was created.',
  `serialized` smallint(6) NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Cache table for data required to bootstrap Drupal, may be...';

--
-- Table structure for table 'cache_field'
--

CREATE TABLE IF NOT EXISTS `cache_field` (
  `cid` varchar(255) NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or 0 for never.',
  `created` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry was created.',
  `serialized` smallint(6) NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Generic cache table for caching things not separated out...';

--
-- Table structure for table 'cache_filter'
--

CREATE TABLE IF NOT EXISTS `cache_filter` (
  `cid` varchar(255) NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or 0 for never.',
  `created` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry was created.',
  `serialized` smallint(6) NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Cache table for the Filter module to store already...';

--
-- Table structure for table 'cache_form'
--

CREATE TABLE IF NOT EXISTS `cache_form` (
  `cid` varchar(255) NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or 0 for never.',
  `created` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry was created.',
  `serialized` smallint(6) NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Cache table for the form system to store recently built...';

--
-- Table structure for table 'cache_image'
--

CREATE TABLE IF NOT EXISTS `cache_image` (
  `cid` varchar(255) NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or 0 for never.',
  `created` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry was created.',
  `serialized` smallint(6) NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Cache table used to store information about image...';

--
-- Dumping data for table 'cache_image'
--

/*!40000 ALTER TABLE cache_image DISABLE KEYS */;
/*!40000 ALTER TABLE cache_image ENABLE KEYS */;

--
-- Table structure for table 'cache_libraries'
--

CREATE TABLE IF NOT EXISTS `cache_libraries` (
  `cid` varchar(255) NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or 0 for never.',
  `created` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry was created.',
  `serialized` smallint(6) NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Cache table to store library information.';

--
-- Dumping data for table 'cache_libraries'
--

/*!40000 ALTER TABLE cache_libraries DISABLE KEYS */;
INSERT INTO `cache_libraries` VALUES
('colorbox', 'a:17:{s:4:"name";s:15:"Colorbox plugin";s:10:"vendor url";s:34:"http://www.jacklmoore.com/colorbox";s:12:"download url";s:34:"http://www.jacklmoore.com/colorbox";s:17:"version arguments";a:3:{s:4:"file";s:22:"jquery.colorbox-min.js";s:7:"pattern";s:30:"@(?i:Colorbox) v([0-9\\.a-z]+)@";s:5:"lines";i:5;}s:5:"files";a:1:{s:2:"js";a:1:{s:22:"jquery.colorbox-min.js";a:0:{}}}s:8:"variants";a:2:{s:8:"minified";a:2:{s:5:"files";a:1:{s:2:"js";a:1:{s:22:"jquery.colorbox-min.js";a:0:{}}}s:9:"installed";b:1;}s:6:"source";a:2:{s:5:"files";a:1:{s:2:"js";a:1:{s:18:"jquery.colorbox.js";a:0:{}}}s:9:"installed";b:1;}}s:6:"module";s:8:"colorbox";s:12:"machine name";s:8:"colorbox";s:4:"path";s:0:"";s:12:"library path";s:28:"sites/all/libraries/colorbox";s:16:"version callback";s:21:"libraries_get_version";s:12:"dependencies";a:0:{}s:8:"versions";a:0:{}s:17:"integration files";a:0:{}s:9:"callbacks";a:6:{s:4:"info";a:1:{i:0;s:23:"libraries_prepare_files";}s:10:"pre-detect";a:0:{}s:11:"post-detect";a:1:{i:0;s:29:"libraries_detect_dependencies";}s:21:"pre-dependencies-load";a:0:{}s:8:"pre-load";a:0:{}s:9:"post-load";a:0:{}}s:9:"installed";b:1;s:7:"version";s:6:"1.4.26";}', '0', '1379068589', 1),
('easing', 'a:17:{s:4:"name";s:13:"jQuery Easing";s:10:"vendor url";s:40:"http://gsgd.co.uk/sandbox/jquery/easing/";s:12:"download url";s:40:"http://gsgd.co.uk/sandbox/jquery/easing/";s:17:"version arguments";a:2:{s:4:"file";s:16:"jquery.easing.js";s:7:"pattern";s:32:"/jQuery\\s+Easing\\s+v?([0-9\\.]+)/";}s:5:"files";a:1:{s:2:"js";a:1:{s:16:"jquery.easing.js";a:0:{}}}s:6:"module";s:8:"jqeasing";s:12:"machine name";s:6:"easing";s:4:"path";s:0:"";s:12:"library path";s:26:"sites/all/libraries/easing";s:16:"version callback";s:21:"libraries_get_version";s:12:"dependencies";a:0:{}s:8:"variants";a:0:{}s:8:"versions";a:0:{}s:17:"integration files";a:0:{}s:9:"callbacks";a:6:{s:4:"info";a:1:{i:0;s:23:"libraries_prepare_files";}s:10:"pre-detect";a:0:{}s:11:"post-detect";a:1:{i:0;s:29:"libraries_detect_dependencies";}s:21:"pre-dependencies-load";a:0:{}s:8:"pre-load";a:0:{}s:9:"post-load";a:0:{}}s:9:"installed";b:1;s:7:"version";s:3:"1.3";}', '0', '1379068589', 1),
('flexslider', 'a:17:{s:4:"name";s:10:"FlexSlider";s:10:"vendor url";s:36:"http://www.woothemes.com/flexslider/";s:12:"download url";s:39:"https://github.com/woothemes/FlexSlider";s:17:"version arguments";a:3:{s:4:"file";s:24:"jquery.flexslider-min.js";s:7:"pattern";s:32:"/jQuery FlexSlider v(\\d+\\.+\\d+)/";s:5:"lines";i:2;}s:5:"files";a:2:{s:2:"js";a:1:{s:24:"jquery.flexslider-min.js";a:0:{}}s:3:"css";a:1:{s:14:"flexslider.css";a:0:{}}}s:17:"integration files";a:1:{s:10:"flexslider";a:1:{s:3:"css";a:1:{s:29:"assets/css/flexslider_img.css";a:0:{}}}}s:6:"module";s:10:"flexslider";s:12:"machine name";s:10:"flexslider";s:4:"path";s:0:"";s:12:"library path";s:30:"sites/all/libraries/flexslider";s:16:"version callback";s:21:"libraries_get_version";s:12:"dependencies";a:1:{i:0;s:6:"easing";}s:8:"variants";a:0:{}s:8:"versions";a:0:{}s:9:"callbacks";a:6:{s:4:"info";a:1:{i:0;s:23:"libraries_prepare_files";}s:10:"pre-detect";a:0:{}s:11:"post-detect";a:1:{i:0;s:29:"libraries_detect_dependencies";}s:21:"pre-dependencies-load";a:0:{}s:8:"pre-load";a:0:{}s:9:"post-load";a:0:{}}s:9:"installed";b:1;s:7:"version";s:3:"2.1";}', '0', '1379068589', 1);
/*!40000 ALTER TABLE cache_libraries ENABLE KEYS */;

--
-- Table structure for table 'cache_menu'
--

CREATE TABLE IF NOT EXISTS `cache_menu` (
  `cid` varchar(255) NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or 0 for never.',
  `created` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry was created.',
  `serialized` smallint(6) NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Cache table for the menu system to store router...';

--
-- Table structure for table 'cache_page'
--

CREATE TABLE IF NOT EXISTS `cache_page` (
  `cid` varchar(255) NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or 0 for never.',
  `created` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry was created.',
  `serialized` smallint(6) NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Cache table used to store compressed pages for anonymous...';

--
-- Table structure for table 'cache_path'
--

CREATE TABLE IF NOT EXISTS `cache_path` (
  `cid` varchar(255) NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or 0 for never.',
  `created` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry was created.',
  `serialized` smallint(6) NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Cache table for path alias lookup.';

--
-- Table structure for table 'cache_update'
--

CREATE TABLE IF NOT EXISTS `cache_update` (
  `cid` varchar(255) NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or 0 for never.',
  `created` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry was created.',
  `serialized` smallint(6) NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Cache table for the Update module to store information...';

--
-- Table structure for table 'cache_views'
--

CREATE TABLE IF NOT EXISTS `cache_views` (
  `cid` varchar(255) NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or 0 for never.',
  `created` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry was created.',
  `serialized` smallint(6) NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Generic cache table for caching things not separated out...';

--
-- Table structure for table 'cache_views_data'
--

CREATE TABLE IF NOT EXISTS `cache_views_data` (
  `cid` varchar(255) NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or 0 for never.',
  `created` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry was created.',
  `serialized` smallint(6) NOT NULL DEFAULT '1' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Cache table for views to store pre-rendered queries,...';

--
-- Table structure for table 'comment'
--

CREATE TABLE IF NOT EXISTS `comment` (
  `cid` int(11) NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique comment ID.',
  `pid` int(11) NOT NULL DEFAULT '0' COMMENT 'The comment.cid to which this comment is a reply. If set to 0, this comment is not a reply to an existing comment.',
  `nid` int(11) NOT NULL DEFAULT '0' COMMENT 'The node.nid to which this comment is a reply.',
  `uid` int(11) NOT NULL DEFAULT '0' COMMENT 'The users.uid who authored the comment. If set to 0, this comment was created by an anonymous user.',
  `subject` varchar(64) NOT NULL DEFAULT '' COMMENT 'The comment title.',
  `hostname` varchar(128) NOT NULL DEFAULT '' COMMENT 'The author’s host name.',
  `created` int(11) NOT NULL DEFAULT '0' COMMENT 'The time that the comment was created, as a Unix timestamp.',
  `changed` int(11) NOT NULL DEFAULT '0' COMMENT 'The time that the comment was last edited, as a Unix timestamp.',
  `status` tinyint(3) unsigned NOT NULL DEFAULT '1',
  `thread` varchar(255) NOT NULL COMMENT 'The vancode representation of the comment’s place in a thread.',
  `name` varchar(60) DEFAULT NULL COMMENT 'The comment author’s name. Uses users.name if the user is logged in, otherwise uses the value typed into the comment form.',
  `mail` varchar(64) DEFAULT NULL COMMENT 'The comment author’s e-mail address from the comment form, if user is anonymous, and the ’Anonymous users may/must leave their contact information’ setting is turned on.',
  `homepage` varchar(255) DEFAULT NULL COMMENT 'The comment author’s home page address from the comment form, if user is anonymous, and the ’Anonymous users may/must leave their contact information’ setting is turned on.',
  `language` varchar(12) NOT NULL DEFAULT '' COMMENT 'The languages.language of this comment.',
  PRIMARY KEY (`cid`),
  KEY `comment_num_new` (`nid`,`status`,`created`,`cid`,`thread`),
  KEY `comment_uid` (`uid`),
  KEY `comment_nid_language` (`nid`,`language`),
  KEY `comment_created` (`created`),
  KEY `comment_status_pid` (`pid`,`status`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores comments and associated data.';

--
-- Dumping data for table 'comment'
--

/*!40000 ALTER TABLE comment DISABLE KEYS */;
INSERT INTO `comment` VALUES
('1', '0', '12', '1', 'Fusce porttitor porta tortor', '192.168.9.7', '1305117336', '1305117335', '1', '01/', 'admin', '', '', 'und'),
('2', '0', '12', '1', 'Suspendisse potenti. Fusce', '192.168.9.7', '1305117342', '1305117342', '1', '02/', 'admin', '', '', 'und'),
('3', '2', '12', '1', 'Lorem ipsum dolor sit amet,', '192.168.9.7', '1305117353', '1305117353', '1', '02.00/', 'admin', '', '', 'und'),
('4', '0', '13', '1', 'Quisque nec libero eu urna', '192.168.9.7', '1305117437', '1305117437', '1', '01/', 'admin', '', '', 'und'),
('5', '0', '14', '1', 'Etiam ornare, tellus quis', '192.168.9.7', '1305117499', '1305117499', '1', '01/', 'admin', '', '', 'und'),
('6', '0', '14', '1', 'Fusce gravida consectetur mi', '192.168.9.7', '1305117505', '1305117505', '1', '02/', 'admin', '', '', 'und'),
('7', '6', '14', '1', 'Lorem ipsum dolor sit amet,', '192.168.9.7', '1305117512', '1305117512', '1', '02.00/', 'admin', '', '', 'und'),
('8', '7', '14', '1', 'Etiam ornare, tellus quis', '192.168.9.7', '1305117521', '1305117521', '1', '02.00.00/', 'admin', '', '', 'und'),
('9', '0', '14', '1', 'Sed ornare ipsum id libero', '192.168.9.7', '1305117530', '1305117530', '1', '03/', 'admin', '', '', 'und'),
('10', '0', '16', '1', 'Suspendisse convallis, risus', '192.168.9.7', '1305117597', '1305117597', '1', '01/', 'admin', '', '', 'und'),
('11', '0', '16', '1', 'Cum sociis natoque penatibus', '192.168.9.7', '1305117601', '1305117601', '1', '02/', 'admin', '', '', 'und'),
('13', '0', '36', '1', 'Aliquam laoreet neque non', '192.168.9.1', '1316531580', '1316532211', '1', '01/', 'admin', '', '', 'und'),
('14', '0', '36', '1', 'Suspendisse semper, velit a', '192.168.9.1', '1316531580', '1316532222', '1', '02/', 'admin', '', '', 'und'),
('15', '14', '36', '1', 'Aenean fermentum justo id', '192.168.9.1', '1316531580', '1316532236', '1', '02.00/', 'admin', '', '', 'und'),
('16', '0', '41', '1', 'Lorem ipsum dolor', '127.0.0.1', '1374076609', '1374076608', '1', '01/', 'admin', '', '', 'und');
/*!40000 ALTER TABLE comment ENABLE KEYS */;

--
-- Table structure for table 'contact'
--

CREATE TABLE IF NOT EXISTS `contact` (
  `cid` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique category ID.',
  `category` varchar(255) NOT NULL DEFAULT '' COMMENT 'Category name.',
  `recipients` longtext NOT NULL COMMENT 'Comma-separated list of recipient e-mail addresses.',
  `reply` longtext NOT NULL COMMENT 'Text of the auto-reply message.',
  `weight` int(11) NOT NULL DEFAULT '0' COMMENT 'The category’s weight.',
  `selected` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'Flag to indicate whether or not category is selected by default. (1 = Yes, 0 = No)',
  PRIMARY KEY (`cid`),
  UNIQUE KEY `category` (`category`),
  KEY `list` (`weight`,`category`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Contact form category settings.';

--
-- Dumping data for table 'contact'
--

/*!40000 ALTER TABLE contact DISABLE KEYS */;
INSERT INTO `contact` VALUES
('1', 'Website feedback', 'admin@admin.com', '', '0', '1');
/*!40000 ALTER TABLE contact ENABLE KEYS */;

--
-- Table structure for table 'ctools_css_cache'
--

CREATE TABLE IF NOT EXISTS `ctools_css_cache` (
  `cid` varchar(128) NOT NULL COMMENT 'The CSS ID this cache object belongs to.',
  `filename` varchar(255) DEFAULT NULL COMMENT 'The filename this CSS is stored in.',
  `css` longtext COMMENT 'CSS being stored.',
  `filter` tinyint(4) DEFAULT NULL COMMENT 'Whether or not this CSS needs to be filtered.',
  PRIMARY KEY (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='A special cache used to store CSS that must be non-volatile.';

--
-- Dumping data for table 'ctools_css_cache'
--

/*!40000 ALTER TABLE ctools_css_cache DISABLE KEYS */;
INSERT INTO `ctools_css_cache` VALUES
('flexiblev2:1', 'public://ctools/css/15cc8ccb9dac3ada75f377bde14d47dd.css', '.panels-flexible-region {\n  padding: 0;\n}\n\n.panels-flexible-region-inside {\n  padding-right: 0.5em;\n  padding-left: 0.5em;\n}\n\n.panels-flexible-region-inside-first {\n  padding-left: 0;\n}\n\n.panels-flexible-region-inside-last {\n  padding-right: 0;\n}\n\n.panels-flexible-column {\n  padding: 0;\n}\n\n.panels-flexible-column-inside {\n  padding-right: 0.5em;\n  padding-left: 0.5em;\n}\n\n.panels-flexible-column-inside-first {\n  padding-left: 0;\n}\n\n.panels-flexible-column-inside-last {\n  padding-right: 0;\n}\n\n.panels-flexible-row {\n  padding: 0 0 0.5em 0;\n  margin: 0;\n}\n\n.panels-flexible-row-last {\n  padding-bottom: 0;\n}\n\n.panels-flexible-column-1-main {\n  float: left;\n  width: 99.0000%;\n}\n\n.panels-flexible-1-inside {\n  padding-right: 0px;\n}\n\n.panels-flexible-1 {\n  width: auto;\n}\n\n.panels-flexible-region-1-center {\n  float: left;\n  width: 99.0000%;\n}\n\n.panels-flexible-row-1-main-row-inside {\n  padding-right: 0px;\n}\n\n.panels-flexible-region-1-contacts_region {\n  float: left;\n  width: 99.0000%;\n}\n\n.panels-flexible-row-1-1-inside {\n  padding-right: 0px;\n}\n\n', '0'),
('flexiblev2:4', 'public://ctools/css/c420a22ab2386d788d654ef520400902.css', '.panels-flexible-region {\n  padding: 0;\n}\n\n.panels-flexible-region-inside {\n  padding-right: 0.5em;\n  padding-left: 0.5em;\n}\n\n.panels-flexible-region-inside-first {\n  padding-left: 0;\n}\n\n.panels-flexible-region-inside-last {\n  padding-right: 0;\n}\n\n.panels-flexible-column {\n  padding: 0;\n}\n\n.panels-flexible-column-inside {\n  padding-right: 0.5em;\n  padding-left: 0.5em;\n}\n\n.panels-flexible-column-inside-first {\n  padding-left: 0;\n}\n\n.panels-flexible-column-inside-last {\n  padding-right: 0;\n}\n\n.panels-flexible-row {\n  padding: 0 0 0.5em 0;\n  margin: 0;\n}\n\n.panels-flexible-row-last {\n  padding-bottom: 0;\n}\n\n.panels-flexible-column-4-main {\n  float: left;\n  width: 100.0000%;\n}\n\n.panels-flexible-4-inside {\n  padding-right: 0px;\n}\n\n.panels-flexible-4 {\n  width: auto;\n}\n\n.panels-flexible-region-4-center {\n  float: left;\n  width: 100.0000%;\n}\n\n.panels-flexible-row-4-main-row-inside {\n  padding-right: 0px;\n}\n\n', '0');
/*!40000 ALTER TABLE ctools_css_cache ENABLE KEYS */;

--
-- Table structure for table 'ctools_object_cache'
--

CREATE TABLE IF NOT EXISTS `ctools_object_cache` (
  `sid` varchar(64) NOT NULL COMMENT 'The session ID this cache object belongs to.',
  `name` varchar(128) NOT NULL COMMENT 'The name of the object this cache is attached to.',
  `obj` varchar(32) NOT NULL COMMENT 'The type of the object this cache is attached to; this essentially represents the owner so that several sub-systems can use this cache.',
  `updated` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The time this cache was created or updated.',
  `data` longblob COMMENT 'Serialized data being stored.',
  PRIMARY KEY (`sid`,`obj`,`name`),
  KEY `updated` (`updated`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='A special cache used to store objects that are being...';

--
-- Table structure for table 'date_format_locale'
--

CREATE TABLE IF NOT EXISTS `date_format_locale` (
  `format` varchar(100) NOT NULL COMMENT 'The date format string.',
  `type` varchar(64) NOT NULL COMMENT 'The date format type, e.g. medium.',
  `language` varchar(12) NOT NULL COMMENT 'A languages.language for this format to be used with.',
  PRIMARY KEY (`type`,`language`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores configured date formats for each locale.';

--
-- Dumping data for table 'date_format_locale'
--

/*!40000 ALTER TABLE date_format_locale DISABLE KEYS */;
/*!40000 ALTER TABLE date_format_locale ENABLE KEYS */;

--
-- Table structure for table 'date_format_type'
--

CREATE TABLE IF NOT EXISTS `date_format_type` (
  `type` varchar(64) NOT NULL COMMENT 'The date format type, e.g. medium.',
  `title` varchar(255) NOT NULL COMMENT 'The human readable name of the format type.',
  `locked` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'Whether or not this is a system provided format.',
  PRIMARY KEY (`type`),
  KEY `title` (`title`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores configured date format types.';

--
-- Dumping data for table 'date_format_type'
--

/*!40000 ALTER TABLE date_format_type DISABLE KEYS */;
INSERT INTO `date_format_type` VALUES
('long', 'Long', '1'),
('medium', 'Medium', '1'),
('short', 'Short', '1');
/*!40000 ALTER TABLE date_format_type ENABLE KEYS */;

--
-- Table structure for table 'date_formats'
--

CREATE TABLE IF NOT EXISTS `date_formats` (
  `dfid` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'The date format identifier.',
  `format` varchar(100) CHARACTER SET utf8 COLLATE utf8_bin NOT NULL COMMENT 'The date format string.',
  `type` varchar(64) NOT NULL COMMENT 'The date format type, e.g. medium.',
  `locked` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'Whether or not this format can be modified.',
  PRIMARY KEY (`dfid`),
  UNIQUE KEY `formats` (`format`,`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores configured date formats.';

--
-- Dumping data for table 'date_formats'
--

/*!40000 ALTER TABLE date_formats DISABLE KEYS */;
INSERT INTO `date_formats` VALUES
('1', 'Y-m-d H:i', 'short', '1'),
('2', 'm/d/Y - H:i', 'short', '1'),
('3', 'd/m/Y - H:i', 'short', '1'),
('4', 'Y/m/d - H:i', 'short', '1'),
('5', 'd.m.Y - H:i', 'short', '1'),
('6', 'm/d/Y - g:ia', 'short', '1'),
('7', 'd/m/Y - g:ia', 'short', '1'),
('8', 'Y/m/d - g:ia', 'short', '1'),
('9', 'M j Y - H:i', 'short', '1'),
('10', 'j M Y - H:i', 'short', '1'),
('11', 'Y M j - H:i', 'short', '1'),
('12', 'M j Y - g:ia', 'short', '1'),
('13', 'j M Y - g:ia', 'short', '1'),
('14', 'Y M j - g:ia', 'short', '1'),
('15', 'D, Y-m-d H:i', 'medium', '1'),
('16', 'D, m/d/Y - H:i', 'medium', '1'),
('17', 'D, d/m/Y - H:i', 'medium', '1'),
('18', 'D, Y/m/d - H:i', 'medium', '1'),
('19', 'F j, Y - H:i', 'medium', '1'),
('20', 'j F, Y - H:i', 'medium', '1'),
('21', 'Y, F j - H:i', 'medium', '1'),
('22', 'D, m/d/Y - g:ia', 'medium', '1'),
('23', 'D, d/m/Y - g:ia', 'medium', '1'),
('24', 'D, Y/m/d - g:ia', 'medium', '1'),
('25', 'F j, Y - g:ia', 'medium', '1'),
('26', 'j F Y - g:ia', 'medium', '1'),
('27', 'Y, F j - g:ia', 'medium', '1'),
('28', 'j. F Y - G:i', 'medium', '1'),
('29', 'l, F j, Y - H:i', 'long', '1'),
('30', 'l, j F, Y - H:i', 'long', '1'),
('31', 'l, Y,  F j - H:i', 'long', '1'),
('32', 'l, F j, Y - g:ia', 'long', '1'),
('33', 'l, j F Y - g:ia', 'long', '1'),
('34', 'l, Y,  F j - g:ia', 'long', '1'),
('35', 'l, j. F Y - G:i', 'long', '1');
/*!40000 ALTER TABLE date_formats ENABLE KEYS */;

--
-- Table structure for table 'faq_questions'
--

CREATE TABLE IF NOT EXISTS `faq_questions` (
  `nid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The primary identifier for a node.',
  `vid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The primary identifier for a node revision.',
  `question` text NOT NULL COMMENT 'The faq short question text.',
  `detailed_question` text,
  PRIMARY KEY (`nid`,`vid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='A table containing the long question text of each faq...';

--
-- Dumping data for table 'faq_questions'
--

/*!40000 ALTER TABLE faq_questions DISABLE KEYS */;
INSERT INTO `faq_questions` VALUES
('42', '42', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit?', ''),
('43', '43', 'Phasellus non dui magna, sit amet elementum lectus. Nullam ipsum ipsum, bibendum id mollis a, malesuada sit amet turpis?', ''),
('44', '44', 'Nunc commodo nisi ultricies nulla convallis et facilisis enim cursus. Ut purus ligula, consequat a posuere at, ultricies in quam?', ''),
('45', '45', 'Aliquam erat volutpat. Phasellus ac est velit. Proin sit amet urna dui, sed volutpat orci. Nam molestie viverra eros, eu lacinia nunc facilisis sed?', ''),
('46', '46', 'Sed vitae orci enim, ut accumsan sem. Donec orci risus, porta in tempor a, blandit ut risus. Donec vitae velit neque, nec adipiscing ipsum?', '');
/*!40000 ALTER TABLE faq_questions ENABLE KEYS */;

--
-- Table structure for table 'faq_weights'
--

CREATE TABLE IF NOT EXISTS `faq_weights` (
  `tid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The primary identifier for a term or category.  This will be 0 for non-categorized nodes.',
  `nid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The primary identifier for a node.',
  `weight` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A number representing the weight of a node.  Nodes with lower weight values will appear above those with higher weight values.',
  PRIMARY KEY (`nid`,`tid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='A table containing the weight of each faq node by category.';

--
-- Dumping data for table 'faq_weights'
--

/*!40000 ALTER TABLE faq_weights DISABLE KEYS */;
/*!40000 ALTER TABLE faq_weights ENABLE KEYS */;

--
-- Table structure for table 'field_config'
--

CREATE TABLE IF NOT EXISTS `field_config` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'The primary identifier for a field',
  `field_name` varchar(32) NOT NULL COMMENT 'The name of this field. Non-deleted field names are unique, but multiple deleted fields can have the same name.',
  `type` varchar(128) NOT NULL COMMENT 'The type of this field.',
  `module` varchar(128) NOT NULL DEFAULT '' COMMENT 'The module that implements the field type.',
  `active` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether the module that implements the field type is enabled.',
  `storage_type` varchar(128) NOT NULL COMMENT 'The storage backend for the field.',
  `storage_module` varchar(128) NOT NULL DEFAULT '' COMMENT 'The module that implements the storage backend.',
  `storage_active` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether the module that implements the storage backend is enabled.',
  `locked` tinyint(4) NOT NULL DEFAULT '0' COMMENT '@TODO',
  `data` longblob NOT NULL COMMENT 'Serialized data containing the field properties that do not warrant a dedicated column.',
  `cardinality` tinyint(4) NOT NULL DEFAULT '0',
  `translatable` tinyint(4) NOT NULL DEFAULT '0',
  `deleted` tinyint(4) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  KEY `field_name` (`field_name`),
  KEY `active` (`active`),
  KEY `storage_active` (`storage_active`),
  KEY `deleted` (`deleted`),
  KEY `module` (`module`),
  KEY `storage_module` (`storage_module`),
  KEY `type` (`type`),
  KEY `storage_type` (`storage_type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='InnoDB free: 7168 kB';

--
-- Dumping data for table 'field_config'
--

/*!40000 ALTER TABLE field_config DISABLE KEYS */;
INSERT INTO `field_config` VALUES
('1', 'comment_body', 'text_long', 'text', '1', 'field_sql_storage', 'field_sql_storage', '1', '0', 'a:6:{s:12:"entity_types";a:1:{i:0;s:7:"comment";}s:12:"translatable";b:0;s:8:"settings";a:0:{}s:7:"storage";a:4:{s:4:"type";s:17:"field_sql_storage";s:8:"settings";a:0:{}s:6:"module";s:17:"field_sql_storage";s:6:"active";i:1;}s:12:"foreign keys";a:1:{s:6:"format";a:2:{s:5:"table";s:13:"filter_format";s:7:"columns";a:1:{s:6:"format";s:6:"format";}}}s:7:"indexes";a:1:{s:6:"format";a:1:{i:0;s:6:"format";}}}', '1', '0', '0'),
('2', 'body', 'text_with_summary', 'text', '1', 'field_sql_storage', 'field_sql_storage', '1', '0', 'a:6:{s:12:"entity_types";a:1:{i:0;s:4:"node";}s:12:"translatable";b:1;s:8:"settings";a:0:{}s:7:"storage";a:4:{s:4:"type";s:17:"field_sql_storage";s:8:"settings";a:0:{}s:6:"module";s:17:"field_sql_storage";s:6:"active";i:1;}s:12:"foreign keys";a:1:{s:6:"format";a:2:{s:5:"table";s:13:"filter_format";s:7:"columns";a:1:{s:6:"format";s:6:"format";}}}s:7:"indexes";a:1:{s:6:"format";a:1:{i:0;s:6:"format";}}}', '1', '1', '0'),
('3', 'field_tags', 'taxonomy_term_reference', 'taxonomy', '1', 'field_sql_storage', 'field_sql_storage', '1', '0', 'a:6:{s:8:"settings";a:1:{s:14:"allowed_values";a:1:{i:0;a:2:{s:10:"vocabulary";s:4:"tags";s:6:"parent";i:0;}}}s:12:"entity_types";a:0:{}s:12:"translatable";b:0;s:7:"storage";a:4:{s:4:"type";s:17:"field_sql_storage";s:8:"settings";a:0:{}s:6:"module";s:17:"field_sql_storage";s:6:"active";i:1;}s:12:"foreign keys";a:1:{s:3:"tid";a:2:{s:5:"table";s:18:"taxonomy_term_data";s:7:"columns";a:1:{s:3:"tid";s:3:"tid";}}}s:7:"indexes";a:1:{s:3:"tid";a:1:{i:0;s:3:"tid";}}}', '-1', '0', '0'),
('4', 'field_image', 'image', 'image', '1', 'field_sql_storage', 'field_sql_storage', '1', '0', 'a:6:{s:12:"translatable";b:1;s:7:"indexes";a:1:{s:3:"fid";a:1:{i:0;s:3:"fid";}}s:8:"settings";a:2:{s:10:"uri_scheme";s:6:"public";s:13:"default_image";b:0;}s:7:"storage";a:4:{s:4:"type";s:17:"field_sql_storage";s:8:"settings";a:0:{}s:6:"module";s:17:"field_sql_storage";s:6:"active";i:1;}s:12:"entity_types";a:0:{}s:12:"foreign keys";a:1:{s:3:"fid";a:2:{s:5:"table";s:12:"file_managed";s:7:"columns";a:1:{s:3:"fid";s:3:"fid";}}}}', '1', '1', '0'),
('5', 'taxonomy_forums', 'taxonomy_term_reference', 'taxonomy', '1', 'field_sql_storage', 'field_sql_storage', '1', '0', 'a:6:{s:8:"settings";a:1:{s:14:"allowed_values";a:1:{i:0;a:2:{s:10:"vocabulary";s:6:"forums";s:6:"parent";i:0;}}}s:12:"entity_types";a:0:{}s:12:"translatable";b:0;s:7:"storage";a:4:{s:4:"type";s:17:"field_sql_storage";s:8:"settings";a:0:{}s:6:"module";s:17:"field_sql_storage";s:6:"active";i:1;}s:12:"foreign keys";a:1:{s:3:"tid";a:2:{s:5:"table";s:18:"taxonomy_term_data";s:7:"columns";a:1:{s:3:"tid";s:3:"tid";}}}s:7:"indexes";a:1:{s:3:"tid";a:1:{i:0;s:3:"tid";}}}', '1', '0', '0'),
('6', 'field_blog_image', 'image', 'image', '1', 'field_sql_storage', 'field_sql_storage', '1', '0', 'a:7:{s:12:"translatable";s:1:"1";s:12:"entity_types";a:0:{}s:8:"settings";a:2:{s:10:"uri_scheme";s:6:"public";s:13:"default_image";i:0;}s:7:"storage";a:5:{s:4:"type";s:17:"field_sql_storage";s:8:"settings";a:0:{}s:6:"module";s:17:"field_sql_storage";s:6:"active";s:1:"1";s:7:"details";a:1:{s:3:"sql";a:2:{s:18:"FIELD_LOAD_CURRENT";a:1:{s:27:"field_data_field_blog_image";a:3:{s:3:"fid";s:20:"field_blog_image_fid";s:3:"alt";s:20:"field_blog_image_alt";s:5:"title";s:22:"field_blog_image_title";}}s:19:"FIELD_LOAD_REVISION";a:1:{s:31:"field_revision_field_blog_image";a:3:{s:3:"fid";s:20:"field_blog_image_fid";s:3:"alt";s:20:"field_blog_image_alt";s:5:"title";s:22:"field_blog_image_title";}}}}}s:12:"foreign keys";a:1:{s:3:"fid";a:2:{s:5:"table";s:12:"file_managed";s:7:"columns";a:1:{s:3:"fid";s:3:"fid";}}}s:7:"indexes";a:1:{s:3:"fid";a:1:{i:0;s:3:"fid";}}s:2:"id";s:1:"6";}', '1', '1', '0'),
('7', 'field_slide_image', 'image', 'image', '1', 'field_sql_storage', 'field_sql_storage', '1', '0', 'a:7:{s:12:"translatable";s:1:"1";s:12:"entity_types";a:0:{}s:8:"settings";a:2:{s:10:"uri_scheme";s:6:"public";s:13:"default_image";i:0;}s:7:"storage";a:5:{s:4:"type";s:17:"field_sql_storage";s:8:"settings";a:0:{}s:6:"module";s:17:"field_sql_storage";s:6:"active";s:1:"1";s:7:"details";a:1:{s:3:"sql";a:2:{s:18:"FIELD_LOAD_CURRENT";a:1:{s:28:"field_data_field_slide_image";a:3:{s:3:"fid";s:21:"field_slide_image_fid";s:3:"alt";s:21:"field_slide_image_alt";s:5:"title";s:23:"field_slide_image_title";}}s:19:"FIELD_LOAD_REVISION";a:1:{s:32:"field_revision_field_slide_image";a:3:{s:3:"fid";s:21:"field_slide_image_fid";s:3:"alt";s:21:"field_slide_image_alt";s:5:"title";s:23:"field_slide_image_title";}}}}}s:12:"foreign keys";a:1:{s:3:"fid";a:2:{s:5:"table";s:12:"file_managed";s:7:"columns";a:1:{s:3:"fid";s:3:"fid";}}}s:7:"indexes";a:1:{s:3:"fid";a:1:{i:0;s:3:"fid";}}s:2:"id";s:1:"7";}', '1', '1', '0'),
('8', 'field_portfolio_image', 'image', 'image', '1', 'field_sql_storage', 'field_sql_storage', '1', '0', 'a:7:{s:12:"translatable";s:1:"1";s:12:"entity_types";a:0:{}s:8:"settings";a:2:{s:10:"uri_scheme";s:6:"public";s:13:"default_image";i:0;}s:7:"storage";a:5:{s:4:"type";s:17:"field_sql_storage";s:8:"settings";a:0:{}s:6:"module";s:17:"field_sql_storage";s:6:"active";s:1:"1";s:7:"details";a:1:{s:3:"sql";a:2:{s:18:"FIELD_LOAD_CURRENT";a:1:{s:32:"field_data_field_portfolio_image";a:3:{s:3:"fid";s:25:"field_portfolio_image_fid";s:3:"alt";s:25:"field_portfolio_image_alt";s:5:"title";s:27:"field_portfolio_image_title";}}s:19:"FIELD_LOAD_REVISION";a:1:{s:36:"field_revision_field_portfolio_image";a:3:{s:3:"fid";s:25:"field_portfolio_image_fid";s:3:"alt";s:25:"field_portfolio_image_alt";s:5:"title";s:27:"field_portfolio_image_title";}}}}}s:12:"foreign keys";a:1:{s:3:"fid";a:2:{s:5:"table";s:12:"file_managed";s:7:"columns";a:1:{s:3:"fid";s:3:"fid";}}}s:7:"indexes";a:1:{s:3:"fid";a:1:{i:0;s:3:"fid";}}s:2:"id";s:1:"8";}', '1', '1', '0'),
('11', 'field_employee_photo', 'image', 'image', '1', 'field_sql_storage', 'field_sql_storage', '1', '0', 'a:7:{s:12:"translatable";s:1:"1";s:12:"entity_types";a:0:{}s:8:"settings";a:2:{s:10:"uri_scheme";s:6:"public";s:13:"default_image";i:0;}s:7:"storage";a:5:{s:4:"type";s:17:"field_sql_storage";s:8:"settings";a:0:{}s:6:"module";s:17:"field_sql_storage";s:6:"active";s:1:"1";s:7:"details";a:1:{s:3:"sql";a:2:{s:18:"FIELD_LOAD_CURRENT";a:1:{s:31:"field_data_field_employee_photo";a:3:{s:3:"fid";s:24:"field_employee_photo_fid";s:3:"alt";s:24:"field_employee_photo_alt";s:5:"title";s:26:"field_employee_photo_title";}}s:19:"FIELD_LOAD_REVISION";a:1:{s:35:"field_revision_field_employee_photo";a:3:{s:3:"fid";s:24:"field_employee_photo_fid";s:3:"alt";s:24:"field_employee_photo_alt";s:5:"title";s:26:"field_employee_photo_title";}}}}}s:12:"foreign keys";a:1:{s:3:"fid";a:2:{s:5:"table";s:12:"file_managed";s:7:"columns";a:1:{s:3:"fid";s:3:"fid";}}}s:7:"indexes";a:1:{s:3:"fid";a:1:{i:0;s:3:"fid";}}s:2:"id";s:2:"11";}', '1', '1', '0'),
('12', 'field_logo', 'image', 'image', '1', 'field_sql_storage', 'field_sql_storage', '1', '0', 'a:7:{s:12:"translatable";s:1:"1";s:12:"entity_types";a:0:{}s:8:"settings";a:2:{s:10:"uri_scheme";s:6:"public";s:13:"default_image";i:0;}s:7:"storage";a:5:{s:4:"type";s:17:"field_sql_storage";s:8:"settings";a:0:{}s:6:"module";s:17:"field_sql_storage";s:6:"active";s:1:"1";s:7:"details";a:1:{s:3:"sql";a:2:{s:18:"FIELD_LOAD_CURRENT";a:1:{s:21:"field_data_field_logo";a:3:{s:3:"fid";s:14:"field_logo_fid";s:3:"alt";s:14:"field_logo_alt";s:5:"title";s:16:"field_logo_title";}}s:19:"FIELD_LOAD_REVISION";a:1:{s:25:"field_revision_field_logo";a:3:{s:3:"fid";s:14:"field_logo_fid";s:3:"alt";s:14:"field_logo_alt";s:5:"title";s:16:"field_logo_title";}}}}}s:12:"foreign keys";a:1:{s:3:"fid";a:2:{s:5:"table";s:12:"file_managed";s:7:"columns";a:1:{s:3:"fid";s:3:"fid";}}}s:7:"indexes";a:1:{s:3:"fid";a:1:{i:0;s:3:"fid";}}s:2:"id";s:2:"12";}', '1', '1', '0'),
('13', 'field_service_image', 'image', 'image', '1', 'field_sql_storage', 'field_sql_storage', '1', '0', 'a:7:{s:12:"translatable";s:1:"0";s:12:"entity_types";a:0:{}s:8:"settings";a:2:{s:10:"uri_scheme";s:6:"public";s:13:"default_image";i:0;}s:7:"storage";a:5:{s:4:"type";s:17:"field_sql_storage";s:8:"settings";a:0:{}s:6:"module";s:17:"field_sql_storage";s:6:"active";s:1:"1";s:7:"details";a:1:{s:3:"sql";a:2:{s:18:"FIELD_LOAD_CURRENT";a:1:{s:30:"field_data_field_service_image";a:3:{s:3:"fid";s:23:"field_service_image_fid";s:3:"alt";s:23:"field_service_image_alt";s:5:"title";s:25:"field_service_image_title";}}s:19:"FIELD_LOAD_REVISION";a:1:{s:34:"field_revision_field_service_image";a:3:{s:3:"fid";s:23:"field_service_image_fid";s:3:"alt";s:23:"field_service_image_alt";s:5:"title";s:25:"field_service_image_title";}}}}}s:12:"foreign keys";a:1:{s:3:"fid";a:2:{s:5:"table";s:12:"file_managed";s:7:"columns";a:1:{s:3:"fid";s:3:"fid";}}}s:7:"indexes";a:1:{s:3:"fid";a:1:{i:0;s:3:"fid";}}s:2:"id";s:2:"13";}', '1', '0', '0'),
('14', 'field_map', 'getlocations_fields', 'getlocations_fields', '1', 'field_sql_storage', 'field_sql_storage', '1', '0', 'a:7:{s:12:"translatable";s:1:"0";s:12:"entity_types";a:0:{}s:8:"settings";a:60:{s:11:"use_address";s:1:"0";s:19:"input_address_width";s:2:"40";s:17:"autocomplete_bias";i:0;s:19:"restrict_by_country";i:0;s:14:"search_country";s:0:"";s:22:"use_geolocation_button";i:1;s:16:"input_name_width";s:2:"40";s:19:"input_name_required";s:1:"0";s:17:"input_name_weight";s:1:"0";s:18:"input_street_width";s:2:"40";s:21:"input_street_required";s:1:"0";s:19:"input_street_weight";s:1:"0";s:22:"input_additional_width";s:2:"40";s:25:"input_additional_required";s:1:"0";s:23:"input_additional_weight";s:1:"0";s:16:"input_city_width";s:2:"40";s:19:"input_city_required";s:1:"0";s:17:"input_city_weight";s:1:"0";s:20:"input_province_width";s:2:"40";s:23:"input_province_required";s:1:"0";s:21:"input_province_weight";s:1:"0";s:23:"input_postal_code_width";s:2:"40";s:26:"input_postal_code_required";s:1:"0";s:24:"input_postal_code_weight";s:1:"0";s:20:"input_latitude_width";s:2:"20";s:21:"input_latitude_weight";s:1:"0";s:21:"input_longitude_width";s:2:"20";s:22:"input_longitude_weight";s:1:"0";s:16:"input_map_weight";s:1:"0";s:22:"input_geobutton_weight";s:1:"0";s:31:"input_geolocation_button_weight";s:1:"0";s:19:"input_country_width";s:2:"40";s:22:"input_country_required";s:1:"0";s:20:"input_country_weight";s:1:"0";s:17:"city_autocomplete";s:1:"1";s:21:"province_autocomplete";s:1:"1";s:7:"country";s:2:"US";s:20:"use_country_dropdown";s:1:"1";s:15:"per_item_marker";i:0;s:19:"input_marker_weight";s:1:"0";s:14:"latlon_warning";i:0;s:8:"mapwidth";s:4:"100%";s:9:"mapheight";s:5:"300px";s:7:"latlong";s:4:"40,0";s:16:"input_map_marker";s:13:"0_to_99 red 1";s:4:"zoom";s:1:"3";s:11:"controltype";s:5:"small";s:10:"pancontrol";i:1;s:3:"mtc";s:8:"standard";s:7:"maptype";s:3:"Map";s:10:"baselayers";a:4:{s:3:"Map";i:1;s:9:"Satellite";i:1;s:6:"Hybrid";i:0;s:8:"Physical";i:0;}s:8:"behavior";a:4:{s:5:"scale";i:0;s:8:"overview";i:0;s:15:"overview_opened";i:0;s:11:"scrollwheel";i:0;}s:9:"draggable";i:1;s:10:"map_marker";s:6:"drupal";s:15:"node_map_marker";s:6:"drupal";s:15:"user_map_marker";s:6:"drupal";s:21:"vocabulary_map_marker";s:6:"drupal";s:18:"comment_map_marker";s:6:"drupal";s:19:"use_smart_ip_button";i:0;s:28:"input_smart_ip_button_weight";i:0;}s:7:"storage";a:5:{s:4:"type";s:17:"field_sql_storage";s:8:"settings";a:0:{}s:6:"module";s:17:"field_sql_storage";s:6:"active";s:1:"1";s:7:"details";a:1:{s:3:"sql";a:2:{s:18:"FIELD_LOAD_CURRENT";a:1:{s:20:"field_data_field_map";a:1:{s:4:"glid";s:14:"field_map_glid";}}s:19:"FIELD_LOAD_REVISION";a:1:{s:24:"field_revision_field_map";a:1:{s:4:"glid";s:14:"field_map_glid";}}}}}s:12:"foreign keys";a:0:{}s:7:"indexes";a:1:{s:4:"glid";a:1:{i:0;s:4:"glid";}}s:2:"id";s:2:"14";}', '1', '0', '0'),
('15', 'field_position', 'text', 'text', '1', 'field_sql_storage', 'field_sql_storage', '1', '0', 'a:7:{s:12:"translatable";s:1:"0";s:12:"entity_types";a:0:{}s:8:"settings";a:1:{s:10:"max_length";s:3:"255";}s:7:"storage";a:5:{s:4:"type";s:17:"field_sql_storage";s:8:"settings";a:0:{}s:6:"module";s:17:"field_sql_storage";s:6:"active";s:1:"1";s:7:"details";a:1:{s:3:"sql";a:2:{s:18:"FIELD_LOAD_CURRENT";a:1:{s:25:"field_data_field_position";a:2:{s:5:"value";s:20:"field_position_value";s:6:"format";s:21:"field_position_format";}}s:19:"FIELD_LOAD_REVISION";a:1:{s:29:"field_revision_field_position";a:2:{s:5:"value";s:20:"field_position_value";s:6:"format";s:21:"field_position_format";}}}}}s:12:"foreign keys";a:1:{s:6:"format";a:2:{s:5:"table";s:13:"filter_format";s:7:"columns";a:1:{s:6:"format";s:6:"format";}}}s:7:"indexes";a:1:{s:6:"format";a:1:{i:0;s:6:"format";}}s:2:"id";s:2:"15";}', '1', '0', '0'),
('16', 'field_addthis', 'addthis', 'addthis', '1', 'field_sql_storage', 'field_sql_storage', '1', '0', 'a:7:{s:12:"translatable";s:1:"0";s:12:"entity_types";a:0:{}s:8:"settings";a:1:{s:10:"max_length";i:255;}s:7:"storage";a:5:{s:4:"type";s:17:"field_sql_storage";s:8:"settings";a:0:{}s:6:"module";s:17:"field_sql_storage";s:6:"active";s:1:"1";s:7:"details";a:1:{s:3:"sql";a:2:{s:18:"FIELD_LOAD_CURRENT";a:1:{s:24:"field_data_field_addthis";a:1:{s:5:"value";s:19:"field_addthis_value";}}s:19:"FIELD_LOAD_REVISION";a:1:{s:28:"field_revision_field_addthis";a:1:{s:5:"value";s:19:"field_addthis_value";}}}}}s:12:"foreign keys";a:0:{}s:7:"indexes";a:0:{}s:2:"id";s:2:"16";}', '1', '0', '0'),
('17', 'field_addthis_blog', 'addthis', 'addthis', '1', 'field_sql_storage', 'field_sql_storage', '1', '0', 'a:7:{s:12:"translatable";s:1:"0";s:12:"entity_types";a:0:{}s:8:"settings";a:1:{s:10:"max_length";i:255;}s:7:"storage";a:5:{s:4:"type";s:17:"field_sql_storage";s:8:"settings";a:0:{}s:6:"module";s:17:"field_sql_storage";s:6:"active";s:1:"1";s:7:"details";a:1:{s:3:"sql";a:2:{s:18:"FIELD_LOAD_CURRENT";a:1:{s:29:"field_data_field_addthis_blog";a:1:{s:5:"value";s:24:"field_addthis_blog_value";}}s:19:"FIELD_LOAD_REVISION";a:1:{s:33:"field_revision_field_addthis_blog";a:1:{s:5:"value";s:24:"field_addthis_blog_value";}}}}}s:12:"foreign keys";a:0:{}s:7:"indexes";a:0:{}s:2:"id";s:2:"17";}', '1', '0', '0'),
('18', 'field_blog_category', 'taxonomy_term_reference', 'taxonomy', '1', 'field_sql_storage', 'field_sql_storage', '1', '0', 'a:7:{s:12:"translatable";s:1:"0";s:12:"entity_types";a:0:{}s:8:"settings";a:1:{s:14:"allowed_values";a:1:{i:0;a:2:{s:10:"vocabulary";s:13:"blog_cetogory";s:6:"parent";s:1:"0";}}}s:7:"storage";a:5:{s:4:"type";s:17:"field_sql_storage";s:8:"settings";a:0:{}s:6:"module";s:17:"field_sql_storage";s:6:"active";s:1:"1";s:7:"details";a:1:{s:3:"sql";a:2:{s:18:"FIELD_LOAD_CURRENT";a:1:{s:30:"field_data_field_blog_category";a:1:{s:3:"tid";s:23:"field_blog_category_tid";}}s:19:"FIELD_LOAD_REVISION";a:1:{s:34:"field_revision_field_blog_category";a:1:{s:3:"tid";s:23:"field_blog_category_tid";}}}}}s:12:"foreign keys";a:1:{s:3:"tid";a:2:{s:5:"table";s:18:"taxonomy_term_data";s:7:"columns";a:1:{s:3:"tid";s:3:"tid";}}}s:7:"indexes";a:1:{s:3:"tid";a:1:{i:0;s:3:"tid";}}s:2:"id";s:2:"18";}', '-1', '0', '0'),
('19', 'field_portfolio_category', 'taxonomy_term_reference', 'taxonomy', '1', 'field_sql_storage', 'field_sql_storage', '1', '0', 'a:7:{s:12:"translatable";s:1:"0";s:12:"entity_types";a:0:{}s:8:"settings";a:1:{s:14:"allowed_values";a:1:{i:0;a:2:{s:10:"vocabulary";s:20:"portfolio_categories";s:6:"parent";s:1:"0";}}}s:7:"storage";a:5:{s:4:"type";s:17:"field_sql_storage";s:8:"settings";a:0:{}s:6:"module";s:17:"field_sql_storage";s:6:"active";s:1:"1";s:7:"details";a:1:{s:3:"sql";a:2:{s:18:"FIELD_LOAD_CURRENT";a:1:{s:35:"field_data_field_portfolio_category";a:1:{s:3:"tid";s:28:"field_portfolio_category_tid";}}s:19:"FIELD_LOAD_REVISION";a:1:{s:39:"field_revision_field_portfolio_category";a:1:{s:3:"tid";s:28:"field_portfolio_category_tid";}}}}}s:12:"foreign keys";a:1:{s:3:"tid";a:2:{s:5:"table";s:18:"taxonomy_term_data";s:7:"columns";a:1:{s:3:"tid";s:3:"tid";}}}s:7:"indexes";a:1:{s:3:"tid";a:1:{i:0;s:3:"tid";}}s:2:"id";s:2:"19";}', '-1', '0', '0'),
('20', 'field_popular_services_image', 'image', 'image', '1', 'field_sql_storage', 'field_sql_storage', '1', '0', 'a:7:{s:12:"translatable";s:1:"0";s:12:"entity_types";a:0:{}s:8:"settings";a:2:{s:10:"uri_scheme";s:6:"public";s:13:"default_image";i:0;}s:7:"storage";a:5:{s:4:"type";s:17:"field_sql_storage";s:8:"settings";a:0:{}s:6:"module";s:17:"field_sql_storage";s:6:"active";s:1:"1";s:7:"details";a:1:{s:3:"sql";a:2:{s:18:"FIELD_LOAD_CURRENT";a:1:{s:39:"field_data_field_popular_services_image";a:5:{s:3:"fid";s:32:"field_popular_services_image_fid";s:3:"alt";s:32:"field_popular_services_image_alt";s:5:"title";s:34:"field_popular_services_image_title";s:5:"width";s:34:"field_popular_services_image_width";s:6:"height";s:35:"field_popular_services_image_height";}}s:19:"FIELD_LOAD_REVISION";a:1:{s:43:"field_revision_field_popular_services_image";a:5:{s:3:"fid";s:32:"field_popular_services_image_fid";s:3:"alt";s:32:"field_popular_services_image_alt";s:5:"title";s:34:"field_popular_services_image_title";s:5:"width";s:34:"field_popular_services_image_width";s:6:"height";s:35:"field_popular_services_image_height";}}}}}s:12:"foreign keys";a:1:{s:3:"fid";a:2:{s:5:"table";s:12:"file_managed";s:7:"columns";a:1:{s:3:"fid";s:3:"fid";}}}s:7:"indexes";a:1:{s:3:"fid";a:1:{i:0;s:3:"fid";}}s:2:"id";s:2:"20";}', '1', '0', '0'),
('21', 'field_testimonials_position', 'text', 'text', '1', 'field_sql_storage', 'field_sql_storage', '1', '0', 'a:7:{s:12:"translatable";s:1:"0";s:12:"entity_types";a:0:{}s:8:"settings";a:1:{s:10:"max_length";s:3:"255";}s:7:"storage";a:5:{s:4:"type";s:17:"field_sql_storage";s:8:"settings";a:0:{}s:6:"module";s:17:"field_sql_storage";s:6:"active";s:1:"1";s:7:"details";a:1:{s:3:"sql";a:2:{s:18:"FIELD_LOAD_CURRENT";a:1:{s:38:"field_data_field_testimonials_position";a:2:{s:5:"value";s:33:"field_testimonials_position_value";s:6:"format";s:34:"field_testimonials_position_format";}}s:19:"FIELD_LOAD_REVISION";a:1:{s:42:"field_revision_field_testimonials_position";a:2:{s:5:"value";s:33:"field_testimonials_position_value";s:6:"format";s:34:"field_testimonials_position_format";}}}}}s:12:"foreign keys";a:1:{s:6:"format";a:2:{s:5:"table";s:13:"filter_format";s:7:"columns";a:1:{s:6:"format";s:6:"format";}}}s:7:"indexes";a:1:{s:6:"format";a:1:{i:0;s:6:"format";}}s:2:"id";s:2:"21";}', '1', '0', '0');
/*!40000 ALTER TABLE field_config ENABLE KEYS */;

--
-- Table structure for table 'field_config_instance'
--

CREATE TABLE IF NOT EXISTS `field_config_instance` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'The primary identifier for a field instance',
  `field_id` int(11) NOT NULL COMMENT 'The identifier of the field attached by this instance',
  `field_name` varchar(32) NOT NULL DEFAULT '',
  `entity_type` varchar(32) NOT NULL DEFAULT '',
  `bundle` varchar(128) NOT NULL DEFAULT '',
  `data` longblob NOT NULL,
  `deleted` tinyint(4) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  KEY `field_name_bundle` (`field_name`,`entity_type`,`bundle`),
  KEY `deleted` (`deleted`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='InnoDB free: 7168 kB';

--
-- Dumping data for table 'field_config_instance'
--

/*!40000 ALTER TABLE field_config_instance DISABLE KEYS */;
INSERT INTO `field_config_instance` VALUES
('1', '1', 'comment_body', 'comment', 'comment_node_page', 'a:6:{s:5:"label";s:7:"Comment";s:8:"settings";a:2:{s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:8:"required";b:1;s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";i:0;s:8:"settings";a:0:{}s:6:"module";s:4:"text";}}s:6:"widget";a:4:{s:4:"type";s:13:"text_textarea";s:8:"settings";a:1:{s:4:"rows";i:5;}s:6:"weight";i:0;s:6:"module";s:4:"text";}s:11:"description";s:0:"";}', '0'),
('2', '2', 'body', 'node', 'page', 'a:7:{s:5:"label";s:4:"Body";s:11:"widget_type";s:26:"text_textarea_with_summary";s:8:"settings";a:3:{s:15:"display_summary";b:1;s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:7:"display";a:2:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:8:"settings";a:0:{}s:6:"module";s:4:"text";s:6:"weight";i:0;}s:6:"teaser";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:23:"text_summary_or_trimmed";s:8:"settings";a:1:{s:11:"trim_length";i:600;}s:6:"module";s:4:"text";s:6:"weight";i:0;}}s:6:"widget";a:4:{s:4:"type";s:26:"text_textarea_with_summary";s:8:"settings";a:2:{s:4:"rows";i:20;s:12:"summary_rows";i:5;}s:6:"weight";i:-4;s:6:"module";s:4:"text";}s:8:"required";b:0;s:11:"description";s:0:"";}', '0'),
('3', '1', 'comment_body', 'comment', 'comment_node_article', 'a:6:{s:5:"label";s:7:"Comment";s:8:"settings";a:2:{s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:8:"required";b:1;s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";i:0;s:8:"settings";a:0:{}s:6:"module";s:4:"text";}}s:6:"widget";a:4:{s:4:"type";s:13:"text_textarea";s:8:"settings";a:1:{s:4:"rows";i:5;}s:6:"weight";i:0;s:6:"module";s:4:"text";}s:11:"description";s:0:"";}', '0'),
('4', '2', 'body', 'node', 'article', 'a:7:{s:5:"label";s:4:"Body";s:11:"widget_type";s:26:"text_textarea_with_summary";s:8:"settings";a:3:{s:15:"display_summary";b:1;s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:7:"display";a:2:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";s:1:"0";s:8:"settings";a:0:{}s:6:"module";s:4:"text";}s:6:"teaser";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:23:"text_summary_or_trimmed";s:8:"settings";a:1:{s:11:"trim_length";i:600;}s:6:"module";s:4:"text";s:6:"weight";i:0;}}s:6:"widget";a:4:{s:4:"type";s:26:"text_textarea_with_summary";s:8:"settings";a:2:{s:4:"rows";i:20;s:12:"summary_rows";i:5;}s:6:"weight";s:2:"-4";s:6:"module";s:4:"text";}s:8:"required";b:0;s:11:"description";s:0:"";}', '0'),
('5', '3', 'field_tags', 'node', 'article', 'a:6:{s:5:"label";s:4:"Tags";s:11:"description";s:63:"Enter a comma-separated list of words to describe your content.";s:6:"widget";a:4:{s:4:"type";s:21:"taxonomy_autocomplete";s:6:"weight";s:2:"-4";s:8:"settings";a:2:{s:4:"size";i:60;s:17:"autocomplete_path";s:21:"taxonomy/autocomplete";}s:6:"module";s:8:"taxonomy";}s:7:"display";a:2:{s:7:"default";a:5:{s:5:"label";s:5:"above";s:4:"type";s:28:"taxonomy_term_reference_link";s:6:"weight";s:2:"10";s:8:"settings";a:0:{}s:6:"module";s:8:"taxonomy";}s:6:"teaser";a:5:{s:4:"type";s:28:"taxonomy_term_reference_link";s:6:"weight";i:10;s:5:"label";s:5:"above";s:8:"settings";a:0:{}s:6:"module";s:8:"taxonomy";}}s:8:"settings";a:1:{s:18:"user_register_form";b:0;}s:8:"required";b:0;}', '0'),
('6', '4', 'field_image', 'node', 'article', 'a:6:{s:5:"label";s:5:"Image";s:11:"description";s:40:"Upload an image to go with this article.";s:8:"required";b:0;s:8:"settings";a:9:{s:14:"file_directory";s:11:"field/image";s:15:"file_extensions";s:16:"png gif jpg jpeg";s:12:"max_filesize";s:0:"";s:14:"max_resolution";s:0:"";s:14:"min_resolution";s:0:"";s:9:"alt_field";b:1;s:11:"title_field";s:0:"";s:18:"user_register_form";b:0;s:13:"default_image";i:0;}s:6:"widget";a:4:{s:4:"type";s:11:"image_image";s:8:"settings";a:2:{s:18:"progress_indicator";s:8:"throbber";s:19:"preview_image_style";s:9:"thumbnail";}s:6:"weight";s:2:"-1";s:6:"module";s:5:"image";}s:7:"display";a:2:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:5:"image";s:6:"weight";s:2:"-1";s:8:"settings";a:2:{s:11:"image_style";s:9:"full_post";s:10:"image_link";s:0:"";}s:6:"module";s:5:"image";}s:6:"teaser";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:5:"image";s:8:"settings";a:2:{s:11:"image_style";s:6:"medium";s:10:"image_link";s:7:"content";}s:6:"weight";i:-1;s:6:"module";s:5:"image";}}}', '0'),
('7', '1', 'comment_body', 'comment', 'comment_node_book', 'a:6:{s:5:"label";s:7:"Comment";s:8:"settings";a:2:{s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:8:"required";b:1;s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";i:0;s:8:"settings";a:0:{}s:6:"module";s:4:"text";}}s:6:"widget";a:4:{s:4:"type";s:13:"text_textarea";s:8:"settings";a:1:{s:4:"rows";i:5;}s:6:"weight";i:0;s:6:"module";s:4:"text";}s:11:"description";s:0:"";}', '0'),
('8', '2', 'body', 'node', 'book', 'a:7:{s:5:"label";s:4:"Body";s:11:"widget_type";s:26:"text_textarea_with_summary";s:8:"settings";a:3:{s:15:"display_summary";b:1;s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:7:"display";a:2:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:8:"settings";a:0:{}s:6:"module";s:4:"text";s:6:"weight";i:0;}s:6:"teaser";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:23:"text_summary_or_trimmed";s:8:"settings";a:1:{s:11:"trim_length";i:600;}s:6:"module";s:4:"text";s:6:"weight";i:0;}}s:6:"widget";a:4:{s:4:"type";s:26:"text_textarea_with_summary";s:8:"settings";a:2:{s:4:"rows";i:20;s:12:"summary_rows";i:5;}s:6:"weight";i:-4;s:6:"module";s:4:"text";}s:8:"required";b:0;s:11:"description";s:0:"";}', '0'),
('9', '1', 'comment_body', 'comment', 'comment_node_blog', 'a:6:{s:5:"label";s:7:"Comment";s:8:"settings";a:2:{s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:8:"required";b:1;s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";i:0;s:8:"settings";a:0:{}s:6:"module";s:4:"text";}}s:6:"widget";a:4:{s:4:"type";s:13:"text_textarea";s:8:"settings";a:1:{s:4:"rows";i:5;}s:6:"weight";i:0;s:6:"module";s:4:"text";}s:11:"description";s:0:"";}', '0'),
('10', '1', 'comment_body', 'comment', 'comment_node_poll', 'a:6:{s:5:"label";s:7:"Comment";s:8:"settings";a:2:{s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:8:"required";b:1;s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";i:0;s:8:"settings";a:0:{}s:6:"module";s:4:"text";}}s:6:"widget";a:4:{s:4:"type";s:13:"text_textarea";s:8:"settings";a:1:{s:4:"rows";i:5;}s:6:"weight";i:0;s:6:"module";s:4:"text";}s:11:"description";s:0:"";}', '0'),
('11', '2', 'body', 'node', 'blog', 'a:7:{s:5:"label";s:4:"Body";s:11:"widget_type";s:26:"text_textarea_with_summary";s:8:"settings";a:3:{s:15:"display_summary";b:1;s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:7:"display";a:4:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";s:1:"1";s:8:"settings";a:0:{}s:6:"module";s:4:"text";}s:6:"teaser";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_trimmed";s:6:"weight";s:1:"1";s:8:"settings";a:1:{s:11:"trim_length";i:600;}s:6:"module";s:4:"text";}s:4:"full";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";s:1:"1";s:8:"settings";a:0:{}s:6:"module";s:4:"text";}s:5:"print";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";s:1:"0";s:8:"settings";a:0:{}s:6:"module";s:4:"text";}}s:6:"widget";a:4:{s:4:"type";s:26:"text_textarea_with_summary";s:8:"settings";a:2:{s:4:"rows";i:20;s:12:"summary_rows";i:5;}s:6:"weight";s:1:"2";s:6:"module";s:4:"text";}s:8:"required";b:0;s:11:"description";s:0:"";}', '0'),
('12', '5', 'taxonomy_forums', 'node', 'forum', 'a:6:{s:5:"label";s:6:"Forums";s:8:"required";b:1;s:6:"widget";a:4:{s:4:"type";s:14:"options_select";s:8:"settings";a:0:{}s:6:"weight";i:0;s:6:"module";s:7:"options";}s:7:"display";a:2:{s:7:"default";a:5:{s:5:"label";s:5:"above";s:4:"type";s:28:"taxonomy_term_reference_link";s:6:"weight";s:1:"1";s:8:"settings";a:0:{}s:6:"module";s:8:"taxonomy";}s:6:"teaser";a:5:{s:4:"type";s:28:"taxonomy_term_reference_link";s:6:"weight";i:10;s:5:"label";s:5:"above";s:8:"settings";a:0:{}s:6:"module";s:8:"taxonomy";}}s:8:"settings";a:1:{s:18:"user_register_form";b:0;}s:11:"description";s:0:"";}', '0'),
('13', '1', 'comment_body', 'comment', 'comment_node_forum', 'a:6:{s:5:"label";s:7:"Comment";s:8:"settings";a:2:{s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:8:"required";b:1;s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";i:0;s:8:"settings";a:0:{}s:6:"module";s:4:"text";}}s:6:"widget";a:4:{s:4:"type";s:13:"text_textarea";s:8:"settings";a:1:{s:4:"rows";i:5;}s:6:"weight";i:0;s:6:"module";s:4:"text";}s:11:"description";s:0:"";}', '0'),
('14', '2', 'body', 'node', 'forum', 'a:7:{s:5:"label";s:4:"Body";s:11:"widget_type";s:26:"text_textarea_with_summary";s:8:"settings";a:3:{s:15:"display_summary";b:1;s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:7:"display";a:2:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";s:1:"0";s:8:"settings";a:0:{}s:6:"module";s:4:"text";}s:6:"teaser";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:23:"text_summary_or_trimmed";s:8:"settings";a:1:{s:11:"trim_length";i:600;}s:6:"module";s:4:"text";s:6:"weight";i:11;}}s:6:"widget";a:4:{s:4:"type";s:26:"text_textarea_with_summary";s:8:"settings";a:2:{s:4:"rows";i:20;s:12:"summary_rows";i:5;}s:6:"weight";i:1;s:6:"module";s:4:"text";}s:8:"required";b:0;s:11:"description";s:0:"";}', '0'),
('15', '1', 'comment_body', 'comment', 'comment_node_faq', 'a:6:{s:5:"label";s:7:"Comment";s:8:"settings";a:2:{s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:8:"required";b:1;s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";i:0;s:8:"settings";a:0:{}s:6:"module";s:4:"text";}}s:6:"widget";a:4:{s:4:"type";s:13:"text_textarea";s:8:"settings";a:1:{s:4:"rows";i:5;}s:6:"weight";i:0;s:6:"module";s:4:"text";}s:11:"description";s:0:"";}', '0'),
('16', '2', 'body', 'node', 'faq', 'a:6:{s:5:"label";s:4:"Body";s:6:"widget";a:4:{s:4:"type";s:26:"text_textarea_with_summary";s:8:"settings";a:2:{s:4:"rows";i:20;s:12:"summary_rows";i:5;}s:6:"weight";i:-4;s:6:"module";s:4:"text";}s:8:"settings";a:3:{s:15:"display_summary";b:1;s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:7:"display";a:2:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:8:"settings";a:0:{}s:6:"module";s:4:"text";s:6:"weight";i:0;}s:6:"teaser";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:23:"text_summary_or_trimmed";s:8:"settings";a:1:{s:11:"trim_length";i:600;}s:6:"module";s:4:"text";s:6:"weight";i:0;}}s:8:"required";b:0;s:11:"description";s:0:"";}', '0'),
('17', '6', 'field_blog_image', 'node', 'blog', 'a:6:{s:5:"label";s:10:"Blog image";s:6:"widget";a:5:{s:6:"weight";s:1:"3";s:4:"type";s:11:"image_image";s:6:"module";s:5:"image";s:6:"active";i:1;s:8:"settings";a:2:{s:18:"progress_indicator";s:8:"throbber";s:19:"preview_image_style";s:6:"medium";}}s:8:"settings";a:9:{s:14:"file_directory";s:0:"";s:15:"file_extensions";s:16:"png gif jpg jpeg";s:12:"max_filesize";s:0:"";s:14:"max_resolution";s:0:"";s:14:"min_resolution";s:0:"";s:9:"alt_field";i:0;s:11:"title_field";i:0;s:18:"user_register_form";b:0;s:13:"default_image";i:0;}s:7:"display";a:4:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:5:"image";s:6:"weight";s:1:"0";s:8:"settings";a:2:{s:11:"image_style";s:9:"full_post";s:10:"image_link";s:7:"content";}s:6:"module";s:5:"image";}s:4:"full";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:5:"image";s:6:"weight";s:1:"0";s:8:"settings";a:2:{s:11:"image_style";s:9:"full_post";s:10:"image_link";s:0:"";}s:6:"module";s:5:"image";}s:5:"print";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:5:"image";s:6:"weight";s:1:"1";s:8:"settings";a:2:{s:11:"image_style";s:0:"";s:10:"image_link";s:7:"content";}s:6:"module";s:5:"image";}s:6:"teaser";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:5:"image";s:6:"weight";s:1:"0";s:8:"settings";a:2:{s:11:"image_style";s:10:"blog_image";s:10:"image_link";s:7:"content";}s:6:"module";s:5:"image";}}s:8:"required";i:0;s:11:"description";s:0:"";}', '0'),
('18', '1', 'comment_body', 'comment', 'comment_node_slider', 'a:6:{s:5:"label";s:7:"Comment";s:8:"settings";a:2:{s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:8:"required";b:1;s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";i:0;s:8:"settings";a:0:{}s:6:"module";s:4:"text";}}s:6:"widget";a:4:{s:4:"type";s:13:"text_textarea";s:8:"settings";a:1:{s:4:"rows";i:5;}s:6:"weight";i:0;s:6:"module";s:4:"text";}s:11:"description";s:0:"";}', '0'),
('19', '2', 'body', 'node', 'slider', 'a:6:{s:5:"label";s:4:"Body";s:6:"widget";a:4:{s:4:"type";s:26:"text_textarea_with_summary";s:8:"settings";a:2:{s:4:"rows";i:20;s:12:"summary_rows";i:5;}s:6:"weight";s:2:"-4";s:6:"module";s:4:"text";}s:8:"settings";a:3:{s:15:"display_summary";b:1;s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:7:"display";a:2:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";s:1:"1";s:8:"settings";a:0:{}s:6:"module";s:4:"text";}s:6:"teaser";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:23:"text_summary_or_trimmed";s:8:"settings";a:1:{s:11:"trim_length";i:600;}s:6:"module";s:4:"text";s:6:"weight";i:0;}}s:8:"required";b:0;s:11:"description";s:0:"";}', '0'),
('20', '7', 'field_slide_image', 'node', 'slider', 'a:6:{s:5:"label";s:12:"Upload slide";s:6:"widget";a:5:{s:6:"weight";s:2:"-3";s:4:"type";s:11:"image_image";s:6:"module";s:5:"image";s:6:"active";i:1;s:8:"settings";a:2:{s:18:"progress_indicator";s:8:"throbber";s:19:"preview_image_style";s:6:"medium";}}s:8:"settings";a:8:{s:14:"file_directory";s:0:"";s:15:"file_extensions";s:16:"png gif jpg jpeg";s:12:"max_filesize";s:0:"";s:14:"max_resolution";s:0:"";s:14:"min_resolution";s:0:"";s:9:"alt_field";i:0;s:11:"title_field";i:0;s:18:"user_register_form";b:0;}s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:5:"image";s:6:"weight";s:1:"0";s:8:"settings";a:2:{s:11:"image_style";s:10:"blog_image";s:10:"image_link";s:0:"";}s:6:"module";s:5:"image";}}s:8:"required";i:0;s:11:"description";s:0:"";}', '0'),
('21', '1', 'comment_body', 'comment', 'comment_node_quotes', 'a:6:{s:5:"label";s:7:"Comment";s:8:"settings";a:2:{s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:8:"required";b:1;s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";i:0;s:8:"settings";a:0:{}s:6:"module";s:4:"text";}}s:6:"widget";a:4:{s:4:"type";s:13:"text_textarea";s:8:"settings";a:1:{s:4:"rows";i:5;}s:6:"weight";i:0;s:6:"module";s:4:"text";}s:11:"description";s:0:"";}', '0'),
('22', '2', 'body', 'node', 'quotes', 'a:6:{s:5:"label";s:4:"Body";s:6:"widget";a:4:{s:4:"type";s:26:"text_textarea_with_summary";s:8:"settings";a:2:{s:4:"rows";i:20;s:12:"summary_rows";i:5;}s:6:"weight";i:-4;s:6:"module";s:4:"text";}s:8:"settings";a:3:{s:15:"display_summary";b:1;s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:7:"display";a:2:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:8:"settings";a:0:{}s:6:"module";s:4:"text";s:6:"weight";i:0;}s:6:"teaser";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:23:"text_summary_or_trimmed";s:8:"settings";a:1:{s:11:"trim_length";i:600;}s:6:"module";s:4:"text";s:6:"weight";i:0;}}s:8:"required";b:0;s:11:"description";s:0:"";}', '0'),
('23', '1', 'comment_body', 'comment', 'comment_node_panel', 'a:6:{s:5:"label";s:7:"Comment";s:8:"settings";a:2:{s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:8:"required";b:1;s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";i:0;s:8:"settings";a:0:{}s:6:"module";s:4:"text";}}s:6:"widget";a:4:{s:4:"type";s:13:"text_textarea";s:8:"settings";a:1:{s:4:"rows";i:5;}s:6:"weight";i:0;s:6:"module";s:4:"text";}s:11:"description";s:0:"";}', '0'),
('24', '1', 'comment_body', 'comment', 'comment_node_portfolio', 'a:6:{s:5:"label";s:7:"Comment";s:8:"settings";a:2:{s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:8:"required";b:1;s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";i:0;s:8:"settings";a:0:{}s:6:"module";s:4:"text";}}s:6:"widget";a:4:{s:4:"type";s:13:"text_textarea";s:8:"settings";a:1:{s:4:"rows";i:5;}s:6:"weight";i:0;s:6:"module";s:4:"text";}s:11:"description";s:0:"";}', '0'),
('25', '2', 'body', 'node', 'portfolio', 'a:6:{s:5:"label";s:4:"Body";s:6:"widget";a:4:{s:4:"type";s:26:"text_textarea_with_summary";s:8:"settings";a:2:{s:4:"rows";i:20;s:12:"summary_rows";i:5;}s:6:"weight";s:1:"2";s:6:"module";s:4:"text";}s:8:"settings";a:3:{s:15:"display_summary";b:1;s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:7:"display";a:2:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";s:1:"1";s:8:"settings";a:0:{}s:6:"module";s:4:"text";}s:6:"teaser";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:23:"text_summary_or_trimmed";s:8:"settings";a:1:{s:11:"trim_length";i:600;}s:6:"module";s:4:"text";s:6:"weight";i:0;}}s:8:"required";b:0;s:11:"description";s:0:"";}', '0'),
('26', '8', 'field_portfolio_image', 'node', 'portfolio', 'a:6:{s:5:"label";s:12:"Upload Image";s:6:"widget";a:5:{s:6:"weight";s:1:"3";s:4:"type";s:11:"image_image";s:6:"module";s:5:"image";s:6:"active";i:1;s:8:"settings";a:2:{s:18:"progress_indicator";s:8:"throbber";s:19:"preview_image_style";s:6:"medium";}}s:8:"settings";a:9:{s:14:"file_directory";s:0:"";s:15:"file_extensions";s:16:"png gif jpg jpeg";s:12:"max_filesize";s:0:"";s:14:"max_resolution";s:0:"";s:14:"min_resolution";s:0:"";s:9:"alt_field";i:0;s:11:"title_field";i:0;s:18:"user_register_form";b:0;s:13:"default_image";i:0;}s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:5:"image";s:6:"weight";s:1:"0";s:8:"settings";a:2:{s:11:"image_style";s:10:"blog_image";s:10:"image_link";s:0:"";}s:6:"module";s:5:"image";}}s:8:"required";i:0;s:11:"description";s:0:"";}', '0'),
('31', '1', 'comment_body', 'comment', 'comment_node_employee', 'a:6:{s:5:"label";s:7:"Comment";s:8:"settings";a:2:{s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:8:"required";b:1;s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";i:0;s:8:"settings";a:0:{}s:6:"module";s:4:"text";}}s:6:"widget";a:4:{s:4:"type";s:13:"text_textarea";s:8:"settings";a:1:{s:4:"rows";i:5;}s:6:"weight";i:0;s:6:"module";s:4:"text";}s:11:"description";s:0:"";}', '0'),
('32', '2', 'body', 'node', 'employee', 'a:6:{s:5:"label";s:4:"Body";s:6:"widget";a:4:{s:4:"type";s:26:"text_textarea_with_summary";s:8:"settings";a:2:{s:4:"rows";i:20;s:12:"summary_rows";i:5;}s:6:"weight";s:2:"-4";s:6:"module";s:4:"text";}s:8:"settings";a:3:{s:15:"display_summary";b:1;s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:7:"display";a:2:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";s:1:"1";s:8:"settings";a:0:{}s:6:"module";s:4:"text";}s:6:"teaser";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:23:"text_summary_or_trimmed";s:8:"settings";a:1:{s:11:"trim_length";i:600;}s:6:"module";s:4:"text";s:6:"weight";i:0;}}s:8:"required";b:0;s:11:"description";s:0:"";}', '0'),
('33', '11', 'field_employee_photo', 'node', 'employee', 'a:6:{s:5:"label";s:14:"Employee photo";s:6:"widget";a:5:{s:6:"weight";s:2:"-3";s:4:"type";s:11:"image_image";s:6:"module";s:5:"image";s:6:"active";i:1;s:8:"settings";a:2:{s:18:"progress_indicator";s:8:"throbber";s:19:"preview_image_style";s:6:"medium";}}s:8:"settings";a:9:{s:14:"file_directory";s:0:"";s:15:"file_extensions";s:16:"png gif jpg jpeg";s:12:"max_filesize";s:0:"";s:14:"max_resolution";s:0:"";s:14:"min_resolution";s:0:"";s:9:"alt_field";i:0;s:11:"title_field";i:0;s:18:"user_register_form";b:0;s:13:"default_image";i:0;}s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:5:"image";s:6:"weight";s:1:"0";s:8:"settings";a:2:{s:11:"image_style";s:6:"medium";s:10:"image_link";s:0:"";}s:6:"module";s:5:"image";}}s:8:"required";i:0;s:11:"description";s:0:"";}', '0'),
('34', '1', 'comment_body', 'comment', 'comment_node_partners', 'a:6:{s:5:"label";s:7:"Comment";s:8:"settings";a:2:{s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:8:"required";b:1;s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";i:0;s:8:"settings";a:0:{}s:6:"module";s:4:"text";}}s:6:"widget";a:4:{s:4:"type";s:13:"text_textarea";s:8:"settings";a:1:{s:4:"rows";i:5;}s:6:"weight";i:0;s:6:"module";s:4:"text";}s:11:"description";s:0:"";}', '0'),
('35', '2', 'body', 'node', 'partners', 'a:6:{s:5:"label";s:4:"Body";s:6:"widget";a:4:{s:4:"type";s:26:"text_textarea_with_summary";s:8:"settings";a:2:{s:4:"rows";i:20;s:12:"summary_rows";i:5;}s:6:"weight";s:2:"-4";s:6:"module";s:4:"text";}s:8:"settings";a:3:{s:15:"display_summary";b:1;s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:7:"display";a:2:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";s:1:"1";s:8:"settings";a:0:{}s:6:"module";s:4:"text";}s:6:"teaser";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:23:"text_summary_or_trimmed";s:8:"settings";a:1:{s:11:"trim_length";i:600;}s:6:"module";s:4:"text";s:6:"weight";i:0;}}s:8:"required";b:0;s:11:"description";s:0:"";}', '0'),
('36', '12', 'field_logo', 'node', 'partners', 'a:6:{s:5:"label";s:4:"Logo";s:6:"widget";a:5:{s:6:"weight";s:2:"-3";s:4:"type";s:11:"image_image";s:6:"module";s:5:"image";s:6:"active";i:1;s:8:"settings";a:2:{s:18:"progress_indicator";s:8:"throbber";s:19:"preview_image_style";s:6:"medium";}}s:8:"settings";a:8:{s:14:"file_directory";s:0:"";s:15:"file_extensions";s:16:"png gif jpg jpeg";s:12:"max_filesize";s:0:"";s:14:"max_resolution";s:0:"";s:14:"min_resolution";s:0:"";s:9:"alt_field";i:0;s:11:"title_field";i:0;s:18:"user_register_form";b:0;}s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:5:"image";s:6:"weight";s:1:"0";s:8:"settings";a:2:{s:11:"image_style";s:6:"medium";s:10:"image_link";s:0:"";}s:6:"module";s:5:"image";}}s:8:"required";i:0;s:11:"description";s:0:"";}', '0'),
('37', '1', 'comment_body', 'comment', 'comment_node_services', 'a:6:{s:5:"label";s:7:"Comment";s:8:"settings";a:2:{s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:8:"required";b:1;s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";i:0;s:8:"settings";a:0:{}s:6:"module";s:4:"text";}}s:6:"widget";a:4:{s:4:"type";s:13:"text_textarea";s:8:"settings";a:1:{s:4:"rows";i:5;}s:6:"weight";i:0;s:6:"module";s:4:"text";}s:11:"description";s:0:"";}', '0'),
('38', '2', 'body', 'node', 'services', 'a:6:{s:5:"label";s:4:"Body";s:6:"widget";a:4:{s:4:"type";s:26:"text_textarea_with_summary";s:8:"settings";a:2:{s:4:"rows";i:20;s:12:"summary_rows";i:5;}s:6:"weight";s:2:"-4";s:6:"module";s:4:"text";}s:8:"settings";a:3:{s:15:"display_summary";b:1;s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:7:"display";a:2:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";s:1:"1";s:8:"settings";a:0:{}s:6:"module";s:4:"text";}s:6:"teaser";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:23:"text_summary_or_trimmed";s:8:"settings";a:1:{s:11:"trim_length";i:600;}s:6:"module";s:4:"text";s:6:"weight";i:0;}}s:8:"required";b:0;s:11:"description";s:0:"";}', '0'),
('39', '13', 'field_service_image', 'node', 'services', 'a:6:{s:5:"label";s:13:"Service image";s:6:"widget";a:5:{s:6:"weight";s:2:"-3";s:4:"type";s:11:"image_image";s:6:"module";s:5:"image";s:6:"active";i:1;s:8:"settings";a:2:{s:18:"progress_indicator";s:8:"throbber";s:19:"preview_image_style";s:6:"medium";}}s:8:"settings";a:9:{s:14:"file_directory";s:0:"";s:15:"file_extensions";s:16:"png gif jpg jpeg";s:12:"max_filesize";s:0:"";s:14:"max_resolution";s:0:"";s:14:"min_resolution";s:0:"";s:9:"alt_field";i:0;s:11:"title_field";i:0;s:18:"user_register_form";b:0;s:13:"default_image";i:0;}s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:5:"image";s:6:"weight";s:1:"0";s:8:"settings";a:2:{s:11:"image_style";s:9:"full_post";s:10:"image_link";s:0:"";}s:6:"module";s:5:"image";}}s:8:"required";i:0;s:11:"description";s:0:"";}', '0'),
('40', '1', 'comment_body', 'comment', 'comment_node_maps', 'a:6:{s:5:"label";s:7:"Comment";s:8:"settings";a:2:{s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:8:"required";b:1;s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";i:0;s:8:"settings";a:0:{}s:6:"module";s:4:"text";}}s:6:"widget";a:4:{s:4:"type";s:13:"text_textarea";s:8:"settings";a:1:{s:4:"rows";i:5;}s:6:"weight";i:0;s:6:"module";s:4:"text";}s:11:"description";s:0:"";}', '0'),
('41', '2', 'body', 'node', 'maps', 'a:6:{s:5:"label";s:4:"Body";s:6:"widget";a:4:{s:4:"type";s:26:"text_textarea_with_summary";s:8:"settings";a:2:{s:4:"rows";i:20;s:12:"summary_rows";i:5;}s:6:"weight";s:1:"2";s:6:"module";s:4:"text";}s:8:"settings";a:3:{s:15:"display_summary";b:1;s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:7:"display";a:2:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";s:1:"1";s:8:"settings";a:0:{}s:6:"module";s:4:"text";}s:6:"teaser";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:23:"text_summary_or_trimmed";s:8:"settings";a:1:{s:11:"trim_length";i:600;}s:6:"module";s:4:"text";s:6:"weight";i:0;}}s:8:"required";b:0;s:11:"description";s:0:"";}', '0'),
('42', '14', 'field_map', 'node', 'maps', 'a:7:{s:5:"label";s:3:"Map";s:6:"widget";a:5:{s:6:"weight";s:1:"1";s:4:"type";s:19:"getlocations_fields";s:6:"module";s:19:"getlocations_fields";s:6:"active";i:0;s:8:"settings";a:32:{s:7:"country";s:0:"";s:20:"use_country_dropdown";i:1;s:21:"province_autocomplete";i:0;s:17:"city_autocomplete";i:0;s:11:"use_address";i:1;s:19:"input_address_width";i:40;s:16:"input_name_width";i:40;s:18:"input_street_width";i:40;s:22:"input_additional_width";i:40;s:16:"input_city_width";i:40;s:20:"input_province_width";i:40;s:23:"input_postal_code_width";i:40;s:19:"input_country_width";i:40;s:20:"input_latitude_width";i:20;s:21:"input_longitude_width";i:20;s:17:"input_name_weight";i:0;s:19:"input_street_weight";i:0;s:23:"input_additional_weight";i:0;s:17:"input_city_weight";i:0;s:21:"input_province_weight";i:0;s:24:"input_postal_code_weight";i:0;s:20:"input_country_weight";i:0;s:21:"input_latitude_weight";i:0;s:22:"input_longitude_weight";i:0;s:19:"input_name_required";i:0;s:21:"input_street_required";i:0;s:25:"input_additional_required";i:0;s:19:"input_city_required";i:0;s:23:"input_province_required";i:0;s:26:"input_postal_code_required";i:0;s:22:"input_country_required";i:0;s:15:"per_item_marker";i:0;}}s:8:"settings";a:1:{s:18:"user_register_form";b:0;}s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:27:"getlocations_fields_default";s:6:"weight";s:1:"0";s:8:"settings";a:46:{s:15:"display_showmap";i:1;s:15:"display_maplink";i:1;s:16:"display_mapwidth";s:4:"100%";s:17:"display_mapheight";s:5:"300px";s:15:"display_latlong";i:0;s:11:"display_dms";i:0;s:14:"display_onemap";i:0;s:12:"display_name";i:0;s:14:"display_street";i:0;s:18:"display_additional";i:0;s:12:"display_city";i:0;s:16:"display_province";i:0;s:19:"display_postal_code";i:0;s:15:"display_country";i:0;s:12:"country_full";i:0;s:8:"nodezoom";s:2:"12";s:11:"controltype";s:5:"small";s:10:"pancontrol";i:1;s:3:"mtc";s:8:"standard";s:7:"maptype";s:3:"Map";s:10:"baselayers";a:4:{s:3:"Map";i:1;s:9:"Satellite";i:1;s:6:"Hybrid";i:0;s:8:"Physical";i:0;}s:8:"behavior";a:4:{s:5:"scale";i:0;s:8:"overview";i:0;s:15:"overview_opened";i:0;s:11:"scrollwheel";i:0;}s:9:"draggable";i:1;s:15:"streetview_show";i:0;s:11:"trafficinfo";i:0;s:17:"trafficinfo_state";i:0;s:11:"bicycleinfo";i:0;s:17:"bicycleinfo_state";i:0;s:11:"transitinfo";i:0;s:17:"transitinfo_state";i:0;s:8:"poi_show";i:1;s:12:"transit_show";i:1;s:16:"markeractiontype";s:1:"1";s:12:"markeraction";s:1:"2";s:14:"panoramio_show";i:0;s:15:"panoramio_state";i:0;s:10:"map_marker";s:6:"drupal";s:15:"node_map_marker";s:6:"drupal";s:15:"user_map_marker";s:6:"drupal";s:21:"vocabulary_map_marker";s:6:"drupal";s:18:"comment_map_marker";s:6:"drupal";s:12:"weather_show";i:0;s:13:"weather_state";i:0;s:13:"weather_cloud";i:1;s:19:"weather_cloud_state";i:0;s:15:"per_item_marker";i:0;}s:6:"module";s:19:"getlocations_fields";}}s:8:"required";i:1;s:11:"description";s:0:"";s:13:"default_value";a:1:{i:0;a:11:{s:4:"name";s:0:"";s:6:"street";s:0:"";s:10:"additional";s:0:"";s:4:"city";s:0:"";s:8:"province";s:0:"";s:11:"postal_code";s:0:"";s:7:"country";s:2:"US";s:6:"marker";s:0:"";s:8:"latitude";s:0:"";s:9:"longitude";s:0:"";s:6:"active";b:0;}}}', '0'),
('43', '15', 'field_position', 'node', 'employee', 'a:7:{s:5:"label";s:8:"Position";s:6:"widget";a:5:{s:6:"weight";s:2:"-2";s:4:"type";s:14:"text_textfield";s:6:"module";s:4:"text";s:6:"active";i:1;s:8:"settings";a:1:{s:4:"size";s:2:"60";}}s:8:"settings";a:2:{s:15:"text_processing";s:1:"0";s:18:"user_register_form";b:0;}s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:5:"above";s:4:"type";s:12:"text_default";s:8:"settings";a:0:{}s:6:"module";s:4:"text";s:6:"weight";i:2;}}s:8:"required";i:0;s:11:"description";s:0:"";s:13:"default_value";N;}', '0'),
('44', '16', 'field_addthis', 'node', 'article', 'a:7:{s:5:"label";s:7:"Addthis";s:6:"widget";a:5:{s:6:"weight";i:0;s:4:"type";s:21:"addthis_button_widget";s:6:"module";s:7:"addthis";s:6:"active";i:0;s:8:"settings";a:0:{}}s:8:"settings";a:1:{s:18:"user_register_form";b:0;}s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:21:"addthis_basic_toolbox";s:6:"weight";s:2:"11";s:8:"settings";a:4:{s:14:"share_services";s:52:"facebook_like,tweet,google_plusone,pinterest,compact";s:12:"buttons_size";s:19:"addthis_16x16_style";s:19:"counter_orientation";s:10:"horizontal";s:9:"extra_css";s:0:"";}s:6:"module";s:16:"addthis_displays";}}s:8:"required";b:0;s:11:"description";s:0:"";s:13:"default_value";N;}', '0'),
('45', '17', 'field_addthis_blog', 'node', 'blog', 'a:7:{s:5:"label";s:7:"addthis";s:6:"widget";a:5:{s:6:"weight";s:1:"4";s:4:"type";s:21:"addthis_button_widget";s:6:"module";s:7:"addthis";s:6:"active";i:0;s:8:"settings";a:0:{}}s:8:"settings";a:1:{s:18:"user_register_form";b:0;}s:7:"display";a:2:{s:7:"default";a:5:{s:5:"label";s:5:"above";s:4:"type";s:21:"addthis_basic_toolbox";s:6:"weight";s:1:"3";s:8:"settings";a:4:{s:14:"share_services";s:52:"facebook_like,tweet,google_plusone,pinterest,compact";s:12:"buttons_size";s:19:"addthis_16x16_style";s:19:"counter_orientation";s:10:"horizontal";s:9:"extra_css";s:0:"";}s:6:"module";s:16:"addthis_displays";}s:4:"full";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:21:"addthis_basic_toolbox";s:6:"weight";s:1:"2";s:8:"settings";a:4:{s:14:"share_services";s:52:"facebook_like,tweet,google_plusone,pinterest,compact";s:12:"buttons_size";s:19:"addthis_16x16_style";s:19:"counter_orientation";s:10:"horizontal";s:9:"extra_css";s:0:"";}s:6:"module";s:16:"addthis_displays";}}s:8:"required";b:0;s:11:"description";s:0:"";s:13:"default_value";N;}', '0'),
('46', '18', 'field_blog_category', 'node', 'blog', 'a:7:{s:5:"label";s:13:"Blog category";s:6:"widget";a:5:{s:6:"weight";s:1:"1";s:4:"type";s:15:"options_buttons";s:6:"module";s:7:"options";s:6:"active";i:1;s:8:"settings";a:0:{}}s:8:"settings";a:1:{s:18:"user_register_form";b:0;}s:7:"display";a:2:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:28:"taxonomy_term_reference_link";s:6:"weight";s:1:"2";s:8:"settings";a:0:{}s:6:"module";s:8:"taxonomy";}s:4:"full";a:4:{s:5:"label";s:5:"above";s:4:"type";s:6:"hidden";s:6:"weight";s:1:"0";s:8:"settings";a:0:{}}}s:8:"required";i:0;s:11:"description";s:0:"";s:13:"default_value";N;}', '0'),
('47', '19', 'field_portfolio_category', 'node', 'portfolio', 'a:7:{s:5:"label";s:18:"Portfolio Category";s:6:"widget";a:5:{s:6:"weight";s:1:"1";s:4:"type";s:19:"term_reference_tree";s:6:"module";s:19:"term_reference_tree";s:6:"active";i:1;s:8:"settings";a:9:{s:15:"start_minimized";i:0;s:11:"leaves_only";i:0;s:14:"select_parents";i:0;s:19:"cascading_selection";i:0;s:11:"filter_view";s:0:"";s:13:"token_display";s:0:"";s:10:"track_list";i:0;s:9:"max_depth";s:0:"";s:14:"parent_term_id";s:0:"";}}s:8:"settings";a:1:{s:18:"user_register_form";b:0;}s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:28:"taxonomy_term_reference_link";s:6:"weight";s:1:"2";s:8:"settings";a:0:{}s:6:"module";s:8:"taxonomy";}}s:8:"required";i:0;s:11:"description";s:0:"";s:13:"default_value";N;}', '0'),
('48', '1', 'comment_body', 'comment', 'comment_node_popular_services', 'a:6:{s:5:"label";s:7:"Comment";s:8:"settings";a:2:{s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:8:"required";b:1;s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";i:0;s:8:"settings";a:0:{}s:6:"module";s:4:"text";}}s:6:"widget";a:4:{s:4:"type";s:13:"text_textarea";s:8:"settings";a:1:{s:4:"rows";i:5;}s:6:"weight";i:0;s:6:"module";s:4:"text";}s:11:"description";s:0:"";}', '0'),
('49', '2', 'body', 'node', 'popular_services', 'a:6:{s:5:"label";s:4:"Body";s:6:"widget";a:4:{s:4:"type";s:26:"text_textarea_with_summary";s:8:"settings";a:2:{s:4:"rows";i:20;s:12:"summary_rows";i:5;}s:6:"weight";s:2:"-4";s:6:"module";s:4:"text";}s:8:"settings";a:3:{s:15:"display_summary";b:1;s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:7:"display";a:2:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";s:1:"1";s:8:"settings";a:0:{}s:6:"module";s:4:"text";}s:6:"teaser";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:23:"text_summary_or_trimmed";s:8:"settings";a:1:{s:11:"trim_length";i:600;}s:6:"module";s:4:"text";s:6:"weight";i:0;}}s:8:"required";b:0;s:11:"description";s:0:"";}', '0'),
('50', '20', 'field_popular_services_image', 'node', 'popular_services', 'a:6:{s:5:"label";s:22:"Popular services image";s:6:"widget";a:5:{s:6:"weight";s:2:"-3";s:4:"type";s:11:"image_image";s:6:"module";s:5:"image";s:6:"active";i:1;s:8:"settings";a:2:{s:18:"progress_indicator";s:8:"throbber";s:19:"preview_image_style";s:9:"thumbnail";}}s:8:"settings";a:9:{s:14:"file_directory";s:11:"field/image";s:15:"file_extensions";s:16:"png gif jpg jpeg";s:12:"max_filesize";s:0:"";s:14:"max_resolution";s:0:"";s:14:"min_resolution";s:0:"";s:9:"alt_field";i:0;s:11:"title_field";i:0;s:13:"default_image";i:0;s:18:"user_register_form";b:0;}s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:5:"image";s:6:"weight";s:1:"0";s:8:"settings";a:2:{s:11:"image_style";s:9:"full_post";s:10:"image_link";s:0:"";}s:6:"module";s:5:"image";}}s:8:"required";i:0;s:11:"description";s:0:"";}', '0'),
('51', '1', 'comment_body', 'comment', 'comment_node_testimonials', 'a:6:{s:5:"label";s:7:"Comment";s:8:"settings";a:2:{s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:8:"required";b:1;s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";i:0;s:8:"settings";a:0:{}s:6:"module";s:4:"text";}}s:6:"widget";a:4:{s:4:"type";s:13:"text_textarea";s:8:"settings";a:1:{s:4:"rows";i:5;}s:6:"weight";i:0;s:6:"module";s:4:"text";}s:11:"description";s:0:"";}', '0'),
('52', '2', 'body', 'node', 'testimonials', 'a:6:{s:5:"label";s:4:"Body";s:6:"widget";a:4:{s:4:"type";s:26:"text_textarea_with_summary";s:8:"settings";a:2:{s:4:"rows";i:20;s:12:"summary_rows";i:5;}s:6:"weight";s:1:"2";s:6:"module";s:4:"text";}s:8:"settings";a:3:{s:15:"display_summary";b:1;s:15:"text_processing";i:1;s:18:"user_register_form";b:0;}s:7:"display";a:2:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";s:1:"0";s:8:"settings";a:0:{}s:6:"module";s:4:"text";}s:6:"teaser";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:23:"text_summary_or_trimmed";s:8:"settings";a:1:{s:11:"trim_length";i:600;}s:6:"module";s:4:"text";s:6:"weight";i:0;}}s:8:"required";b:0;s:11:"description";s:0:"";}', '0'),
('53', '21', 'field_testimonials_position', 'node', 'testimonials', 'a:7:{s:5:"label";s:21:"Testimonials Position";s:6:"widget";a:5:{s:6:"weight";s:1:"1";s:4:"type";s:14:"text_textfield";s:6:"module";s:4:"text";s:6:"active";i:1;s:8:"settings";a:1:{s:4:"size";s:2:"60";}}s:8:"settings";a:2:{s:15:"text_processing";s:1:"0";s:18:"user_register_form";b:0;}s:7:"display";a:1:{s:7:"default";a:5:{s:5:"label";s:6:"hidden";s:4:"type";s:12:"text_default";s:6:"weight";s:1:"1";s:8:"settings";a:0:{}s:6:"module";s:4:"text";}}s:8:"required";i:0;s:11:"description";s:0:"";s:13:"default_value";N;}', '0');
/*!40000 ALTER TABLE field_config_instance ENABLE KEYS */;

--
-- Table structure for table 'field_data_body'
--

CREATE TABLE IF NOT EXISTS `field_data_body` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned DEFAULT NULL COMMENT 'The entity revision id this data is attached to, or NULL if the entity type is not versioned',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `body_value` longtext,
  `body_summary` longtext,
  `body_format` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`entity_type`,`entity_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `body_format` (`body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Data storage for field 2 (body)';

--
-- Dumping data for table 'field_data_body'
--

/*!40000 ALTER TABLE field_data_body DISABLE KEYS */;
INSERT INTO `field_data_body` VALUES
('node', 'forum', '0', '12', '12', 'en', '0', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus feugiat viverra libero nec cursus. Fusce vestibulum felis non felis viverra dignissim molestie justo semper. Phasellus tortor nisl, interdum a consequat mollis, vehicula id neque. Vivamus interdum ornare erat, eu egestas risus eleifend a. Donec a lacus id nulla volutpat gravida ac sed dui. In hac habitasse platea dictumst. Nulla sagittis aliquam tellus, sit amet facilisis metus imperdiet vitae. Integer convallis, purus vitae lacinia bibendum, dui ligula varius dolor, vitae elementum dui risus sit amet velit. Phasellus enim nibh, pharetra eget bibendum in, condimentum a magna. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Mauris fermentum luctus eleifend. Donec quis velit lorem. Ut fermentum arcu in tellus dictum at porttitor odio porttitor. Vivamus sodales porttitor diam, sit amet faucibus lorem imperdiet in. Nam volutpat, eros ut convallis viverra, odio velit iaculis dui, quis tristique turpis justo non ipsum. Nulla aliquam varius ante sit amet dictum.\r\nNulla aliquam libero at lorem pellentesque tincidunt. Phasellus dictum luctus odio, sit amet adipiscing odio venenatis a. Praesent ut blandit felis. Donec auctor aliquet pellentesque. Fusce vitae auctor lorem. Integer vel urna diam. Integer vitae felis sit amet neque rutrum tincidunt id eget justo. Donec felis velit, faucibus nec congue hendrerit, cursus at nunc. Curabitur ac orci vel mauris eleifend pulvinar. Curabitur mollis, risus nec interdum gravida, velit nisl varius purus, hendrerit vulputate arcu magna a felis. In vitae consequat quam. Maecenas purus quam, tincidunt sit amet venenatis vel, venenatis dignissim nisi. Proin in ultricies risus. Quisque feugiat consequat vestibulum. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nunc cursus purus ut lectus dictum volutpat imperdiet quam commodo. Pellentesque lobortis est quis nulla vestibulum lacinia. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Nullam eu ligula ut urna hendrerit malesuada at viverra justo. Fusce semper nisl a lorem vehicula consectetur.', '', 'filtered_html'),
('node', 'forum', '0', '13', '13', 'en', '0', 'In pellentesque facilisis iaculis. Vestibulum euismod leo ac risus vulputate eget tempor mauris malesuada. Nulla feugiat leo vitae nisl ullamcorper in ornare urna aliquam. Donec eget dui feugiat turpis facilisis euismod. Quisque pretium, erat eu feugiat porttitor, lectus odio euismod elit, eget varius purus massa non erat. Nam neque tellus, imperdiet ac ullamcorper a, elementum eget ipsum. Pellentesque ut sem nibh. Proin nec lectus augue, sit amet ultrices neque. In sit amet lacus justo, a ultricies nibh. Nullam condimentum congue odio, semper consequat nulla dignissim sed. Donec rhoncus, lacus sed commodo laoreet, arcu nulla ullamcorper arcu, in facilisis risus mauris id nibh. Fusce lacinia vulputate odio, ac luctus sapien elementum non.\r\n\r\nSed scelerisque tristique enim, ac feugiat velit ultricies at. Fusce eget dui urna, sed tempus ipsum. Quisque aliquet convallis urna quis rhoncus. Aliquam vestibulum sodales interdum. Quisque quis nisi velit. Duis vestibulum nibh posuere sem commodo pharetra. Etiam eget mauris metus. Quisque congue ante augue. Quisque vehicula accumsan diam sit amet convallis. Donec eu nisl sed tellus condimentum lobortis. Fusce nulla sem, lacinia vel lacinia et, faucibus ac nibh. Etiam a congue massa. Praesent in nisi tellus. Praesent aliquam aliquam enim sit amet congue. Quisque pharetra aliquam odio in aliquam. Nunc et turpis mauris. Nulla tincidunt laoreet dictum. Lorem ipsum dolor sit amet, consectetur adipiscing elit.\r\n\r\nSed nunc nulla, molestie at interdum sit amet, consequat a justo. Nunc lobortis rhoncus malesuada. Nullam enim erat, accumsan sed tincidunt vel, pellentesque nec nibh. Morbi felis est, consequat nec varius consequat, ornare sit amet justo. Nam a tortor eget neque suscipit pharetra. Proin massa ante, porttitor quis commodo ut, fermentum id mi. Praesent ac sapien nunc. Nam id nisl eget dolor varius volutpat vel nec dolor. Vestibulum libero leo, fermentum a euismod ut, vehicula ac mauris. Integer at lectus dui, tempor vulputate lacus.\r\n', '', 'filtered_html'),
('node', 'forum', '0', '14', '14', 'en', '0', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam aliquet auctor tellus, quis pharetra massa blandit ac. Pellentesque feugiat pulvinar tincidunt. Duis consequat mollis massa ut iaculis. Cras commodo magna a ante auctor tempor. Quisque vehicula, tortor lobortis euismod ultricies, odio risus malesuada ipsum, sed euismod enim mauris in tellus. Fusce vehicula augue a dui faucibus fringilla. Etiam ut purus id metus convallis porttitor. Nam porta facilisis mauris, aliquam dapibus lectus imperdiet vitae. Praesent lobortis egestas nisi, quis fringilla nibh ultrices ut. Etiam vel est rhoncus orci viverra placerat porttitor quis nibh. Quisque rutrum euismod odio a porttitor. Suspendisse rhoncus, odio a tempus commodo, eros ipsum viverra enim, in condimentum tortor magna sed nisi. Vivamus quam metus, condimentum in consectetur sed, aliquet id felis. Etiam non leo nunc, a cursus velit. Vestibulum sed urna ut mauris facilisis ullamcorper ut et libero. In bibendum tristique lectus.\r\n\r\nNulla facilisi. Mauris porta magna eget dolor vestibulum dapibus. Integer lacus est, vulputate eget porttitor in, ultricies id nunc. Sed luctus, augue quis hendrerit tincidunt, orci turpis placerat dolor, et luctus neque nisl sed nunc. Ut id interdum massa. Proin a eros ut nibh rhoncus rhoncus at et mauris. Phasellus ornare odio in est mollis tristique. Morbi hendrerit rutrum porttitor. Donec scelerisque ipsum nisl, sed porttitor ante. Morbi posuere leo congue risus fringilla id rutrum sapien aliquam. Nam a dolor quam. Maecenas posuere rhoncus est a auctor. Sed odio nulla, pulvinar a dapibus in, sollicitudin a lectus. Maecenas pretium consectetur eleifend. Ut pharetra ipsum at magna venenatis vel ullamcorper mauris laoreet. Sed lacinia, urna vulputate venenatis eleifend, libero urna rhoncus lorem, a convallis nisl magna a neque. Quisque lobortis, justo in ultricies scelerisque, ante velit commodo urna, sit amet placerat dui nisi vitae est. Vestibulum quis euismod leo. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Morbi ultrices mi vitae ante elementum posuere.\r\n\r\nNunc dapibus, risus eget malesuada pellentesque, lorem turpis pellentesque tortor, et rutrum est nibh quis nisl. Integer suscipit lectus sit amet nibh malesuada aliquam. Ut iaculis tristique felis nec placerat. Maecenas et neque risus. Integer ultricies varius dui a auctor. Vestibulum erat erat, tincidunt et pellentesque eget, mattis ut est. Donec id tortor quis mauris consequat pharetra. Duis commodo consectetur odio, non tempor dui mollis non. Donec tempor, urna vel porta sagittis, mi diam dictum lectus, sit amet egestas justo nisi in quam. Quisque blandit interdum imperdiet. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. In eget feugiat metus. Integer urna enim, congue in pharetra id, rutrum non lectus. Aliquam urna nisi, tempus a facilisis et, varius vel justo. Duis cursus mollis sapien, eget porta ipsum ultricies vel. Ut eu nisl nisi, sit amet dapibus urna. Donec sit amet tempus sem. Nunc ipsum libero, laoreet a accumsan eget, ullamcorper quis tellus. Duis hendrerit tortor lectus.', '', 'filtered_html'),
('node', 'forum', '0', '15', '15', 'en', '0', 'Suspendisse potenti. Fusce diam risus, mattis sit amet pretium in, feugiat sed purus. Vivamus in lectus tellus. Nam justo leo, placerat sit amet imperdiet ut, accumsan quis nulla. Donec tristique tristique massa at malesuada. Nulla eleifend ultricies tempus. Nulla dapibus tempus pulvinar. Nullam urna sem, vestibulum ac porttitor sit amet, semper ut dui. Etiam at turpis sed risus auctor molestie eget quis lectus. Donec lacus tortor, condimentum nec pharetra et, adipiscing a sapien. Nulla ac ante diam. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Phasellus bibendum euismod lobortis. Phasellus semper elementum quam a iaculis. Morbi tristique diam id ante sagittis rutrum.\r\n\r\nMaecenas porttitor varius velit, eget lacinia mi semper et. Ut aliquam, augue at volutpat venenatis, quam tellus gravida enim, cursus blandit libero purus sed quam. Aliquam sollicitudin, mauris ac tincidunt convallis, erat neque mollis lacus, quis placerat odio justo placerat purus. Duis in ipsum eu sem vestibulum imperdiet sed ac neque. Vivamus in augue massa, nec aliquam nulla. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Pellentesque consequat imperdiet odio ut accumsan. Donec vel dolor sit amet ante mollis molestie at nec felis. Quisque sit amet mauris eget massa dictum tempus et mattis eros. Nunc tincidunt mattis massa et malesuada. Fusce tempus pulvinar nisi, vitae consectetur neque iaculis sit amet. Aliquam erat volutpat.\r\n\r\nFusce porttitor porta tortor pulvinar iaculis. Nulla facilisi. Etiam semper hendrerit lectus, sit amet ultricies augue porta ut. Praesent vitae dolor vitae felis congue mollis. Nulla fermentum augue sit amet sem luctus dignissim. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. In dignissim tincidunt mollis. Sed sed massa lorem, sed laoreet est. Pellentesque sit amet orci sed arcu euismod posuere id in nisl. Aenean in quam tortor. Curabitur consequat metus ut nulla viverra tincidunt. In hac habitasse platea dictumst. Suspendisse hendrerit, quam a dignissim pellentesque, turpis risus bibendum massa, quis lacinia sem sem eget est. Praesent magna nisi, dignissim laoreet hendrerit lobortis, gravida non velit. Nullam ut velit augue. Mauris mattis tellus elit, et vehicula purus. Nulla eros libero, pretium id elementum id, euismod non risus. Donec enim nisi, luctus quis vestibulum eu, dapibus quis nisi. Cras porttitor sem sit amet metus fermentum pretium.', '', 'filtered_html'),
('node', 'forum', '0', '16', '16', 'en', '0', 'Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. In mollis gravida auctor. Fusce facilisis blandit quam, at imperdiet magna blandit id. In dignissim rutrum dolor a lobortis. Cras eros ligula, volutpat sed condimentum ut, blandit at enim. Cras ipsum leo, euismod vitae consectetur at, suscipit et turpis. Integer aliquet, dui ac cursus ultricies, nibh ante varius lectus, et blandit libero nulla consectetur massa. Sed lobortis lacinia dui at cursus. Vivamus posuere diam eget libero placerat dapibus. Aliquam sit amet justo nisl. Duis tristique, felis a porttitor dictum, ipsum justo ultrices ante, vel facilisis lectus risus sit amet quam. Mauris vel enim a ante luctus dignissim. Nunc rhoncus convallis dolor. Mauris sem ante, aliquam vel vulputate eget, tristique et tellus. Curabitur cursus, leo eu aliquet tempus, est massa fringilla metus, nec mollis nisl nisi eget ante. Etiam cursus ante consequat nisi feugiat consectetur.\r\n\r\nSuspendisse potenti. Fusce diam risus, mattis sit amet pretium in, feugiat sed purus. Vivamus in lectus tellus. Nam justo leo, placerat sit amet imperdiet ut, accumsan quis nulla. Donec tristique tristique massa at malesuada. Nulla eleifend ultricies tempus. Nulla dapibus tempus pulvinar. Nullam urna sem, vestibulum ac porttitor sit amet, semper ut dui. Etiam at turpis sed risus auctor molestie eget quis lectus. Donec lacus tortor, condimentum nec pharetra et, adipiscing a sapien. Nulla ac ante diam. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Phasellus bibendum euismod lobortis. Phasellus semper elementum quam a iaculis. Morbi tristique diam id ante sagittis rutrum.\r\n\r\nMaecenas porttitor varius velit, eget lacinia mi semper et. Ut aliquam, augue at volutpat venenatis, quam tellus gravida enim, cursus blandit libero purus sed quam. Aliquam sollicitudin, mauris ac tincidunt convallis, erat neque mollis lacus, quis placerat odio justo placerat purus. Duis in ipsum eu sem vestibulum imperdiet sed ac neque. Vivamus in augue massa, nec aliquam nulla. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Pellentesque consequat imperdiet odio ut accumsan. Donec vel dolor sit amet ante mollis molestie at nec felis. Quisque sit amet mauris eget massa dictum tempus et mattis eros. Nunc tincidunt mattis massa et malesuada. Fusce tempus pulvinar nisi, vitae consectetur neque iaculis sit amet. Aliquam erat volutpat.', '', 'filtered_html'),
('node', 'forum', '0', '17', '17', 'en', '0', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Suspendisse eu lectus erat. Morbi malesuada porta lacus, id consequat magna aliquet quis. Vestibulum facilisis vehicula felis, auctor ornare dolor sagittis in. Curabitur ac nunc ante. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Nam vehicula venenatis scelerisque. Pellentesque accumsan eleifend lectus, in ornare erat pharetra ut. Vivamus faucibus feugiat varius. Nam vitae nisi libero. Cras scelerisque egestas lacus id porttitor. Sed in ipsum a nulla tincidunt luctus. Integer tempus, urna et dapibus pharetra, sapien purus eleifend quam, quis convallis nisi quam non justo. Mauris nec magna tortor, vitae cursus diam.\r\n\r\nUt vehicula, quam aliquam fringilla condimentum, diam metus hendrerit nisl, eu tempus erat ante et odio. Nulla elementum fermentum pulvinar. Ut ut enim urna, nec auctor velit. Sed ac risus ligula. Etiam tincidunt tempus est, sit amet mattis nibh fringilla sed. In augue sapien, congue et ornare ornare, auctor at tortor. Praesent hendrerit ipsum pulvinar erat pharetra dictum in vel ligula. Nunc convallis porttitor ipsum, at vestibulum velit vehicula eu. Fusce nisi dui, imperdiet sed auctor ut, porta in quam. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas.\r\n\r\nNam nec est a nulla pulvinar dignissim eget quis enim. Integer facilisis ipsum et leo molestie et cursus mi tristique. Nullam placerat facilisis vehicula. In bibendum commodo urna, mollis volutpat justo ultricies et. Proin quis justo velit. Vestibulum posuere nulla sit amet risus aliquet aliquet ornare enim luctus. Quisque vel massa scelerisque erat ultrices placerat non id augue. Nulla commodo scelerisque massa, ac iaculis eros ultricies a. Praesent ac odio sit amet odio mollis ultricies ac eu erat. Integer eu diam nibh. Nam cursus magna congue augue facilisis tempus. Vivamus dapibus eleifend scelerisque. Curabitur posuere, sapien in sodales suscipit, dolor metus pulvinar ante, varius tincidunt mi metus ac sapien. Curabitur lectus lacus, ullamcorper at bibendum sit amet, congue vitae nisl.', '', 'filtered_html'),
('node', 'forum', '0', '18', '18', 'en', '0', 'Nam nec est a nulla pulvinar dignissim eget quis enim. Integer facilisis ipsum et leo molestie et cursus mi tristique. Nullam placerat facilisis vehicula. In bibendum commodo urna, mollis volutpat justo ultricies et. Proin quis justo velit. Vestibulum posuere nulla sit amet risus aliquet aliquet ornare enim luctus. Quisque vel massa scelerisque erat ultrices placerat non id augue. Nulla commodo scelerisque massa, ac iaculis eros ultricies a. Praesent ac odio sit amet odio mollis ultricies ac eu erat. Integer eu diam nibh. Nam cursus magna congue augue facilisis tempus. Vivamus dapibus eleifend scelerisque. Curabitur posuere, sapien in sodales suscipit, dolor metus pulvinar ante, varius tincidunt mi metus ac sapien. Curabitur lectus lacus, ullamcorper at bibendum sit amet, congue vitae nisl.\r\n\r\nDuis lobortis arcu dignissim mauris accumsan laoreet. Donec nisl risus, tincidunt at interdum nec, elementum vitae metus. Integer non diam nec est imperdiet sollicitudin. Duis ac massa in nibh lacinia pellentesque. Aenean ac metus ac dolor dapibus hendrerit. Vivamus mauris tellus, fringilla quis tempus vehicula, convallis sit amet ligula. Proin eget velit nec urna placerat congue. Vivamus malesuada, libero id sagittis vehicula, elit diam vulputate erat, in aliquet mauris mi sed lacus. Nullam sodales viverra leo nec sollicitudin. Phasellus rhoncus gravida ullamcorper. Mauris a enim orci. Vestibulum eleifend convallis mi, id sodales ante varius ut. Vivamus at tristique nisi. Nunc sem leo, venenatis eu fermentum et, ultrices ut enim. Nullam nec augue neque, vitae posuere nisl. In convallis, sapien at ultrices gravida, enim libero bibendum nunc, eget interdum mauris neque at felis. Mauris tincidunt varius tellus, quis condimentum felis dictum a. Nam porta tellus massa.', '', 'filtered_html'),
('node', 'forum', '0', '19', '19', 'en', '0', 'In ac lectus massa. Pellentesque eros ligula, elementum ut tincidunt nec, sodales et ipsum. Etiam sed neque magna. Nullam aliquet dolor et augue malesuada sagittis. Nullam vitae metus odio, at aliquet velit. In leo arcu, auctor in suscipit sed, auctor vitae purus. Sed vel mauris ante. Vivamus placerat venenatis mauris ut consectetur. Donec condimentum sagittis arcu, eu lobortis erat facilisis sed. Morbi justo dolor, vulputate sed iaculis lacinia, molestie at nunc. Curabitur laoreet accumsan elit, nec venenatis odio faucibus eu. Praesent rhoncus, massa id pellentesque congue, est neque sagittis lacus, a pulvinar quam neque vitae tortor. Nam in mauris mattis neque pretium fringilla sed consectetur tellus.\r\n\r\nAenean nisi ante, tempus eget egestas sit amet, molestie sit amet neque. Fusce interdum mi a ligula euismod posuere. Maecenas auctor, orci vitae viverra bibendum, ante erat molestie nulla, consectetur accumsan nulla nunc vel lacus. Sed pretium neque risus, sit amet laoreet purus. Suspendisse mattis ligula ut erat auctor placerat suscipit sapien pulvinar. Nam ullamcorper nisl et ligula pretium mollis. Etiam convallis, enim id volutpat gravida, enim diam aliquet lectus, et euismod nulla turpis quis leo. Vestibulum consectetur augue eu elit consectetur auctor. Praesent dui nibh, tincidunt eu rutrum ut, vulputate sit amet arcu. Etiam varius mauris non justo tincidunt tristique. Fusce vitae mi a ligula malesuada interdum. Vivamus feugiat arcu sed neque vestibulum sed vulputate est fermentum. Mauris interdum, dui sed luctus rutrum, mauris nibh venenatis leo, nec euismod erat nunc ac augue. Proin justo elit, dictum ac malesuada sed, vehicula fringilla ligula. In tempus lectus quis odio blandit commodo. Mauris aliquam tellus at elit bibendum blandit. Donec non ipsum a lorem lacinia iaculis. Sed purus eros, scelerisque et consectetur sed, dictum eget erat. Donec non magna ligula. Suspendisse a volutpat enim.', '', 'filtered_html'),
('node', 'forum', '0', '20', '20', 'en', '0', 'Aenean nisi ante, tempus eget egestas sit amet, molestie sit amet neque. Fusce interdum mi a ligula euismod posuere. Maecenas auctor, orci vitae viverra bibendum, ante erat molestie nulla, consectetur accumsan nulla nunc vel lacus. Sed pretium neque risus, sit amet laoreet purus. Suspendisse mattis ligula ut erat auctor placerat suscipit sapien pulvinar. Nam ullamcorper nisl et ligula pretium mollis. Etiam convallis, enim id volutpat gravida, enim diam aliquet lectus, et euismod nulla turpis quis leo. Vestibulum consectetur augue eu elit consectetur auctor. Praesent dui nibh, tincidunt eu rutrum ut, vulputate sit amet arcu. Etiam varius mauris non justo tincidunt tristique. Fusce vitae mi a ligula malesuada interdum. Vivamus feugiat arcu sed neque vestibulum sed vulputate est fermentum. Mauris interdum, dui sed luctus rutrum, mauris nibh venenatis leo, nec euismod erat nunc ac augue. Proin justo elit, dictum ac malesuada sed, vehicula fringilla ligula. In tempus lectus quis odio blandit commodo. Mauris aliquam tellus at elit bibendum blandit. Donec non ipsum a lorem lacinia iaculis. Sed purus eros, scelerisque et consectetur sed, dictum eget erat. Donec non magna ligula. Suspendisse a volutpat enim.\r\n\r\nSuspendisse vulputate hendrerit nulla, eget adipiscing nibh rutrum non. Praesent in accumsan risus. Praesent quis eros sem, ac mattis eros. Curabitur erat ante, porttitor et euismod et, molestie a massa. Donec vitae urna quis nibh pretium eleifend. Fusce orci leo, gravida nec venenatis sit amet, interdum vitae dui. Duis vel condimentum neque. In a justo nulla. In hac habitasse platea dictumst. Curabitur vehicula eros sed lectus pellentesque facilisis. Morbi accumsan lorem sit amet purus posuere sed vulputate quam luctus. Fusce molestie, urna at tempor pulvinar, massa purus vehicula neque, consectetur consequat nibh mi et leo. Proin id rhoncus arcu. Etiam vestibulum bibendum nisi nec eleifend. Donec velit turpis, tincidunt sit amet varius eu, rhoncus sed risus. Sed rhoncus dignissim arcu, eu dignissim justo tempus ut. Fusce interdum lectus massa, sit amet rhoncus sem.\r\n\r\nMauris aliquam tempor lorem id mollis. Pellentesque vehicula nunc eu risus condimentum et placerat turpis dignissim. Donec scelerisque tellus sed massa ullamcorper molestie. Pellentesque sem metus, vestibulum rhoncus hendrerit sed, venenatis a ipsum. Duis sit amet dui velit, id rhoncus neque. Etiam leo risus, tincidunt at pharetra eget, sodales sit amet lacus. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Duis eleifend, sem ut iaculis pharetra, sem mauris porttitor ligula, et molestie orci augue et nibh. Ut vulputate aliquam tortor, eu tristique nisl euismod et. Phasellus eget mauris ut metus mattis ullamcorper ut a orci. Nullam quam leo, vulputate id condimentum id, fermentum vitae urna. Donec eget lacus at tortor interdum elementum. Sed vulputate gravida nisi, ac venenatis nisi blandit id. Curabitur ac nibh nibh. Ut ut neque urna. Nunc ullamcorper massa fermentum lacus elementum fringilla. Pellentesque quis metus a leo egestas vehicula.', '', 'filtered_html'),
('node', 'forum', '0', '21', '21', 'en', '0', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec vestibulum ultrices mollis. Sed id purus mattis leo pulvinar hendrerit quis non turpis. Donec eleifend malesuada lorem, ac sagittis dui tempus id. Duis risus mi, fringilla sit amet elementum in, vulputate non orci. Mauris at pharetra elit. Curabitur libero orci, elementum iaculis congue nec, placerat a lorem. Nunc ornare, leo id condimentum dictum, metus ante mattis felis, a venenatis urna magna a nisi. Donec hendrerit malesuada egestas. Mauris ligula tellus, bibendum in pellentesque et, cursus volutpat augue. Ut sollicitudin libero id purus dignissim pellentesque laoreet massa pharetra. Cras dignissim tortor quis erat hendrerit ut adipiscing elit laoreet. Sed hendrerit convallis pretium. Nunc quis turpis turpis, at adipiscing neque. Sed mi nisi, pulvinar non posuere non, varius et lacus. Vestibulum risus metus, vehicula nec ornare eget, ultrices non tortor. In vulputate turpis ipsum, sed cursus mi. Sed elit sem, tristique id tempor eu, molestie et magna. Vestibulum porta nisl a urna tincidunt eget tristique leo blandit.\r\n\r\nProin dictum, libero eget aliquet dictum, nisi mi venenatis sem, sed rhoncus turpis nibh rhoncus elit. Cras porttitor, nunc eu tincidunt vulputate, enim dolor viverra ipsum, vel eleifend risus justo vel neque. Proin hendrerit vestibulum diam, at imperdiet enim rutrum eu. Curabitur eros augue, iaculis in mollis sit amet, tincidunt vitae turpis. Maecenas eu erat vel massa scelerisque mollis sed in ligula. Duis consectetur congue felis a porta. Pellentesque turpis nisl, faucibus et blandit nec, mattis vel purus. Nulla facilisi. Ut viverra fermentum felis, nec dapibus massa suscipit ut. Vestibulum id ligula lacus, et tristique libero.\r\n\r\nCras euismod aliquet massa scelerisque euismod. Phasellus tincidunt, eros sit amet cursus porta, neque velit tincidunt lacus, non mattis risus augue ut erat. Phasellus facilisis ornare massa, ac porttitor erat hendrerit eget. Cras porttitor aliquet aliquam. Phasellus at mauris vitae metus pharetra semper. Aliquam mi ligula, commodo ut pharetra quis, bibendum ac odio. Nullam tincidunt nulla vel massa lacinia varius. Ut tortor urna, faucibus vel posuere ut, hendrerit eu ante. Pellentesque porttitor iaculis sem, a adipiscing sapien commodo sit amet. Duis non massa quis leo fringilla aliquam. Phasellus fermentum congue velit. Sed blandit, ante non ornare iaculis, turpis mauris consectetur nunc, id venenatis turpis odio et ante. Pellentesque bibendum tincidunt justo porta dictum. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris neque eros, pretium nec cursus sit amet, mattis vitae felis. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Aenean vel magna vitae felis euismod congue a at magna. Donec varius mattis diam, vitae ultricies nisi vehicula eu.', '', 'filtered_html'),
('node', 'forum', '0', '22', '22', 'en', '0', 'Cras euismod aliquet massa scelerisque euismod. Phasellus tincidunt, eros sit amet cursus porta, neque velit tincidunt lacus, non mattis risus augue ut erat. Phasellus facilisis ornare massa, ac porttitor erat hendrerit eget. Cras porttitor aliquet aliquam. Phasellus at mauris vitae metus pharetra semper. Aliquam mi ligula, commodo ut pharetra quis, bibendum ac odio. Nullam tincidunt nulla vel massa lacinia varius. Ut tortor urna, faucibus vel posuere ut, hendrerit eu ante. Pellentesque porttitor iaculis sem, a adipiscing sapien commodo sit amet. Duis non massa quis leo fringilla aliquam. Phasellus fermentum congue velit. Sed blandit, ante non ornare iaculis, turpis mauris consectetur nunc, id venenatis turpis odio et ante. Pellentesque bibendum tincidunt justo porta dictum. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris neque eros, pretium nec cursus sit amet, mattis vitae felis. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Aenean vel magna vitae felis euismod congue a at magna. Donec varius mattis diam, vitae ultricies nisi vehicula eu.\r\n\r\nCras congue porttitor ipsum, nec pulvinar risus adipiscing ac. Nam vel augue nibh. Phasellus metus lectus, placerat eu posuere ac, molestie vel diam. Quisque blandit elit in neque vehicula eu fringilla tortor volutpat. Sed non turpis pretium lorem hendrerit pretium in ac dolor. Pellentesque semper volutpat urna vel dictum. Nunc tempor, neque nec elementum luctus, turpis dui lacinia est, vitae placerat nibh mauris eu ipsum. Integer vel orci a quam posuere malesuada eget et turpis. Nunc porttitor, quam non rutrum iaculis, odio tellus condimentum tortor, ut dapibus neque urna quis est. Phasellus ac lectus sed nisi pulvinar consectetur. Sed urna nulla, aliquam et ullamcorper at, porta quis libero. Duis sed est dolor. Morbi quam erat, sagittis volutpat tristique at, blandit non arcu. Suspendisse potenti. Praesent a metus odio. Proin eros ligula, accumsan eu bibendum id, rutrum sed urna. Phasellus quis suscipit mi.\r\n\r\nVestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Sed imperdiet, velit nec semper mattis, elit tellus ultricies nibh, id bibendum justo lacus sit amet urna. Aliquam lacus risus, condimentum ut accumsan non, pretium vel leo. Praesent vel orci eget tortor molestie fringilla at et erat. Integer adipiscing gravida lobortis. Quisque varius, metus in egestas sollicitudin, risus lacus tempor erat, quis ullamcorper arcu magna nec mauris. Aenean tempus sapien nibh, ut ultrices enim. Vivamus in nulla massa, vel aliquam dui. Suspendisse potenti. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Proin condimentum sapien sed ante sodales lobortis. Suspendisse et lectus id nibh lacinia ultricies. Cras commodo laoreet ullamcorper. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Quisque diam tortor, tincidunt nec lacinia vel, suscipit id tellus. Pellentesque vitae semper ipsum.', '', 'filtered_html'),
('node', 'forum', '0', '23', '23', 'en', '0', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec vestibulum ultrices mollis. Sed id purus mattis leo pulvinar hendrerit quis non turpis. Donec eleifend malesuada lorem, ac sagittis dui tempus id. Duis risus mi, fringilla sit amet elementum in, vulputate non orci. Mauris at pharetra elit. Curabitur libero orci, elementum iaculis congue nec, placerat a lorem. Nunc ornare, leo id condimentum dictum, metus ante mattis felis, a venenatis urna magna a nisi. Donec hendrerit malesuada egestas. Mauris ligula tellus, bibendum in pellentesque et, cursus volutpat augue. Ut sollicitudin libero id purus dignissim pellentesque laoreet massa pharetra. Cras dignissim tortor quis erat hendrerit ut adipiscing elit laoreet. Sed hendrerit convallis pretium. Nunc quis turpis turpis, at adipiscing neque. Sed mi nisi, pulvinar non posuere non, varius et lacus. Vestibulum risus metus, vehicula nec ornare eget, ultrices non tortor. In vulputate turpis ipsum, sed cursus mi. Sed elit sem, tristique id tempor eu, molestie et magna. Vestibulum porta nisl a urna tincidunt eget tristique leo blandit.\r\n\r\nProin dictum, libero eget aliquet dictum, nisi mi venenatis sem, sed rhoncus turpis nibh rhoncus elit. Cras porttitor, nunc eu tincidunt vulputate, enim dolor viverra ipsum, vel eleifend risus justo vel neque. Proin hendrerit vestibulum diam, at imperdiet enim rutrum eu. Curabitur eros augue, iaculis in mollis sit amet, tincidunt vitae turpis. Maecenas eu erat vel massa scelerisque mollis sed in ligula. Duis consectetur congue felis a porta. Pellentesque turpis nisl, faucibus et blandit nec, mattis vel purus. Nulla facilisi. Ut viverra fermentum felis, nec dapibus massa suscipit ut. Vestibulum id ligula lacus, et tristique libero.\r\n\r\nCras euismod aliquet massa scelerisque euismod. Phasellus tincidunt, eros sit amet cursus porta, neque velit tincidunt lacus, non mattis risus augue ut erat. Phasellus facilisis ornare massa, ac porttitor erat hendrerit eget. Cras porttitor aliquet aliquam. Phasellus at mauris vitae metus pharetra semper. Aliquam mi ligula, commodo ut pharetra quis, bibendum ac odio. Nullam tincidunt nulla vel massa lacinia varius. Ut tortor urna, faucibus vel posuere ut, hendrerit eu ante. Pellentesque porttitor iaculis sem, a adipiscing sapien commodo sit amet. Duis non massa quis leo fringilla aliquam. Phasellus fermentum congue velit. Sed blandit, ante non ornare iaculis, turpis mauris consectetur nunc, id venenatis turpis odio et ante. Pellentesque bibendum tincidunt justo porta dictum. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris neque eros, pretium nec cursus sit amet, mattis vitae felis. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Aenean vel magna vitae felis euismod congue a at magna. Donec varius mattis diam, vitae ultricies nisi vehicula eu.', '', 'filtered_html'),
('node', 'forum', '0', '24', '24', 'en', '0', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Integer in mollis turpis. Nam faucibus porta magna, molestie faucibus enim posuere vel. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Nullam id libero facilisis augue euismod eleifend. Mauris quam eros, scelerisque quis pharetra nec, ornare ac justo. Etiam euismod felis vel odio rutrum fringilla. Ut non libero sit amet mauris eleifend auctor non non est. Morbi ullamcorper odio a orci scelerisque vehicula eget ac tortor. Cras condimentum orci ac arcu elementum non vehicula nisi rhoncus. Donec libero dolor, dignissim in ultrices vel, lacinia tempus elit. Nam sed ipsum ligula. Fusce interdum consequat neque a varius. Praesent scelerisque, nisl a dictum pulvinar, justo tellus lobortis diam, eget ultricies nunc felis ut leo. Morbi pretium congue tellus at imperdiet. Ut nec mauris sit amet nibh ornare dapibus. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae;\r\n\r\nPraesent non mauris eget nisi porta dignissim in vitae sem. Duis condimentum iaculis nulla vel ullamcorper. Praesent et urna risus, vel fermentum ante. Donec neque ipsum, suscipit sed dictum a, sodales ut tellus. Nullam et varius enim. Aliquam sed eros et leo adipiscing scelerisque. Maecenas varius pulvinar sodales. Maecenas a justo lectus. Mauris non sapien a arcu varius gravida vel at urna. Suspendisse at tortor augue. Proin eleifend blandit neque, ut sodales risus porttitor in. Suspendisse pretium quam quis nunc fermentum vitae vulputate sapien dictum. Aliquam erat volutpat. Maecenas et justo odio. Praesent molestie lacus eu felis commodo ac rutrum sem commodo. Nullam blandit dolor ac felis euismod quis pellentesque purus consequat. Morbi ut molestie nisi. Nullam quam odio, rhoncus vitae adipiscing at, dictum ac libero.\r\n\r\nFusce ac lacus metus, et molestie mi. Nunc eleifend eleifend mauris, at feugiat risus convallis sit amet. Suspendisse sem velit, dignissim vitae vehicula sit amet, mollis vel massa. Curabitur volutpat, ligula eu lobortis elementum, velit sapien sodales mi, vitae dapibus mi lorem convallis sem. Maecenas ac purus luctus lacus tempus mattis sed vitae diam. Vivamus nec ullamcorper diam. Mauris nec est eu mi venenatis accumsan non id nisi. Integer pellentesque aliquam vulputate. Donec volutpat enim nec leo iaculis tempus. Duis ultrices ornare tortor eget lobortis.', '', 'filtered_html'),
('node', 'forum', '0', '25', '25', 'en', '0', 'Fusce ac lacus metus, et molestie mi. Nunc eleifend eleifend mauris, at feugiat risus convallis sit amet. Suspendisse sem velit, dignissim vitae vehicula sit amet, mollis vel massa. Curabitur volutpat, ligula eu lobortis elementum, velit sapien sodales mi, vitae dapibus mi lorem convallis sem. Maecenas ac purus luctus lacus tempus mattis sed vitae diam. Vivamus nec ullamcorper diam. Mauris nec est eu mi venenatis accumsan non id nisi. Integer pellentesque aliquam vulputate. Donec volutpat enim nec leo iaculis tempus. Duis ultrices ornare tortor eget lobortis.\r\n\r\nSuspendisse tempor libero sed ipsum imperdiet semper dapibus tortor laoreet. Suspendisse vitae sem dolor. Etiam sollicitudin tortor ut metus aliquet ullamcorper. Vivamus vel nulla id lorem tincidunt bibendum. Praesent malesuada tortor est. Aenean et dolor est, tempus elementum libero. Proin massa nulla, condimentum ut volutpat sit amet, aliquet vitae orci. Morbi tincidunt ligula at diam venenatis hendrerit dignissim felis condimentum. Quisque iaculis, erat non tristique mattis, libero ligula ultricies massa, vel scelerisque lorem eros eu lectus. Donec bibendum, lacus sed scelerisque pretium, tellus leo pretium sem, id egestas elit ante sit amet est. Mauris pellentesque, tortor at pellentesque vehicula, massa ligula posuere lectus, a dignissim urna magna eu eros. Donec in dui id tortor cursus lobortis. Phasellus placerat malesuada arcu at vehicula. Morbi sagittis ipsum vel diam aliquam in viverra lorem pellentesque. Donec laoreet tincidunt risus. Aenean ut diam in turpis consequat aliquet. Ut libero dui, tempor vel sagittis eu, fringilla a nisi. Aenean orci lectus, cursus et viverra eu, pharetra malesuada elit. Duis nec eros nibh, sit amet suscipit ipsum.\r\n\r\nLorem ipsum dolor sit amet, consectetur adipiscing elit. Ut malesuada ultrices rhoncus. Donec dignissim tincidunt aliquam. Donec tempus dapibus augue, at dictum sapien sodales et. Curabitur a orci nulla. Integer pulvinar nisi vel turpis pellentesque interdum. Praesent auctor scelerisque facilisis. Maecenas eget diam congue justo suscipit adipiscing. Aenean sit amet nunc massa, in placerat leo. Suspendisse pharetra odio eu quam dapibus sagittis. Pellentesque feugiat mattis ultricies.', '', 'filtered_html'),
('node', 'forum', '0', '26', '26', 'en', '0', 'Praesent non mauris eget nisi porta dignissim in vitae sem. Duis condimentum iaculis nulla vel ullamcorper. Praesent et urna risus, vel fermentum ante. Donec neque ipsum, suscipit sed dictum a, sodales ut tellus. Nullam et varius enim. Aliquam sed eros et leo adipiscing scelerisque. Maecenas varius pulvinar sodales. Maecenas a justo lectus. Mauris non sapien a arcu varius gravida vel at urna. Suspendisse at tortor augue. Proin eleifend blandit neque, ut sodales risus porttitor in. Suspendisse pretium quam quis nunc fermentum vitae vulputate sapien dictum. Aliquam erat volutpat. Maecenas et justo odio. Praesent molestie lacus eu felis commodo ac rutrum sem commodo. Nullam blandit dolor ac felis euismod quis pellentesque purus consequat. Morbi ut molestie nisi. Nullam quam odio, rhoncus vitae adipiscing at, dictum ac libero.\r\n\r\nFusce ac lacus metus, et molestie mi. Nunc eleifend eleifend mauris, at feugiat risus convallis sit amet. Suspendisse sem velit, dignissim vitae vehicula sit amet, mollis vel massa. Curabitur volutpat, ligula eu lobortis elementum, velit sapien sodales mi, vitae dapibus mi lorem convallis sem. Maecenas ac purus luctus lacus tempus mattis sed vitae diam. Vivamus nec ullamcorper diam. Mauris nec est eu mi venenatis accumsan non id nisi. Integer pellentesque aliquam vulputate. Donec volutpat enim nec leo iaculis tempus. Duis ultrices ornare tortor eget lobortis.\r\n\r\nSuspendisse tempor libero sed ipsum imperdiet semper dapibus tortor laoreet. Suspendisse vitae sem dolor. Etiam sollicitudin tortor ut metus aliquet ullamcorper. Vivamus vel nulla id lorem tincidunt bibendum. Praesent malesuada tortor est. Aenean et dolor est, tempus elementum libero. Proin massa nulla, condimentum ut volutpat sit amet, aliquet vitae orci. Morbi tincidunt ligula at diam venenatis hendrerit dignissim felis condimentum. Quisque iaculis, erat non tristique mattis, libero ligula ultricies massa, vel scelerisque lorem eros eu lectus. Donec bibendum, lacus sed scelerisque pretium, tellus leo pretium sem, id egestas elit ante sit amet est. Mauris pellentesque, tortor at pellentesque vehicula, massa ligula posuere lectus, a dignissim urna magna eu eros. Donec in dui id tortor cursus lobortis. Phasellus placerat malesuada arcu at vehicula. Morbi sagittis ipsum vel diam aliquam in viverra lorem pellentesque. Donec laoreet tincidunt risus. Aenean ut diam in turpis consequat aliquet. Ut libero dui, tempor vel sagittis eu, fringilla a nisi. Aenean orci lectus, cursus et viverra eu, pharetra malesuada elit. Duis nec eros nibh, sit amet suscipit ipsum.', '', 'filtered_html'),
('node', 'forum', '0', '27', '27', 'en', '0', 'Curabitur feugiat ornare pulvinar. Phasellus mi urna, tempor ut porttitor in, facilisis id sapien. Pellentesque egestas erat laoreet felis aliquam tempus. Fusce turpis sem, auctor et viverra non, faucibus quis mauris. Sed feugiat, libero ut egestas malesuada, magna elit laoreet augue, fermentum tristique metus dolor vitae leo. Nam vel quam in nisl feugiat elementum consectetur a turpis. Fusce dictum risus augue. Nam vel arcu nulla, pellentesque pulvinar mauris. Duis eros libero, tristique posuere adipiscing id, dictum eget dui. Phasellus at neque metus. Nam aliquet venenatis ante, sit amet pulvinar arcu ultricies eget.\r\n\r\nSuspendisse potenti. In sagittis tempor nisi, at egestas sem ultricies a. Nullam ac dolor id leo scelerisque accumsan sit amet id neque. Suspendisse ullamcorper feugiat magna, quis condimentum ante luctus at. Morbi semper luctus quam non mattis. Aenean sed risus nisl. Praesent posuere vehicula neque aliquet luctus. Pellentesque tempus hendrerit gravida. Donec accumsan nisi ut dolor dapibus ac luctus diam hendrerit. Suspendisse sit amet mattis neque. Sed et rhoncus odio. Cras euismod pretium mauris, eget facilisis eros aliquam quis. Suspendisse ut ante lacus. Nullam ut vulputate velit. Aliquam felis nulla, eleifend in lobortis a, semper non velit. Nam ac felis elit, at euismod lacus. Integer fermentum arcu viverra nulla luctus scelerisque. Duis condimentum neque non orci pretium suscipit. In vel ante eget lacus placerat hendrerit.', '', 'filtered_html'),
('node', 'forum', '0', '28', '28', 'en', '0', 'Suspendisse potenti. In sagittis tempor nisi, at egestas sem ultricies a. Nullam ac dolor id leo scelerisque accumsan sit amet id neque. Suspendisse ullamcorper feugiat magna, quis condimentum ante luctus at. Morbi semper luctus quam non mattis. Aenean sed risus nisl. Praesent posuere vehicula neque aliquet luctus. Pellentesque tempus hendrerit gravida. Donec accumsan nisi ut dolor dapibus ac luctus diam hendrerit. Suspendisse sit amet mattis neque. Sed et rhoncus odio. Cras euismod pretium mauris, eget facilisis eros aliquam quis. Suspendisse ut ante lacus. Nullam ut vulputate velit. Aliquam felis nulla, eleifend in lobortis a, semper non velit. Nam ac felis elit, at euismod lacus. Integer fermentum arcu viverra nulla luctus scelerisque. Duis condimentum neque non orci pretium suscipit. In vel ante eget lacus placerat hendrerit.\r\n\r\nPhasellus at nibh nisl. Curabitur nec eros ut neque ultrices luctus. Vivamus dapibus interdum nibh sit amet dictum. Vestibulum rutrum pharetra lacus, quis congue risus consequat non. Duis eget luctus erat. Nullam faucibus neque non eros bibendum iaculis. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Morbi sed tempus massa. Pellentesque tortor nulla, pharetra id pharetra quis, ornare et lectus. Donec quis lacus nec lectus consequat eleifend id at lorem. Donec sodales lacinia nisl, a venenatis lacus scelerisque eget. Sed sagittis turpis nec metus dictum dapibus. Quisque luctus elit vel sapien porta vel consectetur dolor blandit. Cras at erat eu erat egestas mollis. Sed nec augue et nibh sollicitudin facilisis vitae nec odio. Donec luctus fringilla viverra. Cras mattis commodo leo, ut gravida erat rutrum in. Vivamus feugiat sodales egestas. Phasellus eros sem, convallis at scelerisque eu, adipiscing a urna.\r\n\r\nFusce quis molestie sapien. Nunc vestibulum tincidunt dolor eget accumsan. Cras ornare laoreet augue, lacinia rutrum dui semper eget. Cras aliquam odio ac turpis egestas consectetur. In vulputate congue lacinia. Pellentesque ullamcorper nulla quis augue ullamcorper ut dictum massa lacinia. Phasellus ultrices, urna ut scelerisque iaculis, massa nunc dignissim augue, ac placerat odio nibh sed urna. Nulla gravida sem suscipit risus fringilla sit amet aliquet turpis consectetur. Sed placerat convallis enim, in bibendum risus cursus vitae. Suspendisse non justo leo. Nam consectetur consectetur libero quis facilisis. Duis ac arcu nec enim euismod rutrum. Etiam velit quam, laoreet in blandit consectetur, congue at leo. Aenean tempor, arcu ac aliquet tincidunt, massa odio dictum enim, eget mollis justo nisi sit amet ligula. Nunc ipsum quam, mollis sed commodo in, aliquet sed lacus. Nunc vehicula, justo vel consequat placerat, dolor erat placerat leo, ac vestibulum justo diam ac mauris. Vivamus id sem at elit mollis ultricies porta nec magna. Sed aliquet tincidunt pellentesque.', '', 'filtered_html'),
('node', 'forum', '0', '29', '29', 'en', '0', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Quisque sollicitudin elit nec purus ultricies rhoncus. Nulla non pellentesque ligula. Praesent porttitor nunc sit amet odio varius vitae venenatis nunc euismod. Phasellus erat felis, eleifend porttitor lacinia in, vehicula quis elit. Curabitur dui eros, blandit vel mollis et, molestie eu arcu. Aenean sagittis ligula vel purus elementum vel fringilla lorem mollis. Sed scelerisque risus ut metus vehicula a vehicula sem pharetra. Sed at ligula eget diam ullamcorper porta. Cras sagittis posuere ante, a accumsan eros feugiat in. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Nulla pellentesque augue sed metus dapibus vitae convallis purus laoreet. Cras ultrices nulla vel erat sagittis tristique quis quis libero. Proin suscipit sapien quis risus interdum elementum. Duis tempor luctus velit. Fusce vel consequat est.\r\n\r\nCurabitur feugiat ornare pulvinar. Phasellus mi urna, tempor ut porttitor in, facilisis id sapien. Pellentesque egestas erat laoreet felis aliquam tempus. Fusce turpis sem, auctor et viverra non, faucibus quis mauris. Sed feugiat, libero ut egestas malesuada, magna elit laoreet augue, fermentum tristique metus dolor vitae leo. Nam vel quam in nisl feugiat elementum consectetur a turpis. Fusce dictum risus augue. Nam vel arcu nulla, pellentesque pulvinar mauris. Duis eros libero, tristique posuere adipiscing id, dictum eget dui. Phasellus at neque metus. Nam aliquet venenatis ante, sit amet pulvinar arcu ultricies eget.\r\n\r\nSuspendisse potenti. In sagittis tempor nisi, at egestas sem ultricies a. Nullam ac dolor id leo scelerisque accumsan sit amet id neque. Suspendisse ullamcorper feugiat magna, quis condimentum ante luctus at. Morbi semper luctus quam non mattis. Aenean sed risus nisl. Praesent posuere vehicula neque aliquet luctus. Pellentesque tempus hendrerit gravida. Donec accumsan nisi ut dolor dapibus ac luctus diam hendrerit. Suspendisse sit amet mattis neque. Sed et rhoncus odio. Cras euismod pretium mauris, eget facilisis eros aliquam quis. Suspendisse ut ante lacus. Nullam ut vulputate velit. Aliquam felis nulla, eleifend in lobortis a, semper non velit. Nam ac felis elit, at euismod lacus. Integer fermentum arcu viverra nulla luctus scelerisque. Duis condimentum neque non orci pretium suscipit. In vel ante eget lacus placerat hendrerit.', '', 'filtered_html'),
('node', 'forum', '0', '30', '30', 'en', '0', 'Suspendisse potenti. In sagittis tempor nisi, at egestas sem ultricies a. Nullam ac dolor id leo scelerisque accumsan sit amet id neque. Suspendisse ullamcorper feugiat magna, quis condimentum ante luctus at. Morbi semper luctus quam non mattis. Aenean sed risus nisl. Praesent posuere vehicula neque aliquet luctus. Pellentesque tempus hendrerit gravida. Donec accumsan nisi ut dolor dapibus ac luctus diam hendrerit. Suspendisse sit amet mattis neque. Sed et rhoncus odio. Cras euismod pretium mauris, eget facilisis eros aliquam quis. Suspendisse ut ante lacus. Nullam ut vulputate velit. Aliquam felis nulla, eleifend in lobortis a, semper non velit. Nam ac felis elit, at euismod lacus. Integer fermentum arcu viverra nulla luctus scelerisque. Duis condimentum neque non orci pretium suscipit. In vel ante eget lacus placerat hendrerit.\r\n\r\nPhasellus at nibh nisl. Curabitur nec eros ut neque ultrices luctus. Vivamus dapibus interdum nibh sit amet dictum. Vestibulum rutrum pharetra lacus, quis congue risus consequat non. Duis eget luctus erat. Nullam faucibus neque non eros bibendum iaculis. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Morbi sed tempus massa. Pellentesque tortor nulla, pharetra id pharetra quis, ornare et lectus. Donec quis lacus nec lectus consequat eleifend id at lorem. Donec sodales lacinia nisl, a venenatis lacus scelerisque eget. Sed sagittis turpis nec metus dictum dapibus. Quisque luctus elit vel sapien porta vel consectetur dolor blandit. Cras at erat eu erat egestas mollis. Sed nec augue et nibh sollicitudin facilisis vitae nec odio. Donec luctus fringilla viverra. Cras mattis commodo leo, ut gravida erat rutrum in. Vivamus feugiat sodales egestas. Phasellus eros sem, convallis at scelerisque eu, adipiscing a urna.', '', 'filtered_html');
INSERT INTO `field_data_body` VALUES
('node', 'forum', '0', '31', '31', 'en', '0', 'Curabitur eu nibh non odio congue scelerisque consectetur eu justo. Duis ornare interdum sollicitudin. Suspendisse pretium pharetra rhoncus. Pellentesque luctus lacinia luctus. Donec tempor viverra nunc, vel luctus massa consequat ac. Morbi auctor, neque et consectetur aliquam, est leo ultricies magna, at volutpat ante ante ut sem. Sed cursus porta venenatis. Aliquam turpis massa, bibendum sit amet hendrerit eleifend, dictum in mauris. Vivamus ultrices urna nec ipsum pretium quis euismod ligula sollicitudin. Nam cursus molestie condimentum.\r\n\r\nUt aliquet arcu id magna porttitor consequat. Proin at ultricies eros. Curabitur non metus ac neque tempus semper. Donec non nulla id purus congue elementum. Nunc sollicitudin metus sit amet mauris iaculis eget lacinia enim tempor. Phasellus eleifend sodales elit, eu dignissim augue faucibus et. In ac arcu eget risus facilisis laoreet. Nunc vel placerat libero. Duis egestas porta lectus, et egestas ante vestibulum ac. Ut sit amet dui nibh, pretium hendrerit lectus.\r\n\r\nCurabitur imperdiet euismod tortor, id consectetur felis ultricies vel. Sed sagittis accumsan nibh, sit amet fermentum sapien mattis non. Nulla congue quam sed eros iaculis at sagittis mi ornare. Donec rhoncus euismod elit, sit amet tempus odio porta vel. Proin hendrerit, libero eu tempor porttitor, nisl eros ultricies urna, eget sagittis metus ante tristique erat. Ut ac diam sit amet leo venenatis eleifend. Vivamus libero neque, tristique id mollis id, volutpat sit amet ipsum. Vivamus lobortis, erat tempor fermentum facilisis, sem arcu lacinia risus, at euismod enim neque eu magna. Fusce elementum, enim nec venenatis pretium, sapien eros varius metus, consequat sollicitudin sapien nibh et erat. Phasellus consequat felis non quam sodales in scelerisque nibh imperdiet. Nulla in leo massa. Quisque magna urna, posuere eget molestie eu, venenatis sit amet nulla. Maecenas lacus diam, elementum sit amet vulputate sit amet, pulvinar in metus. In egestas, arcu sit amet pharetra ornare, urna libero vulputate est, sed cursus dolor libero quis eros. Quisque venenatis porta arcu ut consectetur. Donec ac magna non tellus tempus aliquam sed at nisl. Nullam orci massa, ultrices ac dictum non, tincidunt ac odio. Phasellus pharetra elementum massa, quis porta neque pretium quis.', '', 'filtered_html'),
('node', 'forum', '0', '32', '32', 'en', '0', 'Aenean quis mattis magna. In pulvinar interdum mauris in ornare. Fusce molestie erat id sapien aliquam pharetra. Suspendisse ornare tincidunt magna. Sed sed turpis justo. Donec eleifend, justo vel bibendum blandit, est sem tempus lorem, vel ultricies felis eros non est. Praesent ac dolor eu justo vestibulum dapibus. Maecenas id odio lectus, in interdum libero. In hac habitasse platea dictumst. Praesent sed urna turpis, sit amet auctor sem. Pellentesque sit amet ante sit amet diam imperdiet ultrices. Proin congue iaculis semper. Vivamus mi enim, dapibus quis laoreet at, hendrerit sit amet eros. Nulla ut lacinia nisi.\r\n\r\nNullam eu erat nibh. Aliquam ipsum sapien, interdum a euismod vitae, vehicula pellentesque dolor. In sit amet eros pretium eros aliquet semper eget id massa. Donec malesuada rutrum est. Sed neque est, ultricies ac dictum at, tincidunt at arcu. In hac habitasse platea dictumst. Cras posuere convallis mattis. Quisque blandit ullamcorper ligula, dapibus tincidunt dolor lacinia non. Aliquam vitae nunc metus. Fusce nec sem sapien.\r\n\r\nMorbi pharetra pharetra purus eu condimentum. Phasellus pulvinar imperdiet mi vitae pellentesque. Nullam sed urna porta ligula tempus venenatis a at metus. Proin feugiat nulla nec mi hendrerit ut iaculis purus pulvinar. Suspendisse id magna lacus, vel consequat arcu. Vestibulum non nulla felis, in tempor magna. Aliquam lacinia iaculis leo, eu consequat mauris molestie nec. Mauris facilisis facilisis eros, quis pretium ipsum consectetur quis. Vestibulum sed massa vitae felis porta elementum. Nulla facilisi. Sed turpis mi, ultrices sed blandit sit amet, rutrum et tellus. Proin luctus egestas turpis, eget luctus dolor mattis a. Nam sed rutrum diam. Sed quis nisl nisl, eu fringilla diam.', '', 'filtered_html'),
('node', 'forum', '0', '33', '33', 'en', '0', 'Morbi pharetra pharetra purus eu condimentum. Phasellus pulvinar imperdiet mi vitae pellentesque. Nullam sed urna porta ligula tempus venenatis a at metus. Proin feugiat nulla nec mi hendrerit ut iaculis purus pulvinar. Suspendisse id magna lacus, vel consequat arcu. Vestibulum non nulla felis, in tempor magna. Aliquam lacinia iaculis leo, eu consequat mauris molestie nec. Mauris facilisis facilisis eros, quis pretium ipsum consectetur quis. Vestibulum sed massa vitae felis porta elementum. Nulla facilisi. Sed turpis mi, ultrices sed blandit sit amet, rutrum et tellus. Proin luctus egestas turpis, eget luctus dolor mattis a. Nam sed rutrum diam. Sed quis nisl nisl, eu fringilla diam.\r\n\r\nAliquam vel euismod nulla. Aliquam erat volutpat. Fusce porta augue vitae felis dignissim pulvinar. Morbi non elit orci. Vestibulum erat libero, ultricies non egestas ut, aliquet in turpis. Aliquam erat volutpat. In mollis, neque a sodales convallis, nulla felis luctus nisl, non fringilla metus neque eu augue. Suspendisse lacinia enim a quam pretium tempus. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Mauris adipiscing ultrices nibh, interdum iaculis diam ultricies ut. Maecenas suscipit, enim a suscipit congue, ipsum mi tempor elit, pretium luctus lorem purus vestibulum diam. Etiam sodales turpis vel tortor sagittis sodales. Donec tellus turpis, consequat eget facilisis nec, interdum quis nulla. Proin bibendum mollis mattis. Proin at eros vitae nulla sagittis sollicitudin nec vel odio. Nam sed nibh vitae mauris viverra rhoncus. Aenean ut lectus eu massa gravida sodales id sed nulla. Donec semper justo facilisis mauris aliquam suscipit. Aenean ut dignissim est.', '', 'filtered_html'),
('node', 'forum', '0', '34', '34', 'en', '0', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam aliquet, ipsum eget sodales blandit, neque purus lacinia nulla, quis sagittis elit lectus fringilla massa. Donec commodo quam eget nunc vestibulum nec venenatis nibh iaculis. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Curabitur lobortis suscipit porttitor. Fusce massa elit, consequat eu tincidunt et, consectetur ut est. In ligula tortor, scelerisque a condimentum id, venenatis vel est. Donec laoreet dictum nisi eget egestas. Sed malesuada erat vel magna dictum sit amet volutpat sem ornare. Fusce bibendum, tellus sit amet elementum porta, ligula enim luctus orci, eget tristique magna eros sit amet sem. Phasellus placerat lacinia placerat. Sed porttitor, nulla quis ullamcorper tempor, risus erat sollicitudin enim, tincidunt iaculis massa mi sit amet dolor. Vivamus molestie odio ut velit pellentesque sagittis. In vitae turpis vel est semper eleifend.\r\n\r\nAenean quis mattis magna. In pulvinar interdum mauris in ornare. Fusce molestie erat id sapien aliquam pharetra. Suspendisse ornare tincidunt magna. Sed sed turpis justo. Donec eleifend, justo vel bibendum blandit, est sem tempus lorem, vel ultricies felis eros non est. Praesent ac dolor eu justo vestibulum dapibus. Maecenas id odio lectus, in interdum libero. In hac habitasse platea dictumst. Praesent sed urna turpis, sit amet auctor sem. Pellentesque sit amet ante sit amet diam imperdiet ultrices. Proin congue iaculis semper. Vivamus mi enim, dapibus quis laoreet at, hendrerit sit amet eros. Nulla ut lacinia nisi.', '', 'filtered_html'),
('node', 'forum', '0', '35', '35', 'en', '0', 'Aenean quis mattis magna. In pulvinar interdum mauris in ornare. Fusce molestie erat id sapien aliquam pharetra. Suspendisse ornare tincidunt magna. Sed sed turpis justo. Donec eleifend, justo vel bibendum blandit, est sem tempus lorem, vel ultricies felis eros non est. Praesent ac dolor eu justo vestibulum dapibus. Maecenas id odio lectus, in interdum libero. In hac habitasse platea dictumst. Praesent sed urna turpis, sit amet auctor sem. Pellentesque sit amet ante sit amet diam imperdiet ultrices. Proin congue iaculis semper. Vivamus mi enim, dapibus quis laoreet at, hendrerit sit amet eros. Nulla ut lacinia nisi.\r\n\r\nNullam eu erat nibh. Aliquam ipsum sapien, interdum a euismod vitae, vehicula pellentesque dolor. In sit amet eros pretium eros aliquet semper eget id massa. Donec malesuada rutrum est. Sed neque est, ultricies ac dictum at, tincidunt at arcu. In hac habitasse platea dictumst. Cras posuere convallis mattis. Quisque blandit ullamcorper ligula, dapibus tincidunt dolor lacinia non. Aliquam vitae nunc metus. Fusce nec sem sapien.\r\n\r\nMorbi pharetra pharetra purus eu condimentum. Phasellus pulvinar imperdiet mi vitae pellentesque. Nullam sed urna porta ligula tempus venenatis a at metus. Proin feugiat nulla nec mi hendrerit ut iaculis purus pulvinar. Suspendisse id magna lacus, vel consequat arcu. Vestibulum non nulla felis, in tempor magna. Aliquam lacinia iaculis leo, eu consequat mauris molestie nec. Mauris facilisis facilisis eros, quis pretium ipsum consectetur quis. Vestibulum sed massa vitae felis porta elementum. Nulla facilisi. Sed turpis mi, ultrices sed blandit sit amet, rutrum et tellus. Proin luctus egestas turpis, eget luctus dolor mattis a. Nam sed rutrum diam. Sed quis nisl nisl, eu fringilla diam.', '', 'filtered_html'),
('node', 'article', '0', '36', '36', 'en', '0', '<p>Aenean placerat tortor ac dui luctus ut mattis est mollis. Donec blandit orci id velit cursus varius. Fusce quam enim, <a href="#">hendrerit nec ultrices</a> a, vestibulum nec enim. Quisque imperdiet ultricies dolor in convallis. Morbi sed fringilla elit. Duis sagittis lectus in orci volutpat elementum. Cras in purus sem. Curabitur augue velit, mollis in suscipit eleifend, faucibus ac elit. Morbi mattis tristique mi, quis lobortis nulla sollicitudin quis. Cras adipiscing enim neque, ut ultrices risus. Pellentesque auctor felis eu nibh volutpat ac malesuada elit blandit. Pellentesque porta felis vel sapien tincidunt rhoncus. Nunc sit amet dui eget odio blandit sagittis. Duis tempus egestas justo vitae rhoncus. Sed mollis, risus in aliquet tincidunt, nisl nunc imperdiet eros, nec dictum ante est at ante. Nunc ullamcorper gravida porttitor. Sed sollicitudin dui vestibulum nisl condimentum at viverra urna dictum. Curabitur felis ligula, mattis ornare rhoncus eget, porta non urna. Nullam non porta est. Vestibulum pretium quam et purus tempus fringilla. Etiam vitae nulla turpis, at interdum erat. Pellentesque aliquet lorem id nunc suscipit pretium. Maecenas vitae erat in erat bibendum tincidunt sit amet eget dolor. Maecenas ultricies nulla et felis rhoncus tincidunt.</p><p>Vestibulum sed arcu nunc. Ut augue felis, elementum ut dapibus posuere, pulvinar at lorem. Class aptent taciti sociosqu ad litora torquent per conubia nostra, <a href="#">per inceptos himenaeos</a>. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Duis dignissim, urna at tincidunt aliquam, sem est scelerisque nibh, nec convallis risus nisl in justo. Suspendisse imperdiet consequat gravida. Curabitur odio velit, tempor ac cursus ut, tempor eu sem. Donec consequat magna purus. In ac leo nulla. Morbi scelerisque ligula quam, consectetur sodales lacus. Sed viverra rutrum est quis tempor.</p><p>In non posuere mauris. Nullam odio tortor, suscipit at semper ut, tempus consectetur tellus. Morbi congue egestas est. Proin tortor mi, tempor sit amet pretium eget, sollicitudin quis elit. Nam massa nisi, viverra in gravida et, tincidunt in elit. Duis nec massa a tortor iaculis aliquam eu vel ante. Duis sagittis consequat imperdiet. Donec metus eros, blandit et vestibulum eget, vehicula at libero. Proin molestie odio vitae odio porta sagittis. Vivamus eu lorem in purus viverra viverra sit amet et orci. Nulla adipiscing neque ut leo ornare faucibus. Cras vel augue enim. Quisque vel volutpat nisl. Proin ullamcorper ultrices faucibus.</p>', '', 'filtered_html'),
('node', 'blog', '0', '37', '37', 'en', '0', '<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Aenean tristique porta ligula, ac elementum felis faucibus vel. Duis in nunc nibh. Aenean dictum lorem non diam ultricies non laoreet dolor auctor. Vestibulum blandit ante non turpis tristique tincidunt. In adipiscing vulputate tortor at accumsan. Curabitur convallis eros sit amet dolor interdum varius. Donec a dolor velit. Aliquam rhoncus sagittis vestibulum. Praesent arcu turpis, lobortis nec aliquet vitae, feugiat quis ipsum.</p><p>Quisque et tellus sit amet mauris luctus dignissim eu quis augue. Vestibulum velit nulla, consectetur vel viverra eu, ultricies sed felis. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Pellentesque id eros et tortor malesuada consequat. Sed commodo sem id diam varius luctus. Morbi justo augue, hendrerit a blandit in, hendrerit facilisis risus. Praesent sed massa tortor. Nam quis sollicitudin sapien. In eu consectetur dolor. Nulla aliquet egestas lacus eget pulvinar. Donec at blandit lorem. Pellentesque ac ipsum purus. Pellentesque tincidunt congue fringilla. Fusce tincidunt mauris et lorem pellentesque faucibus.</p><p>Curabitur adipiscing consectetur arcu, ut vulputate magna tincidunt a. Nam semper commodo nibh, sit amet suscipit lacus convallis vitae. Fusce sit amet sapien pharetra neque consectetur semper quis nec lacus. Morbi a metus non urna pellentesque vestibulum. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Pellentesque imperdiet elit sodales urna egestas molestie. Nulla eu nisi sed eros lacinia cursus ut in dolor. Nunc ut sapien metus, fermentum tincidunt tellus. Duis nec diam mi. Etiam a ligula quis augue scelerisque tincidunt ullamcorper et arcu. Donec aliquet nulla quis dui sodales hendrerit a sed neque.</p><p>Vivamus velit velit, rutrum vitae ultrices eu, facilisis a nisl. Proin velit ipsum, porttitor et vestibulum quis, luctus id augue. Curabitur metus mauris, tincidunt non accumsan ac, iaculis id est. Quisque venenatis magna quis quam adipiscing eget eleifend lorem lacinia. Praesent quis tellus non lorem tempus rhoncus vitae in velit. Praesent vestibulum tempus tempus. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Aenean consequat, tellus in imperdiet faucibus, nibh nisi vehicula metus, eu posuere est sapien adipiscing lacus. Mauris dolor eros, porttitor vitae rhoncus vel, condimentum quis neque. Fusce sodales risus ac sem facilisis ultricies. Maecenas in leo arcu.</p>', '<div>dolore ipsim commete</div>', 'filtered_html'),
('node', 'blog', '0', '38', '38', 'en', '0', '<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur eu elit sed nunc porta molestie vel vitae odio. Donec ut arcu in justo mollis consectetur vel a elit. Curabitur iaculis turpis pellentesque nibh ornare sit amet faucibus quam egestas. Vestibulum lacinia posuere vehicula. Ut eget nulla ut mi pellentesque vehicula. Suspendisse luctus semper ipsum, vel dapibus sem sagittis quis. Nulla vehicula tincidunt libero vitae molestie. Duis et diam ante, nec ultrices eros. Nullam volutpat auctor dolor in interdum. Ut augue sapien, rutrum non tempor id, feugiat in enim. Suspendisse fringilla, magna et vulputate sollicitudin, urna est sollicitudin arcu, eu pretium diam lorem et massa. Vestibulum congue ante ac erat placerat sollicitudin. Donec eget ipsum sit amet libero suscipit aliquam.</p><p>In fringilla, sapien ut consequat dictum, mi enim tincidunt tortor, id tristique dui diam congue erat. Vivamus massa lectus, placerat non adipiscing id, varius eu metus. Nunc arcu augue, aliquet vitae suscipit id, tincidunt sit amet mauris. Nulla eu nibh quis nisl convallis blandit. Sed rhoncus gravida magna ut aliquet. Phasellus consectetur, turpis in convallis rhoncus, mauris orci tincidunt leo, in rutrum purus purus vitae justo. Duis aliquet dolor ut sapien ullamcorper id feugiat nunc interdum. Maecenas id augue sed tellus rutrum pellentesque. Cras vulputate placerat adipiscing. Nulla sed semper lacus. In sollicitudin molestie felis id sollicitudin. Aliquam congue tellus eget ipsum consectetur non feugiat arcu aliquam. Sed pharetra, lacus ac placerat consectetur, magna elit posuere mauris, a dapibus neque augue quis est. Mauris id justo sed dui tincidunt adipiscing. Nam porta nisl in sem dignissim cursus.</p><p>Duis et eros odio. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Cras lorem nulla, dictum eu consequat et, adipiscing eu mi. Vivamus tincidunt sem consectetur urna mollis laoreet. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Praesent vel risus massa, non suscipit sem. Sed malesuada magna et mauris vestibulum blandit. Donec ornare viverra nisi sed eleifend. Duis in tortor tortor, dictum adipiscing est.</p><p>Nunc sed nunc est. Vivamus porttitor interdum odio, tempus semper libero elementum sit amet. Sed ac eros lacus. Sed urna mi, fermentum sit amet tempus sit amet, varius ac odio. Morbi vehicula magna eu nibh dignissim sit amet sagittis nulla porta. Ut ultricies mi mauris. Donec vel vulputate justo. Nulla et tellus lorem. Integer sed magna eget quam malesuada dapibus. Nulla in magna eu erat sagittis lobortis. Mauris a lorem non dolor vestibulum ultrices. Proin turpis dolor, porta eget feugiat nec, bibendum id velit. Aenean molestie nisl id arcu viverra accumsan. Aliquam egestas purus sit amet sem pharetra sed molestie justo malesuada. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus eu urna nec odio malesuada sollicitudin nec ut nunc.</p>', '<div>dolore ipsim commete</div>', 'filtered_html'),
('node', 'blog', '0', '39', '39', 'en', '0', '<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam aliquet pellentesque cursus. Curabitur porta condimentum metus sed consequat. Nulla at mauris eget massa feugiat placerat nec id enim. Cras sollicitudin quam a est ullamcorper eleifend. Proin posuere rutrum urna sed porttitor. Pellentesque aliquam convallis molestie. Donec ut dolor enim, nec pretium felis. Nunc id dui quam, sed molestie libero. Quisque consequat vulputate neque, ultrices tincidunt lacus scelerisque vitae.</p><p>Proin imperdiet, turpis eu gravida vestibulum, ante nisl accumsan sapien, in vestibulum risus dolor interdum purus. Aenean fringilla, justo et aliquet eleifend, urna eros faucibus urna, et pellentesque neque nisl ut risus. Aliquam adipiscing tempor nisi, id porttitor sapien molestie in. Curabitur felis massa, volutpat quis gravida euismod, commodo sit amet arcu. Cras mattis, nisl sit amet egestas tempus, urna quam ultrices augue, nec sodales sapien leo at mauris. In hac habitasse platea dictumst. Etiam facilisis, ligula tempor cursus adipiscing, nisi arcu ullamcorper risus, eget gravida felis odio sit amet erat.Morbi quis dictum libero. Nulla orci lectus, venenatis at mattis non, venenatis eget nunc. Pellentesque vel sapien mauris, at aliquam dui. Etiam fringilla magna nec turpis placerat et posuere quam aliquet. Donec sit amet massa sit amet leo egestas sagittis at a nibh. Vestibulum vitae quam eget tellus scelerisque volutpat vel sit amet nisl. Aliquam vel metus lectus. Pellentesque vitae semper sem. Sed tempor malesuada arcu id tincidunt. Ut tincidunt ullamcorper justo ac euismod. Maecenas a lectus porta nulla semper porta. Ut quis eros elit.</p><p>Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Morbi sagittis ante eu arcu molestie ac fringilla odio vulputate. Nulla sit amet arcu vel sem euismod dictum. Integer nisi urna, consectetur et rhoncus sit amet, semper eu tellus. Pellentesque blandit vestibulum leo ut laoreet. Phasellus sit amet justo ornare dolor consequat rutrum et non elit. Ut rutrum viverra neque non hendrerit. Phasellus nibh mi, pharetra nec tempor sed, faucibus ut felis. Ut quis nisl est. Sed condimentum, urna at elementum placerat, justo arcu iaculis dolor, quis rutrum sapien turpis ac arcu.</p>', '<div>dolore ipsim commete</div>', 'filtered_html'),
('node', 'blog', '0', '40', '40', 'en', '0', '<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nunc dolor metus, pulvinar ac viverra id, porttitor sed lorem. Morbi tincidunt accumsan nisi in mollis. Quisque placerat dictum facilisis. Nam lobortis pharetra libero, vitae facilisis justo tempus gravida. Donec convallis euismod nisi, vitae pellentesque lacus iaculis vulputate. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Phasellus pretium lobortis est at varius. Donec viverra consequat leo, et lobortis ipsum convallis in. Nam commodo ipsum quis risus ultricies at gravida leo varius. Pellentesque at velit ac sem scelerisque blandit et vel lectus. Aenean rhoncus odio eu leo fermentum tincidunt. Fusce sed urna eget nisi congue ornare vestibulum sed ligula. Suspendisse potenti. Sed dapibus, odio vel facilisis rhoncus, leo nunc interdum quam, sed commodo nisl tortor a velit. Etiam orci nisi, pretium a malesuada mattis, adipiscing sed ante.</p><p>Pellentesque at egestas nulla. Morbi justo nunc, scelerisque at pretium ac, tempus quis est. Nunc sodales, ante et mollis cursus, dolor libero rhoncus magna, sed semper augue erat ac nulla. Nulla facilisi. Duis suscipit ipsum a sapien viverra scelerisque. Duis rhoncus est nec augue vulputate vestibulum. Nunc erat mauris, laoreet eu blandit eget, auctor nec dui.</p><p>Suspendisse potenti. Duis congue porta neque id elementum. Etiam ultricies eleifend lorem, in viverra sapien suscipit sed. Ut faucibus imperdiet lacus, a egestas nulla ultrices iaculis. Sed purus lacus, placerat et tempus at, egestas eu libero. In varius turpis vitae orci commodo eu lacinia erat sollicitudin. Nullam lacus ante, gravida vel rutrum sed, semper in dui. Pellentesque volutpat congue dui ut sodales. Phasellus laoreet, velit ut convallis sollicitudin, nunc elit dapibus lectus, sit amet molestie ligula tellus a est. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Sed est nibh, tempus eu ultrices quis, consectetur nec est. Maecenas auctor quam et justo pretium et pulvinar nulla dignissim. Praesent facilisis, nulla quis rutrum aliquet, lorem sem tincidunt nulla, ac bibendum est lectus viverra felis. Phasellus bibendum, justo nec placerat aliquam, massa erat aliquam sem, bibendum mollis odio odio vitae augue. Vivamus non enim nisi, mattis convallis nulla.</p><p>Sed id orci eu mauris posuere fringilla. Pellentesque tincidunt molestie porta. Aenean eget viverra magna. Cras commodo nibh id justo dictum vulputate. Nam venenatis leo vel nisi fringilla at pellentesque orci pharetra. Fusce turpis tortor, mollis sed iaculis et, eleifend sit amet dolor. Aliquam consectetur tempor fringilla. Aenean nisl nulla, faucibus quis dictum in, viverra et arcu. Curabitur eget augue nec risus semper tristique.</p>', '<div>dolore ipsim commete</div>', 'filtered_html'),
('node', 'blog', '0', '41', '41', 'en', '0', '<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Quisque cursus, sem eget sagittis sagittis, nisl magna sodales eros, ut feugiat velit velit non turpis. Cras eu nibh dapibus justo fringilla bibendum. Donec eget aliquam massa. Etiam ac dui felis, sed eleifend mi. Suspendisse consequat urna ac orci mattis consequat. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. In mattis mattis eleifend. Donec leo odio, fringilla nec lacinia in, dignissim molestie erat. Integer dui ipsum, semper sed mattis quis, convallis consequat magna. Quisque quis arcu justo, nec laoreet lacus. In vulputate malesuada auctor. Suspendisse pharetra, diam eu auctor vestibulum, orci sem mattis neque, eget facilisis neque risus vitae libero.</p><p>Duis tincidunt, orci ut porttitor sollicitudin, urna risus porttitor urna, sit amet varius eros enim eu orci. Pellentesque non mauris eget ipsum tristique luctus quis eu orci. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Ut nunc enim, pretium vel blandit ac, euismod eget felis. Aenean sed purus nibh, adipiscing pharetra dui. Aenean sed mauris dui. Etiam tincidunt ornare velit ut ornare. Maecenas ac arcu a orci aliquet accumsan sit amet sit amet augue. Curabitur turpis sem, iaculis et dapibus ac, placerat in quam.</p><p>Proin congue, neque sed sagittis facilisis, enim purus hendrerit orci, in blandit nulla elit eget velit. Sed congue, justo vitae imperdiet condimentum, nisi eros imperdiet tellus, in iaculis tortor velit gravida neque. Etiam convallis nisi tincidunt nisi mollis non pretium elit interdum. Mauris adipiscing, ante ut hendrerit sodales, ante enim commodo enim, sed posuere lacus arcu non est. Donec nibh augue, accumsan at tristique ut, luctus non sem. Nulla ac enim non sapien aliquam interdum. Fusce scelerisque semper massa, sit amet tristique turpis semper sit amet. Aenean adipiscing mauris lorem, et ultrices leo. Maecenas et felis eu turpis feugiat convallis. Phasellus sit amet ipsum quis dolor rhoncus aliquet ac id quam. Nunc ultricies ipsum a tortor tristique eleifend non eget nunc. Praesent vestibulum placerat felis et eleifend. Sed ut commodo diam. Donec et nunc massa, sit amet rutrum diam. Fusce vulputate fermentum dapibus.</p><p>Proin convallis condimentum tortor. Vivamus ut erat at neque consequat bibendum. Integer id libero eget mi semper hendrerit ac et odio. Vestibulum sodales quam quis ante auctor accumsan. Vivamus viverra porta nunc aliquam lobortis. Phasellus porttitor porta massa nec mollis. Vivamus sodales condimentum sem et volutpat. Aliquam erat volutpat. Curabitur accumsan interdum justo, eget cursus dolor ultrices et. Nam dolor orci, dapibus sed facilisis eu, laoreet a nisi. Sed nec nunc sit amet urna viverra dapibus eget a libero. Cras lacinia blandit magna in accumsan. Suspendisse quis dui vel dolor scelerisque tristique. Donec pellentesque scelerisque semper.</p>', '<div>dolore ipsim commete</div>', 'filtered_html'),
('node', 'faq', '0', '42', '42', 'en', '0', 'Suspendisse sem justo, commodo et tristique in, aliquet in nibh. Ut bibendum blandit lacus. Integer sodales, odio sed facilisis adipiscing, felis magna sagittis mauris, sit amet placerat sem nunc vitae velit. Ut sollicitudin augue non tortor semper ultrices. Curabitur libero neque, ultrices feugiat laoreet a, volutpat nec erat. ', '', 'filtered_html'),
('node', 'faq', '0', '43', '43', 'en', '0', 'Aliquam erat volutpat. Donec dapibus nisl sit amet purus vehicula condimentum pulvinar felis cursus. Sed tellus dui, vulputate quis porttitor a, consequat vel lectus. Cras rutrum, lacus vel posuere sodales, turpis elit pretium elit, malesuada aliquam sapien nibh vitae tortor. Vivamus viverra blandit nibh, faucibus hendrerit orci ultrices id.', '', 'filtered_html'),
('node', 'faq', '0', '44', '44', 'en', '0', 'Suspendisse ornare dapibus nisi, vel placerat metus varius non. Cras tellus libero, condimentum a pharetra ac, aliquet at massa. Phasellus ullamcorper varius velit, in hendrerit magna convallis et. Donec porta, enim id tempor varius, tortor diam porttitor odio, at ultricies tellus dui vitae ante. Ut ut enim quam, at consectetur leo.', '', 'filtered_html'),
('node', 'faq', '0', '45', '45', 'en', '0', 'Donec id tortor sit amet enim ornare pretium. Vestibulum felis diam, hendrerit non ornare quis, eleifend quis erat. Quisque et dui sapien, sit amet ultrices odio. Nullam faucibus bibendum felis. Nullam bibendum, turpis et sollicitudin ullamcorper, dui magna dictum turpis, vitae pulvinar lorem orci sed neque. Duis sem leo, rutrum quis tempus eu, volutpat luctus felis. Nulla convallis congue molestie.', '', 'filtered_html'),
('node', 'faq', '0', '46', '46', 'en', '0', 'Phasellus ornare sapien at purus fringilla pellentesque. Ut laoreet gravida risus, eu bibendum lacus mattis eu. Praesent ac pulvinar lectus. Proin eu venenatis eros. Vestibulum id lectus vitae erat eleifend semper et in tortor. Donec venenatis ante eu diam fringilla fermentum. Integer pharetra tellus at erat bibendum sed facilisis velit molestie.', '', 'filtered_html'),
('node', 'slider', '0', '47', '47', 'en', '0', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam neque nisi, interdum ac porta non, condimentum eu tellus. Nunc rhoncus sem quis metus cursus sagittis. Nulla risus massa, sagittis eu lobortis quis, molestie ac urna. Etiam a nisi risus. Proin lacinia auctor dapibus. Mauris sit amet dignissim lectus. Praesent dignissim dui id dui accumsan molestie. Nulla luctus nulla vitae purus posuere in gravida ante vulputate. Quisque faucibus pellentesque risus, a euismod sapien laoreet non. Praesent aliquet mattis neque, quis euismod libero ultricies quis. Maecenas nec urna a lacus ultricies tristique. Sed a massa et dolor feugiat commodo. Praesent sed risus mollis eros sagittis hendrerit.\r\n\r\nProin mattis enim ut arcu elementum ornare pharetra eget ligula. Donec et ante a diam scelerisque fringilla. Quisque nunc ipsum, laoreet eget pellentesque eu, sodales vitae massa. Phasellus non neque in lacus imperdiet varius. Aliquam suscipit, libero non sodales lobortis, erat enim rutrum lacus, id malesuada enim neque commodo risus. In sed erat nisi, non porttitor ante. Maecenas at lorem lacus, eget feugiat justo. Nam lacinia ligula eget ante malesuada luctus. Sed posuere dui quis lectus mollis volutpat. Vivamus suscipit blandit urna sit amet lobortis. Phasellus et elit magna, in molestie nisi. Curabitur mattis nunc et nunc tristique porttitor a cursus lorem. Vestibulum non venenatis nibh. Aenean ultricies, justo in tempus rhoncus, mi eros luctus elit, vel volutpat tellus felis eu ligula. Vivamus mattis orci a nunc commodo fringilla ut eget lacus. Proin vestibulum suscipit tincidunt. Duis dictum aliquet scelerisque. Praesent a tortor purus. ', '<div>Sed utem perspiciatis</div>', 'full_html'),
('node', 'slider', '0', '50', '50', 'en', '0', 'Aliquam erat volutpat. Praesent quis nibh nisl. Cras at libero quam, ut tincidunt diam. Fusce aliquet augue a ipsum ullamcorper semper. Suspendisse potenti. Proin id eros eu lectus blandit suscipit id eget tortor. Nulla augue purus, molestie accumsan ullamcorper ut, dictum sit amet erat. Proin eu leo eros, eu tincidunt lorem. Donec sit amet mauris vitae felis viverra tristique. Mauris varius ante eu ante tincidunt aliquam. Etiam porttitor facilisis molestie. Etiam at tellus eu lacus volutpat suscipit. Nam blandit elit dignissim risus consequat egestas. Proin blandit, turpis ut facilisis aliquet, dui quam fringilla dolor, id rutrum nisi urna ac nunc. Nulla congue justo quis magna laoreet vitae fringilla est venenatis. Cras blandit ante eget turpis eleifend rutrum.\r\n\r\nSed non quam nec tortor molestie luctus nec sit amet massa. Nulla tincidunt orci sit amet nisl eleifend pretium. Donec sit amet libero nec nunc tristique vulputate. Vestibulum vel lectus massa. Curabitur consequat, justo nec bibendum dignissim, felis ipsum pharetra nunc, non eleifend dui diam at ipsum. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Etiam nec justo eu magna lacinia sollicitudin at quis odio. Nullam dui enim, iaculis eu egestas a, volutpat at tortor. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Cras vitae urna sit amet turpis lobortis tristique. Nullam eget orci id massa tempus auctor. Vivamus commodo porta magna non adipiscing. Cras id risus eu tellus mollis malesuada id in orci. Etiam mi magna, gravida id ultrices vel, sollicitudin nec sapien. Curabitur a euismod dui. Fusce vestibulum consequat imperdiet. Ut molestie eros ac lorem eleifend vitae pretium nunc porttitor. ', '<div>Praesent vestibulum</div>', 'full_html'),
('node', 'slider', '0', '51', '51', 'en', '0', 'Curabitur nunc lacus, fermentum eget rhoncus interdum, pellentesque sed dui. Nulla lobortis bibendum ante non malesuada. Aliquam eget condimentum augue. In et libero orci. Praesent ut augue et est interdum blandit tempor in felis. Vivamus laoreet sem sed velit malesuada posuere. Cras dolor augue, commodo non auctor nec, ornare in ipsum. Aenean et urna purus. Integer ac nisl risus, sed interdum libero. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Nullam a ligula quis diam auctor laoreet. Vivamus molestie suscipit malesuada.\r\n\r\nPellentesque tempus lacus in arcu venenatis eget ullamcorper ante euismod. Fusce condimentum, ligula in congue tincidunt, lectus eros hendrerit nibh, id hendrerit dui quam sit amet velit. Pellentesque pretium, magna ac aliquam feugiat, ligula felis mollis enim, nec lacinia ipsum nibh non neque. Aliquam vulputate massa quis lacus porttitor non malesuada dui auctor. Sed bibendum faucibus erat, eu mollis nunc fermentum ut. Nullam vitae pharetra ante. Maecenas viverra fringilla metus, a posuere ligula elementum sit amet. Aenean elit leo, dapibus et vestibulum eu, tristique sit amet ante. In id mi et leo tristique ultrices. In ac lacus nulla. Proin arcu massa, imperdiet eget interdum vel, ultrices eget sapien. Donec vestibulum aliquet leo eu tristique. Cras dolor quam, bibendum non ullamcorper sit amet, aliquam ac elit. ', '<div>Lorem ipsum dolor</div>', 'full_html'),
('node', 'portfolio', '0', '52', '52', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>', '', 'full_html'),
('node', 'portfolio', '0', '53', '53', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>', '', 'full_html'),
('node', 'portfolio', '0', '54', '54', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>', '', 'full_html'),
('node', 'portfolio', '0', '55', '55', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>', '', 'full_html'),
('node', 'portfolio', '0', '56', '56', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>', '', 'full_html'),
('node', 'portfolio', '0', '57', '57', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>', '', 'full_html'),
('node', 'portfolio', '0', '58', '58', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>', '', 'full_html'),
('node', 'employee', '0', '65', '65', 'en', '0', '<p>Curabitur mauris tortor, laoreet et consectetur non, <a href="#">rhoncus sed risus</a>. Donec nisi enim, adipiscing <strong>quis convallis</strong> eu, elementum a urna. Maecenas sit amet metus sem. Sed non est ligula, sit amet vehicula nunc. Maecenas sed quam non urna tincidunt pellentesque ac ut enim. Vestibulum arcu tortor, vulputate nec semper id, commodo eget lacus. Integer mi dolor, malesuada in ullamcorper ut, tincidunt eu arcu. Mauris dictum, libero id rutrum vehicula, est l<strong>igula sagittis urna</strong>, ut convallis purus <strong>purus at dolor</strong>. <em>Praesent nec vehicula</em> tortor. Nulla facilisi. Curabitur mauris sapien, interdum id consequat et, lobortis ut ipsum. Vestibulum tempus augue eu est malesuada viverra. Nunc mattis fermentum metus, a consectetur magna egestas lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Morbi <em>non mauris ligula</em>. Suspendisse facilisis <a href="#">sagittis mauris</a>, ac dictum elit fringilla ut.</p>\r\n\r\n<p>Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Sed vel erat justo. In lorem augue, varius ut hendrerit a, gravida vel lectus. Donec fringilla metus in leo gravida facilisis. Suspendisse lacinia, leo quis auctor suscipit, massa sapien congue sem, sit amet tincidunt enim nibh eget neque. <strong>Proin semper placerat</strong> odio, sit amet vehicula mauris malesuada sed. Nulla facilisi.</p>\r\n\r\n<p>Quisque lectus dui, aliquet eu placerat eu, viverra at velit. Nunc sed magna ut tortor tempor mollis a eu justo. <a href="#">Fusce ultrices</a>, velit eget aliquam auctor, turpis dui tincidunt tellus, id porta libero mauris ac ligula. Donec rutrum est id nisl euismod facilisis. Quisque vitae justo sed sem blandit tincidunt. Phasellus condimentum luctus odio nec aliquam. Donec sed augue sem.</p>\r\n\r\n<p>Sed ullamcorper varius fermentum. Ut commodo quam non <strong>sapien pellentesque porta</strong>.<a href="#"> Vestibulum ante</a> ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Mauris mattis elit et neque congue mollis. Duis lacinia felis at purus hendrerit venenatis. Mauris placerat, nulla non faucibus cursus, mauris urna malesuada augue, vitae vestibulum erat nulla ac odio. Pellentesque enim felis, dictum in <strong>sodales sit amet, placerat non ante</strong>. Etiam <a href="#">dapibus leo ut tellus fermentum</a> a <em>bibendum augue molestie</em>. Maecenas auctor neque id ante bibendum fermentum. Aliquam dui magna, egestas vitae condimentum pharetra, imperdiet sed enim. Donec nisl mauris, facilisis hendrerit aliquam eu, rutrum vitae nisl. Nulla dui eros, vehicula facilisis ornare nec, commodo vitae velit. Sed at justo justo. Nunc justo dolor, condimentum vel dignissim id, malesuada et odio.</p>', '', 'full_html');
INSERT INTO `field_data_body` VALUES
('node', 'employee', '0', '67', '67', 'en', '0', '<p>Ut a augue arcu, ut lacinia arcu. Maecenas blandit odio ac dui scelerisque vitae <a href="#">ullamcorper diam mattis</a>. Etiam pharetra interdum nunc eget elementum. Cras molestie, magna nec auctor cursus, est ante hendrerit libero, eget dignissim urna neque ac risus. Aenean cursus iaculis lacinia. Mauris sit amet felis pretium nulla <a href="#">volutpat vehicula</a> eu et turpis. Maecenas vehicula molestie felis, vitae feugiat lacus mollis faucibus. <strong>Suspendisse sollicitudin</strong> faucibus metus, non tristique justo fermentum vel. <strong>In ligula lacus, gravida</strong> a iaculis id, molestie id nibh. Maecenas suscipit auctor ullamcorper. Vivamus ut odio vel <a href="#">ligula pretium porta</a> a eget arcu. Ut tempus quam eget orci pharetra euismod. Donec id mi eu augue congue vulputate et in ipsum.</p>\r\n\r\n<p>Etiam cursus adipiscing auctor. Phasellus in arcu arcu, <strong>accumsan aliquam massa</strong>. Phasellus lacinia, nulla ut pellentesque viverra, dui odio tristique dolor, eu tincidunt purus sem a lectus. Duis ut sem neque. Duis <em>dignissim, leo nec egestas venenatis</em>, nulla est porta quam, eget commodo nulla turpis sit amet nibh. Ut in arcu eget massa scelerisque dapibus nec ut leo. Curabitur elementum, mauris ac egestas imperdiet, lorem <strong>lorem pellentesque leo</strong>, quis pulvinar <a href="#">nibh dui non massa</a>. Nam sed dapibus metus.</p>\r\n\r\n<p>Aliquam ultrices condimentum urna, id sagittis dui convallis ac. Nulla mollis placerat quam <a href="#">blandit ultricies</a>. Maecenas scelerisque molestie quam, id ornare urna ornare in. Maecenas libero quam, elementum in fringilla eget, tincidunt sit amet mi. Duis sagittis viverra tempus. <strong>Nam in elit orci</strong>, ac venenatis leo. <a href="#">Aenean auctor molestie</a> <strong>nulla, quis luctus</strong> urna vulputate at.</p>\r\n\r\n<p>Vestibulum mollis, nisl accumsan dignissim tristique, <strong>ipsum eros scelerisque tortor</strong>, in suscipit augue mi vitae nunc. Ut vel justo ligula, ut vehicula eros. Duis dictum commodo erat vestibulum consectetur. Nam porta sodales mauris, tristique mattis ante tincidunt eget. <strong>Maecenas ut aliquam risus</strong>. Sed porta porttitor rhoncus. Vestibulum dapibus vestibulum nulla, quis viverra magna pharetra a. Suspendisse elit velit, semper eget consequat at, imperdiet nec leo. Sed ipsum quam, gravida ac eleifend in, <a href="#">cursus eu tellus</a>. Suspendisse mattis lacus arcu, vitae mollis purus. Aliquam ut lorem turpis. In porttitor lectus non nibh dignissim quis fermentum nulla convallis.</p>', '', 'full_html'),
('node', 'employee', '0', '68', '68', 'en', '0', '<p>Aenean sodales dapibus massa, ut <a href="#">feugiat nulla ultrices</a> nec. Vestibulum <strong>at massa in mi scelerisque</strong> placerat ut id dolor. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Phasellus nibh velit, malesuada ut viverra at, ultrices quis libero. Phasellus lectus lacus, scelerisque a condimentum nec, <em>dignissim non felis</em>. Etiam aliquam, leo dictum fringilla elementum, nibh nulla volutpat felis, non ultricies ipsum tortor nec eros. Vivamus placerat, <strong>mi non gravida consequat, neque</strong> tellus congue augue, at molestie purus ligula id leo. Phasellus at diam arcu, quis accumsan enim. Donec gravida facilisis eros. Cras eu elit id lectus congue dapibus et sed mi. Duis scelerisque ligula <a href="#">at sem mollis sed posuere tellus</a> egestas. Donec vel fermentum felis. In hac habitasse platea dictumst. Pellentesque sit amet est at odio adipiscing rhoncus in laoreet enim.</p>\r\n\r\n<p>Nam sollicitudin, <a href="#">quam non pellentesque ornare</a>, dolor enim ornare dolor, sed aliquet neque tortor at risus. Cras et magna eget dui congue aliquam. Suspendisse quis ante non augue tincidunt ornare. Donec vitae lacus elit, ac suscipit justo. <strong>Vestibulum vel est neque, eu</strong> blandit nulla. <em>Phasellus non ornare neque</em>. In bibendum, lorem vitae vulputate posuere, quam purus ultricies lectus, in vehicula eros arcu a quam. Aliquam lacus ante, pharetra interdum egestas vitae, <strong>ultrices eget velit</strong>. Aliquam erat volutpat.</p>\r\n\r\n<p>Praesent mauris est, aliquam sit amet tincidunt sit amet, tristique non turpis. <strong>Aliquam eget quam tellus</strong>. Vivamus aliquam libero sit amet sapien ultricies aliquam. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris vestibulum egestas augue non fringilla. Fusce vel nibh <strong>ligula, nec molestie nisl</strong>. Integer sed massa <a href="#">arcu, non auctor</a> mi. Aenean nisi quam, sollicitudin at tincidunt sit amet, aliquet imperdiet neque.</p>\r\n\r\n<p>Ut a augue arcu, ut lacinia arcu. Maecenas blandit odio ac dui scelerisque vitae <a href="#">ullamcorper diam mattis</a>. Etiam pharetra interdum nunc eget elementum. Cras molestie, magna nec auctor cursus, est ante hendrerit libero, eget dignissim urna neque ac risus. Aenean cursus iaculis lacinia. Mauris sit amet felis pretium nulla <a href="#">volutpat vehicula</a> eu et turpis. Maecenas vehicula molestie felis, vitae feugiat lacus mollis faucibus. <strong>Suspendisse sollicitudin</strong> faucibus metus, non tristique justo fermentum vel. <strong>In ligula lacus, gravida</strong> a iaculis id, molestie id nibh. Maecenas suscipit auctor ullamcorper. Vivamus ut odio vel <a href="#">ligula pretium porta</a> a eget arcu. Ut tempus quam eget orci pharetra euismod. Donec id mi eu augue congue vulputate et in ipsum.</p>', '', 'full_html'),
('node', 'employee', '0', '69', '69', 'en', '0', '<p>Aenean sed fermentum metus. Integer imperdiet nisi vel lectus<strong> fermentum malesuada</strong>. Aliquam tincidunt tempus tempus. Aliquam euismod mauris non eros facilisis nec sagittis ipsum rutrum. Curabitur venenatis molestie eros, vitae sagittis quam viverra a.<a href="#"> Duis vel augue vel metus</a> tempus <em>malesuada</em> <em>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut vulputate, metus at vulputate mattis, nibh lorem molestie ligula, sed tempor enim mi vel augue.</em></p>\r\n\r\n<p>Aenean sodales dapibus massa, ut <a href="#">feugiat nulla ultrices</a> nec. Vestibulum <strong>at massa in mi scelerisque</strong> placerat ut id dolor. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Phasellus nibh velit, malesuada ut viverra at, ultrices quis libero. Phasellus lectus lacus, scelerisque a condimentum nec, <em>dignissim non felis</em>. Etiam aliquam, leo dictum fringilla elementum, nibh nulla volutpat felis, non ultricies ipsum tortor nec eros. Vivamus placerat, <strong>mi non gravida consequat, neque</strong> tellus congue augue, at molestie purus ligula id leo. Phasellus at diam arcu, quis accumsan enim. Donec gravida facilisis eros. Cras eu elit id lectus congue dapibus et sed mi. Duis scelerisque ligula <a href="#">at sem mollis sed posuere tellus</a> egestas. Donec vel fermentum felis. In hac habitasse platea dictumst. Pellentesque sit amet est at odio adipiscing rhoncus in laoreet enim.</p>\r\n\r\n<p>Nam sollicitudin, <a href="#">quam non pellentesque ornare</a>, dolor enim ornare dolor, sed aliquet neque tortor at risus. Cras et magna eget dui congue aliquam. Suspendisse quis ante non augue tincidunt ornare. Donec vitae lacus elit, ac suscipit justo. <strong>Vestibulum vel est neque, eu</strong> blandit nulla. <em>Phasellus non ornare neque</em>. In bibendum, lorem vitae vulputate posuere, quam purus ultricies lectus, in vehicula eros arcu a quam. Aliquam lacus ante, pharetra interdum egestas vitae, <strong>ultrices eget velit</strong>. Aliquam erat volutpat.</p>', '', 'full_html'),
('node', 'employee', '0', '71', '71', 'en', '0', '<p>Sed ullamcorper varius fermentum. Ut commodo quam non <strong>sapien pellentesque porta</strong>.<a href="#"> Vestibulum ante</a> ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Mauris mattis elit et neque congue mollis. Duis lacinia felis at purus hendrerit venenatis. Mauris placerat, nulla non faucibus cursus, mauris urna malesuada augue, vitae vestibulum erat nulla ac odio. Pellentesque enim felis, dictum in <strong>sodales sit amet, placerat non ante</strong>. Etiam <a href="#">dapibus leo ut tellus fermentum</a> a <em>bibendum augue molestie</em>. Maecenas auctor neque id ante bibendum fermentum. Aliquam dui magna, egestas vitae condimentum pharetra, imperdiet sed enim. Donec nisl mauris, facilisis hendrerit aliquam eu, rutrum vitae nisl. Nulla dui eros, vehicula facilisis ornare nec, commodo vitae velit. Sed at justo justo. Nunc justo dolor, condimentum vel dignissim id, malesuada et odio.</p>\r\n\r\n<p>Nulla ultricies enim aliquet augue eleifend iaculis. Nam sollicitudin <strong>ligula ac nisi</strong> iaculis eu scelerisque risus ultricies. Nullam eu elit risus, vel interdum urna. Aenean leo nulla, aliquet vitae ultricies sit amet, porttitor id sapien. In hac habitasse platea dictumst. Donec pharetra gravida augue at hendrerit. Cras ut sagittis justo. Maecenas velit elit, eleifend sed sollicitudin sed, interdum eu erat. Duis rhoncus <a href="#">libero vitae orci</a> interdum vehicula. Sed sodales tellus <strong>at justo interdum</strong> aliquet.</p>\r\n\r\n<p>Proin dolor justo, molestie ac suscipit vel, faucibus nec eros. <strong>Phasellus congue ornare</strong> ipsum, non pellentesque orci luctus in. Sed ligula lorem, <strong>commodo in suscipit</strong> eget, bibendum nec sapien. Duis tincidunt, magna ac ullamcorper euismod, leo lectus ultricies nibh, ut placerat lectus risus vitae orci. Duis tincidunt, dolor vel <a href="#">fermentum eleifend</a>, justo tortor pellentesque turpis, at tincidunt metus metus et velit. Vivamus semper lacinia sodales. Sed ultrices <a href="#">metus tincidunt ante rutrum</a> tincidunt. <strong>Nulla dignissim orci eu ante</strong> dapibus pulvinar. Integer nibh neque, eleifend et egestas eget, suscipit ut purus. Vestibulum pharetra, ante sed mollis vestibulum, arcu turpis dapibus nunc, quis dictum erat nisl sed ante. Fusce est ipsum, suscipit sed aliquet ut, hendrerit eget nisi.</p>\r\n\r\n<p>Pellentesque auctor nisl eget mi accumsan auctor. Vivamus <strong>tempor magna eget tellus</strong> elementum a dignissim felis aliquam. <a href="#">Donec faucibus sem quis</a> nibh iaculis scelerisque aliquet leo eleifend. Fusce accumsan, mauris ut placerat mattis, magna mauris ultricies magna, fermentum <strong>hendrerit nunc turpis quis</strong> mi. Suspendisse cursus arcu eu nunc faucibus in dictum ligula viverra. Donec non semper leo. Sed quis enim arcu, pellentesque vestibulum risus. Ut elit nulla, commodo ac sagittis non, dapibus ut elit. Nunc <em>dignissim lacinia sapien</em> nec blandit.</p>', '', 'full_html'),
('node', 'employee', '0', '73', '73', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>\r\n\r\n<p>Curabitur mauris tortor, laoreet et consectetur non, <a href="#">rhoncus sed risus</a>. Donec nisi enim, adipiscing <strong>quis convallis</strong> eu, elementum a urna. Maecenas sit amet metus sem. Sed non est ligula, sit amet vehicula nunc. Maecenas sed quam non urna tincidunt pellentesque ac ut enim. Vestibulum arcu tortor, vulputate nec semper id, commodo eget lacus. Integer mi dolor, malesuada in ullamcorper ut, tincidunt eu arcu. Mauris dictum, libero id rutrum vehicula, est l<strong>igula sagittis urna</strong>, ut convallis purus <strong>purus at dolor</strong>. <em>Praesent nec vehicula</em> tortor. Nulla facilisi. Curabitur mauris sapien, interdum id consequat et, lobortis ut ipsum. Vestibulum tempus augue eu est malesuada viverra. Nunc mattis fermentum metus, a consectetur magna egestas lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Morbi <em>non mauris ligula</em>. Suspendisse facilisis <a href="#">sagittis mauris</a>, ac dictum elit fringilla ut.</p>', '', 'full_html'),
('node', 'services', '0', '76', '76', 'en', '0', '<p>Nulla at tortor quam, eu ultricies nulla. Maecenas viverra, leo vitae mattis iaculis, nisi nunc semper ligula, eget lobortis est orci et tortor. Maecenas vitae sapien magna, nec malesuada nisi. Proin tempus felis et dolor accumsan id ultrices erat luctus. Duis porta lorem sed est scelerisque tincidunt. Cras nulla magna, accumsan ac commodo in, scelerisque sit amet leo. Nullam sed odio lorem, eu commodo dui. Quisque non justo est, at accumsan nulla. Vivamus ac purus sed nunc cursus hendrerit. Suspendisse nunc mauris, tempus non pretium nec, aliquam ac turpis.</p><p>Curabitur neque dui, viverra et varius et, blandit eget lectus. Etiam augue dolor, facilisis eu convallis ut, rhoncus ut leo. Fusce vitae dictum diam. Aliquam erat volutpat. <a href="#">Duis vehicula ullamcorper elementum</a>. Aliquam iaculis est eu velit faucibus convallis. Aenean ac lacus nec odio cursus aliquet a id urna. Praesent quam elit, malesuada quis accumsan eget, tempus vel quam. Donec adipiscing leo quis sapien suscipit ac bibendum felis posuere. Quisque interdum metus ut eros laoreet ut viverra magna vestibulum. Ut quis diam ligula. Cras mauris sem, malesuada vitae gravida et, condimentum in ante. Pellentesque vel nisi enim, ac varius mi. Duis sem leo, interdum a mollis ut, tempor quis lacus. Sed fringilla est nec ipsum mattis tempus.</p><p>Nulla elementum tincidunt est in dignissim. Cras consequat neque in mi commodo eleifend. Nunc laoreet augue risus, eget consequat leo. Cras enim sapien, blandit vel eleifend sit amet, mattis rutrum neque. Phasellus sed magna quis quam tincidunt porta. Aliquam eget dolor neque, a convallis turpis. Praesent volutpat tristique arcu, sed suscipit magna commodo hendrerit. <a href="#">Curabitur lorem velit</a>, tempor at ultricies eu, feugiat quis dui. Vestibulum gravida vulputate lacus sit amet hendrerit. Sed fringilla, arcu a tempus molestie, diam purus ultrices magna, a convallis risus lorem vitae est. Sed nec neque elit. Donec nec adipiscing velit. Pellentesque ut mauris urna, et volutpat libero. Nulla facilisi. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus.Vivamus a purus non nibh cursus faucibus sit amet ut velit. Morbi tempor sagittis commodo. Aenean a lorem magna, vel lobortis nulla. Praesent ac erat sit amet erat laoreet volutpat. Pellentesque semper ullamcorper euismod. Donec lorem massa, blandit sit amet rhoncus non, lacinia a eros. Pellentesque sed odio varius lectus tempor blandit. Sed ullamcorper malesuada magna non feugiat. In hac habitasse platea dictumst. Etiam sapien metus, aliquet consequat ornare et, commodo sit amet elit. Nunc at neque sed magna aliquet ornare. In congue feugiat sapien, sed congue dui sollicitudin iaculis.</p>', 'Mes cuml dia sed inenia', 'filtered_html'),
('node', 'services', '0', '77', '77', 'en', '0', '<p>Nullam eget felis id metus luctus semper quis vel nulla. Cras diam mauris, molestie eu sodales non, sodales vitae augue. Integer arcu nibh, semper vel cursus eu, adipiscing non lacus. Suspendisse ultrices lacus eu nibh euismod imperdiet. Nunc rutrum pharetra nisl, sed eleifend risus pulvinar in. Nunc venenatis libero et erat interdum et condimentum quam semper. Nulla mattis sem eget odio consequat eget malesuada ante placerat. Sed rhoncus posuere vulputate. Nam dignissim tortor a felis lobortis posuere in et ante. Suspendisse eu risus non nisi euismod condimentum. Aliquam varius orci nec eros sodales fringilla. Donec ac odio urna, a scelerisque dui. Nullam auctor lacus vitae neque porttitor malesuada. Maecenas vel nisi nec lorem auctor suscipit. Proin id tincidunt justo. Phasellus urna ipsum, sagittis convallis consectetur sit amet, vestibulum eu ligula.</p><p>Quisque rutrum erat eget arcu malesuada semper. Praesent faucibus lorem mi, quis interdum ipsum. Vivamus sit amet libero vitae augue ultrices tempor vitae in arcu. <a href="#">Maecenas rutrum, turpis</a> ut pulvinar fringilla, diam massa interdum ligula, sit amet euismod urna dolor non velit. Sed gravida mollis mi, placerat tincidunt nulla hendrerit et. Integer tempor scelerisque tellus, ut facilisis nisi eleifend eget. Aenean consequat mollis urna, et convallis lectus fermentum sit amet. Nulla facilisi. Sed tempor nulla eu leo dapibus porttitor. Vestibulum nec leo et sapien eleifend sagittis. Aliquam at diam quam. Maecenas ut mollis metus.</p><p>Fusce suscipit arcu sed elit lacinia faucibus ut dapibus enim. Mauris ultricies semper leo, quis condimentum nisi ultricies id. Sed et vulputate dolor. Proin nec magna ac ligula ornare tristique ac a lacus. Sed eget nisl in lectus interdum posuere a varius quam. Cras eros lacus, ultrices vitae consequat vitae, fermentum et enim. Nullam iaculis iaculis nisl, vel dictum sem ullamcorper eget. Integer mattis dapibus posuere. Fusce ut viverra velit. Duis vitae cursus nulla. Morbi felis mauris, consequat sed ornare a, sollicitudin at neque. Quisque non magna sed odio vehicula ornare at facilisis ante. Nam dui magna, sollicitudin sed porta eget, ultrices non risus. Praesent quis pulvinar leo. In id nunc ligula, quis laoreet nunc.</p><p>Morbi fringilla bibendum neque, nec facilisis odio ullamcorper sed. Proin hendrerit ornare fringilla. Curabitur iaculis sapien eget felis laoreet tempus. Nam convallis convallis purus, quis varius eros tempus et. Nunc vel libero sit amet massa semper vestibulum quis in nunc. Nunc sapien eros, imperdiet id elementum sit amet, feugiat nec tellus. Donec condimentum vestibulum consequat. Sed luctus enim quis quam luctus auctor. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque nec diam felis, quis vulputate orci. Nunc semper orci eget dolor auctor fringilla. In gravida euismod hendrerit. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Phasellus quis magna tortor. Vestibulum sed sapien eu nibh interdum imperdiet vitae ut dui.</p>', 'Mes cuml dia sed inenia', 'filtered_html'),
('node', 'services', '0', '78', '78', 'en', '0', '<p>Vestibulum quis felis ut enim aliquam iaculis. Nullam pharetra tortor at quam viverra volutpat. Phasellus vel faucibus dolor. Curabitur ac nisi non metus dignissim dapibus eu vel nibh. Phasellus semper dictum dapibus. Etiam tincidunt adipiscing ipsum. Praesent in urna ipsum. Mauris iaculis suscipit volutpat. Aliquam erat volutpat. Aliquam vestibulum lectus vitae sapien dictum id interdum nunc suscipit. Aenean pellentesque auctor porttitor. Phasellus auctor arcu sed mi pellentesque sodales. Aenean eros lectus, varius a consectetur imperdiet, hendrerit eu leo. Cras odio libero, cursus ac pharetra vitae, iaculis in orci. Proin id felis neque, ac fermentum orci. Integer nisi nulla, commodo ac sodales sit amet, condimentum ac arcu.</p><p>Donec a justo nisi. Maecenas fermentum orci ut turpis aliquet tristique. Etiam at lorem ut diam fermentum elementum. <a href="#">Maecenas aliquet dolor ac orci</a> ultrices facilisis. Nam et arcu pharetra neque elementum hendrerit eu ac lorem. Ut dapibus lacus a nisl convallis at vehicula diam fermentum. Curabitur adipiscing, lorem sed laoreet elementum, erat velit dictum leo, in aliquet dui ipsum vel erat.</p><p>Sed nec fringilla massa. Sed ultrices molestie sem a sodales. In hac habitasse platea dictumst. Nunc eros libero, mollis sit amet sodales ut, faucibus et mauris. Praesent egestas sollicitudin ultrices. Fusce ultrices sem nec lacus convallis a tempor velit consectetur. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque sed tortor enim.</p><p>Pellentesque eu mauris sed tortor ullamcorper lobortis quis non neque. Suspendisse scelerisque erat tellus, eu congue ante. Cras pretium euismod quam eu pulvinar. Morbi dapibus sollicitudin sapien et sollicitudin. Vestibulum viverra dictum sem, eget fermentum eros pretium in. Phasellus ut leo at ligula convallis pretium. Aliquam mollis luctus quam et mattis. Sed semper nunc porttitor erat elementum porttitor. Cras sit amet volutpat augue. Nam tortor diam, aliquam vel volutpat eget, convallis a diam. Proin metus metus, commodo quis commodo nec, fermentum eget arcu. Pellentesque eleifend leo sed lacus eleifend malesuada. Duis porttitor augue vel ante lacinia quis pharetra augue facilisis. Praesent dapibus dapibus dignissim. Quisque vitae orci nec mauris fringilla vehicula id nec ipsum</p>', 'Mes cuml dia sed inenia', 'filtered_html'),
('node', 'page', '0', '79', '79', 'en', '0', '<p><strong>Lorem ipsum dolor sit amet, consectetur adipiscing elit.</strong> Sed non arcu enim. Nam sed magna magna, eget tempus neque. Donec lectus enim, auctor ut dignissim sit amet, auctor aliquam tortor. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Phasellus a lectus id nibh mattis ultrices. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Duis suscipit eleifend mauris non condimentum. Mauris iaculis, nibh id interdum hendrerit, turpis turpis placerat dui, ac mattis augue quam eu tortor. Aenean condimentum feugiat rhoncus. Vestibulum id nulla auctor eros vehicula pellentesque.</p>\r\n<p><strong>Proin nec nibh erat, ut interdum tortor.</strong> Aliquam lectus risus, hendrerit vitae mollis et, molestie nec turpis. Nullam gravida diam sed velit dignissim bibendum. Cras tristique mi eu tortor aliquet a blandit urna tempor. Maecenas adipiscing euismod sagittis. Suspendisse vulputate convallis tellus, sed mattis justo faucibus ac. Phasellus non diam ut nisl viverra sodales. Aenean at nunc quis tortor consequat scelerisque. In dignissim, ante vel imperdiet venenatis, felis nisi imperdiet lectus, et ultrices eros justo in lacus. Quisque et ante ac metus eleifend laoreet. Cras leo metus, pharetra et molestie quis, iaculis ut felis.</p>\r\n<p><strong>Nullam sed viverra libero.</strong> Vestibulum imperdiet fermentum massa, a fringilla tortor varius vel. Praesent ac metus massa, ac dapibus lorem. Nunc cursus nisi eget dui suscipit aliquam viverra odio iaculis. Donec commodo erat non arcu volutpat viverra. Nulla facilisi. Nam sagittis metus sit amet quam porttitor sollicitudin. Mauris aliquam felis at enim gravida porta. Sed ultrices aliquam convallis. Sed non consequat ligula. Sed purus felis, pellentesque quis pretium ut, bibendum at est.</p>\r\n<p><strong>Quisque lacinia iaculis fermentum.</strong> Sed sed ante mauris, at pretium mauris. Mauris leo sem, dictum eget tincidunt at, gravida vel lacus. Nam fringilla tristique lectus. Etiam aliquam odio ac arcu posuere placerat. Nunc ipsum eros, euismod vitae molestie at, euismod ut nisl. Pellentesque a convallis dui. Nunc porttitor, turpis vel faucibus sollicitudin, dui nunc placerat risus, non eleifend nulla risus at diam. Integer eget dui dui, ut porta felis. Nam nisi nisl, eleifend a pulvinar nec, pulvinar vitae lorem. In tristique egestas ligula. Mauris sed dui nec leo molestie tempor. Praesent pellentesque molestie magna, a venenatis orci viverra in. Donec eget dui sit amet tortor ornare semper non et est. Suspendisse a orci ut velit consectetur placerat. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Maecenas lacinia tincidunt leo in tincidunt.</p>\r\n<p><strong>Fusce lacus tortor, venenatis id fringilla convallis, interdum nec elit.</strong> Sed viverra, felis in laoreet ultrices, leo ligula molestie augue, vel tincidunt turpis mi vel orci. Nunc dolor orci, ultricies sed vestibulum sed, cursus nec risus. Duis augue risus, ullamcorper vel condimentum cursus, aliquam nec risus. Nunc id mauris in massa lacinia bibendum. Mauris lacinia sagittis adipiscing. Maecenas gravida sapien at magna semper dignissim a vel erat. Phasellus nec risus vel augue bibendum bibendum. Nullam posuere libero dui, id gravida erat. Morbi est tortor, auctor a iaculis ullamcorper, gravida eget magna. Nam aliquam enim non justo volutpat eget aliquet diam iaculis. Cras dui eros, consectetur eu mattis eleifend, laoreet in turpis. Curabitur eu porta lacus.</p>\r\nemail: <a href="mailto:admin@demolink.org">admin@demolink.org</a>', '', 'full_html'),
('node', 'portfolio', '0', '82', '82', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>', '', 'full_html'),
('node', 'popular_services', '0', '83', '83', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>\r\n\r\n<p>Curabitur mauris tortor, laoreet et consectetur non, <a href="#">rhoncus sed risus</a>. Donec nisi enim, adipiscing <strong>quis convallis</strong> eu, elementum a urna. Maecenas sit amet metus sem. Sed non est ligula, sit amet vehicula nunc. Maecenas sed quam non urna tincidunt pellentesque ac ut enim. Vestibulum arcu tortor, vulputate nec semper id, commodo eget lacus. Integer mi dolor, malesuada in ullamcorper ut, tincidunt eu arcu. Mauris dictum, libero id rutrum vehicula, est l<strong>igula sagittis urna</strong>, ut convallis purus <strong>purus at dolor</strong>. <em>Praesent nec vehicula</em> tortor. Nulla facilisi. Curabitur mauris sapien, interdum id consequat et, lobortis ut ipsum. Vestibulum tempus augue eu est malesuada viverra. Nunc mattis fermentum metus, a consectetur magna egestas lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Morbi <em>non mauris ligula</em>. Suspendisse facilisis <a href="#">sagittis mauris</a>, ac dictum elit fringilla ut.</p>', '', 'full_html'),
('node', 'popular_services', '0', '84', '84', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>\r\n\r\n<p>Curabitur mauris tortor, laoreet et consectetur non, <a href="#">rhoncus sed risus</a>. Donec nisi enim, adipiscing <strong>quis convallis</strong> eu, elementum a urna. Maecenas sit amet metus sem. Sed non est ligula, sit amet vehicula nunc. Maecenas sed quam non urna tincidunt pellentesque ac ut enim. Vestibulum arcu tortor, vulputate nec semper id, commodo eget lacus. Integer mi dolor, malesuada in ullamcorper ut, tincidunt eu arcu. Mauris dictum, libero id rutrum vehicula, est l<strong>igula sagittis urna</strong>, ut convallis purus <strong>purus at dolor</strong>. <em>Praesent nec vehicula</em> tortor. Nulla facilisi. Curabitur mauris sapien, interdum id consequat et, lobortis ut ipsum. Vestibulum tempus augue eu est malesuada viverra. Nunc mattis fermentum metus, a consectetur magna egestas lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Morbi <em>non mauris ligula</em>. Suspendisse facilisis <a href="#">sagittis mauris</a>, ac dictum elit fringilla ut.</p>', '', 'full_html'),
('node', 'popular_services', '0', '85', '85', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>\r\n\r\n<p>Curabitur mauris tortor, laoreet et consectetur non, <a href="#">rhoncus sed risus</a>. Donec nisi enim, adipiscing <strong>quis convallis</strong> eu, elementum a urna. Maecenas sit amet metus sem. Sed non est ligula, sit amet vehicula nunc. Maecenas sed quam non urna tincidunt pellentesque ac ut enim. Vestibulum arcu tortor, vulputate nec semper id, commodo eget lacus. Integer mi dolor, malesuada in ullamcorper ut, tincidunt eu arcu. Mauris dictum, libero id rutrum vehicula, est l<strong>igula sagittis urna</strong>, ut convallis purus <strong>purus at dolor</strong>. <em>Praesent nec vehicula</em> tortor. Nulla facilisi. Curabitur mauris sapien, interdum id consequat et, lobortis ut ipsum. Vestibulum tempus augue eu est malesuada viverra. Nunc mattis fermentum metus, a consectetur magna egestas lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Morbi <em>non mauris ligula</em>. Suspendisse facilisis <a href="#">sagittis mauris</a>, ac dictum elit fringilla ut.</p>', '', 'full_html'),
('node', 'popular_services', '0', '86', '86', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>\r\n\r\n<p>Curabitur mauris tortor, laoreet et consectetur non, <a href="#">rhoncus sed risus</a>. Donec nisi enim, adipiscing <strong>quis convallis</strong> eu, elementum a urna. Maecenas sit amet metus sem. Sed non est ligula, sit amet vehicula nunc. Maecenas sed quam non urna tincidunt pellentesque ac ut enim. Vestibulum arcu tortor, vulputate nec semper id, commodo eget lacus. Integer mi dolor, malesuada in ullamcorper ut, tincidunt eu arcu. Mauris dictum, libero id rutrum vehicula, est l<strong>igula sagittis urna</strong>, ut convallis purus <strong>purus at dolor</strong>. <em>Praesent nec vehicula</em> tortor. Nulla facilisi. Curabitur mauris sapien, interdum id consequat et, lobortis ut ipsum. Vestibulum tempus augue eu est malesuada viverra. Nunc mattis fermentum metus, a consectetur magna egestas lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Morbi <em>non mauris ligula</em>. Suspendisse facilisis <a href="#">sagittis mauris</a>, ac dictum elit fringilla ut.</p>', '', 'full_html'),
('node', 'popular_services', '0', '87', '87', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>\r\n\r\n<p>Curabitur mauris tortor, laoreet et consectetur non, <a href="#">rhoncus sed risus</a>. Donec nisi enim, adipiscing <strong>quis convallis</strong> eu, elementum a urna. Maecenas sit amet metus sem. Sed non est ligula, sit amet vehicula nunc. Maecenas sed quam non urna tincidunt pellentesque ac ut enim. Vestibulum arcu tortor, vulputate nec semper id, commodo eget lacus. Integer mi dolor, malesuada in ullamcorper ut, tincidunt eu arcu. Mauris dictum, libero id rutrum vehicula, est l<strong>igula sagittis urna</strong>, ut convallis purus <strong>purus at dolor</strong>. <em>Praesent nec vehicula</em> tortor. Nulla facilisi. Curabitur mauris sapien, interdum id consequat et, lobortis ut ipsum. Vestibulum tempus augue eu est malesuada viverra. Nunc mattis fermentum metus, a consectetur magna egestas lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Morbi <em>non mauris ligula</em>. Suspendisse facilisis <a href="#">sagittis mauris</a>, ac dictum elit fringilla ut.</p>', '', 'full_html'),
('node', 'testimonials', '0', '88', '88', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>\r\n\r\n<p>Curabitur mauris tortor, laoreet et consectetur non, <a href="#">rhoncus sed risus</a>. Donec nisi enim, adipiscing <strong>quis convallis</strong> eu, elementum a urna. Maecenas sit amet metus sem. Sed non est ligula, sit amet vehicula nunc. Maecenas sed quam non urna tincidunt pellentesque ac ut enim. Vestibulum arcu tortor, vulputate nec semper id, commodo eget lacus. Integer mi dolor, malesuada in ullamcorper ut, tincidunt eu arcu. Mauris dictum, libero id rutrum vehicula, est l<strong>igula sagittis urna</strong>, ut convallis purus <strong>purus at dolor</strong>. <em>Praesent nec vehicula</em> tortor. Nulla facilisi. Curabitur mauris sapien, interdum id consequat et, lobortis ut ipsum. Vestibulum tempus augue eu est malesuada viverra. Nunc mattis fermentum metus, a consectetur magna egestas lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Morbi <em>non mauris ligula</em>. Suspendisse facilisis <a href="#">sagittis mauris</a>, ac dictum elit fringilla ut.</p>', '', 'full_html'),
('node', 'testimonials', '0', '89', '89', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>\r\n\r\n<p>Curabitur mauris tortor, laoreet et consectetur non, <a href="#">rhoncus sed risus</a>. Donec nisi enim, adipiscing <strong>quis convallis</strong> eu, elementum a urna. Maecenas sit amet metus sem. Sed non est ligula, sit amet vehicula nunc. Maecenas sed quam non urna tincidunt pellentesque ac ut enim. Vestibulum arcu tortor, vulputate nec semper id, commodo eget lacus. Integer mi dolor, malesuada in ullamcorper ut, tincidunt eu arcu. Mauris dictum, libero id rutrum vehicula, est l<strong>igula sagittis urna</strong>, ut convallis purus <strong>purus at dolor</strong>. <em>Praesent nec vehicula</em> tortor. Nulla facilisi. Curabitur mauris sapien, interdum id consequat et, lobortis ut ipsum. Vestibulum tempus augue eu est malesuada viverra. Nunc mattis fermentum metus, a consectetur magna egestas lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Morbi <em>non mauris ligula</em>. Suspendisse facilisis <a href="#">sagittis mauris</a>, ac dictum elit fringilla ut.</p>', '', 'full_html');
/*!40000 ALTER TABLE field_data_body ENABLE KEYS */;

--
-- Table structure for table 'field_data_comment_body'
--

CREATE TABLE IF NOT EXISTS `field_data_comment_body` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned DEFAULT NULL COMMENT 'The entity revision id this data is attached to, or NULL if the entity type is not versioned',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `comment_body_value` longtext,
  `comment_body_format` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`entity_type`,`entity_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `comment_body_format` (`comment_body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Data storage for field 1 (comment_body)';

--
-- Dumping data for table 'field_data_comment_body'
--

/*!40000 ALTER TABLE field_data_comment_body DISABLE KEYS */;
INSERT INTO `field_data_comment_body` VALUES
('comment', 'comment_node_forum', '0', '1', '1', 'und', '0', 'Fusce porttitor porta tortor pulvinar iaculis. Nulla facilisi. Etiam semper hendrerit lectus, sit amet ultricies augue porta ut. Praesent vitae dolor vitae felis congue mollis. Nulla fermentum augue sit amet sem luctus dignissim. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. In dignissim tincidunt mollis. Sed sed massa lorem, sed laoreet est. Pellentesque sit amet orci sed arcu euismod posuere id in nisl. Aenean in quam tortor. Curabitur consequat metus ut nulla viverra tincidunt. In hac habitasse platea dictumst. Suspendisse hendrerit, quam a dignissim pellentesque, turpis risus bibendum massa, quis lacinia sem sem eget est. Praesent magna nisi, dignissim laoreet hendrerit lobortis, gravida non velit. Nullam ut velit augue. Mauris mattis tellus elit, et vehicula purus. Nulla eros libero, pretium id elementum id, euismod non risus. Donec enim nisi, luctus quis vestibulum eu, dapibus quis nisi. Cras porttitor sem sit amet metus fermentum pretium.', 'filtered_html'),
('comment', 'comment_node_forum', '0', '2', '2', 'und', '0', 'Suspendisse potenti. Fusce diam risus, mattis sit amet pretium in, feugiat sed purus. Vivamus in lectus tellus. Nam justo leo, placerat sit amet imperdiet ut, accumsan quis nulla. Donec tristique tristique massa at malesuada. Nulla eleifend ultricies tempus. Nulla dapibus tempus pulvinar. Nullam urna sem, vestibulum ac porttitor sit amet, semper ut dui. Etiam at turpis sed risus auctor molestie eget quis lectus. Donec lacus tortor, condimentum nec pharetra et, adipiscing a sapien. Nulla ac ante diam. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Phasellus bibendum euismod lobortis. Phasellus semper elementum quam a iaculis. Morbi tristique diam id ante sagittis rutrum.', 'filtered_html'),
('comment', 'comment_node_forum', '0', '3', '3', 'und', '0', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut egestas ante ac nunc dignissim vitae blandit lectus vulputate. Aliquam ultrices cursus scelerisque. Nullam interdum facilisis eros ut dignissim. Morbi luctus ultrices eros, vel varius urna facilisis nec. Aliquam vulputate placerat velit id semper. Fusce nisi ante, pulvinar rutrum semper non, imperdiet quis urna. Duis blandit, lacus eget pretium blandit, justo orci molestie turpis, sit amet tincidunt justo lacus eget augue. Etiam sodales egestas tincidunt. Quisque et est tellus, eu commodo eros. Phasellus sed est nisl, vel posuere massa. Fusce eu diam nec eros elementum congue a a augue. Donec tempus velit id leo vestibulum luctus. Quisque mattis, orci eget feugiat volutpat, dui orci lobortis metus, quis elementum leo urna quis urna. Nullam et dolor urna. Praesent tincidunt velit at mauris pharetra sit amet rhoncus enim sollicitudin. Morbi non aliquet nisl.', 'filtered_html'),
('comment', 'comment_node_forum', '0', '4', '4', 'und', '0', 'Quisque nec libero eu urna volutpat cursus. Quisque elit velit, consequat at fringilla quis, tincidunt ac nisi. Donec consequat nisl nec leo vulputate nec fermentum sapien porttitor. Aliquam hendrerit faucibus diam, at dictum quam euismod at. Sed luctus tempus libero, vitae viverra est laoreet sit amet. Duis sit amet neque dui, eu rutrum urna. Nunc purus urna, hendrerit id suscipit nec, pulvinar quis justo. Pellentesque id purus vel nibh iaculis iaculis. Suspendisse non ante eros. Duis condimentum tempor nulla at venenatis. Quisque tristique dui sit amet lorem vulputate eget eleifend ipsum sodales.', 'filtered_html'),
('comment', 'comment_node_forum', '0', '5', '5', 'und', '0', 'Etiam ornare, tellus quis facilisis eleifend, sem enim ultrices sem, ut convallis eros massa sed mauris. Nulla facilisi. Quisque eu neque eu erat bibendum pharetra a sit amet tortor. Fusce a augue ante. In hac habitasse platea dictumst. Aliquam eu purus eu lorem placerat aliquam. Proin in ante vitae diam cursus condimentum. Donec commodo nunc eu enim placerat ut tempor tortor feugiat. In porttitor lacinia mi sed condimentum. Nam imperdiet sapien fringilla felis auctor faucibus. Morbi feugiat dui vel mi facilisis eu molestie nisl sagittis. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Praesent nisl nisi, bibendum pulvinar blandit non, pretium vitae metus. Quisque turpis justo, facilisis in semper at, semper in urna. Vivamus pellentesque sollicitudin erat at iaculis. Quisque ullamcorper nunc at enim convallis vehicula. Fusce vel mi ante. Aenean quam libero, elementum et varius in, eleifend hendrerit eros.', 'filtered_html'),
('comment', 'comment_node_forum', '0', '6', '6', 'und', '0', 'Fusce gravida consectetur mi non tincidunt. Sed dictum lacinia mauris, sed tempus ligula blandit ac. Nam et posuere quam. Integer dui orci, vulputate et pulvinar lobortis, lacinia vel elit. Duis accumsan scelerisque arcu, sit amet lacinia urna faucibus sit amet. Pellentesque sed est mollis purus ornare gravida. Pellentesque interdum justo vel urna pretium tempor. Maecenas sed sapien arcu, sit amet tempus eros. Pellentesque cursus tempus facilisis. Cras auctor mauris a sem vestibulum fermentum.', 'filtered_html'),
('comment', 'comment_node_forum', '0', '7', '7', 'und', '0', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Aliquam euismod viverra volutpat. Praesent orci neque, pellentesque tempus pharetra quis, laoreet eget dolor. Ut adipiscing auctor dignissim. Nam eu odio sit amet lacus accumsan congue. Ut tempor est condimentum urna posuere porttitor. Mauris orci purus, adipiscing non cursus at, lacinia et quam. Integer ullamcorper leo sit amet nulla venenatis sit amet vehicula diam pulvinar. In hac habitasse platea dictumst. Suspendisse ante sapien, gravida semper pretium sit amet, sollicitudin id eros. Donec eget tellus sit amet magna malesuada consectetur. Pellentesque luctus leo mi. Suspendisse vulputate auctor magna tempus scelerisque. Vivamus vehicula rhoncus erat ut luctus. Mauris sed dui id lorem ornare consectetur ac lacinia tortor. Maecenas nunc leo, placerat eget rhoncus a, pellentesque at erat.', 'filtered_html'),
('comment', 'comment_node_forum', '0', '8', '8', 'und', '0', 'Etiam ornare, tellus quis facilisis eleifend, sem enim ultrices sem, ut convallis eros massa sed mauris. Nulla facilisi. Quisque eu neque eu erat bibendum pharetra a sit amet tortor. Fusce a augue ante. In hac habitasse platea dictumst. Aliquam eu purus eu lorem placerat aliquam. Proin in ante vitae diam cursus condimentum. Donec commodo nunc eu enim placerat ut tempor tortor feugiat. In porttitor lacinia mi sed condimentum. Nam imperdiet sapien fringilla felis auctor faucibus. Morbi feugiat dui vel mi facilisis eu molestie nisl sagittis. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Praesent nisl nisi, bibendum pulvinar blandit non, pretium vitae metus. Quisque turpis justo, facilisis in semper at, semper in urna. Vivamus pellentesque sollicitudin erat at iaculis. Quisque ullamcorper nunc at enim convallis vehicula. Fusce vel mi ante. Aenean quam libero, elementum et varius in, eleifend hendrerit eros.', 'filtered_html'),
('comment', 'comment_node_forum', '0', '9', '9', 'und', '0', 'Sed ornare ipsum id libero interdum vel eleifend neque egestas. Mauris sodales urna vitae felis placerat venenatis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Sed justo magna, sagittis nec consequat id, placerat sit amet magna. Praesent lacus metus, aliquet ut sodales et, porta ut nunc. Nulla id massa in erat imperdiet pulvinar. Duis ut metus in mi volutpat convallis et id mi. Fusce in mi sit amet augue faucibus elementum. Praesent odio tortor, tincidunt ac lacinia sit amet, pellentesque id dolor. Ut pretium imperdiet sem, non ornare sem pretium ut. Maecenas sit amet arcu nisi.', 'filtered_html'),
('comment', 'comment_node_forum', '0', '10', '10', 'und', '0', 'Suspendisse convallis, risus a tempor gravida, purus nunc condimentum lorem, eget lacinia lectus augue eget ante. Cras aliquet luctus sapien, sed euismod mi porttitor ut. Nam vulputate, nulla eu tincidunt convallis, leo neque elementum leo, sit amet vulputate libero lectus in mauris. Praesent arcu ipsum, rhoncus nec tincidunt quis, rutrum a augue. Fusce congue, lacus nec pharetra venenatis, risus sapien congue purus, non dictum tellus sem id enim. Donec imperdiet pharetra tempus. Duis ac augue nec urna iaculis aliquet. Sed malesuada semper mauris, id cursus velit convallis rutrum. Phasellus pulvinar, nulla a condimentum varius, enim tortor porttitor sem, adipiscing fringilla felis massa vitae mi. Pellentesque vestibulum elit non turpis convallis scelerisque. Integer scelerisque scelerisque lorem, nec aliquam turpis molestie nec.', 'filtered_html'),
('comment', 'comment_node_forum', '0', '11', '11', 'und', '0', 'Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Mauris sed tempor arcu. Suspendisse potenti. Fusce a nibh sed libero faucibus faucibus. In hac habitasse platea dictumst. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam ac velit ligula. Aliquam aliquam est vitae dui faucibus consectetur non at sapien. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Suspendisse velit ligula, faucibus ac elementum vel, sagittis vitae sapien. Sed nec sem ut dui venenatis lobortis. Phasellus et lorem vitae mi aliquet tincidunt. Nunc et sodales nulla. Donec eu diam a ante condimentum lobortis.', 'filtered_html'),
('comment', 'comment_node_article', '0', '13', '13', 'und', '0', '<p>Aliquam laoreet neque non ipsum pharetra eget ultrices eros dictum. Nunc a enim justo. Donec venenatis, libero nec feugiat congue, mi sem scelerisque magna, congue pellentesque tortor turpis et eros. Donec ligula quam, aliquam eu vehicula ut, aliquet eu erat. Vestibulum posuere, justo eu venenatis consectetur, eros nibh vulputate mauris, dignissim blandit sapien dolor ut augue.</p>', 'filtered_html'),
('comment', 'comment_node_article', '0', '14', '14', 'und', '0', '<p>Suspendisse semper, velit a venenatis rhoncus, leo nulla porttitor justo, a volutpat nisi tortor vitae nisi. Nam volutpat interdum placerat. Sed posuere felis et sem commodo tempus.</p>', 'filtered_html'),
('comment', 'comment_node_article', '0', '15', '15', 'und', '0', '<p>Aenean fermentum justo id nibh sagittis vestibulum. Donec vel interdum mi. Morbi vel diam vel arcu vestibulum vehicula. Nam vitae eros eu leo feugiat aliquam. Quisque sodales, felis quis ullamcorper suscipit, mi ipsum porta magna, ut dapibus odio dolor a nisl. Mauris ac enim nisl, id feugiat metus. Nunc purus enim, euismod nec fringilla a, bibendum in turpis. Praesent ac orci purus, in vulputate risus.</p>', 'filtered_html'),
('comment', 'comment_node_blog', '0', '16', '16', 'und', '0', '<p>Curabitur mauris tortor, laoreet et consectetur non, <a href="#">rhoncus sed risus</a>. Donec nisi enim, adipiscing <strong>quis convallis</strong> eu, elementum a urna. Maecenas sit amet metus sem. Sed non est ligula, sit amet vehicula nunc. Maecenas sed quam non urna tincidunt pellentesque ac ut enim. Vestibulum arcu tortor, vulputate nec semper id, commodo eget lacus. Integer mi dolor, malesuada in ullamcorper ut, tincidunt eu arcu. Mauris dictum, libero id rutrum vehicula, est l<strong>igula sagittis urna</strong>, ut convallis purus <strong>purus at dolor</strong>. <em>Praesent nec vehicula</em> tortor. Nulla facilisi. Curabitur mauris sapien, interdum id consequat et, lobortis ut ipsum. Vestibulum tempus augue eu est malesuada viverra. Nunc mattis fermentum metus, a consectetur magna egestas lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Morbi <em>non mauris ligula</em>. Suspendisse facilisis <a href="#">sagittis mauris</a>, ac dictum elit fringilla ut.</p>', 'full_html');
/*!40000 ALTER TABLE field_data_comment_body ENABLE KEYS */;

--
-- Table structure for table 'field_data_field_addthis'
--

CREATE TABLE IF NOT EXISTS `field_data_field_addthis` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned DEFAULT NULL COMMENT 'The entity revision id this data is attached to, or NULL if the entity type is not versioned',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_addthis_value` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`entity_type`,`entity_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Data storage for field 16 (field_addthis)';

--
-- Dumping data for table 'field_data_field_addthis'
--

/*!40000 ALTER TABLE field_data_field_addthis DISABLE KEYS */;
INSERT INTO `field_data_field_addthis` VALUES
('node', 'article', '0', '36', '36', 'und', '0', 'Dummy value');
/*!40000 ALTER TABLE field_data_field_addthis ENABLE KEYS */;

--
-- Table structure for table 'field_data_field_addthis_blog'
--

CREATE TABLE IF NOT EXISTS `field_data_field_addthis_blog` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned DEFAULT NULL COMMENT 'The entity revision id this data is attached to, or NULL if the entity type is not versioned',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_addthis_blog_value` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`entity_type`,`entity_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Data storage for field 17 (field_addthis_blog)';

--
-- Dumping data for table 'field_data_field_addthis_blog'
--

/*!40000 ALTER TABLE field_data_field_addthis_blog DISABLE KEYS */;
INSERT INTO `field_data_field_addthis_blog` VALUES
('node', 'blog', '0', '37', '37', 'und', '0', 'Dummy value'),
('node', 'blog', '0', '38', '38', 'und', '0', 'Dummy value'),
('node', 'blog', '0', '39', '39', 'und', '0', 'Dummy value'),
('node', 'blog', '0', '40', '40', 'und', '0', 'Dummy value'),
('node', 'blog', '0', '41', '41', 'und', '0', 'Dummy value');
/*!40000 ALTER TABLE field_data_field_addthis_blog ENABLE KEYS */;

--
-- Table structure for table 'field_data_field_blog_category'
--

CREATE TABLE IF NOT EXISTS `field_data_field_blog_category` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned DEFAULT NULL COMMENT 'The entity revision id this data is attached to, or NULL if the entity type is not versioned',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_blog_category_tid` int(10) unsigned DEFAULT NULL,
  PRIMARY KEY (`entity_type`,`entity_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_blog_category_tid` (`field_blog_category_tid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Data storage for field 18 (field_blog_category)';

--
-- Dumping data for table 'field_data_field_blog_category'
--

/*!40000 ALTER TABLE field_data_field_blog_category DISABLE KEYS */;
INSERT INTO `field_data_field_blog_category` VALUES
('node', 'blog', '0', '37', '37', 'und', '0', '27'),
('node', 'blog', '0', '37', '37', 'und', '1', '26'),
('node', 'blog', '0', '38', '38', 'und', '0', '19'),
('node', 'blog', '0', '38', '38', 'und', '1', '23'),
('node', 'blog', '0', '38', '38', 'und', '2', '26'),
('node', 'blog', '0', '38', '38', 'und', '3', '20'),
('node', 'blog', '0', '39', '39', 'und', '0', '19'),
('node', 'blog', '0', '39', '39', 'und', '1', '23'),
('node', 'blog', '0', '40', '40', 'und', '0', '25'),
('node', 'blog', '0', '40', '40', 'und', '1', '19'),
('node', 'blog', '0', '40', '40', 'und', '2', '18'),
('node', 'blog', '0', '40', '40', 'und', '3', '27'),
('node', 'blog', '0', '40', '40', 'und', '4', '23'),
('node', 'blog', '0', '40', '40', 'und', '5', '24'),
('node', 'blog', '0', '40', '40', 'und', '6', '26'),
('node', 'blog', '0', '40', '40', 'und', '7', '22'),
('node', 'blog', '0', '40', '40', 'und', '8', '20'),
('node', 'blog', '0', '41', '41', 'und', '0', '25'),
('node', 'blog', '0', '41', '41', 'und', '1', '19'),
('node', 'blog', '0', '41', '41', 'und', '2', '18'),
('node', 'blog', '0', '41', '41', 'und', '3', '21'),
('node', 'blog', '0', '41', '41', 'und', '4', '20');
/*!40000 ALTER TABLE field_data_field_blog_category ENABLE KEYS */;

--
-- Table structure for table 'field_data_field_blog_image'
--

CREATE TABLE IF NOT EXISTS `field_data_field_blog_image` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned DEFAULT NULL COMMENT 'The entity revision id this data is attached to, or NULL if the entity type is not versioned',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_blog_image_fid` int(10) unsigned DEFAULT NULL COMMENT 'The file_managed.fid being referenced in this field.',
  `field_blog_image_alt` varchar(512) DEFAULT NULL,
  `field_blog_image_title` varchar(1024) DEFAULT NULL,
  `field_blog_image_width` int(10) unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_blog_image_height` int(10) unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_type`,`entity_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_blog_image_fid` (`field_blog_image_fid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Data storage for field 6 (field_blog_image)';

--
-- Dumping data for table 'field_data_field_blog_image'
--

/*!40000 ALTER TABLE field_data_field_blog_image DISABLE KEYS */;
INSERT INTO `field_data_field_blog_image` VALUES
('node', 'blog', '0', '37', '37', 'en', '0', '96', '', '', '1500', '1125'),
('node', 'blog', '0', '38', '38', 'en', '0', '97', '', '', '1500', '1140'),
('node', 'blog', '0', '39', '39', 'en', '0', '95', '', '', '1500', '899'),
('node', 'blog', '0', '41', '41', 'en', '0', '98', '', '', '1500', '1125');
/*!40000 ALTER TABLE field_data_field_blog_image ENABLE KEYS */;

--
-- Table structure for table 'field_data_field_employee_photo'
--

CREATE TABLE IF NOT EXISTS `field_data_field_employee_photo` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned DEFAULT NULL COMMENT 'The entity revision id this data is attached to, or NULL if the entity type is not versioned',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_employee_photo_fid` int(10) unsigned DEFAULT NULL COMMENT 'The file_managed.fid being referenced in this field.',
  `field_employee_photo_alt` varchar(512) DEFAULT NULL,
  `field_employee_photo_title` varchar(1024) DEFAULT NULL,
  `field_employee_photo_width` int(10) unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_employee_photo_height` int(10) unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_type`,`entity_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_employee_photo_fid` (`field_employee_photo_fid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Data storage for field 11 (field_employee_photo)';

--
-- Dumping data for table 'field_data_field_employee_photo'
--

/*!40000 ALTER TABLE field_data_field_employee_photo DISABLE KEYS */;
INSERT INTO `field_data_field_employee_photo` VALUES
('node', 'employee', '0', '65', '65', 'en', '0', '46', '', '', '1200', '886'),
('node', 'employee', '0', '67', '67', 'en', '0', '50', '', '', '1264', '1600'),
('node', 'employee', '0', '68', '68', 'en', '0', '49', '', '', '1600', '1491'),
('node', 'employee', '0', '69', '69', 'en', '0', '48', '', '', '900', '600'),
('node', 'employee', '0', '71', '71', 'en', '0', '47', '', '', '1067', '993'),
('node', 'employee', '0', '73', '73', 'en', '0', '45', '', '', '1290', '1600');
/*!40000 ALTER TABLE field_data_field_employee_photo ENABLE KEYS */;

--
-- Table structure for table 'field_data_field_image'
--

CREATE TABLE IF NOT EXISTS `field_data_field_image` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned DEFAULT NULL COMMENT 'The entity revision id this data is attached to, or NULL if the entity type is not versioned',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_image_fid` int(10) unsigned DEFAULT NULL COMMENT 'The file_managed.fid being referenced in this field.',
  `field_image_alt` varchar(512) DEFAULT NULL,
  `field_image_title` varchar(1024) DEFAULT NULL,
  `field_image_width` int(10) unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_image_height` int(10) unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_type`,`entity_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_image_fid` (`field_image_fid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Data storage for field 4 (field_image)';

--
-- Dumping data for table 'field_data_field_image'
--

/*!40000 ALTER TABLE field_data_field_image DISABLE KEYS */;
/*!40000 ALTER TABLE field_data_field_image ENABLE KEYS */;

--
-- Table structure for table 'field_data_field_logo'
--

CREATE TABLE IF NOT EXISTS `field_data_field_logo` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned DEFAULT NULL COMMENT 'The entity revision id this data is attached to, or NULL if the entity type is not versioned',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_logo_fid` int(10) unsigned DEFAULT NULL COMMENT 'The file_managed.fid being referenced in this field.',
  `field_logo_alt` varchar(512) DEFAULT NULL,
  `field_logo_title` varchar(1024) DEFAULT NULL,
  `field_logo_width` int(10) unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_logo_height` int(10) unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_type`,`entity_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_logo_fid` (`field_logo_fid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Data storage for field 12 (field_logo)';

--
-- Dumping data for table 'field_data_field_logo'
--

/*!40000 ALTER TABLE field_data_field_logo DISABLE KEYS */;
/*!40000 ALTER TABLE field_data_field_logo ENABLE KEYS */;

--
-- Table structure for table 'field_data_field_map'
--

CREATE TABLE IF NOT EXISTS `field_data_field_map` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned DEFAULT NULL COMMENT 'The entity revision id this data is attached to, or NULL if the entity type is not versioned',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_map_glid` int(10) unsigned NOT NULL,
  PRIMARY KEY (`entity_type`,`entity_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_map_glid` (`field_map_glid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Data storage for field 14 (field_map)';

--
-- Dumping data for table 'field_data_field_map'
--

/*!40000 ALTER TABLE field_data_field_map DISABLE KEYS */;
INSERT INTO `field_data_field_map` VALUES
('node', 'maps', '0', '81', '81', 'und', '0', '2');
/*!40000 ALTER TABLE field_data_field_map ENABLE KEYS */;

--
-- Table structure for table 'field_data_field_popular_services_image'
--

CREATE TABLE IF NOT EXISTS `field_data_field_popular_services_image` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned DEFAULT NULL COMMENT 'The entity revision id this data is attached to, or NULL if the entity type is not versioned',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_popular_services_image_fid` int(10) unsigned DEFAULT NULL COMMENT 'The file_managed.fid being referenced in this field.',
  `field_popular_services_image_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image’s ’alt’ attribute.',
  `field_popular_services_image_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image’s ’title’ attribute.',
  `field_popular_services_image_width` int(10) unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_popular_services_image_height` int(10) unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_type`,`entity_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_popular_services_image_fid` (`field_popular_services_image_fid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Data storage for field 20 (field_popular_services_image)';

--
-- Dumping data for table 'field_data_field_popular_services_image'
--

/*!40000 ALTER TABLE field_data_field_popular_services_image DISABLE KEYS */;
INSERT INTO `field_data_field_popular_services_image` VALUES
('node', 'popular_services', '0', '83', '83', 'und', '0', '102', '', '', '1500', '997'),
('node', 'popular_services', '0', '84', '84', 'und', '0', '103', '', '', '1500', '1140'),
('node', 'popular_services', '0', '85', '85', 'und', '0', '99', '', '', '1500', '1059'),
('node', 'popular_services', '0', '86', '86', 'und', '0', '100', '', '', '1500', '1140'),
('node', 'popular_services', '0', '87', '87', 'und', '0', '101', '', '', '1500', '825');
/*!40000 ALTER TABLE field_data_field_popular_services_image ENABLE KEYS */;

--
-- Table structure for table 'field_data_field_portfolio_category'
--

CREATE TABLE IF NOT EXISTS `field_data_field_portfolio_category` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned DEFAULT NULL COMMENT 'The entity revision id this data is attached to, or NULL if the entity type is not versioned',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_portfolio_category_tid` int(10) unsigned DEFAULT NULL,
  PRIMARY KEY (`entity_type`,`entity_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_portfolio_category_tid` (`field_portfolio_category_tid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Data storage for field 19 (field_portfolio_category)';

--
-- Dumping data for table 'field_data_field_portfolio_category'
--

/*!40000 ALTER TABLE field_data_field_portfolio_category DISABLE KEYS */;
INSERT INTO `field_data_field_portfolio_category` VALUES
('node', 'portfolio', '0', '52', '52', 'und', '0', '28'),
('node', 'portfolio', '0', '52', '52', 'und', '1', '29'),
('node', 'portfolio', '0', '53', '53', 'und', '0', '28'),
('node', 'portfolio', '0', '53', '53', 'und', '1', '30'),
('node', 'portfolio', '0', '54', '54', 'und', '0', '28'),
('node', 'portfolio', '0', '55', '55', 'und', '0', '28'),
('node', 'portfolio', '0', '55', '55', 'und', '1', '31'),
('node', 'portfolio', '0', '56', '56', 'und', '0', '28'),
('node', 'portfolio', '0', '56', '56', 'und', '1', '29'),
('node', 'portfolio', '0', '57', '57', 'und', '0', '28'),
('node', 'portfolio', '0', '57', '57', 'und', '1', '29'),
('node', 'portfolio', '0', '57', '57', 'und', '2', '31'),
('node', 'portfolio', '0', '58', '58', 'und', '0', '28'),
('node', 'portfolio', '0', '58', '58', 'und', '1', '31'),
('node', 'portfolio', '0', '82', '82', 'und', '0', '28');
/*!40000 ALTER TABLE field_data_field_portfolio_category ENABLE KEYS */;

--
-- Table structure for table 'field_data_field_portfolio_image'
--

CREATE TABLE IF NOT EXISTS `field_data_field_portfolio_image` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned DEFAULT NULL COMMENT 'The entity revision id this data is attached to, or NULL if the entity type is not versioned',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_portfolio_image_fid` int(10) unsigned DEFAULT NULL COMMENT 'The file_managed.fid being referenced in this field.',
  `field_portfolio_image_alt` varchar(512) DEFAULT NULL,
  `field_portfolio_image_title` varchar(1024) DEFAULT NULL,
  `field_portfolio_image_width` int(10) unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_portfolio_image_height` int(10) unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_type`,`entity_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_portfolio_image_fid` (`field_portfolio_image_fid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Data storage for field 8 (field_portfolio_image)';

--
-- Dumping data for table 'field_data_field_portfolio_image'
--

/*!40000 ALTER TABLE field_data_field_portfolio_image DISABLE KEYS */;
INSERT INTO `field_data_field_portfolio_image` VALUES
('node', 'portfolio', '0', '52', '52', 'en', '0', '105', '', '', '1500', '1000'),
('node', 'portfolio', '0', '53', '53', 'en', '0', '106', '', '', '1500', '1125'),
('node', 'portfolio', '0', '54', '54', 'en', '0', '107', '', '', '1500', '1125'),
('node', 'portfolio', '0', '55', '55', 'en', '0', '108', '', '', '1500', '1125'),
('node', 'portfolio', '0', '56', '56', 'en', '0', '109', '', '', '1500', '1000'),
('node', 'portfolio', '0', '57', '57', 'en', '0', '104', '', '', '1500', '1125'),
('node', 'portfolio', '0', '58', '58', 'en', '0', '110', '', '', '1500', '1042'),
('node', 'portfolio', '0', '82', '82', 'en', '0', '111', '', '', '1500', '1000');
/*!40000 ALTER TABLE field_data_field_portfolio_image ENABLE KEYS */;

--
-- Table structure for table 'field_data_field_position'
--

CREATE TABLE IF NOT EXISTS `field_data_field_position` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned DEFAULT NULL COMMENT 'The entity revision id this data is attached to, or NULL if the entity type is not versioned',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_position_value` varchar(255) DEFAULT NULL,
  `field_position_format` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`entity_type`,`entity_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_position_format` (`field_position_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Data storage for field 15 (field_position)';

--
-- Dumping data for table 'field_data_field_position'
--

/*!40000 ALTER TABLE field_data_field_position DISABLE KEYS */;
INSERT INTO `field_data_field_position` VALUES
('node', 'employee', '0', '65', '65', 'und', '0', 'Programmer', NULL),
('node', 'employee', '0', '67', '67', 'und', '0', 'Manager', NULL),
('node', 'employee', '0', '68', '68', 'und', '0', 'Seller', NULL),
('node', 'employee', '0', '69', '69', 'und', '0', 'CEO', NULL),
('node', 'employee', '0', '71', '71', 'und', '0', 'Support', NULL),
('node', 'employee', '0', '73', '73', 'und', '0', 'Billing', NULL);
/*!40000 ALTER TABLE field_data_field_position ENABLE KEYS */;

--
-- Table structure for table 'field_data_field_service_image'
--

CREATE TABLE IF NOT EXISTS `field_data_field_service_image` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned DEFAULT NULL COMMENT 'The entity revision id this data is attached to, or NULL if the entity type is not versioned',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_service_image_fid` int(10) unsigned DEFAULT NULL COMMENT 'The file_managed.fid being referenced in this field.',
  `field_service_image_alt` varchar(512) DEFAULT NULL,
  `field_service_image_title` varchar(1024) DEFAULT NULL,
  `field_service_image_width` int(10) unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_service_image_height` int(10) unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_type`,`entity_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_service_image_fid` (`field_service_image_fid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Data storage for field 13 (field_service_image)';

--
-- Dumping data for table 'field_data_field_service_image'
--

/*!40000 ALTER TABLE field_data_field_service_image DISABLE KEYS */;
INSERT INTO `field_data_field_service_image` VALUES
('node', 'services', '0', '76', '76', 'und', '0', '92', '', '', '1500', '1000'),
('node', 'services', '0', '77', '77', 'und', '0', '91', '', '', '1500', '1093'),
('node', 'services', '0', '78', '78', 'und', '0', '90', '', '', '1500', '900');
/*!40000 ALTER TABLE field_data_field_service_image ENABLE KEYS */;

--
-- Table structure for table 'field_data_field_slide_image'
--

CREATE TABLE IF NOT EXISTS `field_data_field_slide_image` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned DEFAULT NULL COMMENT 'The entity revision id this data is attached to, or NULL if the entity type is not versioned',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_slide_image_fid` int(10) unsigned DEFAULT NULL COMMENT 'The file_managed.fid being referenced in this field.',
  `field_slide_image_alt` varchar(512) DEFAULT NULL,
  `field_slide_image_title` varchar(1024) DEFAULT NULL,
  `field_slide_image_width` int(10) unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_slide_image_height` int(10) unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_type`,`entity_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_slide_image_fid` (`field_slide_image_fid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Data storage for field 7 (field_slide_image)';

--
-- Dumping data for table 'field_data_field_slide_image'
--

/*!40000 ALTER TABLE field_data_field_slide_image DISABLE KEYS */;
INSERT INTO `field_data_field_slide_image` VALUES
('node', 'slider', '0', '47', '47', 'en', '0', '87', '', '', '1950', '510'),
('node', 'slider', '0', '50', '50', 'en', '0', '88', '', '', '1950', '510'),
('node', 'slider', '0', '51', '51', 'en', '0', '89', '', '', '1950', '510');
/*!40000 ALTER TABLE field_data_field_slide_image ENABLE KEYS */;

--
-- Table structure for table 'field_data_field_tags'
--

CREATE TABLE IF NOT EXISTS `field_data_field_tags` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned DEFAULT NULL COMMENT 'The entity revision id this data is attached to, or NULL if the entity type is not versioned',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_tags_tid` int(10) unsigned DEFAULT NULL,
  PRIMARY KEY (`entity_type`,`entity_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_tags_tid` (`field_tags_tid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Data storage for field 3 (field_tags)';

--
-- Dumping data for table 'field_data_field_tags'
--

/*!40000 ALTER TABLE field_data_field_tags DISABLE KEYS */;
INSERT INTO `field_data_field_tags` VALUES
('node', 'article', '0', '36', '36', 'und', '0', '15'),
('node', 'article', '0', '36', '36', 'und', '1', '16'),
('node', 'article', '0', '36', '36', 'und', '2', '17');
/*!40000 ALTER TABLE field_data_field_tags ENABLE KEYS */;

--
-- Table structure for table 'field_data_field_testimonials_position'
--

CREATE TABLE IF NOT EXISTS `field_data_field_testimonials_position` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned DEFAULT NULL COMMENT 'The entity revision id this data is attached to, or NULL if the entity type is not versioned',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_testimonials_position_value` varchar(255) DEFAULT NULL,
  `field_testimonials_position_format` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`entity_type`,`entity_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_testimonials_position_format` (`field_testimonials_position_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Data storage for field 21 (field_testimonials_position)';

--
-- Dumping data for table 'field_data_field_testimonials_position'
--

/*!40000 ALTER TABLE field_data_field_testimonials_position DISABLE KEYS */;
INSERT INTO `field_data_field_testimonials_position` VALUES
('node', 'testimonials', '0', '88', '88', 'und', '0', 'MEtho org', NULL),
('node', 'testimonials', '0', '89', '89', 'und', '0', 'MEtho org', NULL);
/*!40000 ALTER TABLE field_data_field_testimonials_position ENABLE KEYS */;

--
-- Table structure for table 'field_data_taxonomy_forums'
--

CREATE TABLE IF NOT EXISTS `field_data_taxonomy_forums` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned DEFAULT NULL COMMENT 'The entity revision id this data is attached to, or NULL if the entity type is not versioned',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `taxonomy_forums_tid` int(10) unsigned DEFAULT NULL,
  PRIMARY KEY (`entity_type`,`entity_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `taxonomy_forums_tid` (`taxonomy_forums_tid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Data storage for field 5 (taxonomy_forums)';

--
-- Dumping data for table 'field_data_taxonomy_forums'
--

/*!40000 ALTER TABLE field_data_taxonomy_forums DISABLE KEYS */;
INSERT INTO `field_data_taxonomy_forums` VALUES
('node', 'forum', '0', '12', '12', 'und', '0', '1'),
('node', 'forum', '0', '13', '13', 'und', '0', '1'),
('node', 'forum', '0', '14', '14', 'und', '0', '1'),
('node', 'forum', '0', '15', '15', 'und', '0', '1'),
('node', 'forum', '0', '16', '16', 'und', '0', '1'),
('node', 'forum', '0', '17', '17', 'und', '0', '5'),
('node', 'forum', '0', '18', '18', 'und', '0', '5'),
('node', 'forum', '0', '19', '19', 'und', '0', '5'),
('node', 'forum', '0', '20', '20', 'und', '0', '5'),
('node', 'forum', '0', '21', '21', 'und', '0', '6'),
('node', 'forum', '0', '22', '22', 'und', '0', '6'),
('node', 'forum', '0', '23', '23', 'und', '0', '6'),
('node', 'forum', '0', '24', '24', 'und', '0', '6'),
('node', 'forum', '0', '25', '25', 'und', '0', '7'),
('node', 'forum', '0', '26', '26', 'und', '0', '7'),
('node', 'forum', '0', '27', '27', 'und', '0', '7'),
('node', 'forum', '0', '28', '28', 'und', '0', '8'),
('node', 'forum', '0', '29', '29', 'und', '0', '8'),
('node', 'forum', '0', '30', '30', 'und', '0', '8'),
('node', 'forum', '0', '31', '31', 'und', '0', '8'),
('node', 'forum', '0', '32', '32', 'und', '0', '8'),
('node', 'forum', '0', '33', '33', 'und', '0', '9'),
('node', 'forum', '0', '34', '34', 'und', '0', '9'),
('node', 'forum', '0', '35', '35', 'und', '0', '10');
/*!40000 ALTER TABLE field_data_taxonomy_forums ENABLE KEYS */;

--
-- Table structure for table 'field_revision_body'
--

CREATE TABLE IF NOT EXISTS `field_revision_body` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `body_value` longtext,
  `body_summary` longtext,
  `body_format` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`entity_type`,`entity_id`,`revision_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `body_format` (`body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Revision archive storage for field 2 (body)';

--
-- Dumping data for table 'field_revision_body'
--

/*!40000 ALTER TABLE field_revision_body DISABLE KEYS */;
INSERT INTO `field_revision_body` VALUES
('node', 'forum', '0', '12', '12', 'en', '0', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus feugiat viverra libero nec cursus. Fusce vestibulum felis non felis viverra dignissim molestie justo semper. Phasellus tortor nisl, interdum a consequat mollis, vehicula id neque. Vivamus interdum ornare erat, eu egestas risus eleifend a. Donec a lacus id nulla volutpat gravida ac sed dui. In hac habitasse platea dictumst. Nulla sagittis aliquam tellus, sit amet facilisis metus imperdiet vitae. Integer convallis, purus vitae lacinia bibendum, dui ligula varius dolor, vitae elementum dui risus sit amet velit. Phasellus enim nibh, pharetra eget bibendum in, condimentum a magna. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Mauris fermentum luctus eleifend. Donec quis velit lorem. Ut fermentum arcu in tellus dictum at porttitor odio porttitor. Vivamus sodales porttitor diam, sit amet faucibus lorem imperdiet in. Nam volutpat, eros ut convallis viverra, odio velit iaculis dui, quis tristique turpis justo non ipsum. Nulla aliquam varius ante sit amet dictum.\r\nNulla aliquam libero at lorem pellentesque tincidunt. Phasellus dictum luctus odio, sit amet adipiscing odio venenatis a. Praesent ut blandit felis. Donec auctor aliquet pellentesque. Fusce vitae auctor lorem. Integer vel urna diam. Integer vitae felis sit amet neque rutrum tincidunt id eget justo. Donec felis velit, faucibus nec congue hendrerit, cursus at nunc. Curabitur ac orci vel mauris eleifend pulvinar. Curabitur mollis, risus nec interdum gravida, velit nisl varius purus, hendrerit vulputate arcu magna a felis. In vitae consequat quam. Maecenas purus quam, tincidunt sit amet venenatis vel, venenatis dignissim nisi. Proin in ultricies risus. Quisque feugiat consequat vestibulum. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nunc cursus purus ut lectus dictum volutpat imperdiet quam commodo. Pellentesque lobortis est quis nulla vestibulum lacinia. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Nullam eu ligula ut urna hendrerit malesuada at viverra justo. Fusce semper nisl a lorem vehicula consectetur.', '', 'filtered_html'),
('node', 'forum', '0', '13', '13', 'en', '0', 'In pellentesque facilisis iaculis. Vestibulum euismod leo ac risus vulputate eget tempor mauris malesuada. Nulla feugiat leo vitae nisl ullamcorper in ornare urna aliquam. Donec eget dui feugiat turpis facilisis euismod. Quisque pretium, erat eu feugiat porttitor, lectus odio euismod elit, eget varius purus massa non erat. Nam neque tellus, imperdiet ac ullamcorper a, elementum eget ipsum. Pellentesque ut sem nibh. Proin nec lectus augue, sit amet ultrices neque. In sit amet lacus justo, a ultricies nibh. Nullam condimentum congue odio, semper consequat nulla dignissim sed. Donec rhoncus, lacus sed commodo laoreet, arcu nulla ullamcorper arcu, in facilisis risus mauris id nibh. Fusce lacinia vulputate odio, ac luctus sapien elementum non.\r\n\r\nSed scelerisque tristique enim, ac feugiat velit ultricies at. Fusce eget dui urna, sed tempus ipsum. Quisque aliquet convallis urna quis rhoncus. Aliquam vestibulum sodales interdum. Quisque quis nisi velit. Duis vestibulum nibh posuere sem commodo pharetra. Etiam eget mauris metus. Quisque congue ante augue. Quisque vehicula accumsan diam sit amet convallis. Donec eu nisl sed tellus condimentum lobortis. Fusce nulla sem, lacinia vel lacinia et, faucibus ac nibh. Etiam a congue massa. Praesent in nisi tellus. Praesent aliquam aliquam enim sit amet congue. Quisque pharetra aliquam odio in aliquam. Nunc et turpis mauris. Nulla tincidunt laoreet dictum. Lorem ipsum dolor sit amet, consectetur adipiscing elit.\r\n\r\nSed nunc nulla, molestie at interdum sit amet, consequat a justo. Nunc lobortis rhoncus malesuada. Nullam enim erat, accumsan sed tincidunt vel, pellentesque nec nibh. Morbi felis est, consequat nec varius consequat, ornare sit amet justo. Nam a tortor eget neque suscipit pharetra. Proin massa ante, porttitor quis commodo ut, fermentum id mi. Praesent ac sapien nunc. Nam id nisl eget dolor varius volutpat vel nec dolor. Vestibulum libero leo, fermentum a euismod ut, vehicula ac mauris. Integer at lectus dui, tempor vulputate lacus.\r\n', '', 'filtered_html'),
('node', 'forum', '0', '14', '14', 'en', '0', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam aliquet auctor tellus, quis pharetra massa blandit ac. Pellentesque feugiat pulvinar tincidunt. Duis consequat mollis massa ut iaculis. Cras commodo magna a ante auctor tempor. Quisque vehicula, tortor lobortis euismod ultricies, odio risus malesuada ipsum, sed euismod enim mauris in tellus. Fusce vehicula augue a dui faucibus fringilla. Etiam ut purus id metus convallis porttitor. Nam porta facilisis mauris, aliquam dapibus lectus imperdiet vitae. Praesent lobortis egestas nisi, quis fringilla nibh ultrices ut. Etiam vel est rhoncus orci viverra placerat porttitor quis nibh. Quisque rutrum euismod odio a porttitor. Suspendisse rhoncus, odio a tempus commodo, eros ipsum viverra enim, in condimentum tortor magna sed nisi. Vivamus quam metus, condimentum in consectetur sed, aliquet id felis. Etiam non leo nunc, a cursus velit. Vestibulum sed urna ut mauris facilisis ullamcorper ut et libero. In bibendum tristique lectus.\r\n\r\nNulla facilisi. Mauris porta magna eget dolor vestibulum dapibus. Integer lacus est, vulputate eget porttitor in, ultricies id nunc. Sed luctus, augue quis hendrerit tincidunt, orci turpis placerat dolor, et luctus neque nisl sed nunc. Ut id interdum massa. Proin a eros ut nibh rhoncus rhoncus at et mauris. Phasellus ornare odio in est mollis tristique. Morbi hendrerit rutrum porttitor. Donec scelerisque ipsum nisl, sed porttitor ante. Morbi posuere leo congue risus fringilla id rutrum sapien aliquam. Nam a dolor quam. Maecenas posuere rhoncus est a auctor. Sed odio nulla, pulvinar a dapibus in, sollicitudin a lectus. Maecenas pretium consectetur eleifend. Ut pharetra ipsum at magna venenatis vel ullamcorper mauris laoreet. Sed lacinia, urna vulputate venenatis eleifend, libero urna rhoncus lorem, a convallis nisl magna a neque. Quisque lobortis, justo in ultricies scelerisque, ante velit commodo urna, sit amet placerat dui nisi vitae est. Vestibulum quis euismod leo. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Morbi ultrices mi vitae ante elementum posuere.\r\n\r\nNunc dapibus, risus eget malesuada pellentesque, lorem turpis pellentesque tortor, et rutrum est nibh quis nisl. Integer suscipit lectus sit amet nibh malesuada aliquam. Ut iaculis tristique felis nec placerat. Maecenas et neque risus. Integer ultricies varius dui a auctor. Vestibulum erat erat, tincidunt et pellentesque eget, mattis ut est. Donec id tortor quis mauris consequat pharetra. Duis commodo consectetur odio, non tempor dui mollis non. Donec tempor, urna vel porta sagittis, mi diam dictum lectus, sit amet egestas justo nisi in quam. Quisque blandit interdum imperdiet. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. In eget feugiat metus. Integer urna enim, congue in pharetra id, rutrum non lectus. Aliquam urna nisi, tempus a facilisis et, varius vel justo. Duis cursus mollis sapien, eget porta ipsum ultricies vel. Ut eu nisl nisi, sit amet dapibus urna. Donec sit amet tempus sem. Nunc ipsum libero, laoreet a accumsan eget, ullamcorper quis tellus. Duis hendrerit tortor lectus.', '', 'filtered_html'),
('node', 'forum', '0', '15', '15', 'en', '0', 'Suspendisse potenti. Fusce diam risus, mattis sit amet pretium in, feugiat sed purus. Vivamus in lectus tellus. Nam justo leo, placerat sit amet imperdiet ut, accumsan quis nulla. Donec tristique tristique massa at malesuada. Nulla eleifend ultricies tempus. Nulla dapibus tempus pulvinar. Nullam urna sem, vestibulum ac porttitor sit amet, semper ut dui. Etiam at turpis sed risus auctor molestie eget quis lectus. Donec lacus tortor, condimentum nec pharetra et, adipiscing a sapien. Nulla ac ante diam. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Phasellus bibendum euismod lobortis. Phasellus semper elementum quam a iaculis. Morbi tristique diam id ante sagittis rutrum.\r\n\r\nMaecenas porttitor varius velit, eget lacinia mi semper et. Ut aliquam, augue at volutpat venenatis, quam tellus gravida enim, cursus blandit libero purus sed quam. Aliquam sollicitudin, mauris ac tincidunt convallis, erat neque mollis lacus, quis placerat odio justo placerat purus. Duis in ipsum eu sem vestibulum imperdiet sed ac neque. Vivamus in augue massa, nec aliquam nulla. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Pellentesque consequat imperdiet odio ut accumsan. Donec vel dolor sit amet ante mollis molestie at nec felis. Quisque sit amet mauris eget massa dictum tempus et mattis eros. Nunc tincidunt mattis massa et malesuada. Fusce tempus pulvinar nisi, vitae consectetur neque iaculis sit amet. Aliquam erat volutpat.\r\n\r\nFusce porttitor porta tortor pulvinar iaculis. Nulla facilisi. Etiam semper hendrerit lectus, sit amet ultricies augue porta ut. Praesent vitae dolor vitae felis congue mollis. Nulla fermentum augue sit amet sem luctus dignissim. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. In dignissim tincidunt mollis. Sed sed massa lorem, sed laoreet est. Pellentesque sit amet orci sed arcu euismod posuere id in nisl. Aenean in quam tortor. Curabitur consequat metus ut nulla viverra tincidunt. In hac habitasse platea dictumst. Suspendisse hendrerit, quam a dignissim pellentesque, turpis risus bibendum massa, quis lacinia sem sem eget est. Praesent magna nisi, dignissim laoreet hendrerit lobortis, gravida non velit. Nullam ut velit augue. Mauris mattis tellus elit, et vehicula purus. Nulla eros libero, pretium id elementum id, euismod non risus. Donec enim nisi, luctus quis vestibulum eu, dapibus quis nisi. Cras porttitor sem sit amet metus fermentum pretium.', '', 'filtered_html'),
('node', 'forum', '0', '16', '16', 'en', '0', 'Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. In mollis gravida auctor. Fusce facilisis blandit quam, at imperdiet magna blandit id. In dignissim rutrum dolor a lobortis. Cras eros ligula, volutpat sed condimentum ut, blandit at enim. Cras ipsum leo, euismod vitae consectetur at, suscipit et turpis. Integer aliquet, dui ac cursus ultricies, nibh ante varius lectus, et blandit libero nulla consectetur massa. Sed lobortis lacinia dui at cursus. Vivamus posuere diam eget libero placerat dapibus. Aliquam sit amet justo nisl. Duis tristique, felis a porttitor dictum, ipsum justo ultrices ante, vel facilisis lectus risus sit amet quam. Mauris vel enim a ante luctus dignissim. Nunc rhoncus convallis dolor. Mauris sem ante, aliquam vel vulputate eget, tristique et tellus. Curabitur cursus, leo eu aliquet tempus, est massa fringilla metus, nec mollis nisl nisi eget ante. Etiam cursus ante consequat nisi feugiat consectetur.\r\n\r\nSuspendisse potenti. Fusce diam risus, mattis sit amet pretium in, feugiat sed purus. Vivamus in lectus tellus. Nam justo leo, placerat sit amet imperdiet ut, accumsan quis nulla. Donec tristique tristique massa at malesuada. Nulla eleifend ultricies tempus. Nulla dapibus tempus pulvinar. Nullam urna sem, vestibulum ac porttitor sit amet, semper ut dui. Etiam at turpis sed risus auctor molestie eget quis lectus. Donec lacus tortor, condimentum nec pharetra et, adipiscing a sapien. Nulla ac ante diam. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Phasellus bibendum euismod lobortis. Phasellus semper elementum quam a iaculis. Morbi tristique diam id ante sagittis rutrum.\r\n\r\nMaecenas porttitor varius velit, eget lacinia mi semper et. Ut aliquam, augue at volutpat venenatis, quam tellus gravida enim, cursus blandit libero purus sed quam. Aliquam sollicitudin, mauris ac tincidunt convallis, erat neque mollis lacus, quis placerat odio justo placerat purus. Duis in ipsum eu sem vestibulum imperdiet sed ac neque. Vivamus in augue massa, nec aliquam nulla. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Pellentesque consequat imperdiet odio ut accumsan. Donec vel dolor sit amet ante mollis molestie at nec felis. Quisque sit amet mauris eget massa dictum tempus et mattis eros. Nunc tincidunt mattis massa et malesuada. Fusce tempus pulvinar nisi, vitae consectetur neque iaculis sit amet. Aliquam erat volutpat.', '', 'filtered_html'),
('node', 'forum', '0', '17', '17', 'en', '0', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Suspendisse eu lectus erat. Morbi malesuada porta lacus, id consequat magna aliquet quis. Vestibulum facilisis vehicula felis, auctor ornare dolor sagittis in. Curabitur ac nunc ante. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Nam vehicula venenatis scelerisque. Pellentesque accumsan eleifend lectus, in ornare erat pharetra ut. Vivamus faucibus feugiat varius. Nam vitae nisi libero. Cras scelerisque egestas lacus id porttitor. Sed in ipsum a nulla tincidunt luctus. Integer tempus, urna et dapibus pharetra, sapien purus eleifend quam, quis convallis nisi quam non justo. Mauris nec magna tortor, vitae cursus diam.\r\n\r\nUt vehicula, quam aliquam fringilla condimentum, diam metus hendrerit nisl, eu tempus erat ante et odio. Nulla elementum fermentum pulvinar. Ut ut enim urna, nec auctor velit. Sed ac risus ligula. Etiam tincidunt tempus est, sit amet mattis nibh fringilla sed. In augue sapien, congue et ornare ornare, auctor at tortor. Praesent hendrerit ipsum pulvinar erat pharetra dictum in vel ligula. Nunc convallis porttitor ipsum, at vestibulum velit vehicula eu. Fusce nisi dui, imperdiet sed auctor ut, porta in quam. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas.\r\n\r\nNam nec est a nulla pulvinar dignissim eget quis enim. Integer facilisis ipsum et leo molestie et cursus mi tristique. Nullam placerat facilisis vehicula. In bibendum commodo urna, mollis volutpat justo ultricies et. Proin quis justo velit. Vestibulum posuere nulla sit amet risus aliquet aliquet ornare enim luctus. Quisque vel massa scelerisque erat ultrices placerat non id augue. Nulla commodo scelerisque massa, ac iaculis eros ultricies a. Praesent ac odio sit amet odio mollis ultricies ac eu erat. Integer eu diam nibh. Nam cursus magna congue augue facilisis tempus. Vivamus dapibus eleifend scelerisque. Curabitur posuere, sapien in sodales suscipit, dolor metus pulvinar ante, varius tincidunt mi metus ac sapien. Curabitur lectus lacus, ullamcorper at bibendum sit amet, congue vitae nisl.', '', 'filtered_html'),
('node', 'forum', '0', '18', '18', 'en', '0', 'Nam nec est a nulla pulvinar dignissim eget quis enim. Integer facilisis ipsum et leo molestie et cursus mi tristique. Nullam placerat facilisis vehicula. In bibendum commodo urna, mollis volutpat justo ultricies et. Proin quis justo velit. Vestibulum posuere nulla sit amet risus aliquet aliquet ornare enim luctus. Quisque vel massa scelerisque erat ultrices placerat non id augue. Nulla commodo scelerisque massa, ac iaculis eros ultricies a. Praesent ac odio sit amet odio mollis ultricies ac eu erat. Integer eu diam nibh. Nam cursus magna congue augue facilisis tempus. Vivamus dapibus eleifend scelerisque. Curabitur posuere, sapien in sodales suscipit, dolor metus pulvinar ante, varius tincidunt mi metus ac sapien. Curabitur lectus lacus, ullamcorper at bibendum sit amet, congue vitae nisl.\r\n\r\nDuis lobortis arcu dignissim mauris accumsan laoreet. Donec nisl risus, tincidunt at interdum nec, elementum vitae metus. Integer non diam nec est imperdiet sollicitudin. Duis ac massa in nibh lacinia pellentesque. Aenean ac metus ac dolor dapibus hendrerit. Vivamus mauris tellus, fringilla quis tempus vehicula, convallis sit amet ligula. Proin eget velit nec urna placerat congue. Vivamus malesuada, libero id sagittis vehicula, elit diam vulputate erat, in aliquet mauris mi sed lacus. Nullam sodales viverra leo nec sollicitudin. Phasellus rhoncus gravida ullamcorper. Mauris a enim orci. Vestibulum eleifend convallis mi, id sodales ante varius ut. Vivamus at tristique nisi. Nunc sem leo, venenatis eu fermentum et, ultrices ut enim. Nullam nec augue neque, vitae posuere nisl. In convallis, sapien at ultrices gravida, enim libero bibendum nunc, eget interdum mauris neque at felis. Mauris tincidunt varius tellus, quis condimentum felis dictum a. Nam porta tellus massa.', '', 'filtered_html'),
('node', 'forum', '0', '19', '19', 'en', '0', 'In ac lectus massa. Pellentesque eros ligula, elementum ut tincidunt nec, sodales et ipsum. Etiam sed neque magna. Nullam aliquet dolor et augue malesuada sagittis. Nullam vitae metus odio, at aliquet velit. In leo arcu, auctor in suscipit sed, auctor vitae purus. Sed vel mauris ante. Vivamus placerat venenatis mauris ut consectetur. Donec condimentum sagittis arcu, eu lobortis erat facilisis sed. Morbi justo dolor, vulputate sed iaculis lacinia, molestie at nunc. Curabitur laoreet accumsan elit, nec venenatis odio faucibus eu. Praesent rhoncus, massa id pellentesque congue, est neque sagittis lacus, a pulvinar quam neque vitae tortor. Nam in mauris mattis neque pretium fringilla sed consectetur tellus.\r\n\r\nAenean nisi ante, tempus eget egestas sit amet, molestie sit amet neque. Fusce interdum mi a ligula euismod posuere. Maecenas auctor, orci vitae viverra bibendum, ante erat molestie nulla, consectetur accumsan nulla nunc vel lacus. Sed pretium neque risus, sit amet laoreet purus. Suspendisse mattis ligula ut erat auctor placerat suscipit sapien pulvinar. Nam ullamcorper nisl et ligula pretium mollis. Etiam convallis, enim id volutpat gravida, enim diam aliquet lectus, et euismod nulla turpis quis leo. Vestibulum consectetur augue eu elit consectetur auctor. Praesent dui nibh, tincidunt eu rutrum ut, vulputate sit amet arcu. Etiam varius mauris non justo tincidunt tristique. Fusce vitae mi a ligula malesuada interdum. Vivamus feugiat arcu sed neque vestibulum sed vulputate est fermentum. Mauris interdum, dui sed luctus rutrum, mauris nibh venenatis leo, nec euismod erat nunc ac augue. Proin justo elit, dictum ac malesuada sed, vehicula fringilla ligula. In tempus lectus quis odio blandit commodo. Mauris aliquam tellus at elit bibendum blandit. Donec non ipsum a lorem lacinia iaculis. Sed purus eros, scelerisque et consectetur sed, dictum eget erat. Donec non magna ligula. Suspendisse a volutpat enim.', '', 'filtered_html'),
('node', 'forum', '0', '20', '20', 'en', '0', 'Aenean nisi ante, tempus eget egestas sit amet, molestie sit amet neque. Fusce interdum mi a ligula euismod posuere. Maecenas auctor, orci vitae viverra bibendum, ante erat molestie nulla, consectetur accumsan nulla nunc vel lacus. Sed pretium neque risus, sit amet laoreet purus. Suspendisse mattis ligula ut erat auctor placerat suscipit sapien pulvinar. Nam ullamcorper nisl et ligula pretium mollis. Etiam convallis, enim id volutpat gravida, enim diam aliquet lectus, et euismod nulla turpis quis leo. Vestibulum consectetur augue eu elit consectetur auctor. Praesent dui nibh, tincidunt eu rutrum ut, vulputate sit amet arcu. Etiam varius mauris non justo tincidunt tristique. Fusce vitae mi a ligula malesuada interdum. Vivamus feugiat arcu sed neque vestibulum sed vulputate est fermentum. Mauris interdum, dui sed luctus rutrum, mauris nibh venenatis leo, nec euismod erat nunc ac augue. Proin justo elit, dictum ac malesuada sed, vehicula fringilla ligula. In tempus lectus quis odio blandit commodo. Mauris aliquam tellus at elit bibendum blandit. Donec non ipsum a lorem lacinia iaculis. Sed purus eros, scelerisque et consectetur sed, dictum eget erat. Donec non magna ligula. Suspendisse a volutpat enim.\r\n\r\nSuspendisse vulputate hendrerit nulla, eget adipiscing nibh rutrum non. Praesent in accumsan risus. Praesent quis eros sem, ac mattis eros. Curabitur erat ante, porttitor et euismod et, molestie a massa. Donec vitae urna quis nibh pretium eleifend. Fusce orci leo, gravida nec venenatis sit amet, interdum vitae dui. Duis vel condimentum neque. In a justo nulla. In hac habitasse platea dictumst. Curabitur vehicula eros sed lectus pellentesque facilisis. Morbi accumsan lorem sit amet purus posuere sed vulputate quam luctus. Fusce molestie, urna at tempor pulvinar, massa purus vehicula neque, consectetur consequat nibh mi et leo. Proin id rhoncus arcu. Etiam vestibulum bibendum nisi nec eleifend. Donec velit turpis, tincidunt sit amet varius eu, rhoncus sed risus. Sed rhoncus dignissim arcu, eu dignissim justo tempus ut. Fusce interdum lectus massa, sit amet rhoncus sem.\r\n\r\nMauris aliquam tempor lorem id mollis. Pellentesque vehicula nunc eu risus condimentum et placerat turpis dignissim. Donec scelerisque tellus sed massa ullamcorper molestie. Pellentesque sem metus, vestibulum rhoncus hendrerit sed, venenatis a ipsum. Duis sit amet dui velit, id rhoncus neque. Etiam leo risus, tincidunt at pharetra eget, sodales sit amet lacus. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Duis eleifend, sem ut iaculis pharetra, sem mauris porttitor ligula, et molestie orci augue et nibh. Ut vulputate aliquam tortor, eu tristique nisl euismod et. Phasellus eget mauris ut metus mattis ullamcorper ut a orci. Nullam quam leo, vulputate id condimentum id, fermentum vitae urna. Donec eget lacus at tortor interdum elementum. Sed vulputate gravida nisi, ac venenatis nisi blandit id. Curabitur ac nibh nibh. Ut ut neque urna. Nunc ullamcorper massa fermentum lacus elementum fringilla. Pellentesque quis metus a leo egestas vehicula.', '', 'filtered_html'),
('node', 'forum', '0', '21', '21', 'en', '0', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec vestibulum ultrices mollis. Sed id purus mattis leo pulvinar hendrerit quis non turpis. Donec eleifend malesuada lorem, ac sagittis dui tempus id. Duis risus mi, fringilla sit amet elementum in, vulputate non orci. Mauris at pharetra elit. Curabitur libero orci, elementum iaculis congue nec, placerat a lorem. Nunc ornare, leo id condimentum dictum, metus ante mattis felis, a venenatis urna magna a nisi. Donec hendrerit malesuada egestas. Mauris ligula tellus, bibendum in pellentesque et, cursus volutpat augue. Ut sollicitudin libero id purus dignissim pellentesque laoreet massa pharetra. Cras dignissim tortor quis erat hendrerit ut adipiscing elit laoreet. Sed hendrerit convallis pretium. Nunc quis turpis turpis, at adipiscing neque. Sed mi nisi, pulvinar non posuere non, varius et lacus. Vestibulum risus metus, vehicula nec ornare eget, ultrices non tortor. In vulputate turpis ipsum, sed cursus mi. Sed elit sem, tristique id tempor eu, molestie et magna. Vestibulum porta nisl a urna tincidunt eget tristique leo blandit.\r\n\r\nProin dictum, libero eget aliquet dictum, nisi mi venenatis sem, sed rhoncus turpis nibh rhoncus elit. Cras porttitor, nunc eu tincidunt vulputate, enim dolor viverra ipsum, vel eleifend risus justo vel neque. Proin hendrerit vestibulum diam, at imperdiet enim rutrum eu. Curabitur eros augue, iaculis in mollis sit amet, tincidunt vitae turpis. Maecenas eu erat vel massa scelerisque mollis sed in ligula. Duis consectetur congue felis a porta. Pellentesque turpis nisl, faucibus et blandit nec, mattis vel purus. Nulla facilisi. Ut viverra fermentum felis, nec dapibus massa suscipit ut. Vestibulum id ligula lacus, et tristique libero.\r\n\r\nCras euismod aliquet massa scelerisque euismod. Phasellus tincidunt, eros sit amet cursus porta, neque velit tincidunt lacus, non mattis risus augue ut erat. Phasellus facilisis ornare massa, ac porttitor erat hendrerit eget. Cras porttitor aliquet aliquam. Phasellus at mauris vitae metus pharetra semper. Aliquam mi ligula, commodo ut pharetra quis, bibendum ac odio. Nullam tincidunt nulla vel massa lacinia varius. Ut tortor urna, faucibus vel posuere ut, hendrerit eu ante. Pellentesque porttitor iaculis sem, a adipiscing sapien commodo sit amet. Duis non massa quis leo fringilla aliquam. Phasellus fermentum congue velit. Sed blandit, ante non ornare iaculis, turpis mauris consectetur nunc, id venenatis turpis odio et ante. Pellentesque bibendum tincidunt justo porta dictum. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris neque eros, pretium nec cursus sit amet, mattis vitae felis. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Aenean vel magna vitae felis euismod congue a at magna. Donec varius mattis diam, vitae ultricies nisi vehicula eu.', '', 'filtered_html'),
('node', 'forum', '0', '22', '22', 'en', '0', 'Cras euismod aliquet massa scelerisque euismod. Phasellus tincidunt, eros sit amet cursus porta, neque velit tincidunt lacus, non mattis risus augue ut erat. Phasellus facilisis ornare massa, ac porttitor erat hendrerit eget. Cras porttitor aliquet aliquam. Phasellus at mauris vitae metus pharetra semper. Aliquam mi ligula, commodo ut pharetra quis, bibendum ac odio. Nullam tincidunt nulla vel massa lacinia varius. Ut tortor urna, faucibus vel posuere ut, hendrerit eu ante. Pellentesque porttitor iaculis sem, a adipiscing sapien commodo sit amet. Duis non massa quis leo fringilla aliquam. Phasellus fermentum congue velit. Sed blandit, ante non ornare iaculis, turpis mauris consectetur nunc, id venenatis turpis odio et ante. Pellentesque bibendum tincidunt justo porta dictum. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris neque eros, pretium nec cursus sit amet, mattis vitae felis. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Aenean vel magna vitae felis euismod congue a at magna. Donec varius mattis diam, vitae ultricies nisi vehicula eu.\r\n\r\nCras congue porttitor ipsum, nec pulvinar risus adipiscing ac. Nam vel augue nibh. Phasellus metus lectus, placerat eu posuere ac, molestie vel diam. Quisque blandit elit in neque vehicula eu fringilla tortor volutpat. Sed non turpis pretium lorem hendrerit pretium in ac dolor. Pellentesque semper volutpat urna vel dictum. Nunc tempor, neque nec elementum luctus, turpis dui lacinia est, vitae placerat nibh mauris eu ipsum. Integer vel orci a quam posuere malesuada eget et turpis. Nunc porttitor, quam non rutrum iaculis, odio tellus condimentum tortor, ut dapibus neque urna quis est. Phasellus ac lectus sed nisi pulvinar consectetur. Sed urna nulla, aliquam et ullamcorper at, porta quis libero. Duis sed est dolor. Morbi quam erat, sagittis volutpat tristique at, blandit non arcu. Suspendisse potenti. Praesent a metus odio. Proin eros ligula, accumsan eu bibendum id, rutrum sed urna. Phasellus quis suscipit mi.\r\n\r\nVestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Sed imperdiet, velit nec semper mattis, elit tellus ultricies nibh, id bibendum justo lacus sit amet urna. Aliquam lacus risus, condimentum ut accumsan non, pretium vel leo. Praesent vel orci eget tortor molestie fringilla at et erat. Integer adipiscing gravida lobortis. Quisque varius, metus in egestas sollicitudin, risus lacus tempor erat, quis ullamcorper arcu magna nec mauris. Aenean tempus sapien nibh, ut ultrices enim. Vivamus in nulla massa, vel aliquam dui. Suspendisse potenti. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Proin condimentum sapien sed ante sodales lobortis. Suspendisse et lectus id nibh lacinia ultricies. Cras commodo laoreet ullamcorper. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Quisque diam tortor, tincidunt nec lacinia vel, suscipit id tellus. Pellentesque vitae semper ipsum.', '', 'filtered_html'),
('node', 'forum', '0', '23', '23', 'en', '0', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec vestibulum ultrices mollis. Sed id purus mattis leo pulvinar hendrerit quis non turpis. Donec eleifend malesuada lorem, ac sagittis dui tempus id. Duis risus mi, fringilla sit amet elementum in, vulputate non orci. Mauris at pharetra elit. Curabitur libero orci, elementum iaculis congue nec, placerat a lorem. Nunc ornare, leo id condimentum dictum, metus ante mattis felis, a venenatis urna magna a nisi. Donec hendrerit malesuada egestas. Mauris ligula tellus, bibendum in pellentesque et, cursus volutpat augue. Ut sollicitudin libero id purus dignissim pellentesque laoreet massa pharetra. Cras dignissim tortor quis erat hendrerit ut adipiscing elit laoreet. Sed hendrerit convallis pretium. Nunc quis turpis turpis, at adipiscing neque. Sed mi nisi, pulvinar non posuere non, varius et lacus. Vestibulum risus metus, vehicula nec ornare eget, ultrices non tortor. In vulputate turpis ipsum, sed cursus mi. Sed elit sem, tristique id tempor eu, molestie et magna. Vestibulum porta nisl a urna tincidunt eget tristique leo blandit.\r\n\r\nProin dictum, libero eget aliquet dictum, nisi mi venenatis sem, sed rhoncus turpis nibh rhoncus elit. Cras porttitor, nunc eu tincidunt vulputate, enim dolor viverra ipsum, vel eleifend risus justo vel neque. Proin hendrerit vestibulum diam, at imperdiet enim rutrum eu. Curabitur eros augue, iaculis in mollis sit amet, tincidunt vitae turpis. Maecenas eu erat vel massa scelerisque mollis sed in ligula. Duis consectetur congue felis a porta. Pellentesque turpis nisl, faucibus et blandit nec, mattis vel purus. Nulla facilisi. Ut viverra fermentum felis, nec dapibus massa suscipit ut. Vestibulum id ligula lacus, et tristique libero.\r\n\r\nCras euismod aliquet massa scelerisque euismod. Phasellus tincidunt, eros sit amet cursus porta, neque velit tincidunt lacus, non mattis risus augue ut erat. Phasellus facilisis ornare massa, ac porttitor erat hendrerit eget. Cras porttitor aliquet aliquam. Phasellus at mauris vitae metus pharetra semper. Aliquam mi ligula, commodo ut pharetra quis, bibendum ac odio. Nullam tincidunt nulla vel massa lacinia varius. Ut tortor urna, faucibus vel posuere ut, hendrerit eu ante. Pellentesque porttitor iaculis sem, a adipiscing sapien commodo sit amet. Duis non massa quis leo fringilla aliquam. Phasellus fermentum congue velit. Sed blandit, ante non ornare iaculis, turpis mauris consectetur nunc, id venenatis turpis odio et ante. Pellentesque bibendum tincidunt justo porta dictum. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris neque eros, pretium nec cursus sit amet, mattis vitae felis. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Aenean vel magna vitae felis euismod congue a at magna. Donec varius mattis diam, vitae ultricies nisi vehicula eu.', '', 'filtered_html'),
('node', 'forum', '0', '24', '24', 'en', '0', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Integer in mollis turpis. Nam faucibus porta magna, molestie faucibus enim posuere vel. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Nullam id libero facilisis augue euismod eleifend. Mauris quam eros, scelerisque quis pharetra nec, ornare ac justo. Etiam euismod felis vel odio rutrum fringilla. Ut non libero sit amet mauris eleifend auctor non non est. Morbi ullamcorper odio a orci scelerisque vehicula eget ac tortor. Cras condimentum orci ac arcu elementum non vehicula nisi rhoncus. Donec libero dolor, dignissim in ultrices vel, lacinia tempus elit. Nam sed ipsum ligula. Fusce interdum consequat neque a varius. Praesent scelerisque, nisl a dictum pulvinar, justo tellus lobortis diam, eget ultricies nunc felis ut leo. Morbi pretium congue tellus at imperdiet. Ut nec mauris sit amet nibh ornare dapibus. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae;\r\n\r\nPraesent non mauris eget nisi porta dignissim in vitae sem. Duis condimentum iaculis nulla vel ullamcorper. Praesent et urna risus, vel fermentum ante. Donec neque ipsum, suscipit sed dictum a, sodales ut tellus. Nullam et varius enim. Aliquam sed eros et leo adipiscing scelerisque. Maecenas varius pulvinar sodales. Maecenas a justo lectus. Mauris non sapien a arcu varius gravida vel at urna. Suspendisse at tortor augue. Proin eleifend blandit neque, ut sodales risus porttitor in. Suspendisse pretium quam quis nunc fermentum vitae vulputate sapien dictum. Aliquam erat volutpat. Maecenas et justo odio. Praesent molestie lacus eu felis commodo ac rutrum sem commodo. Nullam blandit dolor ac felis euismod quis pellentesque purus consequat. Morbi ut molestie nisi. Nullam quam odio, rhoncus vitae adipiscing at, dictum ac libero.\r\n\r\nFusce ac lacus metus, et molestie mi. Nunc eleifend eleifend mauris, at feugiat risus convallis sit amet. Suspendisse sem velit, dignissim vitae vehicula sit amet, mollis vel massa. Curabitur volutpat, ligula eu lobortis elementum, velit sapien sodales mi, vitae dapibus mi lorem convallis sem. Maecenas ac purus luctus lacus tempus mattis sed vitae diam. Vivamus nec ullamcorper diam. Mauris nec est eu mi venenatis accumsan non id nisi. Integer pellentesque aliquam vulputate. Donec volutpat enim nec leo iaculis tempus. Duis ultrices ornare tortor eget lobortis.', '', 'filtered_html'),
('node', 'forum', '0', '25', '25', 'en', '0', 'Fusce ac lacus metus, et molestie mi. Nunc eleifend eleifend mauris, at feugiat risus convallis sit amet. Suspendisse sem velit, dignissim vitae vehicula sit amet, mollis vel massa. Curabitur volutpat, ligula eu lobortis elementum, velit sapien sodales mi, vitae dapibus mi lorem convallis sem. Maecenas ac purus luctus lacus tempus mattis sed vitae diam. Vivamus nec ullamcorper diam. Mauris nec est eu mi venenatis accumsan non id nisi. Integer pellentesque aliquam vulputate. Donec volutpat enim nec leo iaculis tempus. Duis ultrices ornare tortor eget lobortis.\r\n\r\nSuspendisse tempor libero sed ipsum imperdiet semper dapibus tortor laoreet. Suspendisse vitae sem dolor. Etiam sollicitudin tortor ut metus aliquet ullamcorper. Vivamus vel nulla id lorem tincidunt bibendum. Praesent malesuada tortor est. Aenean et dolor est, tempus elementum libero. Proin massa nulla, condimentum ut volutpat sit amet, aliquet vitae orci. Morbi tincidunt ligula at diam venenatis hendrerit dignissim felis condimentum. Quisque iaculis, erat non tristique mattis, libero ligula ultricies massa, vel scelerisque lorem eros eu lectus. Donec bibendum, lacus sed scelerisque pretium, tellus leo pretium sem, id egestas elit ante sit amet est. Mauris pellentesque, tortor at pellentesque vehicula, massa ligula posuere lectus, a dignissim urna magna eu eros. Donec in dui id tortor cursus lobortis. Phasellus placerat malesuada arcu at vehicula. Morbi sagittis ipsum vel diam aliquam in viverra lorem pellentesque. Donec laoreet tincidunt risus. Aenean ut diam in turpis consequat aliquet. Ut libero dui, tempor vel sagittis eu, fringilla a nisi. Aenean orci lectus, cursus et viverra eu, pharetra malesuada elit. Duis nec eros nibh, sit amet suscipit ipsum.\r\n\r\nLorem ipsum dolor sit amet, consectetur adipiscing elit. Ut malesuada ultrices rhoncus. Donec dignissim tincidunt aliquam. Donec tempus dapibus augue, at dictum sapien sodales et. Curabitur a orci nulla. Integer pulvinar nisi vel turpis pellentesque interdum. Praesent auctor scelerisque facilisis. Maecenas eget diam congue justo suscipit adipiscing. Aenean sit amet nunc massa, in placerat leo. Suspendisse pharetra odio eu quam dapibus sagittis. Pellentesque feugiat mattis ultricies.', '', 'filtered_html'),
('node', 'forum', '0', '26', '26', 'en', '0', 'Praesent non mauris eget nisi porta dignissim in vitae sem. Duis condimentum iaculis nulla vel ullamcorper. Praesent et urna risus, vel fermentum ante. Donec neque ipsum, suscipit sed dictum a, sodales ut tellus. Nullam et varius enim. Aliquam sed eros et leo adipiscing scelerisque. Maecenas varius pulvinar sodales. Maecenas a justo lectus. Mauris non sapien a arcu varius gravida vel at urna. Suspendisse at tortor augue. Proin eleifend blandit neque, ut sodales risus porttitor in. Suspendisse pretium quam quis nunc fermentum vitae vulputate sapien dictum. Aliquam erat volutpat. Maecenas et justo odio. Praesent molestie lacus eu felis commodo ac rutrum sem commodo. Nullam blandit dolor ac felis euismod quis pellentesque purus consequat. Morbi ut molestie nisi. Nullam quam odio, rhoncus vitae adipiscing at, dictum ac libero.\r\n\r\nFusce ac lacus metus, et molestie mi. Nunc eleifend eleifend mauris, at feugiat risus convallis sit amet. Suspendisse sem velit, dignissim vitae vehicula sit amet, mollis vel massa. Curabitur volutpat, ligula eu lobortis elementum, velit sapien sodales mi, vitae dapibus mi lorem convallis sem. Maecenas ac purus luctus lacus tempus mattis sed vitae diam. Vivamus nec ullamcorper diam. Mauris nec est eu mi venenatis accumsan non id nisi. Integer pellentesque aliquam vulputate. Donec volutpat enim nec leo iaculis tempus. Duis ultrices ornare tortor eget lobortis.\r\n\r\nSuspendisse tempor libero sed ipsum imperdiet semper dapibus tortor laoreet. Suspendisse vitae sem dolor. Etiam sollicitudin tortor ut metus aliquet ullamcorper. Vivamus vel nulla id lorem tincidunt bibendum. Praesent malesuada tortor est. Aenean et dolor est, tempus elementum libero. Proin massa nulla, condimentum ut volutpat sit amet, aliquet vitae orci. Morbi tincidunt ligula at diam venenatis hendrerit dignissim felis condimentum. Quisque iaculis, erat non tristique mattis, libero ligula ultricies massa, vel scelerisque lorem eros eu lectus. Donec bibendum, lacus sed scelerisque pretium, tellus leo pretium sem, id egestas elit ante sit amet est. Mauris pellentesque, tortor at pellentesque vehicula, massa ligula posuere lectus, a dignissim urna magna eu eros. Donec in dui id tortor cursus lobortis. Phasellus placerat malesuada arcu at vehicula. Morbi sagittis ipsum vel diam aliquam in viverra lorem pellentesque. Donec laoreet tincidunt risus. Aenean ut diam in turpis consequat aliquet. Ut libero dui, tempor vel sagittis eu, fringilla a nisi. Aenean orci lectus, cursus et viverra eu, pharetra malesuada elit. Duis nec eros nibh, sit amet suscipit ipsum.', '', 'filtered_html'),
('node', 'forum', '0', '27', '27', 'en', '0', 'Curabitur feugiat ornare pulvinar. Phasellus mi urna, tempor ut porttitor in, facilisis id sapien. Pellentesque egestas erat laoreet felis aliquam tempus. Fusce turpis sem, auctor et viverra non, faucibus quis mauris. Sed feugiat, libero ut egestas malesuada, magna elit laoreet augue, fermentum tristique metus dolor vitae leo. Nam vel quam in nisl feugiat elementum consectetur a turpis. Fusce dictum risus augue. Nam vel arcu nulla, pellentesque pulvinar mauris. Duis eros libero, tristique posuere adipiscing id, dictum eget dui. Phasellus at neque metus. Nam aliquet venenatis ante, sit amet pulvinar arcu ultricies eget.\r\n\r\nSuspendisse potenti. In sagittis tempor nisi, at egestas sem ultricies a. Nullam ac dolor id leo scelerisque accumsan sit amet id neque. Suspendisse ullamcorper feugiat magna, quis condimentum ante luctus at. Morbi semper luctus quam non mattis. Aenean sed risus nisl. Praesent posuere vehicula neque aliquet luctus. Pellentesque tempus hendrerit gravida. Donec accumsan nisi ut dolor dapibus ac luctus diam hendrerit. Suspendisse sit amet mattis neque. Sed et rhoncus odio. Cras euismod pretium mauris, eget facilisis eros aliquam quis. Suspendisse ut ante lacus. Nullam ut vulputate velit. Aliquam felis nulla, eleifend in lobortis a, semper non velit. Nam ac felis elit, at euismod lacus. Integer fermentum arcu viverra nulla luctus scelerisque. Duis condimentum neque non orci pretium suscipit. In vel ante eget lacus placerat hendrerit.', '', 'filtered_html'),
('node', 'forum', '0', '28', '28', 'en', '0', 'Suspendisse potenti. In sagittis tempor nisi, at egestas sem ultricies a. Nullam ac dolor id leo scelerisque accumsan sit amet id neque. Suspendisse ullamcorper feugiat magna, quis condimentum ante luctus at. Morbi semper luctus quam non mattis. Aenean sed risus nisl. Praesent posuere vehicula neque aliquet luctus. Pellentesque tempus hendrerit gravida. Donec accumsan nisi ut dolor dapibus ac luctus diam hendrerit. Suspendisse sit amet mattis neque. Sed et rhoncus odio. Cras euismod pretium mauris, eget facilisis eros aliquam quis. Suspendisse ut ante lacus. Nullam ut vulputate velit. Aliquam felis nulla, eleifend in lobortis a, semper non velit. Nam ac felis elit, at euismod lacus. Integer fermentum arcu viverra nulla luctus scelerisque. Duis condimentum neque non orci pretium suscipit. In vel ante eget lacus placerat hendrerit.\r\n\r\nPhasellus at nibh nisl. Curabitur nec eros ut neque ultrices luctus. Vivamus dapibus interdum nibh sit amet dictum. Vestibulum rutrum pharetra lacus, quis congue risus consequat non. Duis eget luctus erat. Nullam faucibus neque non eros bibendum iaculis. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Morbi sed tempus massa. Pellentesque tortor nulla, pharetra id pharetra quis, ornare et lectus. Donec quis lacus nec lectus consequat eleifend id at lorem. Donec sodales lacinia nisl, a venenatis lacus scelerisque eget. Sed sagittis turpis nec metus dictum dapibus. Quisque luctus elit vel sapien porta vel consectetur dolor blandit. Cras at erat eu erat egestas mollis. Sed nec augue et nibh sollicitudin facilisis vitae nec odio. Donec luctus fringilla viverra. Cras mattis commodo leo, ut gravida erat rutrum in. Vivamus feugiat sodales egestas. Phasellus eros sem, convallis at scelerisque eu, adipiscing a urna.\r\n\r\nFusce quis molestie sapien. Nunc vestibulum tincidunt dolor eget accumsan. Cras ornare laoreet augue, lacinia rutrum dui semper eget. Cras aliquam odio ac turpis egestas consectetur. In vulputate congue lacinia. Pellentesque ullamcorper nulla quis augue ullamcorper ut dictum massa lacinia. Phasellus ultrices, urna ut scelerisque iaculis, massa nunc dignissim augue, ac placerat odio nibh sed urna. Nulla gravida sem suscipit risus fringilla sit amet aliquet turpis consectetur. Sed placerat convallis enim, in bibendum risus cursus vitae. Suspendisse non justo leo. Nam consectetur consectetur libero quis facilisis. Duis ac arcu nec enim euismod rutrum. Etiam velit quam, laoreet in blandit consectetur, congue at leo. Aenean tempor, arcu ac aliquet tincidunt, massa odio dictum enim, eget mollis justo nisi sit amet ligula. Nunc ipsum quam, mollis sed commodo in, aliquet sed lacus. Nunc vehicula, justo vel consequat placerat, dolor erat placerat leo, ac vestibulum justo diam ac mauris. Vivamus id sem at elit mollis ultricies porta nec magna. Sed aliquet tincidunt pellentesque.', '', 'filtered_html'),
('node', 'forum', '0', '29', '29', 'en', '0', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Quisque sollicitudin elit nec purus ultricies rhoncus. Nulla non pellentesque ligula. Praesent porttitor nunc sit amet odio varius vitae venenatis nunc euismod. Phasellus erat felis, eleifend porttitor lacinia in, vehicula quis elit. Curabitur dui eros, blandit vel mollis et, molestie eu arcu. Aenean sagittis ligula vel purus elementum vel fringilla lorem mollis. Sed scelerisque risus ut metus vehicula a vehicula sem pharetra. Sed at ligula eget diam ullamcorper porta. Cras sagittis posuere ante, a accumsan eros feugiat in. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Nulla pellentesque augue sed metus dapibus vitae convallis purus laoreet. Cras ultrices nulla vel erat sagittis tristique quis quis libero. Proin suscipit sapien quis risus interdum elementum. Duis tempor luctus velit. Fusce vel consequat est.\r\n\r\nCurabitur feugiat ornare pulvinar. Phasellus mi urna, tempor ut porttitor in, facilisis id sapien. Pellentesque egestas erat laoreet felis aliquam tempus. Fusce turpis sem, auctor et viverra non, faucibus quis mauris. Sed feugiat, libero ut egestas malesuada, magna elit laoreet augue, fermentum tristique metus dolor vitae leo. Nam vel quam in nisl feugiat elementum consectetur a turpis. Fusce dictum risus augue. Nam vel arcu nulla, pellentesque pulvinar mauris. Duis eros libero, tristique posuere adipiscing id, dictum eget dui. Phasellus at neque metus. Nam aliquet venenatis ante, sit amet pulvinar arcu ultricies eget.\r\n\r\nSuspendisse potenti. In sagittis tempor nisi, at egestas sem ultricies a. Nullam ac dolor id leo scelerisque accumsan sit amet id neque. Suspendisse ullamcorper feugiat magna, quis condimentum ante luctus at. Morbi semper luctus quam non mattis. Aenean sed risus nisl. Praesent posuere vehicula neque aliquet luctus. Pellentesque tempus hendrerit gravida. Donec accumsan nisi ut dolor dapibus ac luctus diam hendrerit. Suspendisse sit amet mattis neque. Sed et rhoncus odio. Cras euismod pretium mauris, eget facilisis eros aliquam quis. Suspendisse ut ante lacus. Nullam ut vulputate velit. Aliquam felis nulla, eleifend in lobortis a, semper non velit. Nam ac felis elit, at euismod lacus. Integer fermentum arcu viverra nulla luctus scelerisque. Duis condimentum neque non orci pretium suscipit. In vel ante eget lacus placerat hendrerit.', '', 'filtered_html'),
('node', 'forum', '0', '30', '30', 'en', '0', 'Suspendisse potenti. In sagittis tempor nisi, at egestas sem ultricies a. Nullam ac dolor id leo scelerisque accumsan sit amet id neque. Suspendisse ullamcorper feugiat magna, quis condimentum ante luctus at. Morbi semper luctus quam non mattis. Aenean sed risus nisl. Praesent posuere vehicula neque aliquet luctus. Pellentesque tempus hendrerit gravida. Donec accumsan nisi ut dolor dapibus ac luctus diam hendrerit. Suspendisse sit amet mattis neque. Sed et rhoncus odio. Cras euismod pretium mauris, eget facilisis eros aliquam quis. Suspendisse ut ante lacus. Nullam ut vulputate velit. Aliquam felis nulla, eleifend in lobortis a, semper non velit. Nam ac felis elit, at euismod lacus. Integer fermentum arcu viverra nulla luctus scelerisque. Duis condimentum neque non orci pretium suscipit. In vel ante eget lacus placerat hendrerit.\r\n\r\nPhasellus at nibh nisl. Curabitur nec eros ut neque ultrices luctus. Vivamus dapibus interdum nibh sit amet dictum. Vestibulum rutrum pharetra lacus, quis congue risus consequat non. Duis eget luctus erat. Nullam faucibus neque non eros bibendum iaculis. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Morbi sed tempus massa. Pellentesque tortor nulla, pharetra id pharetra quis, ornare et lectus. Donec quis lacus nec lectus consequat eleifend id at lorem. Donec sodales lacinia nisl, a venenatis lacus scelerisque eget. Sed sagittis turpis nec metus dictum dapibus. Quisque luctus elit vel sapien porta vel consectetur dolor blandit. Cras at erat eu erat egestas mollis. Sed nec augue et nibh sollicitudin facilisis vitae nec odio. Donec luctus fringilla viverra. Cras mattis commodo leo, ut gravida erat rutrum in. Vivamus feugiat sodales egestas. Phasellus eros sem, convallis at scelerisque eu, adipiscing a urna.', '', 'filtered_html');
INSERT INTO `field_revision_body` VALUES
('node', 'forum', '0', '31', '31', 'en', '0', 'Curabitur eu nibh non odio congue scelerisque consectetur eu justo. Duis ornare interdum sollicitudin. Suspendisse pretium pharetra rhoncus. Pellentesque luctus lacinia luctus. Donec tempor viverra nunc, vel luctus massa consequat ac. Morbi auctor, neque et consectetur aliquam, est leo ultricies magna, at volutpat ante ante ut sem. Sed cursus porta venenatis. Aliquam turpis massa, bibendum sit amet hendrerit eleifend, dictum in mauris. Vivamus ultrices urna nec ipsum pretium quis euismod ligula sollicitudin. Nam cursus molestie condimentum.\r\n\r\nUt aliquet arcu id magna porttitor consequat. Proin at ultricies eros. Curabitur non metus ac neque tempus semper. Donec non nulla id purus congue elementum. Nunc sollicitudin metus sit amet mauris iaculis eget lacinia enim tempor. Phasellus eleifend sodales elit, eu dignissim augue faucibus et. In ac arcu eget risus facilisis laoreet. Nunc vel placerat libero. Duis egestas porta lectus, et egestas ante vestibulum ac. Ut sit amet dui nibh, pretium hendrerit lectus.\r\n\r\nCurabitur imperdiet euismod tortor, id consectetur felis ultricies vel. Sed sagittis accumsan nibh, sit amet fermentum sapien mattis non. Nulla congue quam sed eros iaculis at sagittis mi ornare. Donec rhoncus euismod elit, sit amet tempus odio porta vel. Proin hendrerit, libero eu tempor porttitor, nisl eros ultricies urna, eget sagittis metus ante tristique erat. Ut ac diam sit amet leo venenatis eleifend. Vivamus libero neque, tristique id mollis id, volutpat sit amet ipsum. Vivamus lobortis, erat tempor fermentum facilisis, sem arcu lacinia risus, at euismod enim neque eu magna. Fusce elementum, enim nec venenatis pretium, sapien eros varius metus, consequat sollicitudin sapien nibh et erat. Phasellus consequat felis non quam sodales in scelerisque nibh imperdiet. Nulla in leo massa. Quisque magna urna, posuere eget molestie eu, venenatis sit amet nulla. Maecenas lacus diam, elementum sit amet vulputate sit amet, pulvinar in metus. In egestas, arcu sit amet pharetra ornare, urna libero vulputate est, sed cursus dolor libero quis eros. Quisque venenatis porta arcu ut consectetur. Donec ac magna non tellus tempus aliquam sed at nisl. Nullam orci massa, ultrices ac dictum non, tincidunt ac odio. Phasellus pharetra elementum massa, quis porta neque pretium quis.', '', 'filtered_html'),
('node', 'forum', '0', '32', '32', 'en', '0', 'Aenean quis mattis magna. In pulvinar interdum mauris in ornare. Fusce molestie erat id sapien aliquam pharetra. Suspendisse ornare tincidunt magna. Sed sed turpis justo. Donec eleifend, justo vel bibendum blandit, est sem tempus lorem, vel ultricies felis eros non est. Praesent ac dolor eu justo vestibulum dapibus. Maecenas id odio lectus, in interdum libero. In hac habitasse platea dictumst. Praesent sed urna turpis, sit amet auctor sem. Pellentesque sit amet ante sit amet diam imperdiet ultrices. Proin congue iaculis semper. Vivamus mi enim, dapibus quis laoreet at, hendrerit sit amet eros. Nulla ut lacinia nisi.\r\n\r\nNullam eu erat nibh. Aliquam ipsum sapien, interdum a euismod vitae, vehicula pellentesque dolor. In sit amet eros pretium eros aliquet semper eget id massa. Donec malesuada rutrum est. Sed neque est, ultricies ac dictum at, tincidunt at arcu. In hac habitasse platea dictumst. Cras posuere convallis mattis. Quisque blandit ullamcorper ligula, dapibus tincidunt dolor lacinia non. Aliquam vitae nunc metus. Fusce nec sem sapien.\r\n\r\nMorbi pharetra pharetra purus eu condimentum. Phasellus pulvinar imperdiet mi vitae pellentesque. Nullam sed urna porta ligula tempus venenatis a at metus. Proin feugiat nulla nec mi hendrerit ut iaculis purus pulvinar. Suspendisse id magna lacus, vel consequat arcu. Vestibulum non nulla felis, in tempor magna. Aliquam lacinia iaculis leo, eu consequat mauris molestie nec. Mauris facilisis facilisis eros, quis pretium ipsum consectetur quis. Vestibulum sed massa vitae felis porta elementum. Nulla facilisi. Sed turpis mi, ultrices sed blandit sit amet, rutrum et tellus. Proin luctus egestas turpis, eget luctus dolor mattis a. Nam sed rutrum diam. Sed quis nisl nisl, eu fringilla diam.', '', 'filtered_html'),
('node', 'forum', '0', '33', '33', 'en', '0', 'Morbi pharetra pharetra purus eu condimentum. Phasellus pulvinar imperdiet mi vitae pellentesque. Nullam sed urna porta ligula tempus venenatis a at metus. Proin feugiat nulla nec mi hendrerit ut iaculis purus pulvinar. Suspendisse id magna lacus, vel consequat arcu. Vestibulum non nulla felis, in tempor magna. Aliquam lacinia iaculis leo, eu consequat mauris molestie nec. Mauris facilisis facilisis eros, quis pretium ipsum consectetur quis. Vestibulum sed massa vitae felis porta elementum. Nulla facilisi. Sed turpis mi, ultrices sed blandit sit amet, rutrum et tellus. Proin luctus egestas turpis, eget luctus dolor mattis a. Nam sed rutrum diam. Sed quis nisl nisl, eu fringilla diam.\r\n\r\nAliquam vel euismod nulla. Aliquam erat volutpat. Fusce porta augue vitae felis dignissim pulvinar. Morbi non elit orci. Vestibulum erat libero, ultricies non egestas ut, aliquet in turpis. Aliquam erat volutpat. In mollis, neque a sodales convallis, nulla felis luctus nisl, non fringilla metus neque eu augue. Suspendisse lacinia enim a quam pretium tempus. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Mauris adipiscing ultrices nibh, interdum iaculis diam ultricies ut. Maecenas suscipit, enim a suscipit congue, ipsum mi tempor elit, pretium luctus lorem purus vestibulum diam. Etiam sodales turpis vel tortor sagittis sodales. Donec tellus turpis, consequat eget facilisis nec, interdum quis nulla. Proin bibendum mollis mattis. Proin at eros vitae nulla sagittis sollicitudin nec vel odio. Nam sed nibh vitae mauris viverra rhoncus. Aenean ut lectus eu massa gravida sodales id sed nulla. Donec semper justo facilisis mauris aliquam suscipit. Aenean ut dignissim est.', '', 'filtered_html'),
('node', 'forum', '0', '34', '34', 'en', '0', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam aliquet, ipsum eget sodales blandit, neque purus lacinia nulla, quis sagittis elit lectus fringilla massa. Donec commodo quam eget nunc vestibulum nec venenatis nibh iaculis. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Curabitur lobortis suscipit porttitor. Fusce massa elit, consequat eu tincidunt et, consectetur ut est. In ligula tortor, scelerisque a condimentum id, venenatis vel est. Donec laoreet dictum nisi eget egestas. Sed malesuada erat vel magna dictum sit amet volutpat sem ornare. Fusce bibendum, tellus sit amet elementum porta, ligula enim luctus orci, eget tristique magna eros sit amet sem. Phasellus placerat lacinia placerat. Sed porttitor, nulla quis ullamcorper tempor, risus erat sollicitudin enim, tincidunt iaculis massa mi sit amet dolor. Vivamus molestie odio ut velit pellentesque sagittis. In vitae turpis vel est semper eleifend.\r\n\r\nAenean quis mattis magna. In pulvinar interdum mauris in ornare. Fusce molestie erat id sapien aliquam pharetra. Suspendisse ornare tincidunt magna. Sed sed turpis justo. Donec eleifend, justo vel bibendum blandit, est sem tempus lorem, vel ultricies felis eros non est. Praesent ac dolor eu justo vestibulum dapibus. Maecenas id odio lectus, in interdum libero. In hac habitasse platea dictumst. Praesent sed urna turpis, sit amet auctor sem. Pellentesque sit amet ante sit amet diam imperdiet ultrices. Proin congue iaculis semper. Vivamus mi enim, dapibus quis laoreet at, hendrerit sit amet eros. Nulla ut lacinia nisi.', '', 'filtered_html'),
('node', 'forum', '0', '35', '35', 'en', '0', 'Aenean quis mattis magna. In pulvinar interdum mauris in ornare. Fusce molestie erat id sapien aliquam pharetra. Suspendisse ornare tincidunt magna. Sed sed turpis justo. Donec eleifend, justo vel bibendum blandit, est sem tempus lorem, vel ultricies felis eros non est. Praesent ac dolor eu justo vestibulum dapibus. Maecenas id odio lectus, in interdum libero. In hac habitasse platea dictumst. Praesent sed urna turpis, sit amet auctor sem. Pellentesque sit amet ante sit amet diam imperdiet ultrices. Proin congue iaculis semper. Vivamus mi enim, dapibus quis laoreet at, hendrerit sit amet eros. Nulla ut lacinia nisi.\r\n\r\nNullam eu erat nibh. Aliquam ipsum sapien, interdum a euismod vitae, vehicula pellentesque dolor. In sit amet eros pretium eros aliquet semper eget id massa. Donec malesuada rutrum est. Sed neque est, ultricies ac dictum at, tincidunt at arcu. In hac habitasse platea dictumst. Cras posuere convallis mattis. Quisque blandit ullamcorper ligula, dapibus tincidunt dolor lacinia non. Aliquam vitae nunc metus. Fusce nec sem sapien.\r\n\r\nMorbi pharetra pharetra purus eu condimentum. Phasellus pulvinar imperdiet mi vitae pellentesque. Nullam sed urna porta ligula tempus venenatis a at metus. Proin feugiat nulla nec mi hendrerit ut iaculis purus pulvinar. Suspendisse id magna lacus, vel consequat arcu. Vestibulum non nulla felis, in tempor magna. Aliquam lacinia iaculis leo, eu consequat mauris molestie nec. Mauris facilisis facilisis eros, quis pretium ipsum consectetur quis. Vestibulum sed massa vitae felis porta elementum. Nulla facilisi. Sed turpis mi, ultrices sed blandit sit amet, rutrum et tellus. Proin luctus egestas turpis, eget luctus dolor mattis a. Nam sed rutrum diam. Sed quis nisl nisl, eu fringilla diam.', '', 'filtered_html'),
('node', 'article', '0', '36', '36', 'en', '0', '<p>Aenean placerat tortor ac dui luctus ut mattis est mollis. Donec blandit orci id velit cursus varius. Fusce quam enim, <a href="#">hendrerit nec ultrices</a> a, vestibulum nec enim. Quisque imperdiet ultricies dolor in convallis. Morbi sed fringilla elit. Duis sagittis lectus in orci volutpat elementum. Cras in purus sem. Curabitur augue velit, mollis in suscipit eleifend, faucibus ac elit. Morbi mattis tristique mi, quis lobortis nulla sollicitudin quis. Cras adipiscing enim neque, ut ultrices risus. Pellentesque auctor felis eu nibh volutpat ac malesuada elit blandit. Pellentesque porta felis vel sapien tincidunt rhoncus. Nunc sit amet dui eget odio blandit sagittis. Duis tempus egestas justo vitae rhoncus. Sed mollis, risus in aliquet tincidunt, nisl nunc imperdiet eros, nec dictum ante est at ante. Nunc ullamcorper gravida porttitor. Sed sollicitudin dui vestibulum nisl condimentum at viverra urna dictum. Curabitur felis ligula, mattis ornare rhoncus eget, porta non urna. Nullam non porta est. Vestibulum pretium quam et purus tempus fringilla. Etiam vitae nulla turpis, at interdum erat. Pellentesque aliquet lorem id nunc suscipit pretium. Maecenas vitae erat in erat bibendum tincidunt sit amet eget dolor. Maecenas ultricies nulla et felis rhoncus tincidunt.</p><p>Vestibulum sed arcu nunc. Ut augue felis, elementum ut dapibus posuere, pulvinar at lorem. Class aptent taciti sociosqu ad litora torquent per conubia nostra, <a href="#">per inceptos himenaeos</a>. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Duis dignissim, urna at tincidunt aliquam, sem est scelerisque nibh, nec convallis risus nisl in justo. Suspendisse imperdiet consequat gravida. Curabitur odio velit, tempor ac cursus ut, tempor eu sem. Donec consequat magna purus. In ac leo nulla. Morbi scelerisque ligula quam, consectetur sodales lacus. Sed viverra rutrum est quis tempor.</p><p>In non posuere mauris. Nullam odio tortor, suscipit at semper ut, tempus consectetur tellus. Morbi congue egestas est. Proin tortor mi, tempor sit amet pretium eget, sollicitudin quis elit. Nam massa nisi, viverra in gravida et, tincidunt in elit. Duis nec massa a tortor iaculis aliquam eu vel ante. Duis sagittis consequat imperdiet. Donec metus eros, blandit et vestibulum eget, vehicula at libero. Proin molestie odio vitae odio porta sagittis. Vivamus eu lorem in purus viverra viverra sit amet et orci. Nulla adipiscing neque ut leo ornare faucibus. Cras vel augue enim. Quisque vel volutpat nisl. Proin ullamcorper ultrices faucibus.</p>', '', 'filtered_html'),
('node', 'blog', '0', '37', '37', 'en', '0', '<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Aenean tristique porta ligula, ac elementum felis faucibus vel. Duis in nunc nibh. Aenean dictum lorem non diam ultricies non laoreet dolor auctor. Vestibulum blandit ante non turpis tristique tincidunt. In adipiscing vulputate tortor at accumsan. Curabitur convallis eros sit amet dolor interdum varius. Donec a dolor velit. Aliquam rhoncus sagittis vestibulum. Praesent arcu turpis, lobortis nec aliquet vitae, feugiat quis ipsum.</p><p>Quisque et tellus sit amet mauris luctus dignissim eu quis augue. Vestibulum velit nulla, consectetur vel viverra eu, ultricies sed felis. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Pellentesque id eros et tortor malesuada consequat. Sed commodo sem id diam varius luctus. Morbi justo augue, hendrerit a blandit in, hendrerit facilisis risus. Praesent sed massa tortor. Nam quis sollicitudin sapien. In eu consectetur dolor. Nulla aliquet egestas lacus eget pulvinar. Donec at blandit lorem. Pellentesque ac ipsum purus. Pellentesque tincidunt congue fringilla. Fusce tincidunt mauris et lorem pellentesque faucibus.</p><p>Curabitur adipiscing consectetur arcu, ut vulputate magna tincidunt a. Nam semper commodo nibh, sit amet suscipit lacus convallis vitae. Fusce sit amet sapien pharetra neque consectetur semper quis nec lacus. Morbi a metus non urna pellentesque vestibulum. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Pellentesque imperdiet elit sodales urna egestas molestie. Nulla eu nisi sed eros lacinia cursus ut in dolor. Nunc ut sapien metus, fermentum tincidunt tellus. Duis nec diam mi. Etiam a ligula quis augue scelerisque tincidunt ullamcorper et arcu. Donec aliquet nulla quis dui sodales hendrerit a sed neque.</p><p>Vivamus velit velit, rutrum vitae ultrices eu, facilisis a nisl. Proin velit ipsum, porttitor et vestibulum quis, luctus id augue. Curabitur metus mauris, tincidunt non accumsan ac, iaculis id est. Quisque venenatis magna quis quam adipiscing eget eleifend lorem lacinia. Praesent quis tellus non lorem tempus rhoncus vitae in velit. Praesent vestibulum tempus tempus. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Aenean consequat, tellus in imperdiet faucibus, nibh nisi vehicula metus, eu posuere est sapien adipiscing lacus. Mauris dolor eros, porttitor vitae rhoncus vel, condimentum quis neque. Fusce sodales risus ac sem facilisis ultricies. Maecenas in leo arcu.</p>', '<div>dolore ipsim commete</div>', 'filtered_html'),
('node', 'blog', '0', '38', '38', 'en', '0', '<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur eu elit sed nunc porta molestie vel vitae odio. Donec ut arcu in justo mollis consectetur vel a elit. Curabitur iaculis turpis pellentesque nibh ornare sit amet faucibus quam egestas. Vestibulum lacinia posuere vehicula. Ut eget nulla ut mi pellentesque vehicula. Suspendisse luctus semper ipsum, vel dapibus sem sagittis quis. Nulla vehicula tincidunt libero vitae molestie. Duis et diam ante, nec ultrices eros. Nullam volutpat auctor dolor in interdum. Ut augue sapien, rutrum non tempor id, feugiat in enim. Suspendisse fringilla, magna et vulputate sollicitudin, urna est sollicitudin arcu, eu pretium diam lorem et massa. Vestibulum congue ante ac erat placerat sollicitudin. Donec eget ipsum sit amet libero suscipit aliquam.</p><p>In fringilla, sapien ut consequat dictum, mi enim tincidunt tortor, id tristique dui diam congue erat. Vivamus massa lectus, placerat non adipiscing id, varius eu metus. Nunc arcu augue, aliquet vitae suscipit id, tincidunt sit amet mauris. Nulla eu nibh quis nisl convallis blandit. Sed rhoncus gravida magna ut aliquet. Phasellus consectetur, turpis in convallis rhoncus, mauris orci tincidunt leo, in rutrum purus purus vitae justo. Duis aliquet dolor ut sapien ullamcorper id feugiat nunc interdum. Maecenas id augue sed tellus rutrum pellentesque. Cras vulputate placerat adipiscing. Nulla sed semper lacus. In sollicitudin molestie felis id sollicitudin. Aliquam congue tellus eget ipsum consectetur non feugiat arcu aliquam. Sed pharetra, lacus ac placerat consectetur, magna elit posuere mauris, a dapibus neque augue quis est. Mauris id justo sed dui tincidunt adipiscing. Nam porta nisl in sem dignissim cursus.</p><p>Duis et eros odio. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Cras lorem nulla, dictum eu consequat et, adipiscing eu mi. Vivamus tincidunt sem consectetur urna mollis laoreet. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Praesent vel risus massa, non suscipit sem. Sed malesuada magna et mauris vestibulum blandit. Donec ornare viverra nisi sed eleifend. Duis in tortor tortor, dictum adipiscing est.</p><p>Nunc sed nunc est. Vivamus porttitor interdum odio, tempus semper libero elementum sit amet. Sed ac eros lacus. Sed urna mi, fermentum sit amet tempus sit amet, varius ac odio. Morbi vehicula magna eu nibh dignissim sit amet sagittis nulla porta. Ut ultricies mi mauris. Donec vel vulputate justo. Nulla et tellus lorem. Integer sed magna eget quam malesuada dapibus. Nulla in magna eu erat sagittis lobortis. Mauris a lorem non dolor vestibulum ultrices. Proin turpis dolor, porta eget feugiat nec, bibendum id velit. Aenean molestie nisl id arcu viverra accumsan. Aliquam egestas purus sit amet sem pharetra sed molestie justo malesuada. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus eu urna nec odio malesuada sollicitudin nec ut nunc.</p>', '<div>dolore ipsim commete</div>', 'filtered_html'),
('node', 'blog', '0', '39', '39', 'en', '0', '<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam aliquet pellentesque cursus. Curabitur porta condimentum metus sed consequat. Nulla at mauris eget massa feugiat placerat nec id enim. Cras sollicitudin quam a est ullamcorper eleifend. Proin posuere rutrum urna sed porttitor. Pellentesque aliquam convallis molestie. Donec ut dolor enim, nec pretium felis. Nunc id dui quam, sed molestie libero. Quisque consequat vulputate neque, ultrices tincidunt lacus scelerisque vitae.</p><p>Proin imperdiet, turpis eu gravida vestibulum, ante nisl accumsan sapien, in vestibulum risus dolor interdum purus. Aenean fringilla, justo et aliquet eleifend, urna eros faucibus urna, et pellentesque neque nisl ut risus. Aliquam adipiscing tempor nisi, id porttitor sapien molestie in. Curabitur felis massa, volutpat quis gravida euismod, commodo sit amet arcu. Cras mattis, nisl sit amet egestas tempus, urna quam ultrices augue, nec sodales sapien leo at mauris. In hac habitasse platea dictumst. Etiam facilisis, ligula tempor cursus adipiscing, nisi arcu ullamcorper risus, eget gravida felis odio sit amet erat.Morbi quis dictum libero. Nulla orci lectus, venenatis at mattis non, venenatis eget nunc. Pellentesque vel sapien mauris, at aliquam dui. Etiam fringilla magna nec turpis placerat et posuere quam aliquet. Donec sit amet massa sit amet leo egestas sagittis at a nibh. Vestibulum vitae quam eget tellus scelerisque volutpat vel sit amet nisl. Aliquam vel metus lectus. Pellentesque vitae semper sem. Sed tempor malesuada arcu id tincidunt. Ut tincidunt ullamcorper justo ac euismod. Maecenas a lectus porta nulla semper porta. Ut quis eros elit.</p><p>Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Morbi sagittis ante eu arcu molestie ac fringilla odio vulputate. Nulla sit amet arcu vel sem euismod dictum. Integer nisi urna, consectetur et rhoncus sit amet, semper eu tellus. Pellentesque blandit vestibulum leo ut laoreet. Phasellus sit amet justo ornare dolor consequat rutrum et non elit. Ut rutrum viverra neque non hendrerit. Phasellus nibh mi, pharetra nec tempor sed, faucibus ut felis. Ut quis nisl est. Sed condimentum, urna at elementum placerat, justo arcu iaculis dolor, quis rutrum sapien turpis ac arcu.</p>', '<div>dolore ipsim commete</div>', 'filtered_html'),
('node', 'blog', '0', '40', '40', 'en', '0', '<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nunc dolor metus, pulvinar ac viverra id, porttitor sed lorem. Morbi tincidunt accumsan nisi in mollis. Quisque placerat dictum facilisis. Nam lobortis pharetra libero, vitae facilisis justo tempus gravida. Donec convallis euismod nisi, vitae pellentesque lacus iaculis vulputate. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Phasellus pretium lobortis est at varius. Donec viverra consequat leo, et lobortis ipsum convallis in. Nam commodo ipsum quis risus ultricies at gravida leo varius. Pellentesque at velit ac sem scelerisque blandit et vel lectus. Aenean rhoncus odio eu leo fermentum tincidunt. Fusce sed urna eget nisi congue ornare vestibulum sed ligula. Suspendisse potenti. Sed dapibus, odio vel facilisis rhoncus, leo nunc interdum quam, sed commodo nisl tortor a velit. Etiam orci nisi, pretium a malesuada mattis, adipiscing sed ante.</p><p>Pellentesque at egestas nulla. Morbi justo nunc, scelerisque at pretium ac, tempus quis est. Nunc sodales, ante et mollis cursus, dolor libero rhoncus magna, sed semper augue erat ac nulla. Nulla facilisi. Duis suscipit ipsum a sapien viverra scelerisque. Duis rhoncus est nec augue vulputate vestibulum. Nunc erat mauris, laoreet eu blandit eget, auctor nec dui.</p><p>Suspendisse potenti. Duis congue porta neque id elementum. Etiam ultricies eleifend lorem, in viverra sapien suscipit sed. Ut faucibus imperdiet lacus, a egestas nulla ultrices iaculis. Sed purus lacus, placerat et tempus at, egestas eu libero. In varius turpis vitae orci commodo eu lacinia erat sollicitudin. Nullam lacus ante, gravida vel rutrum sed, semper in dui. Pellentesque volutpat congue dui ut sodales. Phasellus laoreet, velit ut convallis sollicitudin, nunc elit dapibus lectus, sit amet molestie ligula tellus a est. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Sed est nibh, tempus eu ultrices quis, consectetur nec est. Maecenas auctor quam et justo pretium et pulvinar nulla dignissim. Praesent facilisis, nulla quis rutrum aliquet, lorem sem tincidunt nulla, ac bibendum est lectus viverra felis. Phasellus bibendum, justo nec placerat aliquam, massa erat aliquam sem, bibendum mollis odio odio vitae augue. Vivamus non enim nisi, mattis convallis nulla.</p><p>Sed id orci eu mauris posuere fringilla. Pellentesque tincidunt molestie porta. Aenean eget viverra magna. Cras commodo nibh id justo dictum vulputate. Nam venenatis leo vel nisi fringilla at pellentesque orci pharetra. Fusce turpis tortor, mollis sed iaculis et, eleifend sit amet dolor. Aliquam consectetur tempor fringilla. Aenean nisl nulla, faucibus quis dictum in, viverra et arcu. Curabitur eget augue nec risus semper tristique.</p>', '<div>dolore ipsim commete</div>', 'filtered_html'),
('node', 'blog', '0', '41', '41', 'en', '0', '<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Quisque cursus, sem eget sagittis sagittis, nisl magna sodales eros, ut feugiat velit velit non turpis. Cras eu nibh dapibus justo fringilla bibendum. Donec eget aliquam massa. Etiam ac dui felis, sed eleifend mi. Suspendisse consequat urna ac orci mattis consequat. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. In mattis mattis eleifend. Donec leo odio, fringilla nec lacinia in, dignissim molestie erat. Integer dui ipsum, semper sed mattis quis, convallis consequat magna. Quisque quis arcu justo, nec laoreet lacus. In vulputate malesuada auctor. Suspendisse pharetra, diam eu auctor vestibulum, orci sem mattis neque, eget facilisis neque risus vitae libero.</p><p>Duis tincidunt, orci ut porttitor sollicitudin, urna risus porttitor urna, sit amet varius eros enim eu orci. Pellentesque non mauris eget ipsum tristique luctus quis eu orci. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Ut nunc enim, pretium vel blandit ac, euismod eget felis. Aenean sed purus nibh, adipiscing pharetra dui. Aenean sed mauris dui. Etiam tincidunt ornare velit ut ornare. Maecenas ac arcu a orci aliquet accumsan sit amet sit amet augue. Curabitur turpis sem, iaculis et dapibus ac, placerat in quam.</p><p>Proin congue, neque sed sagittis facilisis, enim purus hendrerit orci, in blandit nulla elit eget velit. Sed congue, justo vitae imperdiet condimentum, nisi eros imperdiet tellus, in iaculis tortor velit gravida neque. Etiam convallis nisi tincidunt nisi mollis non pretium elit interdum. Mauris adipiscing, ante ut hendrerit sodales, ante enim commodo enim, sed posuere lacus arcu non est. Donec nibh augue, accumsan at tristique ut, luctus non sem. Nulla ac enim non sapien aliquam interdum. Fusce scelerisque semper massa, sit amet tristique turpis semper sit amet. Aenean adipiscing mauris lorem, et ultrices leo. Maecenas et felis eu turpis feugiat convallis. Phasellus sit amet ipsum quis dolor rhoncus aliquet ac id quam. Nunc ultricies ipsum a tortor tristique eleifend non eget nunc. Praesent vestibulum placerat felis et eleifend. Sed ut commodo diam. Donec et nunc massa, sit amet rutrum diam. Fusce vulputate fermentum dapibus.</p><p>Proin convallis condimentum tortor. Vivamus ut erat at neque consequat bibendum. Integer id libero eget mi semper hendrerit ac et odio. Vestibulum sodales quam quis ante auctor accumsan. Vivamus viverra porta nunc aliquam lobortis. Phasellus porttitor porta massa nec mollis. Vivamus sodales condimentum sem et volutpat. Aliquam erat volutpat. Curabitur accumsan interdum justo, eget cursus dolor ultrices et. Nam dolor orci, dapibus sed facilisis eu, laoreet a nisi. Sed nec nunc sit amet urna viverra dapibus eget a libero. Cras lacinia blandit magna in accumsan. Suspendisse quis dui vel dolor scelerisque tristique. Donec pellentesque scelerisque semper.</p>', '<div>dolore ipsim commete</div>', 'filtered_html'),
('node', 'faq', '0', '42', '42', 'en', '0', 'Suspendisse sem justo, commodo et tristique in, aliquet in nibh. Ut bibendum blandit lacus. Integer sodales, odio sed facilisis adipiscing, felis magna sagittis mauris, sit amet placerat sem nunc vitae velit. Ut sollicitudin augue non tortor semper ultrices. Curabitur libero neque, ultrices feugiat laoreet a, volutpat nec erat. ', '', 'filtered_html'),
('node', 'faq', '0', '43', '43', 'en', '0', 'Aliquam erat volutpat. Donec dapibus nisl sit amet purus vehicula condimentum pulvinar felis cursus. Sed tellus dui, vulputate quis porttitor a, consequat vel lectus. Cras rutrum, lacus vel posuere sodales, turpis elit pretium elit, malesuada aliquam sapien nibh vitae tortor. Vivamus viverra blandit nibh, faucibus hendrerit orci ultrices id.', '', 'filtered_html'),
('node', 'faq', '0', '44', '44', 'en', '0', 'Suspendisse ornare dapibus nisi, vel placerat metus varius non. Cras tellus libero, condimentum a pharetra ac, aliquet at massa. Phasellus ullamcorper varius velit, in hendrerit magna convallis et. Donec porta, enim id tempor varius, tortor diam porttitor odio, at ultricies tellus dui vitae ante. Ut ut enim quam, at consectetur leo.', '', 'filtered_html'),
('node', 'faq', '0', '45', '45', 'en', '0', 'Donec id tortor sit amet enim ornare pretium. Vestibulum felis diam, hendrerit non ornare quis, eleifend quis erat. Quisque et dui sapien, sit amet ultrices odio. Nullam faucibus bibendum felis. Nullam bibendum, turpis et sollicitudin ullamcorper, dui magna dictum turpis, vitae pulvinar lorem orci sed neque. Duis sem leo, rutrum quis tempus eu, volutpat luctus felis. Nulla convallis congue molestie.', '', 'filtered_html'),
('node', 'faq', '0', '46', '46', 'en', '0', 'Phasellus ornare sapien at purus fringilla pellentesque. Ut laoreet gravida risus, eu bibendum lacus mattis eu. Praesent ac pulvinar lectus. Proin eu venenatis eros. Vestibulum id lectus vitae erat eleifend semper et in tortor. Donec venenatis ante eu diam fringilla fermentum. Integer pharetra tellus at erat bibendum sed facilisis velit molestie.', '', 'filtered_html'),
('node', 'slider', '0', '47', '47', 'en', '0', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam neque nisi, interdum ac porta non, condimentum eu tellus. Nunc rhoncus sem quis metus cursus sagittis. Nulla risus massa, sagittis eu lobortis quis, molestie ac urna. Etiam a nisi risus. Proin lacinia auctor dapibus. Mauris sit amet dignissim lectus. Praesent dignissim dui id dui accumsan molestie. Nulla luctus nulla vitae purus posuere in gravida ante vulputate. Quisque faucibus pellentesque risus, a euismod sapien laoreet non. Praesent aliquet mattis neque, quis euismod libero ultricies quis. Maecenas nec urna a lacus ultricies tristique. Sed a massa et dolor feugiat commodo. Praesent sed risus mollis eros sagittis hendrerit.\r\n\r\nProin mattis enim ut arcu elementum ornare pharetra eget ligula. Donec et ante a diam scelerisque fringilla. Quisque nunc ipsum, laoreet eget pellentesque eu, sodales vitae massa. Phasellus non neque in lacus imperdiet varius. Aliquam suscipit, libero non sodales lobortis, erat enim rutrum lacus, id malesuada enim neque commodo risus. In sed erat nisi, non porttitor ante. Maecenas at lorem lacus, eget feugiat justo. Nam lacinia ligula eget ante malesuada luctus. Sed posuere dui quis lectus mollis volutpat. Vivamus suscipit blandit urna sit amet lobortis. Phasellus et elit magna, in molestie nisi. Curabitur mattis nunc et nunc tristique porttitor a cursus lorem. Vestibulum non venenatis nibh. Aenean ultricies, justo in tempus rhoncus, mi eros luctus elit, vel volutpat tellus felis eu ligula. Vivamus mattis orci a nunc commodo fringilla ut eget lacus. Proin vestibulum suscipit tincidunt. Duis dictum aliquet scelerisque. Praesent a tortor purus. ', '<div>Sed utem perspiciatis</div>', 'full_html'),
('node', 'slider', '0', '50', '50', 'en', '0', 'Aliquam erat volutpat. Praesent quis nibh nisl. Cras at libero quam, ut tincidunt diam. Fusce aliquet augue a ipsum ullamcorper semper. Suspendisse potenti. Proin id eros eu lectus blandit suscipit id eget tortor. Nulla augue purus, molestie accumsan ullamcorper ut, dictum sit amet erat. Proin eu leo eros, eu tincidunt lorem. Donec sit amet mauris vitae felis viverra tristique. Mauris varius ante eu ante tincidunt aliquam. Etiam porttitor facilisis molestie. Etiam at tellus eu lacus volutpat suscipit. Nam blandit elit dignissim risus consequat egestas. Proin blandit, turpis ut facilisis aliquet, dui quam fringilla dolor, id rutrum nisi urna ac nunc. Nulla congue justo quis magna laoreet vitae fringilla est venenatis. Cras blandit ante eget turpis eleifend rutrum.\r\n\r\nSed non quam nec tortor molestie luctus nec sit amet massa. Nulla tincidunt orci sit amet nisl eleifend pretium. Donec sit amet libero nec nunc tristique vulputate. Vestibulum vel lectus massa. Curabitur consequat, justo nec bibendum dignissim, felis ipsum pharetra nunc, non eleifend dui diam at ipsum. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Etiam nec justo eu magna lacinia sollicitudin at quis odio. Nullam dui enim, iaculis eu egestas a, volutpat at tortor. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Cras vitae urna sit amet turpis lobortis tristique. Nullam eget orci id massa tempus auctor. Vivamus commodo porta magna non adipiscing. Cras id risus eu tellus mollis malesuada id in orci. Etiam mi magna, gravida id ultrices vel, sollicitudin nec sapien. Curabitur a euismod dui. Fusce vestibulum consequat imperdiet. Ut molestie eros ac lorem eleifend vitae pretium nunc porttitor. ', '<div>Praesent vestibulum</div>', 'full_html'),
('node', 'slider', '0', '51', '51', 'en', '0', 'Curabitur nunc lacus, fermentum eget rhoncus interdum, pellentesque sed dui. Nulla lobortis bibendum ante non malesuada. Aliquam eget condimentum augue. In et libero orci. Praesent ut augue et est interdum blandit tempor in felis. Vivamus laoreet sem sed velit malesuada posuere. Cras dolor augue, commodo non auctor nec, ornare in ipsum. Aenean et urna purus. Integer ac nisl risus, sed interdum libero. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Nullam a ligula quis diam auctor laoreet. Vivamus molestie suscipit malesuada.\r\n\r\nPellentesque tempus lacus in arcu venenatis eget ullamcorper ante euismod. Fusce condimentum, ligula in congue tincidunt, lectus eros hendrerit nibh, id hendrerit dui quam sit amet velit. Pellentesque pretium, magna ac aliquam feugiat, ligula felis mollis enim, nec lacinia ipsum nibh non neque. Aliquam vulputate massa quis lacus porttitor non malesuada dui auctor. Sed bibendum faucibus erat, eu mollis nunc fermentum ut. Nullam vitae pharetra ante. Maecenas viverra fringilla metus, a posuere ligula elementum sit amet. Aenean elit leo, dapibus et vestibulum eu, tristique sit amet ante. In id mi et leo tristique ultrices. In ac lacus nulla. Proin arcu massa, imperdiet eget interdum vel, ultrices eget sapien. Donec vestibulum aliquet leo eu tristique. Cras dolor quam, bibendum non ullamcorper sit amet, aliquam ac elit. ', '<div>Lorem ipsum dolor</div>', 'full_html'),
('node', 'portfolio', '0', '52', '52', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>', '', 'full_html'),
('node', 'portfolio', '0', '53', '53', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>', '', 'full_html'),
('node', 'portfolio', '0', '54', '54', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>', '', 'full_html'),
('node', 'portfolio', '0', '55', '55', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>', '', 'full_html'),
('node', 'portfolio', '0', '56', '56', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>', '', 'full_html'),
('node', 'portfolio', '0', '57', '57', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>', '', 'full_html'),
('node', 'portfolio', '0', '58', '58', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>', '', 'full_html'),
('node', 'employee', '0', '65', '65', 'en', '0', '<p>Curabitur mauris tortor, laoreet et consectetur non, <a href="#">rhoncus sed risus</a>. Donec nisi enim, adipiscing <strong>quis convallis</strong> eu, elementum a urna. Maecenas sit amet metus sem. Sed non est ligula, sit amet vehicula nunc. Maecenas sed quam non urna tincidunt pellentesque ac ut enim. Vestibulum arcu tortor, vulputate nec semper id, commodo eget lacus. Integer mi dolor, malesuada in ullamcorper ut, tincidunt eu arcu. Mauris dictum, libero id rutrum vehicula, est l<strong>igula sagittis urna</strong>, ut convallis purus <strong>purus at dolor</strong>. <em>Praesent nec vehicula</em> tortor. Nulla facilisi. Curabitur mauris sapien, interdum id consequat et, lobortis ut ipsum. Vestibulum tempus augue eu est malesuada viverra. Nunc mattis fermentum metus, a consectetur magna egestas lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Morbi <em>non mauris ligula</em>. Suspendisse facilisis <a href="#">sagittis mauris</a>, ac dictum elit fringilla ut.</p>\r\n\r\n<p>Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Sed vel erat justo. In lorem augue, varius ut hendrerit a, gravida vel lectus. Donec fringilla metus in leo gravida facilisis. Suspendisse lacinia, leo quis auctor suscipit, massa sapien congue sem, sit amet tincidunt enim nibh eget neque. <strong>Proin semper placerat</strong> odio, sit amet vehicula mauris malesuada sed. Nulla facilisi.</p>\r\n\r\n<p>Quisque lectus dui, aliquet eu placerat eu, viverra at velit. Nunc sed magna ut tortor tempor mollis a eu justo. <a href="#">Fusce ultrices</a>, velit eget aliquam auctor, turpis dui tincidunt tellus, id porta libero mauris ac ligula. Donec rutrum est id nisl euismod facilisis. Quisque vitae justo sed sem blandit tincidunt. Phasellus condimentum luctus odio nec aliquam. Donec sed augue sem.</p>\r\n\r\n<p>Sed ullamcorper varius fermentum. Ut commodo quam non <strong>sapien pellentesque porta</strong>.<a href="#"> Vestibulum ante</a> ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Mauris mattis elit et neque congue mollis. Duis lacinia felis at purus hendrerit venenatis. Mauris placerat, nulla non faucibus cursus, mauris urna malesuada augue, vitae vestibulum erat nulla ac odio. Pellentesque enim felis, dictum in <strong>sodales sit amet, placerat non ante</strong>. Etiam <a href="#">dapibus leo ut tellus fermentum</a> a <em>bibendum augue molestie</em>. Maecenas auctor neque id ante bibendum fermentum. Aliquam dui magna, egestas vitae condimentum pharetra, imperdiet sed enim. Donec nisl mauris, facilisis hendrerit aliquam eu, rutrum vitae nisl. Nulla dui eros, vehicula facilisis ornare nec, commodo vitae velit. Sed at justo justo. Nunc justo dolor, condimentum vel dignissim id, malesuada et odio.</p>', '', 'full_html');
INSERT INTO `field_revision_body` VALUES
('node', 'employee', '0', '67', '67', 'en', '0', '<p>Ut a augue arcu, ut lacinia arcu. Maecenas blandit odio ac dui scelerisque vitae <a href="#">ullamcorper diam mattis</a>. Etiam pharetra interdum nunc eget elementum. Cras molestie, magna nec auctor cursus, est ante hendrerit libero, eget dignissim urna neque ac risus. Aenean cursus iaculis lacinia. Mauris sit amet felis pretium nulla <a href="#">volutpat vehicula</a> eu et turpis. Maecenas vehicula molestie felis, vitae feugiat lacus mollis faucibus. <strong>Suspendisse sollicitudin</strong> faucibus metus, non tristique justo fermentum vel. <strong>In ligula lacus, gravida</strong> a iaculis id, molestie id nibh. Maecenas suscipit auctor ullamcorper. Vivamus ut odio vel <a href="#">ligula pretium porta</a> a eget arcu. Ut tempus quam eget orci pharetra euismod. Donec id mi eu augue congue vulputate et in ipsum.</p>\r\n\r\n<p>Etiam cursus adipiscing auctor. Phasellus in arcu arcu, <strong>accumsan aliquam massa</strong>. Phasellus lacinia, nulla ut pellentesque viverra, dui odio tristique dolor, eu tincidunt purus sem a lectus. Duis ut sem neque. Duis <em>dignissim, leo nec egestas venenatis</em>, nulla est porta quam, eget commodo nulla turpis sit amet nibh. Ut in arcu eget massa scelerisque dapibus nec ut leo. Curabitur elementum, mauris ac egestas imperdiet, lorem <strong>lorem pellentesque leo</strong>, quis pulvinar <a href="#">nibh dui non massa</a>. Nam sed dapibus metus.</p>\r\n\r\n<p>Aliquam ultrices condimentum urna, id sagittis dui convallis ac. Nulla mollis placerat quam <a href="#">blandit ultricies</a>. Maecenas scelerisque molestie quam, id ornare urna ornare in. Maecenas libero quam, elementum in fringilla eget, tincidunt sit amet mi. Duis sagittis viverra tempus. <strong>Nam in elit orci</strong>, ac venenatis leo. <a href="#">Aenean auctor molestie</a> <strong>nulla, quis luctus</strong> urna vulputate at.</p>\r\n\r\n<p>Vestibulum mollis, nisl accumsan dignissim tristique, <strong>ipsum eros scelerisque tortor</strong>, in suscipit augue mi vitae nunc. Ut vel justo ligula, ut vehicula eros. Duis dictum commodo erat vestibulum consectetur. Nam porta sodales mauris, tristique mattis ante tincidunt eget. <strong>Maecenas ut aliquam risus</strong>. Sed porta porttitor rhoncus. Vestibulum dapibus vestibulum nulla, quis viverra magna pharetra a. Suspendisse elit velit, semper eget consequat at, imperdiet nec leo. Sed ipsum quam, gravida ac eleifend in, <a href="#">cursus eu tellus</a>. Suspendisse mattis lacus arcu, vitae mollis purus. Aliquam ut lorem turpis. In porttitor lectus non nibh dignissim quis fermentum nulla convallis.</p>', '', 'full_html'),
('node', 'employee', '0', '68', '68', 'en', '0', '<p>Aenean sodales dapibus massa, ut <a href="#">feugiat nulla ultrices</a> nec. Vestibulum <strong>at massa in mi scelerisque</strong> placerat ut id dolor. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Phasellus nibh velit, malesuada ut viverra at, ultrices quis libero. Phasellus lectus lacus, scelerisque a condimentum nec, <em>dignissim non felis</em>. Etiam aliquam, leo dictum fringilla elementum, nibh nulla volutpat felis, non ultricies ipsum tortor nec eros. Vivamus placerat, <strong>mi non gravida consequat, neque</strong> tellus congue augue, at molestie purus ligula id leo. Phasellus at diam arcu, quis accumsan enim. Donec gravida facilisis eros. Cras eu elit id lectus congue dapibus et sed mi. Duis scelerisque ligula <a href="#">at sem mollis sed posuere tellus</a> egestas. Donec vel fermentum felis. In hac habitasse platea dictumst. Pellentesque sit amet est at odio adipiscing rhoncus in laoreet enim.</p>\r\n\r\n<p>Nam sollicitudin, <a href="#">quam non pellentesque ornare</a>, dolor enim ornare dolor, sed aliquet neque tortor at risus. Cras et magna eget dui congue aliquam. Suspendisse quis ante non augue tincidunt ornare. Donec vitae lacus elit, ac suscipit justo. <strong>Vestibulum vel est neque, eu</strong> blandit nulla. <em>Phasellus non ornare neque</em>. In bibendum, lorem vitae vulputate posuere, quam purus ultricies lectus, in vehicula eros arcu a quam. Aliquam lacus ante, pharetra interdum egestas vitae, <strong>ultrices eget velit</strong>. Aliquam erat volutpat.</p>\r\n\r\n<p>Praesent mauris est, aliquam sit amet tincidunt sit amet, tristique non turpis. <strong>Aliquam eget quam tellus</strong>. Vivamus aliquam libero sit amet sapien ultricies aliquam. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris vestibulum egestas augue non fringilla. Fusce vel nibh <strong>ligula, nec molestie nisl</strong>. Integer sed massa <a href="#">arcu, non auctor</a> mi. Aenean nisi quam, sollicitudin at tincidunt sit amet, aliquet imperdiet neque.</p>\r\n\r\n<p>Ut a augue arcu, ut lacinia arcu. Maecenas blandit odio ac dui scelerisque vitae <a href="#">ullamcorper diam mattis</a>. Etiam pharetra interdum nunc eget elementum. Cras molestie, magna nec auctor cursus, est ante hendrerit libero, eget dignissim urna neque ac risus. Aenean cursus iaculis lacinia. Mauris sit amet felis pretium nulla <a href="#">volutpat vehicula</a> eu et turpis. Maecenas vehicula molestie felis, vitae feugiat lacus mollis faucibus. <strong>Suspendisse sollicitudin</strong> faucibus metus, non tristique justo fermentum vel. <strong>In ligula lacus, gravida</strong> a iaculis id, molestie id nibh. Maecenas suscipit auctor ullamcorper. Vivamus ut odio vel <a href="#">ligula pretium porta</a> a eget arcu. Ut tempus quam eget orci pharetra euismod. Donec id mi eu augue congue vulputate et in ipsum.</p>', '', 'full_html'),
('node', 'employee', '0', '69', '69', 'en', '0', '<p>Aenean sed fermentum metus. Integer imperdiet nisi vel lectus<strong> fermentum malesuada</strong>. Aliquam tincidunt tempus tempus. Aliquam euismod mauris non eros facilisis nec sagittis ipsum rutrum. Curabitur venenatis molestie eros, vitae sagittis quam viverra a.<a href="#"> Duis vel augue vel metus</a> tempus <em>malesuada</em> <em>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut vulputate, metus at vulputate mattis, nibh lorem molestie ligula, sed tempor enim mi vel augue.</em></p>\r\n\r\n<p>Aenean sodales dapibus massa, ut <a href="#">feugiat nulla ultrices</a> nec. Vestibulum <strong>at massa in mi scelerisque</strong> placerat ut id dolor. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Phasellus nibh velit, malesuada ut viverra at, ultrices quis libero. Phasellus lectus lacus, scelerisque a condimentum nec, <em>dignissim non felis</em>. Etiam aliquam, leo dictum fringilla elementum, nibh nulla volutpat felis, non ultricies ipsum tortor nec eros. Vivamus placerat, <strong>mi non gravida consequat, neque</strong> tellus congue augue, at molestie purus ligula id leo. Phasellus at diam arcu, quis accumsan enim. Donec gravida facilisis eros. Cras eu elit id lectus congue dapibus et sed mi. Duis scelerisque ligula <a href="#">at sem mollis sed posuere tellus</a> egestas. Donec vel fermentum felis. In hac habitasse platea dictumst. Pellentesque sit amet est at odio adipiscing rhoncus in laoreet enim.</p>\r\n\r\n<p>Nam sollicitudin, <a href="#">quam non pellentesque ornare</a>, dolor enim ornare dolor, sed aliquet neque tortor at risus. Cras et magna eget dui congue aliquam. Suspendisse quis ante non augue tincidunt ornare. Donec vitae lacus elit, ac suscipit justo. <strong>Vestibulum vel est neque, eu</strong> blandit nulla. <em>Phasellus non ornare neque</em>. In bibendum, lorem vitae vulputate posuere, quam purus ultricies lectus, in vehicula eros arcu a quam. Aliquam lacus ante, pharetra interdum egestas vitae, <strong>ultrices eget velit</strong>. Aliquam erat volutpat.</p>', '', 'full_html'),
('node', 'employee', '0', '71', '71', 'en', '0', '<p>Sed ullamcorper varius fermentum. Ut commodo quam non <strong>sapien pellentesque porta</strong>.<a href="#"> Vestibulum ante</a> ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Mauris mattis elit et neque congue mollis. Duis lacinia felis at purus hendrerit venenatis. Mauris placerat, nulla non faucibus cursus, mauris urna malesuada augue, vitae vestibulum erat nulla ac odio. Pellentesque enim felis, dictum in <strong>sodales sit amet, placerat non ante</strong>. Etiam <a href="#">dapibus leo ut tellus fermentum</a> a <em>bibendum augue molestie</em>. Maecenas auctor neque id ante bibendum fermentum. Aliquam dui magna, egestas vitae condimentum pharetra, imperdiet sed enim. Donec nisl mauris, facilisis hendrerit aliquam eu, rutrum vitae nisl. Nulla dui eros, vehicula facilisis ornare nec, commodo vitae velit. Sed at justo justo. Nunc justo dolor, condimentum vel dignissim id, malesuada et odio.</p>\r\n\r\n<p>Nulla ultricies enim aliquet augue eleifend iaculis. Nam sollicitudin <strong>ligula ac nisi</strong> iaculis eu scelerisque risus ultricies. Nullam eu elit risus, vel interdum urna. Aenean leo nulla, aliquet vitae ultricies sit amet, porttitor id sapien. In hac habitasse platea dictumst. Donec pharetra gravida augue at hendrerit. Cras ut sagittis justo. Maecenas velit elit, eleifend sed sollicitudin sed, interdum eu erat. Duis rhoncus <a href="#">libero vitae orci</a> interdum vehicula. Sed sodales tellus <strong>at justo interdum</strong> aliquet.</p>\r\n\r\n<p>Proin dolor justo, molestie ac suscipit vel, faucibus nec eros. <strong>Phasellus congue ornare</strong> ipsum, non pellentesque orci luctus in. Sed ligula lorem, <strong>commodo in suscipit</strong> eget, bibendum nec sapien. Duis tincidunt, magna ac ullamcorper euismod, leo lectus ultricies nibh, ut placerat lectus risus vitae orci. Duis tincidunt, dolor vel <a href="#">fermentum eleifend</a>, justo tortor pellentesque turpis, at tincidunt metus metus et velit. Vivamus semper lacinia sodales. Sed ultrices <a href="#">metus tincidunt ante rutrum</a> tincidunt. <strong>Nulla dignissim orci eu ante</strong> dapibus pulvinar. Integer nibh neque, eleifend et egestas eget, suscipit ut purus. Vestibulum pharetra, ante sed mollis vestibulum, arcu turpis dapibus nunc, quis dictum erat nisl sed ante. Fusce est ipsum, suscipit sed aliquet ut, hendrerit eget nisi.</p>\r\n\r\n<p>Pellentesque auctor nisl eget mi accumsan auctor. Vivamus <strong>tempor magna eget tellus</strong> elementum a dignissim felis aliquam. <a href="#">Donec faucibus sem quis</a> nibh iaculis scelerisque aliquet leo eleifend. Fusce accumsan, mauris ut placerat mattis, magna mauris ultricies magna, fermentum <strong>hendrerit nunc turpis quis</strong> mi. Suspendisse cursus arcu eu nunc faucibus in dictum ligula viverra. Donec non semper leo. Sed quis enim arcu, pellentesque vestibulum risus. Ut elit nulla, commodo ac sagittis non, dapibus ut elit. Nunc <em>dignissim lacinia sapien</em> nec blandit.</p>', '', 'full_html'),
('node', 'employee', '0', '73', '73', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>\r\n\r\n<p>Curabitur mauris tortor, laoreet et consectetur non, <a href="#">rhoncus sed risus</a>. Donec nisi enim, adipiscing <strong>quis convallis</strong> eu, elementum a urna. Maecenas sit amet metus sem. Sed non est ligula, sit amet vehicula nunc. Maecenas sed quam non urna tincidunt pellentesque ac ut enim. Vestibulum arcu tortor, vulputate nec semper id, commodo eget lacus. Integer mi dolor, malesuada in ullamcorper ut, tincidunt eu arcu. Mauris dictum, libero id rutrum vehicula, est l<strong>igula sagittis urna</strong>, ut convallis purus <strong>purus at dolor</strong>. <em>Praesent nec vehicula</em> tortor. Nulla facilisi. Curabitur mauris sapien, interdum id consequat et, lobortis ut ipsum. Vestibulum tempus augue eu est malesuada viverra. Nunc mattis fermentum metus, a consectetur magna egestas lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Morbi <em>non mauris ligula</em>. Suspendisse facilisis <a href="#">sagittis mauris</a>, ac dictum elit fringilla ut.</p>', '', 'full_html'),
('node', 'services', '0', '76', '76', 'en', '0', '<p>Nulla at tortor quam, eu ultricies nulla. Maecenas viverra, leo vitae mattis iaculis, nisi nunc semper ligula, eget lobortis est orci et tortor. Maecenas vitae sapien magna, nec malesuada nisi. Proin tempus felis et dolor accumsan id ultrices erat luctus. Duis porta lorem sed est scelerisque tincidunt. Cras nulla magna, accumsan ac commodo in, scelerisque sit amet leo. Nullam sed odio lorem, eu commodo dui. Quisque non justo est, at accumsan nulla. Vivamus ac purus sed nunc cursus hendrerit. Suspendisse nunc mauris, tempus non pretium nec, aliquam ac turpis.</p><p>Curabitur neque dui, viverra et varius et, blandit eget lectus. Etiam augue dolor, facilisis eu convallis ut, rhoncus ut leo. Fusce vitae dictum diam. Aliquam erat volutpat. <a href="#">Duis vehicula ullamcorper elementum</a>. Aliquam iaculis est eu velit faucibus convallis. Aenean ac lacus nec odio cursus aliquet a id urna. Praesent quam elit, malesuada quis accumsan eget, tempus vel quam. Donec adipiscing leo quis sapien suscipit ac bibendum felis posuere. Quisque interdum metus ut eros laoreet ut viverra magna vestibulum. Ut quis diam ligula. Cras mauris sem, malesuada vitae gravida et, condimentum in ante. Pellentesque vel nisi enim, ac varius mi. Duis sem leo, interdum a mollis ut, tempor quis lacus. Sed fringilla est nec ipsum mattis tempus.</p><p>Nulla elementum tincidunt est in dignissim. Cras consequat neque in mi commodo eleifend. Nunc laoreet augue risus, eget consequat leo. Cras enim sapien, blandit vel eleifend sit amet, mattis rutrum neque. Phasellus sed magna quis quam tincidunt porta. Aliquam eget dolor neque, a convallis turpis. Praesent volutpat tristique arcu, sed suscipit magna commodo hendrerit. <a href="#">Curabitur lorem velit</a>, tempor at ultricies eu, feugiat quis dui. Vestibulum gravida vulputate lacus sit amet hendrerit. Sed fringilla, arcu a tempus molestie, diam purus ultrices magna, a convallis risus lorem vitae est. Sed nec neque elit. Donec nec adipiscing velit. Pellentesque ut mauris urna, et volutpat libero. Nulla facilisi. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus.Vivamus a purus non nibh cursus faucibus sit amet ut velit. Morbi tempor sagittis commodo. Aenean a lorem magna, vel lobortis nulla. Praesent ac erat sit amet erat laoreet volutpat. Pellentesque semper ullamcorper euismod. Donec lorem massa, blandit sit amet rhoncus non, lacinia a eros. Pellentesque sed odio varius lectus tempor blandit. Sed ullamcorper malesuada magna non feugiat. In hac habitasse platea dictumst. Etiam sapien metus, aliquet consequat ornare et, commodo sit amet elit. Nunc at neque sed magna aliquet ornare. In congue feugiat sapien, sed congue dui sollicitudin iaculis.</p>', 'Mes cuml dia sed inenia', 'filtered_html'),
('node', 'services', '0', '77', '77', 'en', '0', '<p>Nullam eget felis id metus luctus semper quis vel nulla. Cras diam mauris, molestie eu sodales non, sodales vitae augue. Integer arcu nibh, semper vel cursus eu, adipiscing non lacus. Suspendisse ultrices lacus eu nibh euismod imperdiet. Nunc rutrum pharetra nisl, sed eleifend risus pulvinar in. Nunc venenatis libero et erat interdum et condimentum quam semper. Nulla mattis sem eget odio consequat eget malesuada ante placerat. Sed rhoncus posuere vulputate. Nam dignissim tortor a felis lobortis posuere in et ante. Suspendisse eu risus non nisi euismod condimentum. Aliquam varius orci nec eros sodales fringilla. Donec ac odio urna, a scelerisque dui. Nullam auctor lacus vitae neque porttitor malesuada. Maecenas vel nisi nec lorem auctor suscipit. Proin id tincidunt justo. Phasellus urna ipsum, sagittis convallis consectetur sit amet, vestibulum eu ligula.</p><p>Quisque rutrum erat eget arcu malesuada semper. Praesent faucibus lorem mi, quis interdum ipsum. Vivamus sit amet libero vitae augue ultrices tempor vitae in arcu. <a href="#">Maecenas rutrum, turpis</a> ut pulvinar fringilla, diam massa interdum ligula, sit amet euismod urna dolor non velit. Sed gravida mollis mi, placerat tincidunt nulla hendrerit et. Integer tempor scelerisque tellus, ut facilisis nisi eleifend eget. Aenean consequat mollis urna, et convallis lectus fermentum sit amet. Nulla facilisi. Sed tempor nulla eu leo dapibus porttitor. Vestibulum nec leo et sapien eleifend sagittis. Aliquam at diam quam. Maecenas ut mollis metus.</p><p>Fusce suscipit arcu sed elit lacinia faucibus ut dapibus enim. Mauris ultricies semper leo, quis condimentum nisi ultricies id. Sed et vulputate dolor. Proin nec magna ac ligula ornare tristique ac a lacus. Sed eget nisl in lectus interdum posuere a varius quam. Cras eros lacus, ultrices vitae consequat vitae, fermentum et enim. Nullam iaculis iaculis nisl, vel dictum sem ullamcorper eget. Integer mattis dapibus posuere. Fusce ut viverra velit. Duis vitae cursus nulla. Morbi felis mauris, consequat sed ornare a, sollicitudin at neque. Quisque non magna sed odio vehicula ornare at facilisis ante. Nam dui magna, sollicitudin sed porta eget, ultrices non risus. Praesent quis pulvinar leo. In id nunc ligula, quis laoreet nunc.</p><p>Morbi fringilla bibendum neque, nec facilisis odio ullamcorper sed. Proin hendrerit ornare fringilla. Curabitur iaculis sapien eget felis laoreet tempus. Nam convallis convallis purus, quis varius eros tempus et. Nunc vel libero sit amet massa semper vestibulum quis in nunc. Nunc sapien eros, imperdiet id elementum sit amet, feugiat nec tellus. Donec condimentum vestibulum consequat. Sed luctus enim quis quam luctus auctor. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque nec diam felis, quis vulputate orci. Nunc semper orci eget dolor auctor fringilla. In gravida euismod hendrerit. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Phasellus quis magna tortor. Vestibulum sed sapien eu nibh interdum imperdiet vitae ut dui.</p>', 'Mes cuml dia sed inenia', 'filtered_html'),
('node', 'services', '0', '78', '78', 'en', '0', '<p>Vestibulum quis felis ut enim aliquam iaculis. Nullam pharetra tortor at quam viverra volutpat. Phasellus vel faucibus dolor. Curabitur ac nisi non metus dignissim dapibus eu vel nibh. Phasellus semper dictum dapibus. Etiam tincidunt adipiscing ipsum. Praesent in urna ipsum. Mauris iaculis suscipit volutpat. Aliquam erat volutpat. Aliquam vestibulum lectus vitae sapien dictum id interdum nunc suscipit. Aenean pellentesque auctor porttitor. Phasellus auctor arcu sed mi pellentesque sodales. Aenean eros lectus, varius a consectetur imperdiet, hendrerit eu leo. Cras odio libero, cursus ac pharetra vitae, iaculis in orci. Proin id felis neque, ac fermentum orci. Integer nisi nulla, commodo ac sodales sit amet, condimentum ac arcu.</p><p>Donec a justo nisi. Maecenas fermentum orci ut turpis aliquet tristique. Etiam at lorem ut diam fermentum elementum. <a href="#">Maecenas aliquet dolor ac orci</a> ultrices facilisis. Nam et arcu pharetra neque elementum hendrerit eu ac lorem. Ut dapibus lacus a nisl convallis at vehicula diam fermentum. Curabitur adipiscing, lorem sed laoreet elementum, erat velit dictum leo, in aliquet dui ipsum vel erat.</p><p>Sed nec fringilla massa. Sed ultrices molestie sem a sodales. In hac habitasse platea dictumst. Nunc eros libero, mollis sit amet sodales ut, faucibus et mauris. Praesent egestas sollicitudin ultrices. Fusce ultrices sem nec lacus convallis a tempor velit consectetur. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque sed tortor enim.</p><p>Pellentesque eu mauris sed tortor ullamcorper lobortis quis non neque. Suspendisse scelerisque erat tellus, eu congue ante. Cras pretium euismod quam eu pulvinar. Morbi dapibus sollicitudin sapien et sollicitudin. Vestibulum viverra dictum sem, eget fermentum eros pretium in. Phasellus ut leo at ligula convallis pretium. Aliquam mollis luctus quam et mattis. Sed semper nunc porttitor erat elementum porttitor. Cras sit amet volutpat augue. Nam tortor diam, aliquam vel volutpat eget, convallis a diam. Proin metus metus, commodo quis commodo nec, fermentum eget arcu. Pellentesque eleifend leo sed lacus eleifend malesuada. Duis porttitor augue vel ante lacinia quis pharetra augue facilisis. Praesent dapibus dapibus dignissim. Quisque vitae orci nec mauris fringilla vehicula id nec ipsum</p>', 'Mes cuml dia sed inenia', 'filtered_html'),
('node', 'page', '0', '79', '79', 'en', '0', '<p><strong>Lorem ipsum dolor sit amet, consectetur adipiscing elit.</strong> Sed non arcu enim. Nam sed magna magna, eget tempus neque. Donec lectus enim, auctor ut dignissim sit amet, auctor aliquam tortor. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Phasellus a lectus id nibh mattis ultrices. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Duis suscipit eleifend mauris non condimentum. Mauris iaculis, nibh id interdum hendrerit, turpis turpis placerat dui, ac mattis augue quam eu tortor. Aenean condimentum feugiat rhoncus. Vestibulum id nulla auctor eros vehicula pellentesque.</p>\r\n<p><strong>Proin nec nibh erat, ut interdum tortor.</strong> Aliquam lectus risus, hendrerit vitae mollis et, molestie nec turpis. Nullam gravida diam sed velit dignissim bibendum. Cras tristique mi eu tortor aliquet a blandit urna tempor. Maecenas adipiscing euismod sagittis. Suspendisse vulputate convallis tellus, sed mattis justo faucibus ac. Phasellus non diam ut nisl viverra sodales. Aenean at nunc quis tortor consequat scelerisque. In dignissim, ante vel imperdiet venenatis, felis nisi imperdiet lectus, et ultrices eros justo in lacus. Quisque et ante ac metus eleifend laoreet. Cras leo metus, pharetra et molestie quis, iaculis ut felis.</p>\r\n<p><strong>Nullam sed viverra libero.</strong> Vestibulum imperdiet fermentum massa, a fringilla tortor varius vel. Praesent ac metus massa, ac dapibus lorem. Nunc cursus nisi eget dui suscipit aliquam viverra odio iaculis. Donec commodo erat non arcu volutpat viverra. Nulla facilisi. Nam sagittis metus sit amet quam porttitor sollicitudin. Mauris aliquam felis at enim gravida porta. Sed ultrices aliquam convallis. Sed non consequat ligula. Sed purus felis, pellentesque quis pretium ut, bibendum at est.</p>\r\n<p><strong>Quisque lacinia iaculis fermentum.</strong> Sed sed ante mauris, at pretium mauris. Mauris leo sem, dictum eget tincidunt at, gravida vel lacus. Nam fringilla tristique lectus. Etiam aliquam odio ac arcu posuere placerat. Nunc ipsum eros, euismod vitae molestie at, euismod ut nisl. Pellentesque a convallis dui. Nunc porttitor, turpis vel faucibus sollicitudin, dui nunc placerat risus, non eleifend nulla risus at diam. Integer eget dui dui, ut porta felis. Nam nisi nisl, eleifend a pulvinar nec, pulvinar vitae lorem. In tristique egestas ligula. Mauris sed dui nec leo molestie tempor. Praesent pellentesque molestie magna, a venenatis orci viverra in. Donec eget dui sit amet tortor ornare semper non et est. Suspendisse a orci ut velit consectetur placerat. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Maecenas lacinia tincidunt leo in tincidunt.</p>\r\n<p><strong>Fusce lacus tortor, venenatis id fringilla convallis, interdum nec elit.</strong> Sed viverra, felis in laoreet ultrices, leo ligula molestie augue, vel tincidunt turpis mi vel orci. Nunc dolor orci, ultricies sed vestibulum sed, cursus nec risus. Duis augue risus, ullamcorper vel condimentum cursus, aliquam nec risus. Nunc id mauris in massa lacinia bibendum. Mauris lacinia sagittis adipiscing. Maecenas gravida sapien at magna semper dignissim a vel erat. Phasellus nec risus vel augue bibendum bibendum. Nullam posuere libero dui, id gravida erat. Morbi est tortor, auctor a iaculis ullamcorper, gravida eget magna. Nam aliquam enim non justo volutpat eget aliquet diam iaculis. Cras dui eros, consectetur eu mattis eleifend, laoreet in turpis. Curabitur eu porta lacus.</p>\r\nemail: <a href="mailto:admin@demolink.org">admin@demolink.org</a>', '', 'full_html'),
('node', 'portfolio', '0', '82', '82', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>', '', 'full_html'),
('node', 'popular_services', '0', '83', '83', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>\r\n\r\n<p>Curabitur mauris tortor, laoreet et consectetur non, <a href="#">rhoncus sed risus</a>. Donec nisi enim, adipiscing <strong>quis convallis</strong> eu, elementum a urna. Maecenas sit amet metus sem. Sed non est ligula, sit amet vehicula nunc. Maecenas sed quam non urna tincidunt pellentesque ac ut enim. Vestibulum arcu tortor, vulputate nec semper id, commodo eget lacus. Integer mi dolor, malesuada in ullamcorper ut, tincidunt eu arcu. Mauris dictum, libero id rutrum vehicula, est l<strong>igula sagittis urna</strong>, ut convallis purus <strong>purus at dolor</strong>. <em>Praesent nec vehicula</em> tortor. Nulla facilisi. Curabitur mauris sapien, interdum id consequat et, lobortis ut ipsum. Vestibulum tempus augue eu est malesuada viverra. Nunc mattis fermentum metus, a consectetur magna egestas lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Morbi <em>non mauris ligula</em>. Suspendisse facilisis <a href="#">sagittis mauris</a>, ac dictum elit fringilla ut.</p>', '', 'full_html'),
('node', 'popular_services', '0', '84', '84', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>\r\n\r\n<p>Curabitur mauris tortor, laoreet et consectetur non, <a href="#">rhoncus sed risus</a>. Donec nisi enim, adipiscing <strong>quis convallis</strong> eu, elementum a urna. Maecenas sit amet metus sem. Sed non est ligula, sit amet vehicula nunc. Maecenas sed quam non urna tincidunt pellentesque ac ut enim. Vestibulum arcu tortor, vulputate nec semper id, commodo eget lacus. Integer mi dolor, malesuada in ullamcorper ut, tincidunt eu arcu. Mauris dictum, libero id rutrum vehicula, est l<strong>igula sagittis urna</strong>, ut convallis purus <strong>purus at dolor</strong>. <em>Praesent nec vehicula</em> tortor. Nulla facilisi. Curabitur mauris sapien, interdum id consequat et, lobortis ut ipsum. Vestibulum tempus augue eu est malesuada viverra. Nunc mattis fermentum metus, a consectetur magna egestas lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Morbi <em>non mauris ligula</em>. Suspendisse facilisis <a href="#">sagittis mauris</a>, ac dictum elit fringilla ut.</p>', '', 'full_html'),
('node', 'popular_services', '0', '85', '85', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>\r\n\r\n<p>Curabitur mauris tortor, laoreet et consectetur non, <a href="#">rhoncus sed risus</a>. Donec nisi enim, adipiscing <strong>quis convallis</strong> eu, elementum a urna. Maecenas sit amet metus sem. Sed non est ligula, sit amet vehicula nunc. Maecenas sed quam non urna tincidunt pellentesque ac ut enim. Vestibulum arcu tortor, vulputate nec semper id, commodo eget lacus. Integer mi dolor, malesuada in ullamcorper ut, tincidunt eu arcu. Mauris dictum, libero id rutrum vehicula, est l<strong>igula sagittis urna</strong>, ut convallis purus <strong>purus at dolor</strong>. <em>Praesent nec vehicula</em> tortor. Nulla facilisi. Curabitur mauris sapien, interdum id consequat et, lobortis ut ipsum. Vestibulum tempus augue eu est malesuada viverra. Nunc mattis fermentum metus, a consectetur magna egestas lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Morbi <em>non mauris ligula</em>. Suspendisse facilisis <a href="#">sagittis mauris</a>, ac dictum elit fringilla ut.</p>', '', 'full_html'),
('node', 'popular_services', '0', '86', '86', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>\r\n\r\n<p>Curabitur mauris tortor, laoreet et consectetur non, <a href="#">rhoncus sed risus</a>. Donec nisi enim, adipiscing <strong>quis convallis</strong> eu, elementum a urna. Maecenas sit amet metus sem. Sed non est ligula, sit amet vehicula nunc. Maecenas sed quam non urna tincidunt pellentesque ac ut enim. Vestibulum arcu tortor, vulputate nec semper id, commodo eget lacus. Integer mi dolor, malesuada in ullamcorper ut, tincidunt eu arcu. Mauris dictum, libero id rutrum vehicula, est l<strong>igula sagittis urna</strong>, ut convallis purus <strong>purus at dolor</strong>. <em>Praesent nec vehicula</em> tortor. Nulla facilisi. Curabitur mauris sapien, interdum id consequat et, lobortis ut ipsum. Vestibulum tempus augue eu est malesuada viverra. Nunc mattis fermentum metus, a consectetur magna egestas lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Morbi <em>non mauris ligula</em>. Suspendisse facilisis <a href="#">sagittis mauris</a>, ac dictum elit fringilla ut.</p>', '', 'full_html'),
('node', 'popular_services', '0', '87', '87', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>\r\n\r\n<p>Curabitur mauris tortor, laoreet et consectetur non, <a href="#">rhoncus sed risus</a>. Donec nisi enim, adipiscing <strong>quis convallis</strong> eu, elementum a urna. Maecenas sit amet metus sem. Sed non est ligula, sit amet vehicula nunc. Maecenas sed quam non urna tincidunt pellentesque ac ut enim. Vestibulum arcu tortor, vulputate nec semper id, commodo eget lacus. Integer mi dolor, malesuada in ullamcorper ut, tincidunt eu arcu. Mauris dictum, libero id rutrum vehicula, est l<strong>igula sagittis urna</strong>, ut convallis purus <strong>purus at dolor</strong>. <em>Praesent nec vehicula</em> tortor. Nulla facilisi. Curabitur mauris sapien, interdum id consequat et, lobortis ut ipsum. Vestibulum tempus augue eu est malesuada viverra. Nunc mattis fermentum metus, a consectetur magna egestas lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Morbi <em>non mauris ligula</em>. Suspendisse facilisis <a href="#">sagittis mauris</a>, ac dictum elit fringilla ut.</p>', '', 'full_html'),
('node', 'testimonials', '0', '88', '88', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>\r\n\r\n<p>Curabitur mauris tortor, laoreet et consectetur non, <a href="#">rhoncus sed risus</a>. Donec nisi enim, adipiscing <strong>quis convallis</strong> eu, elementum a urna. Maecenas sit amet metus sem. Sed non est ligula, sit amet vehicula nunc. Maecenas sed quam non urna tincidunt pellentesque ac ut enim. Vestibulum arcu tortor, vulputate nec semper id, commodo eget lacus. Integer mi dolor, malesuada in ullamcorper ut, tincidunt eu arcu. Mauris dictum, libero id rutrum vehicula, est l<strong>igula sagittis urna</strong>, ut convallis purus <strong>purus at dolor</strong>. <em>Praesent nec vehicula</em> tortor. Nulla facilisi. Curabitur mauris sapien, interdum id consequat et, lobortis ut ipsum. Vestibulum tempus augue eu est malesuada viverra. Nunc mattis fermentum metus, a consectetur magna egestas lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Morbi <em>non mauris ligula</em>. Suspendisse facilisis <a href="#">sagittis mauris</a>, ac dictum elit fringilla ut.</p>', '', 'full_html'),
('node', 'testimonials', '0', '89', '89', 'en', '0', '<p>Vivamus vel eros eget magna <strong>volutpat sagittis</strong>. Nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis. Curabitur et libero sit amet ante hendrerit molestie. Cras a erat in leo lobortis tincidunt. Praesent aliquet, eros sit amet dapibus convallis, ligula magna pellentesque urna, quis laoreet erat velit ullamcorper odio. Curabitur eget molestie sem. Maecenas pretium ante non purus tincidunt egestas. Fusce tincidunt, velit sit amet <strong>euismod interdum</strong>, quam ipsum interdum nulla, et tincidunt lectus diam id purus. Pellentesque sodales magna id tellus ultrices pellentesque. Aliquam libero mi, faucibus quis hendrerit nec, porta ac mauris. Duis ullamcorper est quis est rhoncus <em>vitae pulvinar mauris</em> pretium. Sed elit dui, vehicula ac gravida sit amet, iaculis in sem. Aliquam id quam arcu, sed tristique eros. <strong>Pellentesque vestibulum</strong>, <a href="#">elit ac tincidunt suscipit</a>, metus mi laoreet tellus, quis imperdiet sem dolor at massa. Nullam tincidunt, justo at dictum viverra, tortor metus bibendum mauris, fermentum ullamcorper mi ante in odio. Sed id orci et est iaculis iaculis.</p>\r\n\r\n<p>Maecenas odio nunc, malesuada ac posuere vel, interdum id eros. In dictum arcu vel lorem tempus nec <strong>faucibus metus</strong> sodales. Aenean ut sem nunc. Curabitur convallis euismod nulla, a malesuada orci accumsan ut. Donec pellentesque ligula sed massa tristique ac auctor purus aliquet. <strong>Vestibulum malesuada commodo magna</strong> id hendrerit. Sed at ante ipsum. Integer nec justo aliquet mi porttitor scelerisque eget quis elit.</p>\r\n\r\n<p>Curabitur mauris tortor, laoreet et consectetur non, <a href="#">rhoncus sed risus</a>. Donec nisi enim, adipiscing <strong>quis convallis</strong> eu, elementum a urna. Maecenas sit amet metus sem. Sed non est ligula, sit amet vehicula nunc. Maecenas sed quam non urna tincidunt pellentesque ac ut enim. Vestibulum arcu tortor, vulputate nec semper id, commodo eget lacus. Integer mi dolor, malesuada in ullamcorper ut, tincidunt eu arcu. Mauris dictum, libero id rutrum vehicula, est l<strong>igula sagittis urna</strong>, ut convallis purus <strong>purus at dolor</strong>. <em>Praesent nec vehicula</em> tortor. Nulla facilisi. Curabitur mauris sapien, interdum id consequat et, lobortis ut ipsum. Vestibulum tempus augue eu est malesuada viverra. Nunc mattis fermentum metus, a consectetur magna egestas lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Morbi <em>non mauris ligula</em>. Suspendisse facilisis <a href="#">sagittis mauris</a>, ac dictum elit fringilla ut.</p>', '', 'full_html');
/*!40000 ALTER TABLE field_revision_body ENABLE KEYS */;

--
-- Table structure for table 'field_revision_comment_body'
--

CREATE TABLE IF NOT EXISTS `field_revision_comment_body` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `comment_body_value` longtext,
  `comment_body_format` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`entity_type`,`entity_id`,`revision_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `comment_body_format` (`comment_body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Revision archive storage for field 1 (comment_body)';

--
-- Dumping data for table 'field_revision_comment_body'
--

/*!40000 ALTER TABLE field_revision_comment_body DISABLE KEYS */;
INSERT INTO `field_revision_comment_body` VALUES
('comment', 'comment_node_forum', '0', '1', '1', 'und', '0', 'Fusce porttitor porta tortor pulvinar iaculis. Nulla facilisi. Etiam semper hendrerit lectus, sit amet ultricies augue porta ut. Praesent vitae dolor vitae felis congue mollis. Nulla fermentum augue sit amet sem luctus dignissim. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. In dignissim tincidunt mollis. Sed sed massa lorem, sed laoreet est. Pellentesque sit amet orci sed arcu euismod posuere id in nisl. Aenean in quam tortor. Curabitur consequat metus ut nulla viverra tincidunt. In hac habitasse platea dictumst. Suspendisse hendrerit, quam a dignissim pellentesque, turpis risus bibendum massa, quis lacinia sem sem eget est. Praesent magna nisi, dignissim laoreet hendrerit lobortis, gravida non velit. Nullam ut velit augue. Mauris mattis tellus elit, et vehicula purus. Nulla eros libero, pretium id elementum id, euismod non risus. Donec enim nisi, luctus quis vestibulum eu, dapibus quis nisi. Cras porttitor sem sit amet metus fermentum pretium.', 'filtered_html'),
('comment', 'comment_node_forum', '0', '2', '2', 'und', '0', 'Suspendisse potenti. Fusce diam risus, mattis sit amet pretium in, feugiat sed purus. Vivamus in lectus tellus. Nam justo leo, placerat sit amet imperdiet ut, accumsan quis nulla. Donec tristique tristique massa at malesuada. Nulla eleifend ultricies tempus. Nulla dapibus tempus pulvinar. Nullam urna sem, vestibulum ac porttitor sit amet, semper ut dui. Etiam at turpis sed risus auctor molestie eget quis lectus. Donec lacus tortor, condimentum nec pharetra et, adipiscing a sapien. Nulla ac ante diam. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Phasellus bibendum euismod lobortis. Phasellus semper elementum quam a iaculis. Morbi tristique diam id ante sagittis rutrum.', 'filtered_html'),
('comment', 'comment_node_forum', '0', '3', '3', 'und', '0', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut egestas ante ac nunc dignissim vitae blandit lectus vulputate. Aliquam ultrices cursus scelerisque. Nullam interdum facilisis eros ut dignissim. Morbi luctus ultrices eros, vel varius urna facilisis nec. Aliquam vulputate placerat velit id semper. Fusce nisi ante, pulvinar rutrum semper non, imperdiet quis urna. Duis blandit, lacus eget pretium blandit, justo orci molestie turpis, sit amet tincidunt justo lacus eget augue. Etiam sodales egestas tincidunt. Quisque et est tellus, eu commodo eros. Phasellus sed est nisl, vel posuere massa. Fusce eu diam nec eros elementum congue a a augue. Donec tempus velit id leo vestibulum luctus. Quisque mattis, orci eget feugiat volutpat, dui orci lobortis metus, quis elementum leo urna quis urna. Nullam et dolor urna. Praesent tincidunt velit at mauris pharetra sit amet rhoncus enim sollicitudin. Morbi non aliquet nisl.', 'filtered_html'),
('comment', 'comment_node_forum', '0', '4', '4', 'und', '0', 'Quisque nec libero eu urna volutpat cursus. Quisque elit velit, consequat at fringilla quis, tincidunt ac nisi. Donec consequat nisl nec leo vulputate nec fermentum sapien porttitor. Aliquam hendrerit faucibus diam, at dictum quam euismod at. Sed luctus tempus libero, vitae viverra est laoreet sit amet. Duis sit amet neque dui, eu rutrum urna. Nunc purus urna, hendrerit id suscipit nec, pulvinar quis justo. Pellentesque id purus vel nibh iaculis iaculis. Suspendisse non ante eros. Duis condimentum tempor nulla at venenatis. Quisque tristique dui sit amet lorem vulputate eget eleifend ipsum sodales.', 'filtered_html'),
('comment', 'comment_node_forum', '0', '5', '5', 'und', '0', 'Etiam ornare, tellus quis facilisis eleifend, sem enim ultrices sem, ut convallis eros massa sed mauris. Nulla facilisi. Quisque eu neque eu erat bibendum pharetra a sit amet tortor. Fusce a augue ante. In hac habitasse platea dictumst. Aliquam eu purus eu lorem placerat aliquam. Proin in ante vitae diam cursus condimentum. Donec commodo nunc eu enim placerat ut tempor tortor feugiat. In porttitor lacinia mi sed condimentum. Nam imperdiet sapien fringilla felis auctor faucibus. Morbi feugiat dui vel mi facilisis eu molestie nisl sagittis. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Praesent nisl nisi, bibendum pulvinar blandit non, pretium vitae metus. Quisque turpis justo, facilisis in semper at, semper in urna. Vivamus pellentesque sollicitudin erat at iaculis. Quisque ullamcorper nunc at enim convallis vehicula. Fusce vel mi ante. Aenean quam libero, elementum et varius in, eleifend hendrerit eros.', 'filtered_html'),
('comment', 'comment_node_forum', '0', '6', '6', 'und', '0', 'Fusce gravida consectetur mi non tincidunt. Sed dictum lacinia mauris, sed tempus ligula blandit ac. Nam et posuere quam. Integer dui orci, vulputate et pulvinar lobortis, lacinia vel elit. Duis accumsan scelerisque arcu, sit amet lacinia urna faucibus sit amet. Pellentesque sed est mollis purus ornare gravida. Pellentesque interdum justo vel urna pretium tempor. Maecenas sed sapien arcu, sit amet tempus eros. Pellentesque cursus tempus facilisis. Cras auctor mauris a sem vestibulum fermentum.', 'filtered_html'),
('comment', 'comment_node_forum', '0', '7', '7', 'und', '0', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Aliquam euismod viverra volutpat. Praesent orci neque, pellentesque tempus pharetra quis, laoreet eget dolor. Ut adipiscing auctor dignissim. Nam eu odio sit amet lacus accumsan congue. Ut tempor est condimentum urna posuere porttitor. Mauris orci purus, adipiscing non cursus at, lacinia et quam. Integer ullamcorper leo sit amet nulla venenatis sit amet vehicula diam pulvinar. In hac habitasse platea dictumst. Suspendisse ante sapien, gravida semper pretium sit amet, sollicitudin id eros. Donec eget tellus sit amet magna malesuada consectetur. Pellentesque luctus leo mi. Suspendisse vulputate auctor magna tempus scelerisque. Vivamus vehicula rhoncus erat ut luctus. Mauris sed dui id lorem ornare consectetur ac lacinia tortor. Maecenas nunc leo, placerat eget rhoncus a, pellentesque at erat.', 'filtered_html'),
('comment', 'comment_node_forum', '0', '8', '8', 'und', '0', 'Etiam ornare, tellus quis facilisis eleifend, sem enim ultrices sem, ut convallis eros massa sed mauris. Nulla facilisi. Quisque eu neque eu erat bibendum pharetra a sit amet tortor. Fusce a augue ante. In hac habitasse platea dictumst. Aliquam eu purus eu lorem placerat aliquam. Proin in ante vitae diam cursus condimentum. Donec commodo nunc eu enim placerat ut tempor tortor feugiat. In porttitor lacinia mi sed condimentum. Nam imperdiet sapien fringilla felis auctor faucibus. Morbi feugiat dui vel mi facilisis eu molestie nisl sagittis. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Praesent nisl nisi, bibendum pulvinar blandit non, pretium vitae metus. Quisque turpis justo, facilisis in semper at, semper in urna. Vivamus pellentesque sollicitudin erat at iaculis. Quisque ullamcorper nunc at enim convallis vehicula. Fusce vel mi ante. Aenean quam libero, elementum et varius in, eleifend hendrerit eros.', 'filtered_html'),
('comment', 'comment_node_forum', '0', '9', '9', 'und', '0', 'Sed ornare ipsum id libero interdum vel eleifend neque egestas. Mauris sodales urna vitae felis placerat venenatis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Sed justo magna, sagittis nec consequat id, placerat sit amet magna. Praesent lacus metus, aliquet ut sodales et, porta ut nunc. Nulla id massa in erat imperdiet pulvinar. Duis ut metus in mi volutpat convallis et id mi. Fusce in mi sit amet augue faucibus elementum. Praesent odio tortor, tincidunt ac lacinia sit amet, pellentesque id dolor. Ut pretium imperdiet sem, non ornare sem pretium ut. Maecenas sit amet arcu nisi.', 'filtered_html'),
('comment', 'comment_node_forum', '0', '10', '10', 'und', '0', 'Suspendisse convallis, risus a tempor gravida, purus nunc condimentum lorem, eget lacinia lectus augue eget ante. Cras aliquet luctus sapien, sed euismod mi porttitor ut. Nam vulputate, nulla eu tincidunt convallis, leo neque elementum leo, sit amet vulputate libero lectus in mauris. Praesent arcu ipsum, rhoncus nec tincidunt quis, rutrum a augue. Fusce congue, lacus nec pharetra venenatis, risus sapien congue purus, non dictum tellus sem id enim. Donec imperdiet pharetra tempus. Duis ac augue nec urna iaculis aliquet. Sed malesuada semper mauris, id cursus velit convallis rutrum. Phasellus pulvinar, nulla a condimentum varius, enim tortor porttitor sem, adipiscing fringilla felis massa vitae mi. Pellentesque vestibulum elit non turpis convallis scelerisque. Integer scelerisque scelerisque lorem, nec aliquam turpis molestie nec.', 'filtered_html'),
('comment', 'comment_node_forum', '0', '11', '11', 'und', '0', 'Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Mauris sed tempor arcu. Suspendisse potenti. Fusce a nibh sed libero faucibus faucibus. In hac habitasse platea dictumst. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam ac velit ligula. Aliquam aliquam est vitae dui faucibus consectetur non at sapien. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Suspendisse velit ligula, faucibus ac elementum vel, sagittis vitae sapien. Sed nec sem ut dui venenatis lobortis. Phasellus et lorem vitae mi aliquet tincidunt. Nunc et sodales nulla. Donec eu diam a ante condimentum lobortis.', 'filtered_html'),
('comment', 'comment_node_article', '0', '13', '13', 'und', '0', '<p>Aliquam laoreet neque non ipsum pharetra eget ultrices eros dictum. Nunc a enim justo. Donec venenatis, libero nec feugiat congue, mi sem scelerisque magna, congue pellentesque tortor turpis et eros. Donec ligula quam, aliquam eu vehicula ut, aliquet eu erat. Vestibulum posuere, justo eu venenatis consectetur, eros nibh vulputate mauris, dignissim blandit sapien dolor ut augue.</p>', 'filtered_html'),
('comment', 'comment_node_article', '0', '14', '14', 'und', '0', '<p>Suspendisse semper, velit a venenatis rhoncus, leo nulla porttitor justo, a volutpat nisi tortor vitae nisi. Nam volutpat interdum placerat. Sed posuere felis et sem commodo tempus.</p>', 'filtered_html'),
('comment', 'comment_node_article', '0', '15', '15', 'und', '0', '<p>Aenean fermentum justo id nibh sagittis vestibulum. Donec vel interdum mi. Morbi vel diam vel arcu vestibulum vehicula. Nam vitae eros eu leo feugiat aliquam. Quisque sodales, felis quis ullamcorper suscipit, mi ipsum porta magna, ut dapibus odio dolor a nisl. Mauris ac enim nisl, id feugiat metus. Nunc purus enim, euismod nec fringilla a, bibendum in turpis. Praesent ac orci purus, in vulputate risus.</p>', 'filtered_html'),
('comment', 'comment_node_blog', '0', '16', '16', 'und', '0', '<p>Curabitur mauris tortor, laoreet et consectetur non, <a href="#">rhoncus sed risus</a>. Donec nisi enim, adipiscing <strong>quis convallis</strong> eu, elementum a urna. Maecenas sit amet metus sem. Sed non est ligula, sit amet vehicula nunc. Maecenas sed quam non urna tincidunt pellentesque ac ut enim. Vestibulum arcu tortor, vulputate nec semper id, commodo eget lacus. Integer mi dolor, malesuada in ullamcorper ut, tincidunt eu arcu. Mauris dictum, libero id rutrum vehicula, est l<strong>igula sagittis urna</strong>, ut convallis purus <strong>purus at dolor</strong>. <em>Praesent nec vehicula</em> tortor. Nulla facilisi. Curabitur mauris sapien, interdum id consequat et, lobortis ut ipsum. Vestibulum tempus augue eu est malesuada viverra. Nunc mattis fermentum metus, a consectetur magna egestas lobortis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Morbi <em>non mauris ligula</em>. Suspendisse facilisis <a href="#">sagittis mauris</a>, ac dictum elit fringilla ut.</p>', 'full_html');
/*!40000 ALTER TABLE field_revision_comment_body ENABLE KEYS */;

--
-- Table structure for table 'field_revision_field_addthis'
--

CREATE TABLE IF NOT EXISTS `field_revision_field_addthis` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_addthis_value` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`entity_type`,`entity_id`,`revision_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Revision archive storage for field 16 (field_addthis)';

--
-- Dumping data for table 'field_revision_field_addthis'
--

/*!40000 ALTER TABLE field_revision_field_addthis DISABLE KEYS */;
INSERT INTO `field_revision_field_addthis` VALUES
('node', 'article', '0', '36', '36', 'und', '0', 'Dummy value');
/*!40000 ALTER TABLE field_revision_field_addthis ENABLE KEYS */;

--
-- Table structure for table 'field_revision_field_addthis_blog'
--

CREATE TABLE IF NOT EXISTS `field_revision_field_addthis_blog` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_addthis_blog_value` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`entity_type`,`entity_id`,`revision_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Revision archive storage for field 17 (field_addthis_blog)';

--
-- Dumping data for table 'field_revision_field_addthis_blog'
--

/*!40000 ALTER TABLE field_revision_field_addthis_blog DISABLE KEYS */;
INSERT INTO `field_revision_field_addthis_blog` VALUES
('node', 'blog', '0', '37', '37', 'und', '0', 'Dummy value'),
('node', 'blog', '0', '38', '38', 'und', '0', 'Dummy value'),
('node', 'blog', '0', '39', '39', 'und', '0', 'Dummy value'),
('node', 'blog', '0', '40', '40', 'und', '0', 'Dummy value'),
('node', 'blog', '0', '41', '41', 'und', '0', 'Dummy value');
/*!40000 ALTER TABLE field_revision_field_addthis_blog ENABLE KEYS */;

--
-- Table structure for table 'field_revision_field_blog_category'
--

CREATE TABLE IF NOT EXISTS `field_revision_field_blog_category` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_blog_category_tid` int(10) unsigned DEFAULT NULL,
  PRIMARY KEY (`entity_type`,`entity_id`,`revision_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_blog_category_tid` (`field_blog_category_tid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Revision archive storage for field 18 (field_blog_category)';

--
-- Dumping data for table 'field_revision_field_blog_category'
--

/*!40000 ALTER TABLE field_revision_field_blog_category DISABLE KEYS */;
INSERT INTO `field_revision_field_blog_category` VALUES
('node', 'blog', '0', '37', '37', 'und', '0', '27'),
('node', 'blog', '0', '37', '37', 'und', '1', '26'),
('node', 'blog', '0', '38', '38', 'und', '0', '19'),
('node', 'blog', '0', '38', '38', 'und', '1', '23'),
('node', 'blog', '0', '38', '38', 'und', '2', '26'),
('node', 'blog', '0', '38', '38', 'und', '3', '20'),
('node', 'blog', '0', '39', '39', 'und', '0', '19'),
('node', 'blog', '0', '39', '39', 'und', '1', '23'),
('node', 'blog', '0', '40', '40', 'und', '0', '25'),
('node', 'blog', '0', '40', '40', 'und', '1', '19'),
('node', 'blog', '0', '40', '40', 'und', '2', '18'),
('node', 'blog', '0', '40', '40', 'und', '3', '27'),
('node', 'blog', '0', '40', '40', 'und', '4', '23'),
('node', 'blog', '0', '40', '40', 'und', '5', '24'),
('node', 'blog', '0', '40', '40', 'und', '6', '26'),
('node', 'blog', '0', '40', '40', 'und', '7', '22'),
('node', 'blog', '0', '40', '40', 'und', '8', '20'),
('node', 'blog', '0', '41', '41', 'und', '0', '25'),
('node', 'blog', '0', '41', '41', 'und', '1', '19'),
('node', 'blog', '0', '41', '41', 'und', '2', '18'),
('node', 'blog', '0', '41', '41', 'und', '3', '21'),
('node', 'blog', '0', '41', '41', 'und', '4', '20');
/*!40000 ALTER TABLE field_revision_field_blog_category ENABLE KEYS */;

--
-- Table structure for table 'field_revision_field_blog_image'
--

CREATE TABLE IF NOT EXISTS `field_revision_field_blog_image` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_blog_image_fid` int(10) unsigned DEFAULT NULL COMMENT 'The file_managed.fid being referenced in this field.',
  `field_blog_image_alt` varchar(512) DEFAULT NULL,
  `field_blog_image_title` varchar(1024) DEFAULT NULL,
  `field_blog_image_width` int(10) unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_blog_image_height` int(10) unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_type`,`entity_id`,`revision_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_blog_image_fid` (`field_blog_image_fid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Revision archive storage for field 6 (field_blog_image)';

--
-- Dumping data for table 'field_revision_field_blog_image'
--

/*!40000 ALTER TABLE field_revision_field_blog_image DISABLE KEYS */;
INSERT INTO `field_revision_field_blog_image` VALUES
('node', 'blog', '0', '37', '37', 'en', '0', '96', '', '', '1500', '1125'),
('node', 'blog', '0', '38', '38', 'en', '0', '97', '', '', '1500', '1140'),
('node', 'blog', '0', '39', '39', 'en', '0', '95', '', '', '1500', '899'),
('node', 'blog', '0', '41', '41', 'en', '0', '98', '', '', '1500', '1125');
/*!40000 ALTER TABLE field_revision_field_blog_image ENABLE KEYS */;

--
-- Table structure for table 'field_revision_field_employee_photo'
--

CREATE TABLE IF NOT EXISTS `field_revision_field_employee_photo` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_employee_photo_fid` int(10) unsigned DEFAULT NULL COMMENT 'The file_managed.fid being referenced in this field.',
  `field_employee_photo_alt` varchar(512) DEFAULT NULL,
  `field_employee_photo_title` varchar(1024) DEFAULT NULL,
  `field_employee_photo_width` int(10) unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_employee_photo_height` int(10) unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_type`,`entity_id`,`revision_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_employee_photo_fid` (`field_employee_photo_fid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Revision archive storage for field 11 (field_employee_photo)';

--
-- Dumping data for table 'field_revision_field_employee_photo'
--

/*!40000 ALTER TABLE field_revision_field_employee_photo DISABLE KEYS */;
INSERT INTO `field_revision_field_employee_photo` VALUES
('node', 'employee', '0', '65', '65', 'en', '0', '46', '', '', '1200', '886'),
('node', 'employee', '0', '67', '67', 'en', '0', '50', '', '', '1264', '1600'),
('node', 'employee', '0', '68', '68', 'en', '0', '49', '', '', '1600', '1491'),
('node', 'employee', '0', '69', '69', 'en', '0', '48', '', '', '900', '600'),
('node', 'employee', '0', '71', '71', 'en', '0', '47', '', '', '1067', '993'),
('node', 'employee', '0', '73', '73', 'en', '0', '45', '', '', '1290', '1600');
/*!40000 ALTER TABLE field_revision_field_employee_photo ENABLE KEYS */;

--
-- Table structure for table 'field_revision_field_image'
--

CREATE TABLE IF NOT EXISTS `field_revision_field_image` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_image_fid` int(10) unsigned DEFAULT NULL COMMENT 'The file_managed.fid being referenced in this field.',
  `field_image_alt` varchar(512) DEFAULT NULL,
  `field_image_title` varchar(1024) DEFAULT NULL,
  `field_image_width` int(10) unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_image_height` int(10) unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_type`,`entity_id`,`revision_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_image_fid` (`field_image_fid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Revision archive storage for field 4 (field_image)';

--
-- Dumping data for table 'field_revision_field_image'
--

/*!40000 ALTER TABLE field_revision_field_image DISABLE KEYS */;
/*!40000 ALTER TABLE field_revision_field_image ENABLE KEYS */;

--
-- Table structure for table 'field_revision_field_logo'
--

CREATE TABLE IF NOT EXISTS `field_revision_field_logo` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_logo_fid` int(10) unsigned DEFAULT NULL COMMENT 'The file_managed.fid being referenced in this field.',
  `field_logo_alt` varchar(512) DEFAULT NULL,
  `field_logo_title` varchar(1024) DEFAULT NULL,
  `field_logo_width` int(10) unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_logo_height` int(10) unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_type`,`entity_id`,`revision_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_logo_fid` (`field_logo_fid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Revision archive storage for field 12 (field_logo)';

--
-- Dumping data for table 'field_revision_field_logo'
--

/*!40000 ALTER TABLE field_revision_field_logo DISABLE KEYS */;
/*!40000 ALTER TABLE field_revision_field_logo ENABLE KEYS */;

--
-- Table structure for table 'field_revision_field_map'
--

CREATE TABLE IF NOT EXISTS `field_revision_field_map` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_map_glid` int(10) unsigned NOT NULL,
  PRIMARY KEY (`entity_type`,`entity_id`,`revision_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_map_glid` (`field_map_glid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Revision archive storage for field 14 (field_map)';

--
-- Dumping data for table 'field_revision_field_map'
--

/*!40000 ALTER TABLE field_revision_field_map DISABLE KEYS */;
INSERT INTO `field_revision_field_map` VALUES
('node', 'maps', '0', '81', '81', 'und', '0', '2');
/*!40000 ALTER TABLE field_revision_field_map ENABLE KEYS */;

--
-- Table structure for table 'field_revision_field_popular_services_image'
--

CREATE TABLE IF NOT EXISTS `field_revision_field_popular_services_image` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_popular_services_image_fid` int(10) unsigned DEFAULT NULL COMMENT 'The file_managed.fid being referenced in this field.',
  `field_popular_services_image_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image’s ’alt’ attribute.',
  `field_popular_services_image_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image’s ’title’ attribute.',
  `field_popular_services_image_width` int(10) unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_popular_services_image_height` int(10) unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_type`,`entity_id`,`revision_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_popular_services_image_fid` (`field_popular_services_image_fid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Revision archive storage for field 20 (field_popular...';

--
-- Dumping data for table 'field_revision_field_popular_services_image'
--

/*!40000 ALTER TABLE field_revision_field_popular_services_image DISABLE KEYS */;
INSERT INTO `field_revision_field_popular_services_image` VALUES
('node', 'popular_services', '0', '83', '83', 'und', '0', '102', '', '', '1500', '997'),
('node', 'popular_services', '0', '84', '84', 'und', '0', '103', '', '', '1500', '1140'),
('node', 'popular_services', '0', '85', '85', 'und', '0', '99', '', '', '1500', '1059'),
('node', 'popular_services', '0', '86', '86', 'und', '0', '100', '', '', '1500', '1140'),
('node', 'popular_services', '0', '87', '87', 'und', '0', '101', '', '', '1500', '825');
/*!40000 ALTER TABLE field_revision_field_popular_services_image ENABLE KEYS */;

--
-- Table structure for table 'field_revision_field_portfolio_category'
--

CREATE TABLE IF NOT EXISTS `field_revision_field_portfolio_category` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_portfolio_category_tid` int(10) unsigned DEFAULT NULL,
  PRIMARY KEY (`entity_type`,`entity_id`,`revision_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_portfolio_category_tid` (`field_portfolio_category_tid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Revision archive storage for field 19 (field_portfolio...';

--
-- Dumping data for table 'field_revision_field_portfolio_category'
--

/*!40000 ALTER TABLE field_revision_field_portfolio_category DISABLE KEYS */;
INSERT INTO `field_revision_field_portfolio_category` VALUES
('node', 'portfolio', '0', '52', '52', 'und', '0', '28'),
('node', 'portfolio', '0', '52', '52', 'und', '1', '29'),
('node', 'portfolio', '0', '53', '53', 'und', '0', '28'),
('node', 'portfolio', '0', '53', '53', 'und', '1', '30'),
('node', 'portfolio', '0', '54', '54', 'und', '0', '28'),
('node', 'portfolio', '0', '55', '55', 'und', '0', '28'),
('node', 'portfolio', '0', '55', '55', 'und', '1', '31'),
('node', 'portfolio', '0', '56', '56', 'und', '0', '28'),
('node', 'portfolio', '0', '56', '56', 'und', '1', '29'),
('node', 'portfolio', '0', '57', '57', 'und', '0', '28'),
('node', 'portfolio', '0', '57', '57', 'und', '1', '29'),
('node', 'portfolio', '0', '57', '57', 'und', '2', '31'),
('node', 'portfolio', '0', '58', '58', 'und', '0', '28'),
('node', 'portfolio', '0', '58', '58', 'und', '1', '31'),
('node', 'portfolio', '0', '82', '82', 'und', '0', '28');
/*!40000 ALTER TABLE field_revision_field_portfolio_category ENABLE KEYS */;

--
-- Table structure for table 'field_revision_field_portfolio_image'
--

CREATE TABLE IF NOT EXISTS `field_revision_field_portfolio_image` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_portfolio_image_fid` int(10) unsigned DEFAULT NULL COMMENT 'The file_managed.fid being referenced in this field.',
  `field_portfolio_image_alt` varchar(512) DEFAULT NULL,
  `field_portfolio_image_title` varchar(1024) DEFAULT NULL,
  `field_portfolio_image_width` int(10) unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_portfolio_image_height` int(10) unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_type`,`entity_id`,`revision_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_portfolio_image_fid` (`field_portfolio_image_fid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Revision archive storage for field 8 (field_portfolio_image)';

--
-- Dumping data for table 'field_revision_field_portfolio_image'
--

/*!40000 ALTER TABLE field_revision_field_portfolio_image DISABLE KEYS */;
INSERT INTO `field_revision_field_portfolio_image` VALUES
('node', 'portfolio', '0', '52', '52', 'en', '0', '105', '', '', '1500', '1000'),
('node', 'portfolio', '0', '53', '53', 'en', '0', '106', '', '', '1500', '1125'),
('node', 'portfolio', '0', '54', '54', 'en', '0', '107', '', '', '1500', '1125'),
('node', 'portfolio', '0', '55', '55', 'en', '0', '108', '', '', '1500', '1125'),
('node', 'portfolio', '0', '56', '56', 'en', '0', '109', '', '', '1500', '1000'),
('node', 'portfolio', '0', '57', '57', 'en', '0', '104', '', '', '1500', '1125'),
('node', 'portfolio', '0', '58', '58', 'en', '0', '110', '', '', '1500', '1042'),
('node', 'portfolio', '0', '82', '82', 'en', '0', '111', '', '', '1500', '1000');
/*!40000 ALTER TABLE field_revision_field_portfolio_image ENABLE KEYS */;

--
-- Table structure for table 'field_revision_field_position'
--

CREATE TABLE IF NOT EXISTS `field_revision_field_position` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_position_value` varchar(255) DEFAULT NULL,
  `field_position_format` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`entity_type`,`entity_id`,`revision_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_position_format` (`field_position_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Revision archive storage for field 15 (field_position)';

--
-- Dumping data for table 'field_revision_field_position'
--

/*!40000 ALTER TABLE field_revision_field_position DISABLE KEYS */;
INSERT INTO `field_revision_field_position` VALUES
('node', 'employee', '0', '65', '65', 'und', '0', 'Programmer', NULL),
('node', 'employee', '0', '67', '67', 'und', '0', 'Manager', NULL),
('node', 'employee', '0', '68', '68', 'und', '0', 'Seller', NULL),
('node', 'employee', '0', '69', '69', 'und', '0', 'CEO', NULL),
('node', 'employee', '0', '71', '71', 'und', '0', 'Support', NULL),
('node', 'employee', '0', '73', '73', 'und', '0', 'Billing', NULL);
/*!40000 ALTER TABLE field_revision_field_position ENABLE KEYS */;

--
-- Table structure for table 'field_revision_field_service_image'
--

CREATE TABLE IF NOT EXISTS `field_revision_field_service_image` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_service_image_fid` int(10) unsigned DEFAULT NULL COMMENT 'The file_managed.fid being referenced in this field.',
  `field_service_image_alt` varchar(512) DEFAULT NULL,
  `field_service_image_title` varchar(1024) DEFAULT NULL,
  `field_service_image_width` int(10) unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_service_image_height` int(10) unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_type`,`entity_id`,`revision_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_service_image_fid` (`field_service_image_fid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Revision archive storage for field 13 (field_service_image)';

--
-- Dumping data for table 'field_revision_field_service_image'
--

/*!40000 ALTER TABLE field_revision_field_service_image DISABLE KEYS */;
INSERT INTO `field_revision_field_service_image` VALUES
('node', 'services', '0', '76', '76', 'und', '0', '92', '', '', '1500', '1000'),
('node', 'services', '0', '77', '77', 'und', '0', '91', '', '', '1500', '1093'),
('node', 'services', '0', '78', '78', 'und', '0', '90', '', '', '1500', '900');
/*!40000 ALTER TABLE field_revision_field_service_image ENABLE KEYS */;

--
-- Table structure for table 'field_revision_field_slide_image'
--

CREATE TABLE IF NOT EXISTS `field_revision_field_slide_image` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_slide_image_fid` int(10) unsigned DEFAULT NULL COMMENT 'The file_managed.fid being referenced in this field.',
  `field_slide_image_alt` varchar(512) DEFAULT NULL,
  `field_slide_image_title` varchar(1024) DEFAULT NULL,
  `field_slide_image_width` int(10) unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_slide_image_height` int(10) unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_type`,`entity_id`,`revision_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_slide_image_fid` (`field_slide_image_fid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Revision archive storage for field 7 (field_slide_image)';

--
-- Dumping data for table 'field_revision_field_slide_image'
--

/*!40000 ALTER TABLE field_revision_field_slide_image DISABLE KEYS */;
INSERT INTO `field_revision_field_slide_image` VALUES
('node', 'slider', '0', '47', '47', 'en', '0', '87', '', '', '1950', '510'),
('node', 'slider', '0', '50', '50', 'en', '0', '88', '', '', '1950', '510'),
('node', 'slider', '0', '51', '51', 'en', '0', '89', '', '', '1950', '510');
/*!40000 ALTER TABLE field_revision_field_slide_image ENABLE KEYS */;

--
-- Table structure for table 'field_revision_field_tags'
--

CREATE TABLE IF NOT EXISTS `field_revision_field_tags` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_tags_tid` int(10) unsigned DEFAULT NULL,
  PRIMARY KEY (`entity_type`,`entity_id`,`revision_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_tags_tid` (`field_tags_tid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Revision archive storage for field 3 (field_tags)';

--
-- Dumping data for table 'field_revision_field_tags'
--

/*!40000 ALTER TABLE field_revision_field_tags DISABLE KEYS */;
INSERT INTO `field_revision_field_tags` VALUES
('node', 'article', '0', '36', '36', 'und', '0', '15'),
('node', 'article', '0', '36', '36', 'und', '1', '16'),
('node', 'article', '0', '36', '36', 'und', '2', '17');
/*!40000 ALTER TABLE field_revision_field_tags ENABLE KEYS */;

--
-- Table structure for table 'field_revision_field_testimonials_position'
--

CREATE TABLE IF NOT EXISTS `field_revision_field_testimonials_position` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_testimonials_position_value` varchar(255) DEFAULT NULL,
  `field_testimonials_position_format` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`entity_type`,`entity_id`,`revision_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `field_testimonials_position_format` (`field_testimonials_position_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Revision archive storage for field 21 (field_testimonials...';

--
-- Dumping data for table 'field_revision_field_testimonials_position'
--

/*!40000 ALTER TABLE field_revision_field_testimonials_position DISABLE KEYS */;
INSERT INTO `field_revision_field_testimonials_position` VALUES
('node', 'testimonials', '0', '88', '88', 'und', '0', 'MEtho org', NULL),
('node', 'testimonials', '0', '89', '89', 'und', '0', 'MEtho org', NULL);
/*!40000 ALTER TABLE field_revision_field_testimonials_position ENABLE KEYS */;

--
-- Table structure for table 'field_revision_taxonomy_forums'
--

CREATE TABLE IF NOT EXISTS `field_revision_taxonomy_forums` (
  `entity_type` varchar(128) NOT NULL DEFAULT '' COMMENT 'The entity type this data is attached to',
  `bundle` varchar(128) NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int(10) unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int(10) unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `language` varchar(32) NOT NULL DEFAULT '' COMMENT 'The language for this data item.',
  `delta` int(10) unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `taxonomy_forums_tid` int(10) unsigned DEFAULT NULL,
  PRIMARY KEY (`entity_type`,`entity_id`,`revision_id`,`deleted`,`delta`,`language`),
  KEY `entity_type` (`entity_type`),
  KEY `bundle` (`bundle`),
  KEY `deleted` (`deleted`),
  KEY `entity_id` (`entity_id`),
  KEY `revision_id` (`revision_id`),
  KEY `language` (`language`),
  KEY `taxonomy_forums_tid` (`taxonomy_forums_tid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Revision archive storage for field 5 (taxonomy_forums)';

--
-- Dumping data for table 'field_revision_taxonomy_forums'
--

/*!40000 ALTER TABLE field_revision_taxonomy_forums DISABLE KEYS */;
INSERT INTO `field_revision_taxonomy_forums` VALUES
('node', 'forum', '0', '12', '12', 'und', '0', '1'),
('node', 'forum', '0', '13', '13', 'und', '0', '1'),
('node', 'forum', '0', '14', '14', 'und', '0', '1'),
('node', 'forum', '0', '15', '15', 'und', '0', '1'),
('node', 'forum', '0', '16', '16', 'und', '0', '1'),
('node', 'forum', '0', '17', '17', 'und', '0', '5'),
('node', 'forum', '0', '18', '18', 'und', '0', '5'),
('node', 'forum', '0', '19', '19', 'und', '0', '5'),
('node', 'forum', '0', '20', '20', 'und', '0', '5'),
('node', 'forum', '0', '21', '21', 'und', '0', '6'),
('node', 'forum', '0', '22', '22', 'und', '0', '6'),
('node', 'forum', '0', '23', '23', 'und', '0', '6'),
('node', 'forum', '0', '24', '24', 'und', '0', '6'),
('node', 'forum', '0', '25', '25', 'und', '0', '7'),
('node', 'forum', '0', '26', '26', 'und', '0', '7'),
('node', 'forum', '0', '27', '27', 'und', '0', '7'),
('node', 'forum', '0', '28', '28', 'und', '0', '8'),
('node', 'forum', '0', '29', '29', 'und', '0', '8'),
('node', 'forum', '0', '30', '30', 'und', '0', '8'),
('node', 'forum', '0', '31', '31', 'und', '0', '8'),
('node', 'forum', '0', '32', '32', 'und', '0', '8'),
('node', 'forum', '0', '33', '33', 'und', '0', '9'),
('node', 'forum', '0', '34', '34', 'und', '0', '9'),
('node', 'forum', '0', '35', '35', 'und', '0', '10');
/*!40000 ALTER TABLE field_revision_taxonomy_forums ENABLE KEYS */;

--
-- Table structure for table 'file_managed'
--

CREATE TABLE IF NOT EXISTS `file_managed` (
  `fid` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'File ID.',
  `uid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The users.uid of the user who is associated with the file.',
  `filename` varchar(255) NOT NULL DEFAULT '' COMMENT 'Name of the file with no path components. This may differ from the basename of the URI if the file is renamed to avoid overwriting an existing file.',
  `uri` varchar(255) CHARACTER SET utf8 COLLATE utf8_bin NOT NULL DEFAULT '' COMMENT 'The URI to access the file (either local or remote).',
  `filemime` varchar(255) NOT NULL DEFAULT '' COMMENT 'The file’s MIME type.',
  `filesize` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The size of the file in bytes.',
  `status` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A field indicating the status of the file. Two status are defined in core: temporary (0) and permanent (1). Temporary files older than DRUPAL_MAXIMUM_TEMP_FILE_AGE will be removed during a cron run.',
  `timestamp` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'UNIX timestamp for when the file was added.',
  PRIMARY KEY (`fid`),
  UNIQUE KEY `uri` (`uri`),
  KEY `uid` (`uid`),
  KEY `status` (`status`),
  KEY `timestamp` (`timestamp`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores information for uploaded files.';

--
-- Dumping data for table 'file_managed'
--

/*!40000 ALTER TABLE file_managed DISABLE KEYS */;
INSERT INTO `file_managed` VALUES
('1', '1', 'gmap_markers.js', 'public://js/gmap_markers.js', 'application/x-javascript', '4141', '1', '1353940672'),
('45', '1', 'bigstockphoto_Business_Man_Communicating_On__5120319.jpg', 'public://bigstockphoto_Business_Man_Communicating_On__5120319.jpg', 'image/jpeg', '879833', '1', '1333107157'),
('46', '1', 'bigstockphoto_Businessman_Smiling_569444.jpg', 'public://bigstockphoto_Businessman_Smiling_569444.jpg', 'image/jpeg', '565523', '1', '1333107190'),
('47', '1', 'bigstock_Thoughtful_Young_Man_Using_Lap_7954092.jpg', 'public://bigstock_Thoughtful_Young_Man_Using_Lap_7954092.jpg', 'image/jpeg', '216672', '1', '1333107326'),
('48', '1', 'bigstock_Portrait_Of_An_Attractive_Busi_4965853.jpg', 'public://bigstock_Portrait_Of_An_Attractive_Busi_4965853.jpg', 'image/jpeg', '291351', '1', '1333107426'),
('49', '1', 'bigstock_Beautiful_Happy_Woman_Smiling__10221302.jpg', 'public://bigstock_Beautiful_Happy_Woman_Smiling__10221302.jpg', 'image/jpeg', '1654204', '1', '1333107444'),
('50', '1', 'bigstockphoto_Modern_Lifestyles_-_Woman_Tal_4731963.jpg', 'public://bigstockphoto_Modern_Lifestyles_-_Woman_Tal_4731963.jpg', 'image/jpeg', '902314', '1', '1333107605'),
('52', '155', 'picture-155.png', 'public://pictures/picture-155.png', 'image/png', '928', '1', '1374075585'),
('53', '156', 'picture-156.png', 'public://pictures/picture-156.png', 'image/png', '950', '1', '1374075585'),
('56', '159', 'picture-159.png', 'public://pictures/picture-159.png', 'image/png', '898', '1', '1374075585'),
('87', '1', 'slide-1.jpg', 'public://slide-1_0.jpg', 'image/jpeg', '303943', '1', '1378907751'),
('88', '1', 'slide-2.jpg', 'public://slide-2.jpg', 'image/jpeg', '105290', '1', '1378907811'),
('89', '1', 'slide-3.jpg', 'public://slide-3.jpg', 'image/jpeg', '107445', '1', '1378907850'),
('90', '1', 'Image00022.jpg', 'public://Image00022.jpg', 'image/jpeg', '139640', '1', '1378991281'),
('91', '1', 'Image00021.jpg', 'public://Image00021.jpg', 'image/jpeg', '198687', '1', '1378991290'),
('92', '1', 'Image00020.jpg', 'public://Image00020.jpg', 'image/jpeg', '188926', '1', '1378991299'),
('93', '1', 'picture-157-1378991549.png', 'public://pictures/picture-157-1378991549.png', 'image/png', '8667', '1', '1378991549'),
('94', '1', 'picture-158-1378991570.png', 'public://pictures/picture-158-1378991570.png', 'image/png', '8888', '1', '1378991570'),
('95', '1', 'Image00018.jpg', 'public://Image00018.jpg', 'image/jpeg', '123856', '1', '1378991807'),
('96', '1', 'Image00017.jpg', 'public://Image00017_0.jpg', 'image/jpeg', '200551', '1', '1378991808'),
('97', '1', 'Image00016.jpg', 'public://Image00016_0.jpg', 'image/jpeg', '78054', '1', '1378991809'),
('98', '1', 'Image00015.jpg', 'public://Image00015_0.jpg', 'image/jpeg', '181018', '1', '1378991811'),
('99', '1', 'Image00013.jpg', 'public://field/image/Image00013.jpg', 'image/jpeg', '120130', '1', '1378991996'),
('100', '1', 'Image00012.jpg', 'public://field/image/Image00012.jpg', 'image/jpeg', '94279', '1', '1378991997'),
('101', '1', 'Image00011.jpg', 'public://field/image/Image00011_0.jpg', 'image/jpeg', '119564', '1', '1378991999'),
('102', '1', 'Image00010.jpg', 'public://field/image/Image00010.jpg', 'image/jpeg', '180537', '1', '1378992001'),
('103', '1', 'Image00014.jpg', 'public://field/image/Image00014.jpg', 'image/jpeg', '64979', '1', '1378992051'),
('104', '1', 'Image00001.jpg', 'public://Image00001.jpg', 'image/jpeg', '135926', '1', '1378992218'),
('105', '1', 'Image00002.jpg', 'public://Image00002.jpg', 'image/jpeg', '143588', '1', '1378992221'),
('106', '1', 'Image00003.jpg', 'public://Image00003.jpg', 'image/jpeg', '148758', '1', '1378992222'),
('107', '1', 'Image00004.jpg', 'public://Image00004.jpg', 'image/jpeg', '74493', '1', '1378992224'),
('108', '1', 'Image00005.jpg', 'public://Image00005_0.jpg', 'image/jpeg', '238377', '1', '1378992225'),
('109', '1', 'Image00006.jpg', 'public://Image00006_0.jpg', 'image/jpeg', '97638', '1', '1378992228'),
('110', '1', 'Image00007.jpg', 'public://Image00007_0.jpg', 'image/jpeg', '226227', '1', '1378992230'),
('111', '1', 'Image00008.jpg', 'public://Image00008_0.jpg', 'image/jpeg', '151251', '1', '1378992232');
/*!40000 ALTER TABLE file_managed ENABLE KEYS */;

--
-- Table structure for table 'file_usage'
--

CREATE TABLE IF NOT EXISTS `file_usage` (
  `fid` int(10) unsigned NOT NULL COMMENT 'File ID.',
  `module` varchar(255) NOT NULL DEFAULT '' COMMENT 'The name of the module that is using the file.',
  `type` varchar(64) NOT NULL DEFAULT '' COMMENT 'The name of the object type in which the file is used.',
  `id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The primary key of the object using the file.',
  `count` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The number of times this file is used by this object.',
  PRIMARY KEY (`fid`,`type`,`id`,`module`),
  KEY `type_id` (`type`,`id`),
  KEY `fid_count` (`fid`,`count`),
  KEY `fid_module` (`fid`,`module`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Track where a file is used.';

--
-- Dumping data for table 'file_usage'
--

/*!40000 ALTER TABLE file_usage DISABLE KEYS */;
INSERT INTO `file_usage` VALUES
('45', 'file', 'node', '73', '1'),
('46', 'file', 'node', '65', '1'),
('47', 'file', 'node', '71', '1'),
('48', 'file', 'node', '69', '1'),
('49', 'file', 'node', '68', '1'),
('50', 'file', 'node', '67', '1'),
('87', 'file', 'node', '47', '1'),
('88', 'file', 'node', '50', '1'),
('89', 'file', 'node', '51', '1'),
('90', 'file', 'node', '78', '1'),
('91', 'file', 'node', '77', '1'),
('92', 'file', 'node', '76', '1'),
('93', 'user', 'user', '157', '1'),
('94', 'user', 'user', '158', '1'),
('95', 'file', 'node', '39', '1'),
('96', 'file', 'node', '37', '1'),
('97', 'file', 'node', '38', '1'),
('98', 'file', 'node', '41', '1'),
('99', 'file', 'node', '85', '1'),
('100', 'file', 'node', '86', '1'),
('101', 'file', 'node', '87', '1'),
('102', 'file', 'node', '83', '1'),
('103', 'file', 'node', '84', '1'),
('104', 'file', 'node', '57', '1'),
('105', 'file', 'node', '52', '1'),
('106', 'file', 'node', '53', '1'),
('107', 'file', 'node', '54', '1'),
('108', 'file', 'node', '55', '1'),
('109', 'file', 'node', '56', '1'),
('110', 'file', 'node', '58', '1'),
('111', 'file', 'node', '82', '1');
/*!40000 ALTER TABLE file_usage ENABLE KEYS */;

--
-- Table structure for table 'filter'
--

CREATE TABLE IF NOT EXISTS `filter` (
  `format` varchar(255) NOT NULL COMMENT 'Foreign key: The filter_format.format to which this filter is assigned.',
  `module` varchar(64) NOT NULL DEFAULT '' COMMENT 'The origin module of the filter.',
  `name` varchar(32) NOT NULL DEFAULT '' COMMENT 'Name of the filter being referenced.',
  `weight` int(11) NOT NULL DEFAULT '0' COMMENT 'Weight of filter within format.',
  `status` int(11) NOT NULL DEFAULT '0' COMMENT 'Filter enabled status. (1 = enabled, 0 = disabled)',
  `settings` longblob COMMENT 'A serialized array of name value pairs that store the filter settings for the specific format.',
  PRIMARY KEY (`format`,`name`),
  KEY `list` (`weight`,`module`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Table that maps filters (HTML corrector) to text formats ...';

--
-- Dumping data for table 'filter'
--

/*!40000 ALTER TABLE filter DISABLE KEYS */;
INSERT INTO `filter` VALUES
('filtered_html', 'faq', 'faq_embed', '0', '0', 'a:0:{}'),
('filtered_html', 'filter', 'filter_autop', '2', '0', 'a:0:{}'),
('filtered_html', 'flickr', 'filter_flickr', '0', '0', 'a:0:{}'),
('filtered_html', 'filter', 'filter_html', '1', '0', 'a:3:{s:12:"allowed_html";s:87:"<a> <em> <strong> <cite> <blockquote> <code> <ul> <ol> <li> <dl> <dt> <dd> <p> <iframe>";s:16:"filter_html_help";i:1;s:20:"filter_html_nofollow";i:0;}'),
('filtered_html', 'filter', 'filter_htmlcorrector', '10', '0', 'a:0:{}'),
('filtered_html', 'filter', 'filter_html_escape', '10', '0', 'a:0:{}'),
('filtered_html', 'filter', 'filter_url', '0', '1', 'a:1:{s:17:"filter_url_length";s:2:"72";}'),
('filtered_html', 'gmap', 'gmap_macro', '0', '0', 'a:0:{}'),
('filtered_html', 'php', 'php_code', '0', '0', 'a:0:{}'),
('full_html', 'filter', 'filter_autop', '1', '1', 'a:0:{}'),
('full_html', 'filter', 'filter_html', '10', '0', 'a:3:{s:12:"allowed_html";s:74:"<a> <em> <strong> <cite> <blockquote> <code> <ul> <ol> <li> <dl> <dt> <dd>";s:16:"filter_html_help";i:1;s:20:"filter_html_nofollow";i:0;}'),
('full_html', 'filter', 'filter_htmlcorrector', '10', '1', 'a:0:{}'),
('full_html', 'filter', 'filter_html_escape', '10', '0', 'a:0:{}'),
('full_html', 'filter', 'filter_url', '0', '1', 'a:1:{s:17:"filter_url_length";i:72;}'),
('gmap', 'filter', 'filter_autop', '0', '0', 'a:0:{}'),
('gmap', 'filter', 'filter_html', '-10', '0', 'a:3:{s:12:"allowed_html";s:74:"<a> <em> <strong> <cite> <blockquote> <code> <ul> <ol> <li> <dl> <dt> <dd>";s:16:"filter_html_help";i:1;s:20:"filter_html_nofollow";i:0;}'),
('gmap', 'filter', 'filter_htmlcorrector', '10', '0', 'a:0:{}'),
('gmap', 'filter', 'filter_html_escape', '-10', '0', 'a:0:{}'),
('gmap', 'filter', 'filter_url', '0', '0', 'a:1:{s:17:"filter_url_length";s:2:"72";}'),
('gmap', 'gmap', 'gmap_macro', '0', '1', 'a:0:{}'),
('gmap', 'php', 'php_code', '0', '0', 'a:0:{}'),
('php_code', 'filter', 'filter_autop', '10', '0', 'a:0:{}'),
('php_code', 'filter', 'filter_html', '10', '0', 'a:3:{s:12:"allowed_html";s:74:"<a> <em> <strong> <cite> <blockquote> <code> <ul> <ol> <li> <dl> <dt> <dd>";s:16:"filter_html_help";i:1;s:20:"filter_html_nofollow";i:0;}'),
('php_code', 'filter', 'filter_htmlcorrector', '10', '0', 'a:0:{}'),
('php_code', 'filter', 'filter_html_escape', '10', '0', 'a:0:{}'),
('php_code', 'filter', 'filter_url', '10', '0', 'a:1:{s:17:"filter_url_length";i:72;}'),
('php_code', 'php', 'php_code', '0', '1', 'a:0:{}'),
('plain_text', 'filter', 'filter_autop', '2', '1', 'a:0:{}'),
('plain_text', 'filter', 'filter_html', '10', '0', 'a:3:{s:12:"allowed_html";s:74:"<a> <em> <strong> <cite> <blockquote> <code> <ul> <ol> <li> <dl> <dt> <dd>";s:16:"filter_html_help";i:1;s:20:"filter_html_nofollow";i:0;}'),
('plain_text', 'filter', 'filter_htmlcorrector', '10', '0', 'a:0:{}'),
('plain_text', 'filter', 'filter_html_escape', '0', '1', 'a:0:{}'),
('plain_text', 'filter', 'filter_url', '1', '1', 'a:1:{s:17:"filter_url_length";i:72;}');
/*!40000 ALTER TABLE filter ENABLE KEYS */;

--
-- Table structure for table 'filter_format'
--

CREATE TABLE IF NOT EXISTS `filter_format` (
  `format` varchar(255) NOT NULL COMMENT 'Primary Key: Unique machine name of the format.',
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT 'Name of the text format (Filtered HTML).',
  `cache` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'Flag to indicate whether format is cacheable. (1 = cacheable, 0 = not cacheable)',
  `status` tinyint(3) unsigned NOT NULL DEFAULT '1' COMMENT 'The status of the text format. (1 = enabled, 0 = disabled)',
  `weight` int(11) NOT NULL DEFAULT '0' COMMENT 'Weight of text format to use when listing.',
  PRIMARY KEY (`format`),
  UNIQUE KEY `name` (`name`),
  KEY `status_weight` (`status`,`weight`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores text formats: custom groupings of filters, such as...';

--
-- Dumping data for table 'filter_format'
--

/*!40000 ALTER TABLE filter_format DISABLE KEYS */;
INSERT INTO `filter_format` VALUES
('filtered_html', 'Filtered HTML', '1', '1', '-9'),
('full_html', 'Full HTML', '1', '1', '-10'),
('gmap', 'Gmap', '0', '1', '-6'),
('php_code', 'PHP code', '0', '1', '-8'),
('plain_text', 'Plain text', '1', '1', '-7');
/*!40000 ALTER TABLE filter_format ENABLE KEYS */;

--
-- Table structure for table 'flexslider_optionset'
--

CREATE TABLE IF NOT EXISTS `flexslider_optionset` (
  `name` varchar(255) NOT NULL COMMENT 'The machine-readable option set name.',
  `title` varchar(255) NOT NULL COMMENT 'The human-readable title for this option set.',
  `theme` varchar(255) NOT NULL DEFAULT 'classic' COMMENT 'The flexslider theme.',
  `imagestyle_normal` varchar(255) NOT NULL DEFAULT 'flexslider_full' COMMENT 'The image style for normal images.',
  `options` longblob COMMENT 'The options array.',
  `imagestyle_thumbnail` varchar(255) NOT NULL DEFAULT 'flexslider_thumbnail' COMMENT 'The image style for thumbnail images.',
  PRIMARY KEY (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Store option sets for flexslider instances.';

--
-- Dumping data for table 'flexslider_optionset'
--

/*!40000 ALTER TABLE flexslider_optionset DISABLE KEYS */;
INSERT INTO `flexslider_optionset` VALUES
('default', 'Default', 'classic', 'flexslider_full', 'a:38:{s:9:"namespace";s:5:"flex-";s:8:"selector";s:12:".slides > li";s:6:"easing";s:5:"swing";s:9:"direction";s:10:"horizontal";s:7:"reverse";i:0;s:12:"smoothHeight";i:0;s:7:"startAt";s:1:"0";s:14:"animationSpeed";s:3:"600";s:9:"initDelay";s:1:"0";s:6:"useCSS";i:1;s:5:"touch";i:1;s:5:"video";i:0;s:8:"keyboard";i:1;s:16:"multipleKeyboard";i:0;s:10:"mousewheel";i:0;s:17:"controlsContainer";s:27:".flex-control-nav-container";s:4:"sync";s:0:"";s:8:"asNavFor";s:0:"";s:9:"itemWidth";s:1:"0";s:10:"itemMargin";s:1:"0";s:8:"minItems";s:1:"0";s:8:"maxItems";s:1:"0";s:4:"move";s:1:"0";s:9:"animation";s:4:"fade";s:9:"slideshow";i:1;s:14:"slideshowSpeed";s:4:"7000";s:12:"directionNav";i:0;s:10:"controlNav";s:1:"1";s:8:"prevText";s:8:"Previous";s:8:"nextText";s:4:"Next";s:9:"pausePlay";i:0;s:9:"pauseText";s:5:"Pause";s:8:"playText";s:4:"Play";s:9:"randomize";i:0;s:13:"animationLoop";i:1;s:13:"pauseOnAction";i:1;s:12:"pauseOnHover";i:0;s:14:"manualControls";s:0:"";}', 'flexslider_thumbnail');
/*!40000 ALTER TABLE flexslider_optionset ENABLE KEYS */;

--
-- Table structure for table 'flickr_users'
--

CREATE TABLE IF NOT EXISTS `flickr_users` (
  `uid` int(11) NOT NULL COMMENT 'Primary Key: Drupal user ID',
  `nsid` varchar(64) NOT NULL COMMENT 'Flickr NSID',
  `identifier` varchar(64) NOT NULL COMMENT 'Flickr identifier',
  PRIMARY KEY (`uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Connects Drupal users to their Flickr accounts.';

--
-- Dumping data for table 'flickr_users'
--

/*!40000 ALTER TABLE flickr_users DISABLE KEYS */;
/*!40000 ALTER TABLE flickr_users ENABLE KEYS */;

--
-- Table structure for table 'flood'
--

CREATE TABLE IF NOT EXISTS `flood` (
  `fid` int(11) NOT NULL AUTO_INCREMENT COMMENT 'Unique flood event ID.',
  `event` varchar(64) NOT NULL DEFAULT '' COMMENT 'Name of event (e.g. contact).',
  `identifier` varchar(128) NOT NULL DEFAULT '' COMMENT 'Identifier of the visitor, such as an IP address or hostname.',
  `timestamp` int(11) NOT NULL DEFAULT '0' COMMENT 'Timestamp of the event.',
  `expiration` int(11) NOT NULL DEFAULT '0' COMMENT 'Expiration timestamp. Expired events are purged on cron run.',
  PRIMARY KEY (`fid`),
  KEY `allow` (`event`,`identifier`,`timestamp`),
  KEY `purge` (`expiration`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Flood controls the threshold of events, such as the...';

--
-- Dumping data for table 'flood'
--

/*!40000 ALTER TABLE flood DISABLE KEYS */;
/*!40000 ALTER TABLE flood ENABLE KEYS */;

--
-- Table structure for table 'follow_links'
--

CREATE TABLE IF NOT EXISTS `follow_links` (
  `lid` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Unique identifier for the follow_links.',
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT 'The machine name of the follow_links.',
  `uid` int(11) NOT NULL DEFAULT '0' COMMENT 'User’s users uid.  Sitewide follow_links use uid 0',
  `path` varchar(255) NOT NULL DEFAULT '' COMMENT 'The Drupal path or extenal URL the follow_links should point to.',
  `options` text COMMENT 'A serialized array of options to be passed to the url() or l() function, such as a query string or HTML attributes.',
  `title` varchar(255) NOT NULL DEFAULT '' COMMENT 'The human readable name for the link.',
  `weight` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'The weight of this follow_links.',
  PRIMARY KEY (`lid`),
  UNIQUE KEY `uid_name` (`uid`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores sitewide and user follow links.';

--
-- Dumping data for table 'follow_links'
--

/*!40000 ALTER TABLE follow_links DISABLE KEYS */;
INSERT INTO `follow_links` VALUES
('1', 'this-site', '0', 'rss.xml', 'a:2:{s:5:"query";a:0:{}s:8:"fragment";s:0:"";}', '', '-9'),
('9', 'facebook', '0', 'http://www.facebook.com/', 'a:2:{s:5:"query";a:0:{}s:8:"fragment";s:0:"";}', '', '-10'),
('10', 'twitter', '0', 'https://twitter.com/', 'a:2:{s:5:"query";a:0:{}s:8:"fragment";s:0:"";}', '', '-8'),
('11', 'googleplus', '0', 'https://plus.google.com/', 'a:2:{s:5:"query";a:0:{}s:8:"fragment";s:0:"";}', '', '-7');
/*!40000 ALTER TABLE follow_links ENABLE KEYS */;

--
-- Table structure for table 'forum'
--

CREATE TABLE IF NOT EXISTS `forum` (
  `nid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The node.nid of the node.',
  `vid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'Primary Key: The node.vid of the node.',
  `tid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The taxonomy_term_data.tid of the forum term assigned to the node.',
  PRIMARY KEY (`vid`),
  KEY `forum_topic` (`nid`,`tid`),
  KEY `tid` (`tid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores the relationship of nodes to forum terms.';

--
-- Dumping data for table 'forum'
--

/*!40000 ALTER TABLE forum DISABLE KEYS */;
INSERT INTO `forum` VALUES
('12', '12', '1'),
('13', '13', '1'),
('14', '14', '1'),
('15', '15', '1'),
('16', '16', '1'),
('17', '17', '5'),
('18', '18', '5'),
('19', '19', '5'),
('20', '20', '5'),
('21', '21', '6'),
('22', '22', '6'),
('23', '23', '6'),
('24', '24', '6'),
('25', '25', '7'),
('26', '26', '7'),
('27', '27', '7'),
('28', '28', '8'),
('29', '29', '8'),
('30', '30', '8'),
('31', '31', '8'),
('32', '32', '8'),
('33', '33', '9'),
('34', '34', '9'),
('35', '35', '10');
/*!40000 ALTER TABLE forum ENABLE KEYS */;

--
-- Table structure for table 'forum_index'
--

CREATE TABLE IF NOT EXISTS `forum_index` (
  `nid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The node.nid this record tracks.',
  `title` varchar(255) NOT NULL DEFAULT '' COMMENT 'The title of this node, always treated as non-markup plain text.',
  `tid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The term ID.',
  `sticky` tinyint(4) DEFAULT '0' COMMENT 'Boolean indicating whether the node is sticky.',
  `created` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp when the node was created.',
  `last_comment_timestamp` int(11) NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp of the last comment that was posted within this node, from comment.timestamp.',
  `comment_count` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The total number of comments on this node.',
  KEY `forum_topics` (`nid`,`tid`,`sticky`,`last_comment_timestamp`),
  KEY `created` (`created`),
  KEY `last_comment_timestamp` (`last_comment_timestamp`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Maintains denormalized information about node/term...';

--
-- Dumping data for table 'forum_index'
--

/*!40000 ALTER TABLE forum_index DISABLE KEYS */;
INSERT INTO `forum_index` VALUES
('12', 'Lorem ipsum dolor sit amet', '1', '0', '1305117326', '1305117353', '3'),
('13', 'In pellentesque facilisis iaculis.', '1', '0', '1305117431', '1305117437', '1'),
('14', 'Mauris porta magna eget dolor vestibulum dapibus', '1', '0', '1305117493', '1305117530', '5'),
('15', 'Suspendisse potenti', '1', '0', '1305117558', '1305117558', '0'),
('16', 'Pellentesque habitant morbi tristique senectus', '1', '0', '1305117592', '1305117601', '2'),
('17', 'Ut vehicula, quam aliquam fringilla', '5', '0', '1305117638', '1305117638', '0'),
('18', 'Nam nec est a nulla pulvinar dignissim', '5', '0', '1305117661', '1305117661', '0'),
('19', 'In ac lectus massa. Pellentesque eros ligula', '5', '0', '1305117686', '1305117686', '0'),
('20', 'Suspendisse vulputate hendrerit nulla', '5', '0', '1305117721', '1305117721', '0'),
('21', 'Lorem ipsum dolor sit amet', '6', '0', '1305117759', '1305117759', '0'),
('22', 'Cras euismod aliquet massa scelerisque euismo', '6', '0', '1305117790', '1305117790', '0'),
('23', 'Cras euismod aliquet massa scelerisque', '6', '0', '1305117828', '1305117828', '0'),
('24', 'Praesent non mauris eget nisi', '6', '0', '1305117855', '1305117855', '0'),
('25', 'Suspendisse tempor libero sed ip', '7', '0', '1305117888', '1305117888', '0'),
('26', 'Fusce ac lacus metu', '7', '0', '1305117913', '1305117913', '0'),
('27', 'Curabitur feugiat ornare pul', '7', '0', '1305117944', '1305117944', '0'),
('28', 'Suspendisse potenti', '8', '0', '1305117979', '1305117979', '0'),
('29', 'Curabitur feugiat ornare pulv', '8', '0', '1305118002', '1305118002', '0'),
('30', 'entesque tempus hend', '8', '0', '1305118030', '1305118030', '0'),
('31', 'rius metus, consequat sollicit', '8', '0', '1305118075', '1305118075', '0'),
('32', 'Aliquam vitae nunc metus', '8', '0', '1305118101', '1305118101', '0'),
('33', 'Aliquam lacinia iaculis leo', '9', '0', '1305118138', '1305118138', '0'),
('34', 'Lorem ipsum dolor sit am', '9', '0', '1305118163', '1305118163', '0'),
('35', 'Nullam eu erat nibh', '10', '0', '1305118193', '1305118193', '0');
/*!40000 ALTER TABLE forum_index ENABLE KEYS */;

--
-- Table structure for table 'getlocations_fields'
--

CREATE TABLE IF NOT EXISTS `getlocations_fields` (
  `glid` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique location ID.',
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT 'Place Name.',
  `street` varchar(255) NOT NULL DEFAULT '' COMMENT 'Street address, line 1.',
  `additional` varchar(255) NOT NULL DEFAULT '' COMMENT 'Street address, line 2.',
  `city` varchar(255) NOT NULL DEFAULT '' COMMENT 'City.',
  `province` varchar(255) NOT NULL DEFAULT '' COMMENT 'State / Province.',
  `postal_code` varchar(255) NOT NULL DEFAULT '' COMMENT 'Postal / ZIP code.',
  `country` varchar(255) NOT NULL DEFAULT '' COMMENT 'Country.',
  `address` varchar(255) NOT NULL DEFAULT '' COMMENT 'Address.',
  `latitude` float NOT NULL DEFAULT '0' COMMENT 'Location latitude (decimal degrees).',
  `longitude` float NOT NULL DEFAULT '0' COMMENT 'Location longitude (decimal degrees).',
  `marker` varchar(255) NOT NULL DEFAULT '' COMMENT 'Marker.',
  PRIMARY KEY (`glid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Locational data managed by getlocations_fields module.';

--
-- Dumping data for table 'getlocations_fields'
--

/*!40000 ALTER TABLE getlocations_fields DISABLE KEYS */;
INSERT INTO `getlocations_fields` VALUES
('2', '1000 5th Ave, New York, NY 10028, USA', '1000 5th Ave', 'Manhattan', 'New York', 'New York, New York', '10028', 'US', '', '40.7812', '-73.9667', '');
/*!40000 ALTER TABLE getlocations_fields ENABLE KEYS */;

--
-- Table structure for table 'getlocations_fields_entities'
--

CREATE TABLE IF NOT EXISTS `getlocations_fields_entities` (
  `nid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'Reference to node.nid.',
  `vid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'Reference to node_revision.vid.',
  `uid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'Reference to users.uid.',
  `tid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'Reference to term_data.tid.',
  `cid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'Reference to comment.cid.',
  `field_name` varchar(255) NOT NULL DEFAULT '' COMMENT 'Reference to field name.',
  `glid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'Reference to getlocations_fields.glid.',
  KEY `nid` (`nid`),
  KEY `vid` (`vid`),
  KEY `uid` (`uid`),
  KEY `tid` (`tid`),
  KEY `cid` (`cid`),
  KEY `field_name` (`field_name`),
  KEY `glid` (`glid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='N:M join table to join getlocations_fields entries to...';

--
-- Dumping data for table 'getlocations_fields_entities'
--

/*!40000 ALTER TABLE getlocations_fields_entities DISABLE KEYS */;
INSERT INTO `getlocations_fields_entities` VALUES
('81', '81', '0', '0', '0', 'field_map', '2');
/*!40000 ALTER TABLE getlocations_fields_entities ENABLE KEYS */;

--
-- Table structure for table 'gmap_taxonomy_node'
--

CREATE TABLE IF NOT EXISTS `gmap_taxonomy_node` (
  `nid` int(10) unsigned NOT NULL DEFAULT '0',
  `tid` int(10) unsigned NOT NULL DEFAULT '0',
  `marker` varchar(32) DEFAULT NULL,
  PRIMARY KEY (`nid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='InnoDB free: 7168 kB';

--
-- Dumping data for table 'gmap_taxonomy_node'
--

/*!40000 ALTER TABLE gmap_taxonomy_node DISABLE KEYS */;
/*!40000 ALTER TABLE gmap_taxonomy_node ENABLE KEYS */;

--
-- Table structure for table 'gmap_taxonomy_term'
--

CREATE TABLE IF NOT EXISTS `gmap_taxonomy_term` (
  `tid` int(10) unsigned NOT NULL DEFAULT '0',
  `marker` varchar(32) DEFAULT NULL,
  PRIMARY KEY (`tid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='InnoDB free: 7168 kB';

--
-- Dumping data for table 'gmap_taxonomy_term'
--

/*!40000 ALTER TABLE gmap_taxonomy_term DISABLE KEYS */;
/*!40000 ALTER TABLE gmap_taxonomy_term ENABLE KEYS */;

--
-- Table structure for table 'history'
--

CREATE TABLE IF NOT EXISTS `history` (
  `uid` int(11) NOT NULL DEFAULT '0' COMMENT 'The users.uid that read the node nid.',
  `nid` int(11) NOT NULL DEFAULT '0' COMMENT 'The node.nid that was read.',
  `timestamp` int(11) NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp at which the read occurred.',
  PRIMARY KEY (`uid`,`nid`),
  KEY `nid` (`nid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='A record of which users have read which nodes.';

--
-- Dumping data for table 'history'
--

/*!40000 ALTER TABLE history DISABLE KEYS */;
INSERT INTO `history` VALUES
('1', '14', '1378990886'),
('1', '51', '1378989891'),
('1', '76', '1378991309'),
('1', '79', '1378990427'),
('1', '82', '1379064101'),
('1', '84', '1378992052'),
('1', '87', '1378989975');
/*!40000 ALTER TABLE history ENABLE KEYS */;

--
-- Table structure for table 'image_effects'
--

CREATE TABLE IF NOT EXISTS `image_effects` (
  `ieid` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'The primary identifier for an image effect.',
  `isid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The image_styles.isid for an image style.',
  `weight` int(11) NOT NULL DEFAULT '0' COMMENT 'The weight of the effect in the style.',
  `name` varchar(255) NOT NULL COMMENT 'The unique name of the effect to be executed.',
  `data` longblob NOT NULL COMMENT 'The configuration data for the effect.',
  PRIMARY KEY (`ieid`),
  KEY `isid` (`isid`),
  KEY `weight` (`weight`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores configuration options for image effects.';

--
-- Dumping data for table 'image_effects'
--

/*!40000 ALTER TABLE image_effects DISABLE KEYS */;
INSERT INTO `image_effects` VALUES
('1', '1', '1', 'image_scale_and_crop', 'a:3:{s:5:"width";s:3:"300";s:6:"height";s:3:"245";s:8:"retinafy";i:1;}'),
('2', '2', '1', 'image_scale_and_crop', 'a:3:{s:5:"width";s:2:"80";s:6:"height";s:2:"80";s:8:"retinafy";i:1;}'),
('3', '3', '1', 'image_scale_and_crop', 'a:3:{s:5:"width";s:3:"220";s:6:"height";s:3:"160";s:8:"retinafy";i:1;}'),
('5', '5', '1', 'image_scale_and_crop', 'a:3:{s:5:"width";s:3:"460";s:6:"height";s:3:"330";s:8:"retinafy";i:1;}'),
('6', '6', '1', 'image_scale_and_crop', 'a:3:{s:5:"width";s:3:"300";s:6:"height";s:3:"220";s:8:"retinafy";i:1;}'),
('7', '7', '1', 'image_scale_and_crop', 'a:3:{s:5:"width";s:3:"600";s:6:"height";s:3:"350";s:8:"retinafy";i:1;}'),
('8', '8', '1', 'image_scale_and_crop', 'a:3:{s:5:"width";s:3:"324";s:6:"height";s:3:"267";s:8:"retinafy";i:1;}');
/*!40000 ALTER TABLE image_effects ENABLE KEYS */;

--
-- Table structure for table 'image_styles'
--

CREATE TABLE IF NOT EXISTS `image_styles` (
  `isid` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'The primary identifier for an image style.',
  `name` varchar(255) NOT NULL COMMENT 'The style name.',
  `label` varchar(255) NOT NULL DEFAULT '' COMMENT 'The style administrative name.',
  PRIMARY KEY (`isid`),
  UNIQUE KEY `name` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores configuration options for image styles.';

--
-- Dumping data for table 'image_styles'
--

/*!40000 ALTER TABLE image_styles DISABLE KEYS */;
INSERT INTO `image_styles` VALUES
('1', 'blog_image', 'blog_image'),
('2', 'our_team_80x80', 'our_team_80x80'),
('3', 'portfolio_4_cols', 'portfolio_4_cols'),
('5', 'portfolio_2_cols', 'portfolio_2_cols'),
('6', 'portfolio_3_cols', 'portfolio_3_cols'),
('7', 'full_post', 'full_post'),
('8', '324x267', '324x267');
/*!40000 ALTER TABLE image_styles ENABLE KEYS */;

--
-- Table structure for table 'languages'
--

CREATE TABLE IF NOT EXISTS `languages` (
  `language` varchar(12) NOT NULL DEFAULT '' COMMENT 'Language code, e.g. ’de’ or ’en-US’.',
  `name` varchar(64) NOT NULL DEFAULT '' COMMENT 'Language name in English.',
  `native` varchar(64) NOT NULL DEFAULT '' COMMENT 'Native language name.',
  `direction` int(11) NOT NULL DEFAULT '0' COMMENT 'Direction of language (Left-to-Right = 0, Right-to-Left = 1).',
  `enabled` int(11) NOT NULL DEFAULT '0' COMMENT 'Enabled flag (1 = Enabled, 0 = Disabled).',
  `plurals` int(11) NOT NULL DEFAULT '0' COMMENT 'Number of plural indexes in this language.',
  `formula` varchar(255) NOT NULL DEFAULT '' COMMENT 'Plural formula in PHP code to evaluate to get plural indexes.',
  `domain` varchar(128) NOT NULL DEFAULT '' COMMENT 'Domain to use for this language.',
  `prefix` varchar(128) NOT NULL DEFAULT '' COMMENT 'Path prefix to use for this language.',
  `weight` int(11) NOT NULL DEFAULT '0' COMMENT 'Weight, used in lists of languages.',
  `javascript` varchar(64) NOT NULL DEFAULT '' COMMENT 'Location of JavaScript translation file.',
  PRIMARY KEY (`language`),
  KEY `list` (`weight`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='List of all available languages in the system.';

--
-- Dumping data for table 'languages'
--

/*!40000 ALTER TABLE languages DISABLE KEYS */;
INSERT INTO `languages` VALUES
('en', 'English', 'English', '0', '1', '0', '', '', '', '0', '');
/*!40000 ALTER TABLE languages ENABLE KEYS */;

--
-- Table structure for table 'locales_source'
--

CREATE TABLE IF NOT EXISTS `locales_source` (
  `lid` int(11) NOT NULL AUTO_INCREMENT COMMENT 'Unique identifier of this string.',
  `location` longtext COMMENT 'Drupal path in case of online discovered translations or file path in case of imported strings.',
  `textgroup` varchar(255) NOT NULL DEFAULT 'default' COMMENT 'A module defined group of translations, see hook_locale().',
  `source` blob NOT NULL COMMENT 'The original string in English.',
  `context` varchar(255) NOT NULL DEFAULT '' COMMENT 'The context this string applies to.',
  `version` varchar(20) NOT NULL DEFAULT 'none' COMMENT 'Version of Drupal, where the string was last used (for locales optimization).',
  PRIMARY KEY (`lid`),
  KEY `source_context` (`source`(30),`context`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='List of English source strings.';

--
-- Dumping data for table 'locales_source'
--

/*!40000 ALTER TABLE locales_source DISABLE KEYS */;
INSERT INTO `locales_source` VALUES
('1', 'misc/drupal.js', 'default', 'An AJAX HTTP error occurred.', '', 'none'),
('2', 'misc/drupal.js', 'default', 'HTTP Result Code: !status', '', 'none'),
('3', 'misc/drupal.js', 'default', 'An AJAX HTTP request terminated abnormally.', '', 'none'),
('4', 'misc/drupal.js', 'default', 'Debugging information follows.', '', 'none'),
('5', 'misc/drupal.js', 'default', 'Path: !uri', '', 'none'),
('6', 'misc/drupal.js', 'default', 'StatusText: !statusText', '', 'none'),
('7', 'misc/drupal.js', 'default', 'ResponseText: !responseText', '', 'none'),
('8', 'misc/drupal.js', 'default', 'ReadyState: !readyState', '', 'none'),
('9', 'modules/overlay/overlay-child.js', 'default', 'Loading', '', 'none'),
('10', 'modules/overlay/overlay-child.js; misc/vertical-tabs.js', 'default', '(active tab)', '', 'none'),
('11', 'misc/collapse.js', 'default', 'Hide', '', 'none'),
('12', 'misc/collapse.js', 'default', 'Show', '', 'none'),
('13', 'modules/block/block.js', 'default', 'Not restricted', '', 'none'),
('14', 'modules/block/block.js', 'default', 'Restricted to certain pages', '', 'none'),
('15', 'modules/block/block.js', 'default', 'Not customizable', '', 'none'),
('16', 'modules/block/block.js', 'default', 'The changes to these blocks will not be saved until the <em>Save blocks</em> button is clicked.', '', 'none'),
('17', 'modules/block/block.js', 'default', 'The block cannot be placed in this region.', '', 'none'),
('18', 'misc/tabledrag.js', 'default', 'Re-order rows by numerical weight instead of dragging.', '', 'none'),
('19', 'misc/tabledrag.js', 'default', 'Show row weights', '', 'none'),
('20', 'misc/tabledrag.js', 'default', 'Hide row weights', '', 'none'),
('21', 'misc/tabledrag.js', 'default', 'Drag to re-order', '', 'none'),
('22', 'misc/tabledrag.js', 'default', 'Changes made in this table will not be saved until the form is submitted.', '', 'none'),
('23', 'modules/overlay/overlay-parent.js', 'default', '@title dialog', '', 'none'),
('24', 'modules/contextual/contextual.js', 'default', 'Configure', '', 'none'),
('25', 'modules/toolbar/toolbar.js', 'default', 'Show shortcuts', '', 'none'),
('26', 'modules/toolbar/toolbar.js', 'default', 'Hide shortcuts', '', 'none'),
('27', 'modules/field/modules/text/text.js', 'default', 'Hide summary', '', 'none'),
('28', 'modules/field/modules/text/text.js', 'default', 'Edit summary', '', 'none'),
('29', 'modules/menu/menu.js', 'default', 'Not in menu', '', 'none'),
('30', 'misc/ajax.js', 'default', 'Please wait...', '', 'none'),
('31', 'modules/book/book.js', 'default', 'Not in book', '', 'none'),
('32', 'modules/book/book.js', 'default', 'New book', '', 'none'),
('33', 'modules/node/node.js', 'default', 'New revision', '', 'none'),
('34', 'modules/node/node.js', 'default', 'No revision', '', 'none'),
('35', 'modules/node/node.js', 'default', 'By @name on @date', '', 'none'),
('36', 'modules/node/node.js', 'default', 'By @name', '', 'none'),
('37', 'modules/node/node.js; modules/node/content_types.js', 'default', 'Not published', '', 'none'),
('38', 'modules/path/path.js', 'default', 'Alias: @alias', '', 'none'),
('39', 'modules/path/path.js', 'default', 'No alias', '', 'none'),
('40', 'modules/comment/comment-node-form.js', 'default', '@number comments per page', '', 'none'),
('41', 'misc/autocomplete.js', 'default', 'Autocomplete popup', '', 'none'),
('42', 'misc/autocomplete.js', 'default', 'Searching for matches...', '', 'none'),
('43', 'misc/tableselect.js', 'default', 'Select all rows in this table', '', 'none'),
('44', 'misc/tableselect.js', 'default', 'Deselect all rows in this table', '', 'none'),
('45', 'modules/file/file.js', 'default', 'The selected file %filename cannot be uploaded. Only files with the following extensions are allowed: %extensions.', '', 'none'),
('46', 'misc/machine-name.js', 'default', 'Edit', '', 'none'),
('47', 'modules/filter/filter.admin.js', 'default', 'Enabled', '', 'none'),
('48', 'modules/filter/filter.admin.js', 'default', 'Disabled', '', 'none'),
('49', 'modules/user/user.permissions.js', 'default', 'This permission is inherited from the authenticated user role.', '', 'none'),
('50', 'modules/node/content_types.js', 'default', 'Requires a title', '', 'none'),
('51', 'modules/node/content_types.js', 'default', 'Don''t display post information', '', 'none'),
('52', 'sites/all/modules/views_jqfx_cycle/views_jqfx_cycle.js; sites/all/modules/views_slideshow/js/views_slideshow.js', 'default', 'Resume', '', 'none'),
('53', 'sites/all/modules/views_jqfx_cycle/views_jqfx_cycle.js; sites/all/modules/views_slideshow/js/views_slideshow.js', 'default', 'Pause', '', 'none'),
('54', 'sites/all/modules/views/js/views-admin.js', 'default', 'Remove group', '', 'none'),
('55', 'sites/all/modules/jcarousel/js/jcarousel.js', 'default', 'Internal server error. Please see server or PHP logs for error information.', '', 'none'),
('56', 'sites/all/modules/jcarousel/js/jcarousel.js', 'default', 'An error occurred at @path.\\n\\nError Description: @error', '', 'none'),
('57', 'sites/all/modules/panels/plugins/layouts/flexible/flexible-admin.js', 'default', 'Hide layout designer', '', 'none'),
('58', 'sites/all/modules/panels/plugins/layouts/flexible/flexible-admin.js', 'default', 'Show layout designer', '', 'none'),
('59', 'sites/all/modules/views/js/views-admin.js', 'default', 'Apply (all displays)', '', 'none'),
('60', 'sites/all/modules/views/js/views-admin.js', 'default', 'Apply (this display)', '', 'none'),
('61', 'sites/all/modules/views/js/views-admin.js', 'default', 'Revert to default', '', 'none'),
('62', 'sites/all/modules/scroll_to_top/scroll_to_top.js', 'default', 'Back to Top', '', 'none'),
('63', 'sites/all/modules/views_slideshow/js/views_slideshow.js', 'default', 'There was no action specified.', '', 'none'),
('64', 'sites/all/modules/views_slideshow/js/views_slideshow.js', 'default', 'This slideshow is forced paused.', '', 'none'),
('65', 'sites/all/modules/views_slideshow/js/views_slideshow.js', 'default', 'An invalid integer was specified for slideNum.', '', 'none'),
('66', 'sites/all/modules/views_slideshow/js/views_slideshow.js', 'default', 'An invalid action "!action" was specified.', '', 'none'),
('67', 'sites/all/modules/getlocations/js/icons.js', 'default', 'Request for invalid marker set !b', '', 'none'),
('68', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'There was a problem contacting the Google servers.', '', 'none'),
('69', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'This GeocoderRequest was invalid.', '', 'none'),
('70', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'The webpage has gone over the requests limit in too short a period of time.', '', 'none'),
('71', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'The webpage is not allowed to use the geocoder.', '', 'none'),
('72', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'A geocoding request could not be processed due to a server error. The request may succeed if you try again.', '', 'none'),
('73', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'No result was found for this GeocoderRequest.', '', 'none'),
('74', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'due to an unknown error', '', 'none'),
('75', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'because you didn''t give me permission', '', 'none'),
('76', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'because your browser couldn''t determine your location', '', 'none'),
('77', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'because it was taking too long to determine your location', '', 'none'),
('78', 'sites/all/modules/getlocations/modules/getlocations_fields/js/getlocations_fields.js', 'default', 'This field is required.', '', 'none'),
('79', 'sites/all/modules/getlocations/modules/getlocations_fields/js/getlocations_fields.js', 'default', 'You must fill in the Latitude/Longitude fields. Use the Search or move the marker.', '', 'none'),
('80', 'sites/all/modules/getlocations/modules/getlocations_fields/js/getlocations_fields.js', 'default', 'You must fill in the Latitude/Longitude fields. Use Geocoding or move the marker.', '', 'none'),
('81', 'sites/all/modules/getlocations/modules/getlocations_fields/js/getlocations_fields.js', 'default', 'Geocode for (!a) was not successful for the following reason: !b', '', 'none'),
('82', 'sites/all/modules/getlocations/modules/getlocations_fields/js/getlocations_fields.js', 'default', 'You have not entered an address.', '', 'none'),
('83', 'sites/all/modules/getlocations/modules/getlocations_fields/js/getlocations_fields.js', 'default', 'Drag me to change position', '', 'none'),
('84', 'sites/all/modules/getlocations/modules/getlocations_fields/js/getlocations_fields.js', 'default', 'Browser OK', '', 'none'),
('85', 'sites/all/modules/getlocations/modules/getlocations_fields/js/getlocations_fields.js', 'default', 'Sorry, I couldn''t find your location using the browser', '', 'none'),
('86', 'sites/all/modules/getlocations/modules/getlocations_fields/js/getlocations_fields.js', 'default', 'Geocode was not successful for the following reason: !b', '', 'none'),
('87', 'sites/all/modules/views/js/views-admin.js', 'default', 'Add', '', 'none'),
('88', 'sites/all/modules/back_to_top/js/back_to_top.js', 'default', '<span class=''backtotop-wrapper''>&uarr;</span> TOP', '', 'none'),
('89', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'Full screen', '', 'none'),
('90', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'Normal screen', '', 'none'),
('91', 'sites/all/modules/module_filter/js/module_filter_tab.js', 'default', '+@count', '', 'none'),
('92', 'sites/all/modules/module_filter/js/module_filter_tab.js', 'default', '-@count', '', 'none'),
('93', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'OpenStreetMap', '', 'none'),
('94', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'OSM map', '', 'none'),
('95', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'Kml Layer', '', 'none'),
('96', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'On', '', 'none'),
('97', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'Off', '', 'none'),
('98', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'Traffic Info On', '', 'none'),
('99', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'Traffic Info Off', '', 'none'),
('100', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'Bicycle Info On', '', 'none'),
('101', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'Bicycle Info Off', '', 'none'),
('102', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'Transit Info On', '', 'none'),
('103', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'Transit Info Off', '', 'none'),
('104', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'Panoramio On', '', 'none'),
('105', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'Panoramio Off', '', 'none'),
('106', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'Clouds On', '', 'none'),
('107', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'Clouds Off', '', 'none'),
('108', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'Weather On', '', 'none'),
('109', 'sites/all/modules/getlocations/js/getlocations.js', 'default', 'Weather Off', '', 'none'),
('110', 'sites/all/modules/admin_menu/admin_menu.admin.js', 'default', 'Also allow !name role to !permission?', '', 'none');
/*!40000 ALTER TABLE locales_source ENABLE KEYS */;

--
-- Table structure for table 'locales_target'
--

CREATE TABLE IF NOT EXISTS `locales_target` (
  `lid` int(11) NOT NULL DEFAULT '0' COMMENT 'Source string ID. References locales_source.lid.',
  `translation` blob NOT NULL COMMENT 'Translation string value in this language.',
  `language` varchar(12) NOT NULL DEFAULT '' COMMENT 'Language code. References languages.language.',
  `plid` int(11) NOT NULL DEFAULT '0' COMMENT 'Parent lid (lid of the previous string in the plural chain) in case of plural strings. References locales_source.lid.',
  `plural` int(11) NOT NULL DEFAULT '0' COMMENT 'Plural index number in case of plural strings.',
  PRIMARY KEY (`language`,`lid`,`plural`),
  KEY `lid` (`lid`),
  KEY `plid` (`plid`),
  KEY `plural` (`plural`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores translated versions of strings.';

--
-- Dumping data for table 'locales_target'
--

/*!40000 ALTER TABLE locales_target DISABLE KEYS */;
/*!40000 ALTER TABLE locales_target ENABLE KEYS */;

--
-- Table structure for table 'menu_custom'
--

CREATE TABLE IF NOT EXISTS `menu_custom` (
  `menu_name` varchar(32) NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique key for menu. This is used as a block delta so length is 32.',
  `title` varchar(255) NOT NULL DEFAULT '' COMMENT 'Menu title; displayed at top of block.',
  `description` text COMMENT 'Menu description.',
  PRIMARY KEY (`menu_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Holds definitions for top-level custom menus (for example...';

--
-- Dumping data for table 'menu_custom'
--

/*!40000 ALTER TABLE menu_custom DISABLE KEYS */;
INSERT INTO `menu_custom` VALUES
('devel', 'Development', 'Development link'),
('main-menu', 'Main menu', 'The <em>Main</em> menu is used on many sites to show the major sections of the site, often in a top navigation bar.'),
('management', 'Management', 'The <em>Management</em> menu contains links for administrative tasks.'),
('navigation', 'Navigation', 'The <em>Navigation</em> menu contains links intended for site visitors. Links are added to the <em>Navigation</em> menu automatically by some modules.'),
('user-menu', 'User menu', 'The <em>User</em> menu contains links related to the user''s account, as well as the ''Log out'' link.');
/*!40000 ALTER TABLE menu_custom ENABLE KEYS */;

--
-- Table structure for table 'menu_links'
--

CREATE TABLE IF NOT EXISTS `menu_links` (
  `menu_name` varchar(32) NOT NULL DEFAULT '' COMMENT 'The menu name. All links with the same menu name (such as ’navigation’) are part of the same menu.',
  `mlid` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'The menu link ID (mlid) is the integer primary key.',
  `plid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The parent link ID (plid) is the mlid of the link above in the hierarchy, or zero if the link is at the top level in its menu.',
  `link_path` varchar(255) NOT NULL DEFAULT '' COMMENT 'The Drupal path or external path this link points to.',
  `router_path` varchar(255) NOT NULL DEFAULT '' COMMENT 'For links corresponding to a Drupal path (external = 0), this connects the link to a menu_router.path for joins.',
  `link_title` varchar(255) NOT NULL DEFAULT '' COMMENT 'The text displayed for the link, which may be modified by a title callback stored in menu_router.',
  `options` blob COMMENT 'A serialized array of options to be passed to the url() or l() function, such as a query string or HTML attributes.',
  `module` varchar(255) NOT NULL DEFAULT 'system' COMMENT 'The name of the module that generated this link.',
  `hidden` smallint(6) NOT NULL DEFAULT '0' COMMENT 'A flag for whether the link should be rendered in menus. (1 = a disabled menu item that may be shown on admin screens, -1 = a menu callback, 0 = a normal, visible link)',
  `external` smallint(6) NOT NULL DEFAULT '0' COMMENT 'A flag to indicate if the link points to a full URL starting with a protocol, like http:// (1 = external, 0 = internal).',
  `has_children` smallint(6) NOT NULL DEFAULT '0' COMMENT 'Flag indicating whether any links have this link as a parent (1 = children exist, 0 = no children).',
  `expanded` smallint(6) NOT NULL DEFAULT '0' COMMENT 'Flag for whether this link should be rendered as expanded in menus - expanded links always have their child links displayed, instead of only when the link is in the active trail (1 = expanded, 0 = not expanded)',
  `weight` int(11) NOT NULL DEFAULT '0' COMMENT 'Link weight among links in the same menu at the same depth.',
  `depth` smallint(6) NOT NULL DEFAULT '0' COMMENT 'The depth relative to the top level. A link with plid == 0 will have depth == 1.',
  `customized` smallint(6) NOT NULL DEFAULT '0' COMMENT 'A flag to indicate that the user has manually created or edited the link (1 = customized, 0 = not customized).',
  `p1` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The first mlid in the materialized path. If N = depth, then pN must equal the mlid. If depth > 1 then p(N-1) must equal the plid. All pX where X > depth must equal zero. The columns p1 .. p9 are also called the parents.',
  `p2` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The second mlid in the materialized path. See p1.',
  `p3` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The third mlid in the materialized path. See p1.',
  `p4` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The fourth mlid in the materialized path. See p1.',
  `p5` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The fifth mlid in the materialized path. See p1.',
  `p6` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The sixth mlid in the materialized path. See p1.',
  `p7` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The seventh mlid in the materialized path. See p1.',
  `p8` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The eighth mlid in the materialized path. See p1.',
  `p9` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The ninth mlid in the materialized path. See p1.',
  `updated` smallint(6) NOT NULL DEFAULT '0' COMMENT 'Flag that indicates that this link was generated during the update from Drupal 5.',
  PRIMARY KEY (`mlid`),
  KEY `path_menu` (`link_path`(128),`menu_name`),
  KEY `menu_plid_expand_child` (`menu_name`,`plid`,`expanded`,`has_children`),
  KEY `menu_parents` (`menu_name`,`p1`,`p2`,`p3`,`p4`,`p5`,`p6`,`p7`,`p8`,`p9`),
  KEY `router_path` (`router_path`(128))
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Contains the individual links within a menu.';

--
-- Dumping data for table 'menu_links'
--

/*!40000 ALTER TABLE menu_links DISABLE KEYS */;
INSERT INTO `menu_links` VALUES
('management', '1', '0', 'admin', 'admin', 'Administration', 'a:0:{}', 'system', 0, 0, 1, 0, '9', 1, 0, '1', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('user-menu', '2', '0', 'user', 'user', 'User account', 'a:1:{s:5:"alter";b:1;}', 'system', 0, 0, 0, 0, '-10', 1, 0, '2', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '3', '0', 'comment/%', 'comment/%', 'Comment permalink', 'a:0:{}', 'system', 0, 0, 1, 0, '0', 1, 0, '3', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '4', '0', 'filter/tips', 'filter/tips', 'Compose tips', 'a:0:{}', 'system', 1, 0, 0, 0, '0', 1, 0, '4', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '5', '0', 'node/%', 'node/%', '', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 1, 0, '5', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '6', '0', 'node/add', 'node/add', 'Add content', 'a:0:{}', 'system', 0, 0, 1, 0, '0', 1, 0, '6', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '7', '1', 'admin/appearance', 'admin/appearance', 'Appearance', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:33:"Select and configure your themes.";}}', 'system', 0, 0, 0, 0, '-6', 2, 0, '1', '7', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '8', '1', 'admin/config', 'admin/config', 'Configuration', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:20:"Administer settings.";}}', 'system', 0, 0, 1, 0, '0', 2, 0, '1', '8', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '9', '1', 'admin/content', 'admin/content', 'Content', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:32:"Administer content and comments.";}}', 'system', 0, 0, 1, 0, '-10', 2, 0, '1', '9', '0', '0', '0', '0', '0', '0', '0', 0),
('user-menu', '10', '2', 'user/register', 'user/register', 'Create new account', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 2, 0, '2', '10', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '13', '1', 'admin/index', 'admin/index', 'Index', 'a:0:{}', 'system', -1, 0, 0, 0, '-18', 2, 0, '1', '13', '0', '0', '0', '0', '0', '0', '0', 0),
('user-menu', '14', '2', 'user/login', 'user/login', 'Log in', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 2, 0, '2', '14', '0', '0', '0', '0', '0', '0', '0', 0),
('user-menu', '15', '0', 'user/logout', 'user/logout', 'Log out', 'a:0:{}', 'system', 0, 0, 0, 0, '10', 1, 0, '15', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '16', '1', 'admin/modules', 'admin/modules', 'Modules', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:26:"Extend site functionality.";}}', 'system', 0, 0, 0, 0, '-2', 2, 0, '1', '16', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '17', '0', 'user/%', 'user/%', 'My account', 'a:0:{}', 'system', 0, 0, 1, 0, '0', 1, 0, '17', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '18', '1', 'admin/people', 'admin/people', 'People', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:45:"Manage user accounts, roles, and permissions.";}}', 'system', 0, 0, 0, 0, '-4', 2, 0, '1', '18', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '19', '1', 'admin/reports', 'admin/reports', 'Reports', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:34:"View reports, updates, and errors.";}}', 'system', 0, 0, 1, 0, '5', 2, 0, '1', '19', '0', '0', '0', '0', '0', '0', '0', 0),
('user-menu', '20', '2', 'user/password', 'user/password', 'Request new password', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 2, 0, '2', '20', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '21', '1', 'admin/structure', 'admin/structure', 'Structure', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:45:"Administer blocks, content types, menus, etc.";}}', 'system', 0, 0, 1, 0, '-8', 2, 0, '1', '21', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '22', '1', 'admin/tasks', 'admin/tasks', 'Tasks', 'a:0:{}', 'system', -1, 0, 0, 0, '-20', 2, 0, '1', '22', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '23', '0', 'comment/reply/%', 'comment/reply/%', 'Add new comment', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 1, 0, '23', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '24', '3', 'comment/%/approve', 'comment/%/approve', 'Approve', 'a:0:{}', 'system', 0, 0, 0, 0, '1', 2, 0, '3', '24', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '25', '3', 'comment/%/delete', 'comment/%/delete', 'Delete', 'a:0:{}', 'system', -1, 0, 0, 0, '2', 2, 0, '3', '25', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '26', '3', 'comment/%/edit', 'comment/%/edit', 'Edit', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 2, 0, '3', '26', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '27', '0', 'taxonomy/term/%', 'taxonomy/term/%', 'Taxonomy term', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 1, 0, '27', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '28', '3', 'comment/%/view', 'comment/%/view', 'View comment', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 2, 0, '3', '28', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '29', '18', 'admin/people/create', 'admin/people/create', 'Add user', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 3, 0, '1', '18', '29', '0', '0', '0', '0', '0', '0', 0),
('management', '30', '21', 'admin/structure/block', 'admin/structure/block', 'Blocks', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:79:"Configure what block content appears in your site''s sidebars and other regions.";}}', 'system', 0, 0, 1, 0, '0', 3, 0, '1', '21', '30', '0', '0', '0', '0', '0', '0', 0),
('navigation', '31', '17', 'user/%/cancel', 'user/%/cancel', 'Cancel account', 'a:0:{}', 'system', 0, 0, 1, 0, '0', 2, 0, '17', '31', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '32', '9', 'admin/content/comment', 'admin/content/comment', 'Comments', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:59:"List and edit site comments and the comment approval queue.";}}', 'system', 0, 0, 0, 0, '0', 3, 0, '1', '9', '32', '0', '0', '0', '0', '0', '0', 0),
('management', '34', '9', 'admin/content/node', 'admin/content/node', 'Content', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 3, 0, '1', '9', '34', '0', '0', '0', '0', '0', '0', 0),
('management', '35', '8', 'admin/config/content', 'admin/config/content', 'Content authoring', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:53:"Settings related to formatting and authoring content.";}}', 'system', 0, 0, 1, 0, '-15', 3, 0, '1', '8', '35', '0', '0', '0', '0', '0', '0', 0),
('management', '36', '21', 'admin/structure/types', 'admin/structure/types', 'Content types', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:92:"Manage content types, including default status, front page promotion, comment settings, etc.";}}', 'system', 0, 0, 1, 0, '0', 3, 0, '1', '21', '36', '0', '0', '0', '0', '0', '0', 0),
('navigation', '38', '5', 'node/%/delete', 'node/%/delete', 'Delete', 'a:0:{}', 'system', -1, 0, 0, 0, '1', 2, 0, '5', '38', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '39', '8', 'admin/config/development', 'admin/config/development', 'Development', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:18:"Development tools.";}}', 'system', 0, 0, 1, 0, '-10', 3, 0, '1', '8', '39', '0', '0', '0', '0', '0', '0', 0),
('navigation', '40', '17', 'user/%/edit', 'user/%/edit', 'Edit', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 2, 0, '17', '40', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '41', '5', 'node/%/edit', 'node/%/edit', 'Edit', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 2, 0, '5', '41', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '42', '19', 'admin/reports/fields', 'admin/reports/fields', 'Field list', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:39:"Overview of fields on all entity types.";}}', 'system', 0, 0, 0, 0, '0', 3, 0, '1', '19', '42', '0', '0', '0', '0', '0', '0', 0),
('management', '43', '7', 'admin/appearance/list', 'admin/appearance/list', 'List', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:31:"Select and configure your theme";}}', 'system', -1, 0, 0, 0, '-1', 3, 0, '1', '7', '43', '0', '0', '0', '0', '0', '0', 0),
('management', '44', '16', 'admin/modules/list', 'admin/modules/list', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 3, 0, '1', '16', '44', '0', '0', '0', '0', '0', '0', 0),
('management', '45', '18', 'admin/people/people', 'admin/people/people', 'List', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:50:"Find and manage people interacting with your site.";}}', 'system', -1, 0, 0, 0, '-10', 3, 0, '1', '18', '45', '0', '0', '0', '0', '0', '0', 0),
('management', '46', '8', 'admin/config/media', 'admin/config/media', 'Media', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:12:"Media tools.";}}', 'system', 0, 0, 1, 0, '-10', 3, 0, '1', '8', '46', '0', '0', '0', '0', '0', '0', 0),
('management', '47', '21', 'admin/structure/menu', 'admin/structure/menu', 'Menus', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:86:"Add new menus to your site, edit existing menus, and rename and reorganize menu links.";}}', 'system', 0, 0, 1, 0, '0', 3, 0, '1', '21', '47', '0', '0', '0', '0', '0', '0', 0),
('management', '48', '8', 'admin/config/people', 'admin/config/people', 'People', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:24:"Configure user accounts.";}}', 'system', 0, 0, 1, 0, '-20', 3, 0, '1', '8', '48', '0', '0', '0', '0', '0', '0', 0),
('management', '49', '18', 'admin/people/permissions', 'admin/people/permissions', 'Permissions', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:64:"Determine access to features by selecting permissions for roles.";}}', 'system', -1, 0, 0, 0, '0', 3, 0, '1', '18', '49', '0', '0', '0', '0', '0', '0', 0),
('management', '51', '8', 'admin/config/regional', 'admin/config/regional', 'Regional and language', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:48:"Regional settings, localization and translation.";}}', 'system', 0, 0, 1, 0, '-5', 3, 0, '1', '8', '51', '0', '0', '0', '0', '0', '0', 0),
('navigation', '52', '5', 'node/%/revisions', 'node/%/revisions', 'Revisions', 'a:0:{}', 'system', -1, 0, 1, 0, '2', 2, 0, '5', '52', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '53', '8', 'admin/config/search', 'admin/config/search', 'Search and metadata', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:36:"Local site search, metadata and SEO.";}}', 'system', 0, 0, 1, 0, '-10', 3, 0, '1', '8', '53', '0', '0', '0', '0', '0', '0', 0),
('management', '54', '7', 'admin/appearance/settings', 'admin/appearance/settings', 'Settings', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:46:"Configure default and theme specific settings.";}}', 'system', -1, 0, 0, 0, '20', 3, 0, '1', '7', '54', '0', '0', '0', '0', '0', '0', 0),
('management', '55', '19', 'admin/reports/status', 'admin/reports/status', 'Status report', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:74:"Get a status report about your site''s operation and any detected problems.";}}', 'system', 0, 0, 0, 0, '-60', 3, 0, '1', '19', '55', '0', '0', '0', '0', '0', '0', 0),
('management', '56', '8', 'admin/config/system', 'admin/config/system', 'System', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:37:"General system related configuration.";}}', 'system', 0, 0, 1, 0, '-20', 3, 0, '1', '8', '56', '0', '0', '0', '0', '0', '0', 0),
('management', '57', '21', 'admin/structure/taxonomy', 'admin/structure/taxonomy', 'Taxonomy', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:67:"Manage tagging, categorization, and classification of your content.";}}', 'system', 0, 0, 1, 0, '0', 3, 0, '1', '21', '57', '0', '0', '0', '0', '0', '0', 0),
('management', '60', '16', 'admin/modules/uninstall', 'admin/modules/uninstall', 'Uninstall', 'a:0:{}', 'system', -1, 0, 0, 0, '20', 3, 0, '1', '16', '60', '0', '0', '0', '0', '0', '0', 0),
('management', '61', '8', 'admin/config/user-interface', 'admin/config/user-interface', 'User interface', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:38:"Tools that enhance the user interface.";}}', 'system', 0, 0, 1, 0, '-15', 3, 0, '1', '8', '61', '0', '0', '0', '0', '0', '0', 0),
('navigation', '62', '5', 'node/%/view', 'node/%/view', 'View', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 2, 0, '5', '62', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '63', '17', 'user/%/view', 'user/%/view', 'View', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 2, 0, '17', '63', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '64', '8', 'admin/config/services', 'admin/config/services', 'Web services', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:30:"Tools related to web services.";}}', 'system', 0, 0, 1, 0, '0', 3, 0, '1', '8', '64', '0', '0', '0', '0', '0', '0', 0),
('management', '65', '8', 'admin/config/workflow', 'admin/config/workflow', 'Workflow', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:43:"Content workflow, editorial workflow tools.";}}', 'system', 0, 0, 0, 0, '5', 3, 0, '1', '8', '65', '0', '0', '0', '0', '0', '0', 0),
('navigation', '87', '27', 'taxonomy/term/%/edit', 'taxonomy/term/%/edit', 'Edit', 'a:0:{}', 'system', -1, 0, 0, 0, '10', 2, 0, '27', '87', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '88', '27', 'taxonomy/term/%/view', 'taxonomy/term/%/view', 'View', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 2, 0, '27', '88', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '89', '48', 'admin/config/people/accounts', 'admin/config/people/accounts', 'Account settings', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:109:"Configure default behavior of users, including registration requirements, e-mails, fields, and user pictures.";}}', 'system', 0, 0, 0, 0, '-10', 4, 0, '1', '8', '48', '89', '0', '0', '0', '0', '0', 0),
('management', '90', '56', 'admin/config/system/actions', 'admin/config/system/actions', 'Actions', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:41:"Manage the actions defined for your site.";}}', 'system', 0, 0, 1, 0, '0', 4, 0, '1', '8', '56', '90', '0', '0', '0', '0', '0', 0),
('management', '91', '30', 'admin/structure/block/add', 'admin/structure/block/add', 'Add block', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '30', '91', '0', '0', '0', '0', '0', 0),
('management', '92', '36', 'admin/structure/types/add', 'admin/structure/types/add', 'Add content type', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '36', '92', '0', '0', '0', '0', '0', 0),
('management', '93', '47', 'admin/structure/menu/add', 'admin/structure/menu/add', 'Add menu', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '47', '93', '0', '0', '0', '0', '0', 0),
('management', '94', '57', 'admin/structure/taxonomy/add', 'admin/structure/taxonomy/add', 'Add vocabulary', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '57', '94', '0', '0', '0', '0', '0', 0),
('management', '95', '54', 'admin/appearance/settings/bartik', 'admin/appearance/settings/bartik', 'Bartik', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '7', '54', '95', '0', '0', '0', '0', '0', 0),
('management', '96', '53', 'admin/config/search/clean-urls', 'admin/config/search/clean-urls', 'Clean URLs', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:43:"Enable or disable clean URLs for your site.";}}', 'system', 0, 0, 0, 0, '5', 4, 0, '1', '8', '53', '96', '0', '0', '0', '0', '0', 0),
('management', '97', '56', 'admin/config/system/cron', 'admin/config/system/cron', 'Cron', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:40:"Manage automatic site maintenance tasks.";}}', 'system', 0, 0, 0, 0, '20', 4, 0, '1', '8', '56', '97', '0', '0', '0', '0', '0', 0),
('management', '98', '51', 'admin/config/regional/date-time', 'admin/config/regional/date-time', 'Date and time', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:44:"Configure display formats for date and time.";}}', 'system', 0, 0, 0, 0, '-15', 4, 0, '1', '8', '51', '98', '0', '0', '0', '0', '0', 0),
('management', '100', '46', 'admin/config/media/file-system', 'admin/config/media/file-system', 'File system', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:68:"Tell Drupal where to store uploaded files and how they are accessed.";}}', 'system', 0, 0, 0, 0, '-10', 4, 0, '1', '8', '46', '100', '0', '0', '0', '0', '0', 0),
('management', '101', '54', 'admin/appearance/settings/garland', 'admin/appearance/settings/garland', 'Garland', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '7', '54', '101', '0', '0', '0', '0', '0', 0),
('management', '102', '54', 'admin/appearance/settings/global', 'admin/appearance/settings/global', 'Global settings', 'a:0:{}', 'system', -1, 0, 0, 0, '-1', 4, 0, '1', '7', '54', '102', '0', '0', '0', '0', '0', 0),
('management', '103', '48', 'admin/config/people/ip-blocking', 'admin/config/people/ip-blocking', 'IP address blocking', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:28:"Manage blocked IP addresses.";}}', 'system', 0, 0, 1, 0, '10', 4, 0, '1', '8', '48', '103', '0', '0', '0', '0', '0', 0),
('management', '104', '46', 'admin/config/media/image-styles', 'admin/config/media/image-styles', 'Image styles', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:78:"Configure styles that can be used for resizing or adjusting images on display.";}}', 'system', 0, 0, 1, 0, '0', 4, 0, '1', '8', '46', '104', '0', '0', '0', '0', '0', 0),
('management', '105', '46', 'admin/config/media/image-toolkit', 'admin/config/media/image-toolkit', 'Image toolkit', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:74:"Choose which image toolkit to use if you have installed optional toolkits.";}}', 'system', 0, 0, 0, 0, '20', 4, 0, '1', '8', '46', '105', '0', '0', '0', '0', '0', 0),
('management', '106', '36', 'admin/structure/types/list', 'admin/structure/types/list', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 4, 0, '1', '21', '36', '106', '0', '0', '0', '0', '0', 0),
('management', '107', '44', 'admin/modules/list/confirm', 'admin/modules/list/confirm', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '16', '44', '107', '0', '0', '0', '0', '0', 0),
('management', '108', '57', 'admin/structure/taxonomy/list', 'admin/structure/taxonomy/list', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 4, 0, '1', '21', '57', '108', '0', '0', '0', '0', '0', 0),
('management', '109', '47', 'admin/structure/menu/list', 'admin/structure/menu/list', 'List menus', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 4, 0, '1', '21', '47', '109', '0', '0', '0', '0', '0', 0),
('management', '110', '39', 'admin/config/development/logging', 'admin/config/development/logging', 'Logging and errors', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:154:"Settings for logging and alerts modules. Various modules can route Drupal''s system events to different destinations, such as syslog, database, email, etc.";}}', 'system', 0, 0, 0, 0, '-15', 4, 0, '1', '8', '39', '110', '0', '0', '0', '0', '0', 0),
('management', '111', '39', 'admin/config/development/maintenance', 'admin/config/development/maintenance', 'Maintenance mode', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:62:"Take the site offline for maintenance or bring it back online.";}}', 'system', 0, 0, 0, 0, '-10', 4, 0, '1', '8', '39', '111', '0', '0', '0', '0', '0', 0),
('management', '112', '39', 'admin/config/development/performance', 'admin/config/development/performance', 'Performance', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:101:"Enable or disable page caching for anonymous users and set CSS and JS bandwidth optimization options.";}}', 'system', 0, 0, 0, 0, '-20', 4, 0, '1', '8', '39', '112', '0', '0', '0', '0', '0', 0),
('management', '113', '49', 'admin/people/permissions/list', 'admin/people/permissions/list', 'Permissions', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:64:"Determine access to features by selecting permissions for roles.";}}', 'system', -1, 0, 0, 0, '-8', 4, 0, '1', '18', '49', '113', '0', '0', '0', '0', '0', 0),
('management', '114', '32', 'admin/content/comment/new', 'admin/content/comment/new', 'Published comments', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 4, 0, '1', '9', '32', '114', '0', '0', '0', '0', '0', 0),
('management', '115', '64', 'admin/config/services/rss-publishing', 'admin/config/services/rss-publishing', 'RSS publishing', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:114:"Configure the site description, the number of items per feed and whether feeds should be titles/teasers/full-text.";}}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '8', '64', '115', '0', '0', '0', '0', '0', 0),
('management', '116', '51', 'admin/config/regional/settings', 'admin/config/regional/settings', 'Regional settings', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:54:"Settings for the site''s default time zone and country.";}}', 'system', 0, 0, 0, 0, '-20', 4, 0, '1', '8', '51', '116', '0', '0', '0', '0', '0', 0),
('management', '117', '49', 'admin/people/permissions/roles', 'admin/people/permissions/roles', 'Roles', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:30:"List, edit, or add user roles.";}}', 'system', -1, 0, 1, 0, '-5', 4, 0, '1', '18', '49', '117', '0', '0', '0', '0', '0', 0),
('management', '118', '47', 'admin/structure/menu/settings', 'admin/structure/menu/settings', 'Settings', 'a:0:{}', 'system', -1, 0, 0, 0, '5', 4, 0, '1', '21', '47', '118', '0', '0', '0', '0', '0', 0),
('management', '119', '54', 'admin/appearance/settings/seven', 'admin/appearance/settings/seven', 'Seven', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '7', '54', '119', '0', '0', '0', '0', '0', 0),
('management', '120', '56', 'admin/config/system/site-information', 'admin/config/system/site-information', 'Site information', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:104:"Change site name, e-mail address, slogan, default front page, and number of posts per page, error pages.";}}', 'system', 0, 0, 0, 0, '-20', 4, 0, '1', '8', '56', '120', '0', '0', '0', '0', '0', 0),
('management', '121', '54', 'admin/appearance/settings/stark', 'admin/appearance/settings/stark', 'Stark', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '7', '54', '121', '0', '0', '0', '0', '0', 0),
('management', '123', '35', 'admin/config/content/formats', 'admin/config/content/formats', 'Text formats', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:127:"Configure how content input by users is filtered, including allowed HTML tags. Also allows enabling of module-provided filters.";}}', 'system', 0, 0, 1, 0, '0', 4, 0, '1', '8', '35', '123', '0', '0', '0', '0', '0', 0),
('management', '124', '32', 'admin/content/comment/approval', 'admin/content/comment/approval', 'Unapproved comments', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '9', '32', '124', '0', '0', '0', '0', '0', 0),
('management', '125', '60', 'admin/modules/uninstall/confirm', 'admin/modules/uninstall/confirm', 'Uninstall', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '16', '60', '125', '0', '0', '0', '0', '0', 0),
('management', '127', '57', 'admin/structure/taxonomy/%', 'admin/structure/taxonomy/%', '', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '21', '57', '127', '0', '0', '0', '0', '0', 0),
('navigation', '130', '40', 'user/%/edit/account', 'user/%/edit/account', 'Account', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 3, 0, '17', '40', '130', '0', '0', '0', '0', '0', '0', 0),
('management', '131', '123', 'admin/config/content/formats/%', 'admin/config/content/formats/%', '', 'a:0:{}', 'system', 0, 0, 1, 0, '0', 5, 0, '1', '8', '35', '123', '131', '0', '0', '0', '0', 0),
('management', '132', '104', 'admin/config/media/image-styles/add', 'admin/config/media/image-styles/add', 'Add style', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:22:"Add a new image style.";}}', 'system', -1, 0, 0, 0, '2', 5, 0, '1', '8', '46', '104', '132', '0', '0', '0', '0', 0),
('management', '133', '127', 'admin/structure/taxonomy/%/add', 'admin/structure/taxonomy/%/add', 'Add term', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '57', '127', '133', '0', '0', '0', '0', 0),
('management', '134', '123', 'admin/config/content/formats/add', 'admin/config/content/formats/add', 'Add text format', 'a:0:{}', 'system', -1, 0, 0, 0, '1', 5, 0, '1', '8', '35', '123', '134', '0', '0', '0', '0', 0),
('management', '135', '30', 'admin/structure/block/list/bartik', 'admin/structure/block/list/bartik', 'Bartik', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '30', '135', '0', '0', '0', '0', '0', 0),
('management', '136', '90', 'admin/config/system/actions/configure', 'admin/config/system/actions/configure', 'Configure an advanced action', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '8', '56', '90', '136', '0', '0', '0', '0', 0),
('management', '137', '47', 'admin/structure/menu/manage/%', 'admin/structure/menu/manage/%', 'Customize menu', 'a:0:{}', 'system', 0, 0, 1, 0, '0', 4, 0, '1', '21', '47', '137', '0', '0', '0', '0', '0', 0),
('management', '138', '127', 'admin/structure/taxonomy/%/edit', 'admin/structure/taxonomy/%/edit', 'Edit', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 5, 0, '1', '21', '57', '127', '138', '0', '0', '0', '0', 0),
('management', '139', '36', 'admin/structure/types/manage/%', 'admin/structure/types/manage/%', 'Edit content type', 'a:0:{}', 'system', 0, 0, 1, 0, '0', 4, 0, '1', '21', '36', '139', '0', '0', '0', '0', '0', 0),
('management', '140', '98', 'admin/config/regional/date-time/formats', 'admin/config/regional/date-time/formats', 'Formats', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:51:"Configure display format strings for date and time.";}}', 'system', -1, 0, 1, 0, '-9', 5, 0, '1', '8', '51', '98', '140', '0', '0', '0', '0', 0),
('management', '141', '30', 'admin/structure/block/list/garland', 'admin/structure/block/list/garland', 'Garland', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '30', '141', '0', '0', '0', '0', '0', 0),
('management', '142', '127', 'admin/structure/taxonomy/%/list', 'admin/structure/taxonomy/%/list', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '-20', 5, 0, '1', '21', '57', '127', '142', '0', '0', '0', '0', 0),
('management', '143', '123', 'admin/config/content/formats/list', 'admin/config/content/formats/list', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '8', '35', '123', '143', '0', '0', '0', '0', 0),
('management', '144', '104', 'admin/config/media/image-styles/list', 'admin/config/media/image-styles/list', 'List', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:42:"List the current image styles on the site.";}}', 'system', -1, 0, 0, 0, '1', 5, 0, '1', '8', '46', '104', '144', '0', '0', '0', '0', 0),
('management', '145', '90', 'admin/config/system/actions/manage', 'admin/config/system/actions/manage', 'Manage actions', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:41:"Manage the actions defined for your site.";}}', 'system', -1, 0, 0, 0, '-2', 5, 0, '1', '8', '56', '90', '145', '0', '0', '0', '0', 0),
('management', '146', '89', 'admin/config/people/accounts/settings', 'admin/config/people/accounts/settings', 'Settings', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 5, 0, '1', '8', '48', '89', '146', '0', '0', '0', '0', 0),
('management', '147', '30', 'admin/structure/block/list/seven', 'admin/structure/block/list/seven', 'Seven', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '30', '147', '0', '0', '0', '0', '0', 0),
('management', '148', '30', 'admin/structure/block/list/stark', 'admin/structure/block/list/stark', 'Stark', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '30', '148', '0', '0', '0', '0', '0', 0),
('management', '150', '98', 'admin/config/regional/date-time/types', 'admin/config/regional/date-time/types', 'Types', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:44:"Configure display formats for date and time.";}}', 'system', -1, 0, 1, 0, '-10', 5, 0, '1', '8', '51', '98', '150', '0', '0', '0', '0', 0),
('navigation', '154', '52', 'node/%/revisions/%/delete', 'node/%/revisions/%/delete', 'Delete earlier revision', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 3, 0, '5', '52', '154', '0', '0', '0', '0', '0', '0', 0),
('navigation', '155', '52', 'node/%/revisions/%/revert', 'node/%/revisions/%/revert', 'Revert to earlier revision', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 3, 0, '5', '52', '155', '0', '0', '0', '0', '0', '0', 0),
('navigation', '156', '52', 'node/%/revisions/%/view', 'node/%/revisions/%/view', 'Revisions', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 3, 0, '5', '52', '156', '0', '0', '0', '0', '0', '0', 0),
('management', '157', '141', 'admin/structure/block/list/garland/add', 'admin/structure/block/list/garland/add', 'Add block', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '30', '141', '157', '0', '0', '0', '0', 0),
('management', '159', '148', 'admin/structure/block/list/stark/add', 'admin/structure/block/list/stark/add', 'Add block', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '30', '148', '159', '0', '0', '0', '0', 0),
('management', '164', '150', 'admin/config/regional/date-time/types/add', 'admin/config/regional/date-time/types/add', 'Add date type', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:18:"Add new date type.";}}', 'system', -1, 0, 0, 0, '-10', 6, 0, '1', '8', '51', '98', '150', '164', '0', '0', '0', 0),
('management', '165', '140', 'admin/config/regional/date-time/formats/add', 'admin/config/regional/date-time/formats/add', 'Add format', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:43:"Allow users to add additional date formats.";}}', 'system', -1, 0, 0, 0, '-10', 6, 0, '1', '8', '51', '98', '140', '165', '0', '0', '0', 0),
('management', '166', '137', 'admin/structure/menu/manage/%/add', 'admin/structure/menu/manage/%/add', 'Add link', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '47', '137', '166', '0', '0', '0', '0', 0),
('management', '167', '30', 'admin/structure/block/manage/%/%', 'admin/structure/block/manage/%/%', 'Configure block', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '21', '30', '167', '0', '0', '0', '0', '0', 0),
('navigation', '168', '31', 'user/%/cancel/confirm/%/%', 'user/%/cancel/confirm/%/%', 'Confirm account cancellation', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 3, 0, '17', '31', '168', '0', '0', '0', '0', '0', '0', 0),
('management', '169', '139', 'admin/structure/types/manage/%/delete', 'admin/structure/types/manage/%/delete', 'Delete', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 5, 0, '1', '21', '36', '139', '169', '0', '0', '0', '0', 0),
('management', '170', '103', 'admin/config/people/ip-blocking/delete/%', 'admin/config/people/ip-blocking/delete/%', 'Delete IP address', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 5, 0, '1', '8', '48', '103', '170', '0', '0', '0', '0', 0),
('management', '171', '90', 'admin/config/system/actions/delete/%', 'admin/config/system/actions/delete/%', 'Delete action', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:17:"Delete an action.";}}', 'system', 0, 0, 0, 0, '0', 5, 0, '1', '8', '56', '90', '171', '0', '0', '0', '0', 0),
('management', '172', '137', 'admin/structure/menu/manage/%/delete', 'admin/structure/menu/manage/%/delete', 'Delete menu', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 5, 0, '1', '21', '47', '137', '172', '0', '0', '0', '0', 0),
('management', '173', '47', 'admin/structure/menu/item/%/delete', 'admin/structure/menu/item/%/delete', 'Delete menu link', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '21', '47', '173', '0', '0', '0', '0', '0', 0),
('management', '174', '117', 'admin/people/permissions/roles/delete/%', 'admin/people/permissions/roles/delete/%', 'Delete role', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 5, 0, '1', '18', '49', '117', '174', '0', '0', '0', '0', 0),
('management', '175', '131', 'admin/config/content/formats/%/disable', 'admin/config/content/formats/%/disable', 'Disable text format', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 6, 0, '1', '8', '35', '123', '131', '175', '0', '0', '0', 0),
('management', '176', '139', 'admin/structure/types/manage/%/edit', 'admin/structure/types/manage/%/edit', 'Edit', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '36', '139', '176', '0', '0', '0', '0', 0),
('management', '177', '137', 'admin/structure/menu/manage/%/edit', 'admin/structure/menu/manage/%/edit', 'Edit menu', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '47', '137', '177', '0', '0', '0', '0', 0),
('management', '178', '47', 'admin/structure/menu/item/%/edit', 'admin/structure/menu/item/%/edit', 'Edit menu link', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '21', '47', '178', '0', '0', '0', '0', '0', 0),
('management', '179', '117', 'admin/people/permissions/roles/edit/%', 'admin/people/permissions/roles/edit/%', 'Edit role', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 5, 0, '1', '18', '49', '117', '179', '0', '0', '0', '0', 0),
('management', '180', '104', 'admin/config/media/image-styles/edit/%', 'admin/config/media/image-styles/edit/%', 'Edit style', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:25:"Configure an image style.";}}', 'system', 0, 0, 1, 0, '0', 5, 0, '1', '8', '46', '104', '180', '0', '0', '0', '0', 0),
('management', '181', '137', 'admin/structure/menu/manage/%/list', 'admin/structure/menu/manage/%/list', 'List links', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 5, 0, '1', '21', '47', '137', '181', '0', '0', '0', '0', 0),
('management', '182', '47', 'admin/structure/menu/item/%/reset', 'admin/structure/menu/item/%/reset', 'Reset menu link', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '21', '47', '182', '0', '0', '0', '0', '0', 0),
('management', '183', '104', 'admin/config/media/image-styles/delete/%', 'admin/config/media/image-styles/delete/%', 'Delete style', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:22:"Delete an image style.";}}', 'system', 0, 0, 0, 0, '0', 5, 0, '1', '8', '46', '104', '183', '0', '0', '0', '0', 0),
('management', '184', '104', 'admin/config/media/image-styles/revert/%', 'admin/config/media/image-styles/revert/%', 'Revert style', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:22:"Revert an image style.";}}', 'system', 0, 0, 0, 0, '0', 5, 0, '1', '8', '46', '104', '184', '0', '0', '0', '0', 0),
('management', '185', '139', 'admin/structure/types/manage/%/comment/display', 'admin/structure/types/manage/%/comment/display', 'Comment display', 'a:0:{}', 'system', -1, 0, 0, 0, '4', 5, 0, '1', '21', '36', '139', '185', '0', '0', '0', '0', 0),
('management', '186', '139', 'admin/structure/types/manage/%/comment/fields', 'admin/structure/types/manage/%/comment/fields', 'Comment fields', 'a:0:{}', 'system', -1, 0, 1, 0, '3', 5, 0, '1', '21', '36', '139', '186', '0', '0', '0', '0', 0),
('management', '187', '167', 'admin/structure/block/manage/%/%/configure', 'admin/structure/block/manage/%/%/configure', 'Configure block', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '30', '167', '187', '0', '0', '0', '0', 0),
('management', '188', '167', 'admin/structure/block/manage/%/%/delete', 'admin/structure/block/manage/%/%/delete', 'Delete block', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '30', '167', '188', '0', '0', '0', '0', 0),
('management', '189', '140', 'admin/config/regional/date-time/formats/%/delete', 'admin/config/regional/date-time/formats/%/delete', 'Delete date format', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:47:"Allow users to delete a configured date format.";}}', 'system', 0, 0, 0, 0, '0', 6, 0, '1', '8', '51', '98', '140', '189', '0', '0', '0', 0),
('management', '190', '150', 'admin/config/regional/date-time/types/%/delete', 'admin/config/regional/date-time/types/%/delete', 'Delete date type', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:45:"Allow users to delete a configured date type.";}}', 'system', 0, 0, 0, 0, '0', 6, 0, '1', '8', '51', '98', '150', '190', '0', '0', '0', 0),
('management', '191', '140', 'admin/config/regional/date-time/formats/%/edit', 'admin/config/regional/date-time/formats/%/edit', 'Edit date format', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:45:"Allow users to edit a configured date format.";}}', 'system', 0, 0, 0, 0, '0', 6, 0, '1', '8', '51', '98', '140', '191', '0', '0', '0', 0),
('management', '192', '180', 'admin/config/media/image-styles/edit/%/add/%', 'admin/config/media/image-styles/edit/%/add/%', 'Add image effect', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:28:"Add a new effect to a style.";}}', 'system', 0, 0, 0, 0, '0', 6, 0, '1', '8', '46', '104', '180', '192', '0', '0', '0', 0),
('management', '193', '180', 'admin/config/media/image-styles/edit/%/effects/%', 'admin/config/media/image-styles/edit/%/effects/%', 'Edit image effect', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:39:"Edit an existing effect within a style.";}}', 'system', 0, 0, 1, 0, '0', 6, 0, '1', '8', '46', '104', '180', '193', '0', '0', '0', 0),
('management', '194', '193', 'admin/config/media/image-styles/edit/%/effects/%/delete', 'admin/config/media/image-styles/edit/%/effects/%/delete', 'Delete image effect', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:39:"Delete an existing effect from a style.";}}', 'system', 0, 0, 0, 0, '0', 7, 0, '1', '8', '46', '104', '180', '193', '194', '0', '0', 0),
('management', '195', '47', 'admin/structure/menu/manage/main-menu', 'admin/structure/menu/manage/%', 'Main menu', 'a:0:{}', 'menu', 0, 0, 0, 0, '0', 4, 0, '1', '21', '47', '195', '0', '0', '0', '0', '0', 0),
('management', '196', '47', 'admin/structure/menu/manage/management', 'admin/structure/menu/manage/%', 'Management', 'a:0:{}', 'menu', 0, 0, 0, 0, '0', 4, 0, '1', '21', '47', '196', '0', '0', '0', '0', '0', 0),
('management', '197', '47', 'admin/structure/menu/manage/navigation', 'admin/structure/menu/manage/%', 'Navigation', 'a:0:{}', 'menu', 0, 0, 0, 0, '0', 4, 0, '1', '21', '47', '197', '0', '0', '0', '0', '0', 0),
('management', '198', '47', 'admin/structure/menu/manage/user-menu', 'admin/structure/menu/manage/%', 'User menu', 'a:0:{}', 'menu', 0, 0, 0, 0, '0', 4, 0, '1', '21', '47', '198', '0', '0', '0', '0', '0', 0),
('shortcut-set-1', '199', '0', 'node/add', 'node/add', 'Add content', 'a:0:{}', 'menu', 0, 0, 0, 0, '-20', 1, 0, '199', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('shortcut-set-1', '200', '0', 'admin/content', 'admin/content', 'Find content', 'a:0:{}', 'menu', 0, 0, 0, 0, '-19', 1, 0, '200', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('main-menu', '201', '0', '<front>', '', 'About us', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:0:"";}}', 'menu', 0, 1, 0, 0, '-50', 1, 1, '201', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '202', '0', 'search', 'search', 'Search', 'a:0:{}', 'system', 1, 0, 0, 0, '0', 1, 0, '202', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '203', '202', 'search/node', 'search/node', 'Content', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 2, 0, '202', '203', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '204', '202', 'search/user', 'search/user', 'Users', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 2, 0, '202', '204', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '205', '6', 'node/add/article', 'node/add/article', 'Article', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:89:"Use <em>articles</em> for time-sensitive content like news, press releases or blog posts.";}}', 'system', 0, 0, 0, 0, '0', 2, 0, '6', '205', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '206', '6', 'node/add/page', 'node/add/page', 'Basic page', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:77:"Use <em>basic pages</em> for your static content, such as an ''About us'' page.";}}', 'system', 0, 0, 0, 0, '0', 2, 0, '6', '206', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '207', '203', 'search/node/%', 'search/node/%', 'Content', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 3, 0, '202', '203', '207', '0', '0', '0', '0', '0', '0', 0),
('navigation', '208', '17', 'user/%/shortcuts', 'user/%/shortcuts', 'Shortcuts', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 2, 0, '17', '208', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '210', '204', 'search/user/%', 'search/user/%', 'Users', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 3, 0, '202', '204', '210', '0', '0', '0', '0', '0', '0', 0),
('management', '218', '53', 'admin/config/search/settings', 'admin/config/search/settings', 'Search settings', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:67:"Configure relevance settings for search and other indexing options.";}}', 'system', 0, 0, 0, 0, '-10', 4, 0, '1', '8', '53', '218', '0', '0', '0', '0', '0', 0),
('management', '219', '61', 'admin/config/user-interface/shortcut', 'admin/config/user-interface/shortcut', 'Shortcuts', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:29:"Add and modify shortcut sets.";}}', 'system', 0, 0, 1, 0, '0', 4, 0, '1', '8', '61', '219', '0', '0', '0', '0', '0', 0),
('management', '220', '53', 'admin/config/search/path', 'admin/config/search/path', 'URL aliases', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:46:"Change your site''s URL paths by aliasing them.";}}', 'system', 0, 0, 1, 0, '-5', 4, 0, '1', '8', '53', '220', '0', '0', '0', '0', '0', 0),
('management', '221', '220', 'admin/config/search/path/add', 'admin/config/search/path/add', 'Add alias', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '8', '53', '220', '221', '0', '0', '0', '0', 0),
('management', '222', '219', 'admin/config/user-interface/shortcut/add-set', 'admin/config/user-interface/shortcut/add-set', 'Add shortcut set', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '8', '61', '219', '222', '0', '0', '0', '0', 0),
('management', '223', '218', 'admin/config/search/settings/reindex', 'admin/config/search/settings/reindex', 'Clear index', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '8', '53', '218', '223', '0', '0', '0', '0', 0),
('management', '224', '219', 'admin/config/user-interface/shortcut/%', 'admin/config/user-interface/shortcut/%', 'Edit shortcuts', 'a:0:{}', 'system', 0, 0, 1, 0, '0', 5, 0, '1', '8', '61', '219', '224', '0', '0', '0', '0', 0),
('management', '225', '220', 'admin/config/search/path/list', 'admin/config/search/path/list', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 5, 0, '1', '8', '53', '220', '225', '0', '0', '0', '0', 0),
('management', '226', '224', 'admin/config/user-interface/shortcut/%/add-link', 'admin/config/user-interface/shortcut/%/add-link', 'Add shortcut', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 6, 0, '1', '8', '61', '219', '224', '226', '0', '0', '0', 0),
('management', '227', '220', 'admin/config/search/path/delete/%', 'admin/config/search/path/delete/%', 'Delete alias', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 5, 0, '1', '8', '53', '220', '227', '0', '0', '0', '0', 0),
('management', '228', '224', 'admin/config/user-interface/shortcut/%/delete', 'admin/config/user-interface/shortcut/%/delete', 'Delete shortcut set', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 6, 0, '1', '8', '61', '219', '224', '228', '0', '0', '0', 0),
('management', '229', '220', 'admin/config/search/path/edit/%', 'admin/config/search/path/edit/%', 'Edit alias', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 5, 0, '1', '8', '53', '220', '229', '0', '0', '0', '0', 0),
('management', '230', '224', 'admin/config/user-interface/shortcut/%/edit', 'admin/config/user-interface/shortcut/%/edit', 'Edit set name', 'a:0:{}', 'system', -1, 0, 0, 0, '10', 6, 0, '1', '8', '61', '219', '224', '230', '0', '0', '0', 0),
('management', '231', '219', 'admin/config/user-interface/shortcut/link/%', 'admin/config/user-interface/shortcut/link/%', 'Edit shortcut', 'a:0:{}', 'system', 0, 0, 1, 0, '0', 5, 0, '1', '8', '61', '219', '231', '0', '0', '0', '0', 0),
('management', '232', '224', 'admin/config/user-interface/shortcut/%/links', 'admin/config/user-interface/shortcut/%/links', 'List links', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 6, 0, '1', '8', '61', '219', '224', '232', '0', '0', '0', 0),
('management', '233', '231', 'admin/config/user-interface/shortcut/link/%/delete', 'admin/config/user-interface/shortcut/link/%/delete', 'Delete shortcut', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 6, 0, '1', '8', '61', '219', '231', '233', '0', '0', '0', 0),
('navigation', '320', '0', 'blog', 'blog', 'My Blog', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:0:"";}}', 'system', 1, 0, 1, 0, '0', 1, 1, '320', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '321', '0', 'book', 'book', 'Books', 'a:0:{}', 'system', 1, 0, 0, 0, '0', 1, 0, '321', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '322', '0', 'contact', 'contact', 'Contact', 'a:0:{}', 'system', 1, 0, 0, 0, '0', 1, 0, '322', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '323', '0', 'aggregator', 'aggregator', 'Feed aggregator', 'a:0:{}', 'system', 0, 0, 1, 0, '5', 1, 0, '323', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '324', '0', 'forum', 'forum', 'Forums', 'a:0:{}', 'system', 0, 0, 1, 0, '0', 1, 0, '324', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '325', '0', 'poll', 'poll', 'Polls', 'a:0:{}', 'system', 1, 0, 0, 0, '0', 1, 0, '325', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '326', '0', 'tracker', 'tracker', 'Recent content', 'a:0:{}', 'system', 0, 0, 0, 0, '1', 1, 0, '326', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '327', '326', 'tracker/all', 'tracker/all', 'All recent content', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 2, 0, '326', '327', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '328', '323', 'aggregator/categories', 'aggregator/categories', 'Categories', 'a:0:{}', 'system', 0, 0, 1, 0, '0', 2, 0, '323', '328', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '329', '324', 'forum/%', 'forum/%', 'Forums', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 2, 0, '324', '329', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '330', '320', 'blog/%', 'blog/%', 'My blog', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 2, 0, '320', '330', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '331', '326', 'tracker/%', 'tracker/%', 'My recent content', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 2, 0, '326', '331', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '332', '323', 'aggregator/sources', 'aggregator/sources', 'Sources', 'a:0:{}', 'system', 0, 0, 1, 0, '0', 2, 0, '323', '332', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '333', '328', 'aggregator/categories/%', 'aggregator/categories/%', '', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 3, 0, '323', '328', '333', '0', '0', '0', '0', '0', '0', 0),
('navigation', '334', '332', 'aggregator/sources/%', 'aggregator/sources/%', '', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 3, 0, '323', '332', '334', '0', '0', '0', '0', '0', '0', 0),
('navigation', '335', '6', 'node/add/blog', 'node/add/blog', 'Blog entry', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:58:"Use for multi-user blogs. Every user gets a personal blog.";}}', 'system', 0, 0, 0, 0, '0', 2, 0, '6', '335', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '336', '6', 'node/add/book', 'node/add/book', 'Book page', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:87:"<em>Books</em> have a built-in hierarchical navigation. Use for handbooks or tutorials.";}}', 'system', 0, 0, 0, 0, '0', 2, 0, '6', '336', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '337', '9', 'admin/content/book', 'admin/content/book', 'Books', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:33:"Manage your site''s book outlines.";}}', 'system', -1, 0, 0, 0, '0', 3, 0, '1', '9', '337', '0', '0', '0', '0', '0', '0', 0),
('navigation', '338', '17', 'user/%/contact', 'user/%/contact', 'Contact', 'a:0:{}', 'system', -1, 0, 0, 0, '2', 2, 0, '17', '338', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '339', '21', 'admin/structure/contact', 'admin/structure/contact', 'Contact form', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:71:"Create a system contact form and set up categories for the form to use.";}}', 'system', 0, 0, 1, 0, '0', 3, 0, '1', '21', '339', '0', '0', '0', '0', '0', '0', 0),
('navigation', '340', '6', 'node/add/forum', 'node/add/forum', 'Forum topic', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:69:"A <em>forum topic</em> starts a new discussion thread within a forum.";}}', 'system', 0, 0, 0, 0, '0', 2, 0, '6', '340', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '341', '21', 'admin/structure/forum', 'admin/structure/forum', 'Forums', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:33:"Control forum hierarchy settings.";}}', 'system', 0, 0, 1, 0, '0', 3, 0, '1', '21', '341', '0', '0', '0', '0', '0', '0', 0),
('navigation', '342', '5', 'node/%/outline', 'node/%/outline', 'Outline', 'a:0:{}', 'system', -1, 0, 1, 0, '2', 2, 0, '5', '342', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '343', '6', 'node/add/poll', 'node/add/poll', 'Poll', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:191:"A <em>poll</em> is a question with a set of possible responses. A <em>poll</em>, once created, automatically provides a simple running count of the number of votes received for each response.";}}', 'system', 0, 0, 0, 0, '0', 2, 0, '6', '343', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '345', '5', 'node/%/results', 'node/%/results', 'Results', 'a:0:{}', 'system', -1, 0, 0, 0, '3', 2, 0, '5', '345', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '350', '17', 'user/%/track', 'user/%/track', 'Track', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 2, 0, '17', '350', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '352', '21', 'admin/structure/trigger', 'admin/structure/trigger', 'Triggers', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:34:"Configure when to execute actions.";}}', 'system', 0, 0, 0, 0, '0', 3, 0, '1', '21', '352', '0', '0', '0', '0', '0', '0', 0),
('navigation', '353', '5', 'node/%/votes', 'node/%/votes', 'Votes', 'a:0:{}', 'system', -1, 0, 0, 0, '3', 2, 0, '5', '353', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '368', '333', 'aggregator/categories/%/categorize', 'aggregator/categories/%/categorize', 'Categorize', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '323', '328', '333', '368', '0', '0', '0', '0', '0', 0),
('navigation', '369', '334', 'aggregator/sources/%/categorize', 'aggregator/sources/%/categorize', 'Categorize', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '323', '332', '334', '369', '0', '0', '0', '0', '0', 0),
('navigation', '370', '333', 'aggregator/categories/%/configure', 'aggregator/categories/%/configure', 'Configure', 'a:0:{}', 'system', -1, 0, 0, 0, '1', 4, 0, '323', '328', '333', '370', '0', '0', '0', '0', '0', 0),
('navigation', '371', '334', 'aggregator/sources/%/configure', 'aggregator/sources/%/configure', 'Configure', 'a:0:{}', 'system', -1, 0, 0, 0, '1', 4, 0, '323', '332', '334', '371', '0', '0', '0', '0', '0', 0),
('navigation', '372', '333', 'aggregator/categories/%/view', 'aggregator/categories/%/view', 'View', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 4, 0, '323', '328', '333', '372', '0', '0', '0', '0', '0', 0),
('navigation', '373', '334', 'aggregator/sources/%/view', 'aggregator/sources/%/view', 'View', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 4, 0, '323', '332', '334', '373', '0', '0', '0', '0', '0', 0),
('management', '374', '339', 'admin/structure/contact/add', 'admin/structure/contact/add', 'Add category', 'a:0:{}', 'system', -1, 0, 0, 0, '1', 4, 0, '1', '21', '339', '374', '0', '0', '0', '0', '0', 0);
INSERT INTO `menu_links` VALUES
('management', '375', '352', 'admin/structure/trigger/comment', 'admin/structure/trigger/comment', 'Comment', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '352', '375', '0', '0', '0', '0', '0', 0),
('management', '377', '64', 'admin/config/services/aggregator', 'admin/config/services/aggregator', 'Feed aggregator', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:116:"Configure which content your site aggregates from other sites, how often it polls them, and how they''re categorized.";}}', 'system', 0, 0, 1, 0, '10', 4, 0, '1', '8', '64', '377', '0', '0', '0', '0', '0', 0),
('management', '379', '341', 'admin/structure/forum/list', 'admin/structure/forum/list', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 4, 0, '1', '21', '341', '379', '0', '0', '0', '0', '0', 0),
('management', '380', '337', 'admin/content/book/list', 'admin/content/book/list', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '9', '337', '380', '0', '0', '0', '0', '0', 0),
('management', '381', '352', 'admin/structure/trigger/node', 'admin/structure/trigger/node', 'Node', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '352', '381', '0', '0', '0', '0', '0', 0),
('navigation', '382', '342', 'node/%/outline/remove', 'node/%/outline/remove', 'Remove from outline', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 3, 0, '5', '342', '382', '0', '0', '0', '0', '0', '0', 0),
('management', '383', '337', 'admin/content/book/settings', 'admin/content/book/settings', 'Settings', 'a:0:{}', 'system', -1, 0, 0, 0, '8', 4, 0, '1', '9', '337', '383', '0', '0', '0', '0', '0', 0),
('management', '384', '352', 'admin/structure/trigger/system', 'admin/structure/trigger/system', 'System', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '352', '384', '0', '0', '0', '0', '0', 0),
('management', '385', '352', 'admin/structure/trigger/taxonomy', 'admin/structure/trigger/taxonomy', 'Taxonomy', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '352', '385', '0', '0', '0', '0', '0', 0),
('management', '388', '352', 'admin/structure/trigger/user', 'admin/structure/trigger/user', 'User', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '352', '388', '0', '0', '0', '0', '0', 0),
('navigation', '391', '350', 'user/%/track/content', 'user/%/track/content', 'Track content', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 3, 0, '17', '350', '391', '0', '0', '0', '0', '0', '0', 0),
('management', '392', '352', 'admin/structure/trigger/unassign', 'admin/structure/trigger/unassign', 'Unassign', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:34:"Unassign an action from a trigger.";}}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '352', '392', '0', '0', '0', '0', '0', 0),
('management', '393', '341', 'admin/structure/forum/settings', 'admin/structure/forum/settings', 'Settings', 'a:0:{}', 'system', -1, 0, 0, 0, '5', 4, 0, '1', '21', '341', '393', '0', '0', '0', '0', '0', 0),
('management', '395', '339', 'admin/structure/contact/delete/%', 'admin/structure/contact/delete/%', 'Delete contact', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '21', '339', '395', '0', '0', '0', '0', '0', 0),
('management', '397', '339', 'admin/structure/contact/edit/%', 'admin/structure/contact/edit/%', 'Edit contact category', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '21', '339', '397', '0', '0', '0', '0', '0', 0),
('management', '400', '377', 'admin/config/services/aggregator/list', 'admin/config/services/aggregator/list', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 5, 0, '1', '8', '64', '377', '400', '0', '0', '0', '0', 0),
('management', '406', '377', 'admin/config/services/aggregator/settings', 'admin/config/services/aggregator/settings', 'Settings', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:129:"Configure the behavior of the feed aggregator, including when to discard feed items and how to present feed items and categories.";}}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '8', '64', '377', '406', '0', '0', '0', '0', 0),
('management', '408', '341', 'admin/structure/forum/add/container', 'admin/structure/forum/add/container', 'Add container', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '341', '408', '0', '0', '0', '0', '0', 0),
('management', '409', '341', 'admin/structure/forum/add/forum', 'admin/structure/forum/add/forum', 'Add forum', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '341', '409', '0', '0', '0', '0', '0', 0),
('management', '410', '377', 'admin/config/services/aggregator/add/category', 'admin/config/services/aggregator/add/category', 'Add category', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '8', '64', '377', '410', '0', '0', '0', '0', 0),
('management', '411', '377', 'admin/config/services/aggregator/add/feed', 'admin/config/services/aggregator/add/feed', 'Add feed', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '8', '64', '377', '411', '0', '0', '0', '0', 0),
('management', '414', '341', 'admin/structure/forum/edit/container/%', 'admin/structure/forum/edit/container/%', 'Edit container', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '21', '341', '414', '0', '0', '0', '0', '0', 0),
('management', '415', '341', 'admin/structure/forum/edit/forum/%', 'admin/structure/forum/edit/forum/%', 'Edit forum', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '21', '341', '415', '0', '0', '0', '0', '0', 0),
('management', '418', '377', 'admin/config/services/aggregator/add/opml', 'admin/config/services/aggregator/add/opml', 'Import OPML', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '8', '64', '377', '418', '0', '0', '0', '0', 0),
('management', '419', '377', 'admin/config/services/aggregator/remove/%', 'admin/config/services/aggregator/remove/%', 'Remove items', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 5, 0, '1', '8', '64', '377', '419', '0', '0', '0', '0', 0),
('management', '423', '377', 'admin/config/services/aggregator/update/%', 'admin/config/services/aggregator/update/%', 'Update items', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 5, 0, '1', '8', '64', '377', '423', '0', '0', '0', '0', 0),
('management', '424', '377', 'admin/config/services/aggregator/edit/category/%', 'admin/config/services/aggregator/edit/category/%', 'Edit category', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 5, 0, '1', '8', '64', '377', '424', '0', '0', '0', '0', 0),
('management', '425', '377', 'admin/config/services/aggregator/edit/feed/%', 'admin/config/services/aggregator/edit/feed/%', 'Edit feed', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 5, 0, '1', '8', '64', '377', '425', '0', '0', '0', '0', 0),
('management', '430', '61', 'admin/config/user-interface/superfish', 'admin/config/user-interface/superfish', 'Superfish', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:25:"Configure Superfish Menus";}}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '8', '61', '430', '0', '0', '0', '0', '0', 0),
('main-menu', '435', '0', 'faq', 'faq', 'FAQ''s', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:0:"";}}', 'menu', 0, 0, 0, 0, '-43', 1, 1, '435', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('main-menu', '442', '0', 'contacts', 'contacts', 'Mail us', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:0:"";}}', 'menu', 0, 0, 0, 0, '-46', 1, 1, '442', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '449', '51', 'admin/config/regional/language', 'admin/config/regional/language', 'Languages', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:55:"Configure languages for content and the user interface.";}}', 'system', 0, 0, 1, 0, '-10', 4, 0, '1', '8', '51', '449', '0', '0', '0', '0', '0', 0),
('management', '450', '51', 'admin/config/regional/translate', 'admin/config/regional/translate', 'Translate interface', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:59:"Translate the built in interface and optionally other text.";}}', 'system', 0, 0, 1, 0, '-5', 4, 0, '1', '8', '51', '450', '0', '0', '0', '0', '0', 0),
('management', '451', '449', 'admin/config/regional/language/add', 'admin/config/regional/language/add', 'Add language', 'a:0:{}', 'system', -1, 0, 0, 0, '5', 5, 0, '1', '8', '51', '449', '451', '0', '0', '0', '0', 0),
('management', '452', '449', 'admin/config/regional/language/configure', 'admin/config/regional/language/configure', 'Detection and selection', 'a:0:{}', 'system', -1, 0, 0, 0, '10', 5, 0, '1', '8', '51', '449', '452', '0', '0', '0', '0', 0),
('management', '453', '450', 'admin/config/regional/translate/export', 'admin/config/regional/translate/export', 'Export', 'a:0:{}', 'system', -1, 0, 0, 0, '30', 5, 0, '1', '8', '51', '450', '453', '0', '0', '0', '0', 0),
('management', '454', '450', 'admin/config/regional/translate/import', 'admin/config/regional/translate/import', 'Import', 'a:0:{}', 'system', -1, 0, 0, 0, '20', 5, 0, '1', '8', '51', '450', '454', '0', '0', '0', '0', 0),
('management', '455', '449', 'admin/config/regional/language/overview', 'admin/config/regional/language/overview', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '8', '51', '449', '455', '0', '0', '0', '0', 0),
('management', '456', '98', 'admin/config/regional/date-time/locale', 'admin/config/regional/date-time/locale', 'Localize', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:38:"Configure date formats for each locale";}}', 'system', -1, 0, 1, 0, '-8', 5, 0, '1', '8', '51', '98', '456', '0', '0', '0', '0', 0),
('management', '457', '450', 'admin/config/regional/translate/overview', 'admin/config/regional/translate/overview', 'Overview', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '8', '51', '450', '457', '0', '0', '0', '0', 0),
('management', '458', '450', 'admin/config/regional/translate/translate', 'admin/config/regional/translate/translate', 'Translate', 'a:0:{}', 'system', -1, 0, 0, 0, '10', 5, 0, '1', '8', '51', '450', '458', '0', '0', '0', '0', 0),
('management', '459', '449', 'admin/config/regional/language/delete/%', 'admin/config/regional/language/delete/%', 'Confirm', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 5, 0, '1', '8', '51', '449', '459', '0', '0', '0', '0', 0),
('management', '460', '450', 'admin/config/regional/translate/delete/%', 'admin/config/regional/translate/delete/%', 'Delete string', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 5, 0, '1', '8', '51', '450', '460', '0', '0', '0', '0', 0),
('management', '461', '449', 'admin/config/regional/language/edit/%', 'admin/config/regional/language/edit/%', 'Edit language', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 5, 0, '1', '8', '51', '449', '461', '0', '0', '0', '0', 0),
('management', '462', '450', 'admin/config/regional/translate/edit/%', 'admin/config/regional/translate/edit/%', 'Edit string', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 5, 0, '1', '8', '51', '450', '462', '0', '0', '0', '0', 0),
('management', '463', '452', 'admin/config/regional/language/configure/session', 'admin/config/regional/language/configure/session', 'Session language detection configuration', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 6, 0, '1', '8', '51', '449', '452', '463', '0', '0', '0', 0),
('management', '464', '452', 'admin/config/regional/language/configure/url', 'admin/config/regional/language/configure/url', 'URL language detection configuration', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 6, 0, '1', '8', '51', '449', '452', '464', '0', '0', '0', 0),
('management', '465', '456', 'admin/config/regional/date-time/locale/%/edit', 'admin/config/regional/date-time/locale/%/edit', 'Localize date formats', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:38:"Configure date formats for each locale";}}', 'system', 0, 0, 0, 0, '0', 6, 0, '1', '8', '51', '98', '456', '465', '0', '0', '0', 0),
('management', '466', '456', 'admin/config/regional/date-time/locale/%/reset', 'admin/config/regional/date-time/locale/%/reset', 'Reset date formats', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:47:"Reset localized date formats to global defaults";}}', 'system', 0, 0, 0, 0, '0', 6, 0, '1', '8', '51', '98', '456', '466', '0', '0', '0', 0),
('management', '572', '147', 'admin/structure/block/list/seven/add', 'admin/structure/block/list/seven/add', 'Add block', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '30', '147', '572', '0', '0', '0', '0', 0),
('navigation', '652', '6', 'node/add/faq', 'node/add/faq', 'FAQ', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:43:"A frequently asked question and its answer.";}}', 'system', 0, 0, 0, 0, '0', 2, 0, '6', '652', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '653', '35', 'admin/config/content/faq', 'admin/config/content/faq', 'Frequently Asked Questions', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:79:"Allows the user to configure the layout of questions and answers on a FAQ page.";}}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '8', '35', '653', '0', '0', '0', '0', '0', 0),
('management', '654', '653', 'admin/config/content/faq/categories', 'admin/config/content/faq/categories', 'Categories', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:96:"Allows the user to configure the layout of questions and answers using categories on a FAQ page.";}}', 'system', -1, 0, 0, 0, '-8', 5, 0, '1', '8', '35', '653', '654', '0', '0', '0', '0', 0),
('management', '655', '653', 'admin/config/content/faq/general', 'admin/config/content/faq/general', 'General', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:78:"Allows the user to configure the header and descriptive text for the FAQ page.";}}', 'system', -1, 0, 0, 0, '-10', 5, 0, '1', '8', '35', '653', '655', '0', '0', '0', '0', 0),
('management', '656', '653', 'admin/config/content/faq/questions', 'admin/config/content/faq/questions', 'Questions', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:79:"Allows the user to configure the layout of questions and answers on a FAQ page.";}}', 'system', -1, 0, 0, 0, '-9', 5, 0, '1', '8', '35', '653', '656', '0', '0', '0', '0', 0),
('main-menu', '668', '0', 'blog', 'blog', 'Our Blog', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:0:"";}}', 'menu', 0, 0, 0, 0, '-49', 1, 1, '668', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '670', '21', 'admin/structure/views', 'admin/structure/views', 'Views', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:35:"Manage customized lists of content.";}}', 'system', 0, 0, 1, 0, '0', 3, 0, '1', '21', '670', '0', '0', '0', '0', '0', '0', 0),
('management', '671', '670', 'admin/structure/views/add', 'admin/structure/views/add', 'Add new view', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '670', '671', '0', '0', '0', '0', '0', 0),
('management', '672', '670', 'admin/structure/views/add-template', 'admin/structure/views/add-template', 'Add view from template', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '670', '672', '0', '0', '0', '0', '0', 0),
('management', '674', '670', 'admin/structure/views/import', 'admin/structure/views/import', 'Import', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '670', '674', '0', '0', '0', '0', '0', 0),
('management', '675', '670', 'admin/structure/views/list', 'admin/structure/views/list', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 4, 0, '1', '21', '670', '675', '0', '0', '0', '0', '0', 0),
('management', '676', '670', 'admin/structure/views/settings', 'admin/structure/views/settings', 'Settings', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '670', '676', '0', '0', '0', '0', '0', 0),
('management', '678', '676', 'admin/structure/views/settings/advanced', 'admin/structure/views/settings/advanced', 'Advanced', 'a:0:{}', 'system', -1, 0, 0, 0, '1', 5, 0, '1', '21', '670', '676', '678', '0', '0', '0', '0', 0),
('management', '679', '676', 'admin/structure/views/settings/basic', 'admin/structure/views/settings/basic', 'Basic', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '670', '676', '679', '0', '0', '0', '0', 0),
('management', '681', '670', 'admin/structure/views/view/%', 'admin/structure/views/view/%', '', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '21', '670', '681', '0', '0', '0', '0', '0', 0),
('management', '684', '681', 'admin/structure/views/view/%/break-lock', 'admin/structure/views/view/%/break-lock', 'Break lock', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '670', '681', '684', '0', '0', '0', '0', 0),
('management', '685', '681', 'admin/structure/views/view/%/edit', 'admin/structure/views/view/%/edit', 'Edit view', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 5, 0, '1', '21', '670', '681', '685', '0', '0', '0', '0', 0),
('management', '686', '681', 'admin/structure/views/view/%/clone', 'admin/structure/views/view/%/clone', 'Clone', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '670', '681', '686', '0', '0', '0', '0', 0),
('management', '687', '681', 'admin/structure/views/view/%/delete', 'admin/structure/views/view/%/delete', 'Delete', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '670', '681', '687', '0', '0', '0', '0', 0),
('management', '688', '681', 'admin/structure/views/view/%/export', 'admin/structure/views/view/%/export', 'Export', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '670', '681', '688', '0', '0', '0', '0', 0),
('management', '689', '681', 'admin/structure/views/view/%/revert', 'admin/structure/views/view/%/revert', 'Revert', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '670', '681', '689', '0', '0', '0', '0', 0),
('management', '690', '670', 'admin/structure/views/nojs/preview/%/%', 'admin/structure/views/nojs/preview/%/%', '', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '21', '670', '690', '0', '0', '0', '0', '0', 0),
('management', '691', '670', 'admin/structure/views/ajax/preview/%/%', 'admin/structure/views/ajax/preview/%/%', '', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '21', '670', '691', '0', '0', '0', '0', '0', 0),
('navigation', '692', '6', 'node/add/slider', 'node/add/slider', 'Slider', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:38:"Use to create slides in header-slider.";}}', 'system', 0, 0, 0, 0, '0', 2, 0, '6', '692', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '718', '21', 'admin/structure/mini-panels', 'admin/structure/mini-panels', 'Mini panels', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:94:"Add, edit or delete mini panels, which can be used as blocks or content panes in other panels.";}}', 'system', 0, 0, 0, 0, '0', 3, 0, '1', '21', '718', '0', '0', '0', '0', '0', '0', 0),
('navigation', '719', '6', 'node/add/panel', 'node/add/panel', 'Panel', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:47:"A panel layout broken up into rows and columns.";}}', 'system', 0, 0, 0, 0, '0', 2, 0, '6', '719', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '720', '5', 'node/%/panel_content', 'node/%/panel_content', 'Panel content', 'a:0:{}', 'system', -1, 0, 0, 0, '3', 2, 0, '5', '720', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '721', '5', 'node/%/panel_layout', 'node/%/panel_layout', 'Panel layout', 'a:0:{}', 'system', -1, 0, 0, 0, '2', 2, 0, '5', '721', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '722', '21', 'admin/structure/panels', 'admin/structure/panels', 'Panels', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:49:"Get a bird''s eye view of items related to Panels.";}}', 'system', 0, 0, 0, 0, '0', 3, 0, '1', '21', '722', '0', '0', '0', '0', '0', '0', 0),
('management', '723', '718', 'admin/structure/mini-panels/add', 'admin/structure/mini-panels/add', 'Add', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '718', '723', '0', '0', '0', '0', '0', 0),
('management', '724', '722', 'admin/structure/panels/dashboard', 'admin/structure/panels/dashboard', 'Dashboard', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 4, 0, '1', '21', '722', '724', '0', '0', '0', '0', '0', 0),
('management', '725', '718', 'admin/structure/mini-panels/import', 'admin/structure/mini-panels/import', 'Import', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '718', '725', '0', '0', '0', '0', '0', 0),
('management', '727', '718', 'admin/structure/mini-panels/list', 'admin/structure/mini-panels/list', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 4, 0, '1', '21', '718', '727', '0', '0', '0', '0', '0', 0),
('management', '728', '722', 'admin/structure/panels/settings', 'admin/structure/panels/settings', 'Settings', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '722', '728', '0', '0', '0', '0', '0', 0),
('management', '729', '718', 'admin/structure/mini-panels/settings', 'admin/structure/mini-panels/settings', 'Settings', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '718', '729', '0', '0', '0', '0', '0', 0),
('management', '731', '728', 'admin/structure/panels/settings/general', 'admin/structure/panels/settings/general', 'General', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 5, 0, '1', '21', '722', '728', '731', '0', '0', '0', '0', 0),
('management', '734', '728', 'admin/structure/panels/settings/panels-mini', 'admin/structure/panels/settings/panels-mini', 'Mini panels', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '722', '728', '734', '0', '0', '0', '0', 0),
('management', '735', '728', 'admin/structure/panels/settings/panel-node', 'admin/structure/panels/settings/panel-node', 'Panel nodes', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:67:"Configure which content is available to add to panel node displays.";}}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '722', '728', '735', '0', '0', '0', '0', 0),
('management', '736', '727', 'admin/structure/mini-panels/list/%/export', 'admin/structure/mini-panels/list/%/export', 'Export', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '718', '727', '736', '0', '0', '0', '0', 0),
('navigation', '738', '6', 'node/add/portfolio', 'node/add/portfolio', 'Portfolio', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 2, 0, '6', '738', '0', '0', '0', '0', '0', '0', '0', 0),
('main-menu', '739', '0', 'portfolio', 'portfolio', 'Catalogue', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:0:"";}}', 'system', 0, 0, 1, 0, '-47', 1, 1, '739', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '741', '21', 'admin/structure/pages', 'admin/structure/pages', 'Pages', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:84:"Add, edit and remove overridden system pages and user defined pages from the system.";}}', 'system', 0, 0, 1, 0, '0', 3, 0, '1', '21', '741', '0', '0', '0', '0', '0', '0', 0),
('management', '742', '741', 'admin/structure/pages/add', 'admin/structure/pages/add', 'Add custom page', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '741', '742', '0', '0', '0', '0', '0', 0),
('management', '743', '741', 'admin/structure/pages/import', 'admin/structure/pages/import', 'Import page', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '741', '743', '0', '0', '0', '0', '0', 0),
('management', '744', '741', 'admin/structure/pages/list', 'admin/structure/pages/list', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 4, 0, '1', '21', '741', '744', '0', '0', '0', '0', '0', 0),
('management', '745', '741', 'admin/structure/pages/wizard', 'admin/structure/pages/wizard', 'Wizards', 'a:0:{}', 'system', -1, 0, 0, 0, '-5', 4, 0, '1', '21', '741', '745', '0', '0', '0', '0', '0', 0),
('management', '746', '728', 'admin/structure/panels/settings/panel-page', 'admin/structure/panels/settings/panel-page', 'Panel pages', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 5, 0, '1', '21', '722', '728', '746', '0', '0', '0', '0', 0),
('user-menu', '747', '0', 'user/login', 'user/login', 'Login', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:0:"";}}', 'menu', 0, 0, 0, 0, '0', 1, 1, '747', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '752', '35', 'admin/config/content/wysiwyg', 'admin/config/content/wysiwyg', 'Wysiwyg profiles', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:30:"Configure client-side editors.";}}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '8', '35', '752', '0', '0', '0', '0', '0', 0),
('management', '753', '752', 'admin/config/content/wysiwyg/profile', 'admin/config/content/wysiwyg/profile', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '8', '35', '752', '753', '0', '0', '0', '0', 0),
('management', '754', '753', 'admin/config/content/wysiwyg/profile/%/edit', 'admin/config/content/wysiwyg/profile/%/edit', 'Edit', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 6, 0, '1', '8', '35', '752', '753', '754', '0', '0', '0', 0),
('management', '755', '753', 'admin/config/content/wysiwyg/profile/%/delete', 'admin/config/content/wysiwyg/profile/%/delete', 'Remove', 'a:0:{}', 'system', -1, 0, 0, 0, '10', 6, 0, '1', '8', '35', '752', '753', '755', '0', '0', '0', 0),
('navigation', '771', '6', 'node/add/employee', 'node/add/employee', 'Employee', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:9:"Add staff";}}', 'system', 0, 0, 0, 0, '0', 2, 0, '6', '771', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '773', '6', 'node/add/partners', 'node/add/partners', 'Partners', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 2, 0, '6', '773', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '780', '19', 'admin/reports/updates', 'admin/reports/updates', 'Available updates', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:82:"Get a status report about available updates for your installed modules and themes.";}}', 'system', 0, 0, 0, 0, '-50', 3, 0, '1', '19', '780', '0', '0', '0', '0', '0', '0', 0),
('management', '781', '16', 'admin/modules/install', 'admin/modules/install', 'Install new module', 'a:0:{}', 'system', -1, 0, 0, 0, '25', 3, 0, '1', '16', '781', '0', '0', '0', '0', '0', '0', 0),
('management', '782', '7', 'admin/appearance/install', 'admin/appearance/install', 'Install new theme', 'a:0:{}', 'system', -1, 0, 0, 0, '25', 3, 0, '1', '7', '782', '0', '0', '0', '0', '0', '0', 0),
('management', '783', '16', 'admin/modules/update', 'admin/modules/update', 'Update', 'a:0:{}', 'system', -1, 0, 0, 0, '10', 3, 0, '1', '16', '783', '0', '0', '0', '0', '0', '0', 0),
('management', '784', '7', 'admin/appearance/update', 'admin/appearance/update', 'Update', 'a:0:{}', 'system', -1, 0, 0, 0, '10', 3, 0, '1', '7', '784', '0', '0', '0', '0', '0', '0', 0),
('management', '785', '780', 'admin/reports/updates/install', 'admin/reports/updates/install', 'Install new module or theme', 'a:0:{}', 'system', -1, 0, 0, 0, '25', 4, 0, '1', '19', '780', '785', '0', '0', '0', '0', '0', 0),
('management', '786', '780', 'admin/reports/updates/list', 'admin/reports/updates/list', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '19', '780', '786', '0', '0', '0', '0', '0', 0),
('management', '787', '780', 'admin/reports/updates/update', 'admin/reports/updates/update', 'Update', 'a:0:{}', 'system', -1, 0, 0, 0, '10', 4, 0, '1', '19', '780', '787', '0', '0', '0', '0', '0', 0),
('management', '788', '780', 'admin/reports/updates/settings', 'admin/reports/updates/settings', 'Settings', 'a:0:{}', 'system', -1, 0, 0, 0, '50', 4, 0, '1', '19', '780', '788', '0', '0', '0', '0', '0', 0),
('management', '831', '741', 'admin/structure/pages/edit/%', 'admin/structure/pages/edit/%', 'Edit', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '21', '741', '831', '0', '0', '0', '0', '0', 0),
('management', '832', '741', 'admin/structure/pages/%/operation/%', 'admin/structure/pages/%/operation/%', '', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '21', '741', '832', '0', '0', '0', '0', '0', 0),
('management', '833', '727', 'admin/structure/mini-panels/list/%/edit', 'admin/structure/mini-panels/list/%/edit', 'Edit', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 5, 0, '1', '21', '718', '727', '833', '0', '0', '0', '0', 0),
('navigation', '877', '0', 'faq-page', 'faq-page', 'Frequently Asked Questions', 'a:0:{}', 'system', 1, 0, 0, 0, '1', 1, 0, '877', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '878', '877', 'faq-page/list', 'faq-page/list', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 2, 0, '877', '878', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '879', '877', 'faq-page/order', 'faq-page/order', 'Order', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:78:"Allows the user to configure the order of questions and answers on a FAQ page.";}}', 'system', -1, 0, 0, 0, '-8', 2, 0, '877', '879', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '880', '877', 'faq-page/%/list', 'faq-page/%/list', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 2, 0, '877', '880', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '881', '877', 'faq-page/%/order', 'faq-page/%/order', 'Order', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:78:"Allows the user to configure the order of questions and answers on a FAQ page.";}}', 'system', -1, 0, 0, 0, '-8', 2, 0, '877', '881', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '969', '135', 'admin/structure/block/list/bartik/add', 'admin/structure/block/list/bartik/add', 'Add block', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '30', '135', '969', '0', '0', '0', '0', 0),
('user-menu', '1056', '0', 'faq-questions-top', 'faq-questions-top', 'FAQ', 'a:0:{}', 'system', 1, 0, 0, 0, '0', 1, 1, '1056', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('user-menu', '1057', '0', 'node', 'node', 'Sitemap', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:0:"";}}', 'menu', 1, 0, 0, 0, '0', 1, 1, '1057', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '1058', '6', 'node/add/services', 'node/add/services', 'Services', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 2, 0, '6', '1058', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '1102', '681', 'admin/structure/views/view/%/preview/%', 'admin/structure/views/view/%/preview/%', '', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '670', '681', '1102', '0', '0', '0', '0', 0),
('main-menu', '1145', '739', 'portfolio-1-col', 'portfolio-1-col', 'Portfolio 1 col', 'a:0:{}', 'system', 0, 0, 0, 0, '-50', 2, 1, '739', '1145', '0', '0', '0', '0', '0', '0', '0', 0),
('main-menu', '1146', '739', 'portfolio-2-col', 'portfolio-2-col', 'Portfolio 2 cols', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:0:"";}}', 'system', 0, 0, 0, 0, '-49', 2, 1, '739', '1146', '0', '0', '0', '0', '0', '0', '0', 0),
('main-menu', '1147', '739', 'portfolio-3-col', 'portfolio-3-col', 'Portfolio 3 cols', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:0:"";}}', 'system', 0, 0, 0, 0, '-48', 2, 1, '739', '1147', '0', '0', '0', '0', '0', '0', '0', 0),
('main-menu', '1446', '739', 'portfolio-2-cols', 'portfolio-2-cols', 'Portfolio 2 cols', 'a:0:{}', 'system', 0, 0, 0, 0, '-49', 2, 1, '739', '1446', '0', '0', '0', '0', '0', '0', '0', 0),
('main-menu', '1447', '739', 'portfolio-3-cols', 'portfolio-3-cols', 'Portfolio 3 cols', 'a:0:{}', 'system', 0, 0, 0, 0, '-48', 2, 1, '739', '1447', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '1658', '21', 'admin/structure/demo', 'admin/structure/demo', 'Snapshots', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:36:"Create snapshots and reset the site.";}}', 'system', 0, 0, 0, 0, '0', 3, 0, '1', '21', '1658', '0', '0', '0', '0', '0', '0', 0),
('management', '1659', '1658', 'admin/structure/demo/dump', 'admin/structure/demo/dump', 'Create snapshot', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '1658', '1659', '0', '0', '0', '0', '0', 0),
('management', '1660', '1658', 'admin/structure/demo/list', 'admin/structure/demo/list', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 4, 0, '1', '21', '1658', '1660', '0', '0', '0', '0', '0', 0),
('management', '1661', '1658', 'admin/structure/demo/reset', 'admin/structure/demo/reset', 'Reset', 'a:0:{}', 'system', -1, 0, 0, 0, '3', 4, 0, '1', '21', '1658', '1661', '0', '0', '0', '0', '0', 0),
('management', '1662', '1658', 'admin/structure/demo/settings', 'admin/structure/demo/settings', 'Settings', 'a:0:{}', 'system', -1, 0, 0, 0, '10', 4, 0, '1', '21', '1658', '1662', '0', '0', '0', '0', '0', 0),
('management', '1663', '1658', 'admin/structure/demo/delete/%', 'admin/structure/demo/delete/%', 'Delete snapshot', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '1658', '1663', '0', '0', '0', '0', '0', 0),
('management', '1664', '19', 'admin/reports/views-plugins', 'admin/reports/views-plugins', 'Views plugins', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:38:"Overview of plugins used in all views.";}}', 'system', 0, 0, 0, 0, '0', 3, 0, '1', '19', '1664', '0', '0', '0', '0', '0', '0', 0),
('management', '1666', '64', 'admin/config/services/getlocations', 'admin/config/services/getlocations', 'Get locations', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:23:"Configure Get locations";}}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '8', '64', '1666', '0', '0', '0', '0', '0', 0),
('management', '1667', '64', 'admin/config/services/getlocations_fields', 'admin/config/services/getlocations_fields', 'Getlocations fields', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:29:"Configure Getlocations fields";}}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '8', '64', '1667', '0', '0', '0', '0', '0', 0),
('management', '1668', '42', 'admin/reports/fields/list', 'admin/reports/fields/list', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 4, 0, '1', '19', '42', '1668', '0', '0', '0', '0', '0', 0),
('management', '1669', '42', 'admin/reports/fields/views-fields', 'admin/reports/fields/views-fields', 'Used in views', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:37:"Overview of fields used in all views.";}}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '19', '42', '1669', '0', '0', '0', '0', '0', 0),
('navigation', '1677', '6', 'node/add/maps', 'node/add/maps', 'Maps', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 2, 0, '6', '1677', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '1720', '46', 'admin/config/media/colorbox', 'admin/config/media/colorbox', 'Colorbox', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:25:"Adjust Colorbox settings.";}}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '8', '46', '1720', '0', '0', '0', '0', '0', 0),
('management', '1847', '61', 'admin/config/user-interface/addthis', 'admin/config/user-interface/addthis', 'AddThis', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:27:"Configure AddThis settings.";}}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '8', '61', '1847', '0', '0', '0', '0', '0', 0),
('management', '2226', '1847', 'admin/config/user-interface/addthis/advanced', 'admin/config/user-interface/addthis/advanced', 'Advanced settings', 'a:0:{}', 'system', -1, 0, 0, 0, '10', 5, 0, '1', '8', '61', '1847', '2226', '0', '0', '0', '0', 0),
('management', '2227', '1847', 'admin/config/user-interface/addthis/basic', 'admin/config/user-interface/addthis/basic', 'Basic settings', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '8', '61', '1847', '2227', '0', '0', '0', '0', 0),
('management', '2312', '61', 'admin/config/user-interface/back_to_top', 'admin/config/user-interface/back_to_top', 'Back To Top', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:31:"Administer Back To Top settings";}}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '8', '61', '2312', '0', '0', '0', '0', '0', 0),
('management', '2859', '46', 'admin/config/media/flexslider', 'admin/config/media/flexslider', 'FlexSlider', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:30:"Administer FlexSlider presets.";}}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '8', '46', '2859', '0', '0', '0', '0', '0', 0),
('management', '2860', '2859', 'admin/config/media/flexslider/add', 'admin/config/media/flexslider/add', 'Add', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '8', '46', '2859', '2860', '0', '0', '0', '0', 0),
('management', '2861', '2859', 'admin/config/media/flexslider/advanced', 'admin/config/media/flexslider/advanced', 'Advanced settings', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:50:"Configure the advanced flexslider module settings.";}}', 'system', -1, 0, 0, 0, '2', 5, 0, '1', '8', '46', '2859', '2861', '0', '0', '0', '0', 0),
('management', '2862', '2859', 'admin/config/media/flexslider/import', 'admin/config/media/flexslider/import', 'Import', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '8', '46', '2859', '2862', '0', '0', '0', '0', 0),
('management', '2863', '2859', 'admin/config/media/flexslider/list', 'admin/config/media/flexslider/list', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 5, 0, '1', '8', '46', '2859', '2863', '0', '0', '0', '0', 0),
('management', '2864', '2863', 'admin/config/media/flexslider/list/%/edit', 'admin/config/media/flexslider/list/%/edit', 'Edit', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 6, 0, '1', '8', '46', '2859', '2863', '2864', '0', '0', '0', 0),
('management', '2865', '2863', 'admin/config/media/flexslider/list/%/export', 'admin/config/media/flexslider/list/%/export', 'Export', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 6, 0, '1', '8', '46', '2859', '2863', '2865', '0', '0', '0', 0),
('navigation', '3457', '17', 'user/%/follow', 'user/%/follow', 'Follow', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:47:"Update the associated web service follow links.";}}', 'system', -1, 0, 0, 0, '0', 2, 0, '17', '3457', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '3458', '64', 'admin/config/services/follow', 'admin/config/services/follow', 'Follow', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:49:"Configure the site-wide web service follow links.";}}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '8', '64', '3458', '0', '0', '0', '0', '0', 0),
('management', '3629', '39', 'admin/config/development/jquery_update', 'admin/config/development/jquery_update', 'jQuery update', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:83:"Configure settings related to the jQuery upgrade, the library path and compression.";}}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '8', '39', '3629', '0', '0', '0', '0', '0', 0),
('navigation', '3756', '0', 'semantic-views-demo', 'semantic-views-demo', 'Semantic Views demo', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 1, 0, '3756', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '3757', '3756', 'semantic-views-demo/unformatted', 'semantic-views-demo/unformatted', 'Unformatted', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 2, 0, '3756', '3757', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '3758', '3756', 'semantic-views-demo/grid', 'semantic-views-demo/grid', 'Grid', 'a:0:{}', 'system', -1, 0, 0, 0, '1', 2, 0, '3756', '3758', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '3759', '3756', 'semantic-views-demo/list', 'semantic-views-demo/list', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '2', 2, 0, '3756', '3759', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '3760', '3756', 'semantic-views-demo/unformatted-semantic', 'semantic-views-demo/unformatted-semantic', 'Unformatted (semantic)', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 2, 0, '3756', '3760', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '3761', '3756', 'semantic-views-demo/grid-semantic', 'semantic-views-demo/grid-semantic', 'Grid (semantic)', 'a:0:{}', 'system', -1, 0, 0, 0, '1', 2, 0, '3756', '3761', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '3762', '3756', 'semantic-views-demo/list-semantic', 'semantic-views-demo/list-semantic', 'List (semantic)', 'a:0:{}', 'system', -1, 0, 0, 0, '2', 2, 0, '3756', '3762', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '3763', '8', 'admin/config/administration', 'admin/config/administration', 'Administration', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:21:"Administration tools.";}}', 'system', 0, 0, 1, 0, '0', 3, 0, '1', '8', '3763', '0', '0', '0', '0', '0', '0', 0),
('management', '3764', '3763', 'admin/config/administration/admin_menu', 'admin/config/administration/admin_menu', 'Administration menu', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:36:"Adjust administration menu settings.";}}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '8', '3763', '3764', '0', '0', '0', '0', '0', 0),
('management', '3765', '61', 'admin/config/user-interface/modulefilter', 'admin/config/user-interface/modulefilter', 'Module filter', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:37:"Configure settings for Module Filter.";}}', 'system', 0, 0, 0, 0, '0', 4, 0, '1', '8', '61', '3765', '0', '0', '0', '0', '0', 0),
('main-menu', '3767', '739', 'portfolio-4', 'portfolio-4', 'Catalogue 4', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:0:"";}}', 'system', 0, 0, 0, 0, '-48', 2, 1, '739', '3767', '0', '0', '0', '0', '0', '0', '0', 0),
('main-menu', '3768', '739', 'portfolio-2', 'portfolio-2', 'Catalogue 2', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:0:"";}}', 'system', 0, 0, 0, 0, '-50', 2, 1, '739', '3768', '0', '0', '0', '0', '0', '0', '0', 0),
('main-menu', '3769', '739', 'portfolio-3', 'portfolio-3', 'Catalogue 3', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:0:"";}}', 'system', 0, 0, 0, 0, '-49', 2, 1, '739', '3769', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '3980', '104', 'admin/config/media/image-styles/retina_preview/%', 'admin/config/media/image-styles/retina_preview/%', 'Preview retinafied style', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 5, 0, '1', '8', '46', '104', '3980', '0', '0', '0', '0', 0),
('main-menu', '4192', '0', 'services', 'services', 'Services', 'a:0:{}', 'system', 0, 0, 0, 0, '-48', 1, 1, '4192', '0', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '4193', '6', 'node/add/popular-services', 'node/add/popular-services', 'Popular services', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 2, 0, '6', '4193', '0', '0', '0', '0', '0', '0', '0', 0),
('navigation', '4194', '6', 'node/add/testimonials', 'node/add/testimonials', 'Testimonials', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 2, 0, '6', '4194', '0', '0', '0', '0', '0', '0', '0', 0),
('management', '4279', '54', 'admin/appearance/settings/tipsy', 'admin/appearance/settings/tipsy', 'Tipsy tooltips', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '7', '54', '4279', '0', '0', '0', '0', '0', 0),
('management', '4280', '127', 'admin/structure/taxonomy/%/display', 'admin/structure/taxonomy/%/display', 'Manage display', 'a:0:{}', 'system', -1, 0, 0, 0, '2', 5, 0, '1', '21', '57', '127', '4280', '0', '0', '0', '0', 0),
('management', '4281', '89', 'admin/config/people/accounts/display', 'admin/config/people/accounts/display', 'Manage display', 'a:0:{}', 'system', -1, 0, 0, 0, '2', 5, 0, '1', '8', '48', '89', '4281', '0', '0', '0', '0', 0),
('management', '4282', '127', 'admin/structure/taxonomy/%/fields', 'admin/structure/taxonomy/%/fields', 'Manage fields', 'a:0:{}', 'system', -1, 0, 1, 0, '1', 5, 0, '1', '21', '57', '127', '4282', '0', '0', '0', '0', 0),
('management', '4283', '89', 'admin/config/people/accounts/fields', 'admin/config/people/accounts/fields', 'Manage fields', 'a:0:{}', 'system', -1, 0, 1, 0, '1', 5, 0, '1', '8', '48', '89', '4283', '0', '0', '0', '0', 0),
('management', '4284', '30', 'admin/structure/block/list/tipsy', 'admin/structure/block/list/tipsy', 'Tipsy tooltips', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '30', '4284', '0', '0', '0', '0', '0', 0),
('management', '4285', '4284', 'admin/structure/block/list/tipsy/add', 'admin/structure/block/list/tipsy/add', 'Add block', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '30', '4284', '4285', '0', '0', '0', '0', 0),
('management', '4286', '4280', 'admin/structure/taxonomy/%/display/default', 'admin/structure/taxonomy/%/display/default', 'Default', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 6, 0, '1', '21', '57', '127', '4280', '4286', '0', '0', '0', 0),
('management', '4287', '4281', 'admin/config/people/accounts/display/default', 'admin/config/people/accounts/display/default', 'Default', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 6, 0, '1', '8', '48', '89', '4281', '4287', '0', '0', '0', 0),
('management', '4288', '139', 'admin/structure/types/manage/%/display', 'admin/structure/types/manage/%/display', 'Manage display', 'a:0:{}', 'system', -1, 0, 0, 0, '2', 5, 0, '1', '21', '36', '139', '4288', '0', '0', '0', '0', 0),
('management', '4289', '139', 'admin/structure/types/manage/%/fields', 'admin/structure/types/manage/%/fields', 'Manage fields', 'a:0:{}', 'system', -1, 0, 1, 0, '1', 5, 0, '1', '21', '36', '139', '4289', '0', '0', '0', '0', 0),
('management', '4290', '4280', 'admin/structure/taxonomy/%/display/full', 'admin/structure/taxonomy/%/display/full', 'Taxonomy term page', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 6, 0, '1', '21', '57', '127', '4280', '4290', '0', '0', '0', 0),
('management', '4291', '4281', 'admin/config/people/accounts/display/full', 'admin/config/people/accounts/display/full', 'User account', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 6, 0, '1', '8', '48', '89', '4281', '4291', '0', '0', '0', 0),
('management', '4292', '4282', 'admin/structure/taxonomy/%/fields/%', 'admin/structure/taxonomy/%/fields/%', '', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 6, 0, '1', '21', '57', '127', '4282', '4292', '0', '0', '0', 0),
('management', '4293', '4283', 'admin/config/people/accounts/fields/%', 'admin/config/people/accounts/fields/%', '', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 6, 0, '1', '8', '48', '89', '4283', '4293', '0', '0', '0', 0),
('management', '4294', '4288', 'admin/structure/types/manage/%/display/default', 'admin/structure/types/manage/%/display/default', 'Default', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 6, 0, '1', '21', '36', '139', '4288', '4294', '0', '0', '0', 0),
('management', '4295', '4288', 'admin/structure/types/manage/%/display/full', 'admin/structure/types/manage/%/display/full', 'Full content', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 6, 0, '1', '21', '36', '139', '4288', '4295', '0', '0', '0', 0),
('management', '4296', '4288', 'admin/structure/types/manage/%/display/print', 'admin/structure/types/manage/%/display/print', 'Print', 'a:0:{}', 'system', -1, 0, 0, 0, '5', 6, 0, '1', '21', '36', '139', '4288', '4296', '0', '0', '0', 0),
('management', '4297', '4288', 'admin/structure/types/manage/%/display/rss', 'admin/structure/types/manage/%/display/rss', 'RSS', 'a:0:{}', 'system', -1, 0, 0, 0, '2', 6, 0, '1', '21', '36', '139', '4288', '4297', '0', '0', '0', 0),
('management', '4298', '4288', 'admin/structure/types/manage/%/display/search_index', 'admin/structure/types/manage/%/display/search_index', 'Search index', 'a:0:{}', 'system', -1, 0, 0, 0, '3', 6, 0, '1', '21', '36', '139', '4288', '4298', '0', '0', '0', 0),
('management', '4299', '4288', 'admin/structure/types/manage/%/display/search_result', 'admin/structure/types/manage/%/display/search_result', 'Search result', 'a:0:{}', 'system', -1, 0, 0, 0, '4', 6, 0, '1', '21', '36', '139', '4288', '4299', '0', '0', '0', 0),
('management', '4300', '4288', 'admin/structure/types/manage/%/display/teaser', 'admin/structure/types/manage/%/display/teaser', 'Teaser', 'a:0:{}', 'system', -1, 0, 0, 0, '1', 6, 0, '1', '21', '36', '139', '4288', '4300', '0', '0', '0', 0),
('management', '4301', '4292', 'admin/structure/taxonomy/%/fields/%/delete', 'admin/structure/taxonomy/%/fields/%/delete', 'Delete', 'a:0:{}', 'system', -1, 0, 0, 0, '10', 7, 0, '1', '21', '57', '127', '4282', '4292', '4301', '0', '0', 0),
('management', '4302', '4293', 'admin/config/people/accounts/fields/%/delete', 'admin/config/people/accounts/fields/%/delete', 'Delete', 'a:0:{}', 'system', -1, 0, 0, 0, '10', 7, 0, '1', '8', '48', '89', '4283', '4293', '4302', '0', '0', 0),
('management', '4303', '4292', 'admin/structure/taxonomy/%/fields/%/edit', 'admin/structure/taxonomy/%/fields/%/edit', 'Edit', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 7, 0, '1', '21', '57', '127', '4282', '4292', '4303', '0', '0', 0),
('management', '4304', '4293', 'admin/config/people/accounts/fields/%/edit', 'admin/config/people/accounts/fields/%/edit', 'Edit', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 7, 0, '1', '8', '48', '89', '4283', '4293', '4304', '0', '0', 0),
('management', '4305', '4289', 'admin/structure/types/manage/%/fields/%', 'admin/structure/types/manage/%/fields/%', '', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 6, 0, '1', '21', '36', '139', '4289', '4305', '0', '0', '0', 0),
('management', '4306', '4292', 'admin/structure/taxonomy/%/fields/%/field-settings', 'admin/structure/taxonomy/%/fields/%/field-settings', 'Field settings', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 7, 0, '1', '21', '57', '127', '4282', '4292', '4306', '0', '0', 0),
('management', '4307', '4292', 'admin/structure/taxonomy/%/fields/%/widget-type', 'admin/structure/taxonomy/%/fields/%/widget-type', 'Widget type', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 7, 0, '1', '21', '57', '127', '4282', '4292', '4307', '0', '0', 0),
('management', '4308', '4293', 'admin/config/people/accounts/fields/%/field-settings', 'admin/config/people/accounts/fields/%/field-settings', 'Field settings', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 7, 0, '1', '8', '48', '89', '4283', '4293', '4308', '0', '0', 0),
('management', '4309', '4293', 'admin/config/people/accounts/fields/%/widget-type', 'admin/config/people/accounts/fields/%/widget-type', 'Widget type', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 7, 0, '1', '8', '48', '89', '4283', '4293', '4309', '0', '0', 0),
('management', '4310', '185', 'admin/structure/types/manage/%/comment/display/default', 'admin/structure/types/manage/%/comment/display/default', 'Default', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 6, 0, '1', '21', '36', '139', '185', '4310', '0', '0', '0', 0),
('management', '4311', '185', 'admin/structure/types/manage/%/comment/display/full', 'admin/structure/types/manage/%/comment/display/full', 'Full comment', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 6, 0, '1', '21', '36', '139', '185', '4311', '0', '0', '0', 0),
('management', '4312', '186', 'admin/structure/types/manage/%/comment/fields/%', 'admin/structure/types/manage/%/comment/fields/%', '', 'a:0:{}', 'system', 0, 0, 0, 0, '0', 6, 0, '1', '21', '36', '139', '186', '4312', '0', '0', '0', 0),
('management', '4313', '4305', 'admin/structure/types/manage/%/fields/%/delete', 'admin/structure/types/manage/%/fields/%/delete', 'Delete', 'a:0:{}', 'system', -1, 0, 0, 0, '10', 7, 0, '1', '21', '36', '139', '4289', '4305', '4313', '0', '0', 0),
('management', '4314', '4305', 'admin/structure/types/manage/%/fields/%/edit', 'admin/structure/types/manage/%/fields/%/edit', 'Edit', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 7, 0, '1', '21', '36', '139', '4289', '4305', '4314', '0', '0', 0),
('management', '4315', '4305', 'admin/structure/types/manage/%/fields/%/field-settings', 'admin/structure/types/manage/%/fields/%/field-settings', 'Field settings', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 7, 0, '1', '21', '36', '139', '4289', '4305', '4315', '0', '0', 0),
('management', '4316', '4305', 'admin/structure/types/manage/%/fields/%/widget-type', 'admin/structure/types/manage/%/fields/%/widget-type', 'Widget type', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 7, 0, '1', '21', '36', '139', '4289', '4305', '4316', '0', '0', 0),
('management', '4317', '4312', 'admin/structure/types/manage/%/comment/fields/%/delete', 'admin/structure/types/manage/%/comment/fields/%/delete', 'Delete', 'a:0:{}', 'system', -1, 0, 0, 0, '10', 7, 0, '1', '21', '36', '139', '186', '4312', '4317', '0', '0', 0);
INSERT INTO `menu_links` VALUES
('management', '4318', '4312', 'admin/structure/types/manage/%/comment/fields/%/edit', 'admin/structure/types/manage/%/comment/fields/%/edit', 'Edit', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 7, 0, '1', '21', '36', '139', '186', '4312', '4318', '0', '0', 0),
('management', '4319', '4312', 'admin/structure/types/manage/%/comment/fields/%/field-settings', 'admin/structure/types/manage/%/comment/fields/%/field-settings', 'Field settings', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 7, 0, '1', '21', '36', '139', '186', '4312', '4319', '0', '0', 0),
('management', '4320', '4312', 'admin/structure/types/manage/%/comment/fields/%/widget-type', 'admin/structure/types/manage/%/comment/fields/%/widget-type', 'Widget type', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 7, 0, '1', '21', '36', '139', '186', '4312', '4320', '0', '0', 0),
('management', '4321', '54', 'admin/appearance/settings/theme822', 'admin/appearance/settings/theme822', 'theme822', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '7', '54', '4321', '0', '0', '0', '0', '0', 0),
('management', '4322', '30', 'admin/structure/block/list/theme822', 'admin/structure/block/list/theme822', 'theme822', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 4, 0, '1', '21', '30', '4322', '0', '0', '0', '0', '0', 0),
('management', '4325', '722', 'admin/structure/panels/layouts', 'admin/structure/panels/layouts', 'Layouts', 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:43:"Add, edit or delete custom content layouts.";}}', 'system', -1, 0, 0, 0, '0', 4, 0, '1', '21', '722', '4325', '0', '0', '0', '0', '0', 0),
('management', '4326', '4325', 'admin/structure/panels/layouts/add-flexible', 'admin/structure/panels/layouts/add-flexible', 'Add flexible layout', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '722', '4325', '4326', '0', '0', '0', '0', 0),
('management', '4327', '4325', 'admin/structure/panels/layouts/import', 'admin/structure/panels/layouts/import', 'Import', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 5, 0, '1', '21', '722', '4325', '4327', '0', '0', '0', '0', 0),
('management', '4328', '4325', 'admin/structure/panels/layouts/list', 'admin/structure/panels/layouts/list', 'List', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 5, 0, '1', '21', '722', '4325', '4328', '0', '0', '0', '0', 0),
('management', '4329', '4328', 'admin/structure/panels/layouts/list/%/edit', 'admin/structure/panels/layouts/list/%/edit', 'Edit', 'a:0:{}', 'system', -1, 0, 0, 0, '-10', 6, 0, '1', '21', '722', '4325', '4328', '4329', '0', '0', '0', 0),
('management', '4330', '4328', 'admin/structure/panels/layouts/list/%/export', 'admin/structure/panels/layouts/list/%/export', 'Export', 'a:0:{}', 'system', -1, 0, 0, 0, '0', 6, 0, '1', '21', '722', '4325', '4328', '4330', '0', '0', '0', 0);
/*!40000 ALTER TABLE menu_links ENABLE KEYS */;

--
-- Table structure for table 'menu_router'
--

CREATE TABLE IF NOT EXISTS `menu_router` (
  `path` varchar(255) NOT NULL DEFAULT '' COMMENT 'Primary Key: the Drupal path this entry describes',
  `load_functions` blob NOT NULL COMMENT 'A serialized array of function names (like node_load) to be called to load an object corresponding to a part of the current path.',
  `to_arg_functions` blob NOT NULL COMMENT 'A serialized array of function names (like user_uid_optional_to_arg) to be called to replace a part of the router path with another string.',
  `access_callback` varchar(255) NOT NULL DEFAULT '' COMMENT 'The callback which determines the access to this router path. Defaults to user_access.',
  `access_arguments` blob COMMENT 'A serialized array of arguments for the access callback.',
  `page_callback` varchar(255) NOT NULL DEFAULT '' COMMENT 'The name of the function that renders the page.',
  `page_arguments` blob COMMENT 'A serialized array of arguments for the page callback.',
  `delivery_callback` varchar(255) NOT NULL DEFAULT '' COMMENT 'The name of the function that sends the result of the page_callback function to the browser.',
  `fit` int(11) NOT NULL DEFAULT '0' COMMENT 'A numeric representation of how specific the path is.',
  `number_parts` smallint(6) NOT NULL DEFAULT '0' COMMENT 'Number of parts in this router path.',
  `context` int(11) NOT NULL DEFAULT '0' COMMENT 'Only for local tasks (tabs) - the context of a local task to control its placement.',
  `tab_parent` varchar(255) NOT NULL DEFAULT '' COMMENT 'Only for local tasks (tabs) - the router path of the parent page (which may also be a local task).',
  `tab_root` varchar(255) NOT NULL DEFAULT '' COMMENT 'Router path of the closest non-tab parent page. For pages that are not local tasks, this will be the same as the path.',
  `title` varchar(255) NOT NULL DEFAULT '' COMMENT 'The title for the current page, or the title for the tab if this is a local task.',
  `title_callback` varchar(255) NOT NULL DEFAULT '' COMMENT 'A function which will alter the title. Defaults to t()',
  `title_arguments` varchar(255) NOT NULL DEFAULT '' COMMENT 'A serialized array of arguments for the title callback. If empty, the title will be used as the sole argument for the title callback.',
  `theme_callback` varchar(255) NOT NULL DEFAULT '' COMMENT 'A function which returns the name of the theme that will be used to render this page. If left empty, the default theme will be used.',
  `theme_arguments` varchar(255) NOT NULL DEFAULT '' COMMENT 'A serialized array of arguments for the theme callback.',
  `type` int(11) NOT NULL DEFAULT '0' COMMENT 'Numeric representation of the type of the menu item, like MENU_LOCAL_TASK.',
  `description` text NOT NULL COMMENT 'A description of this item.',
  `position` varchar(255) NOT NULL DEFAULT '' COMMENT 'The position of the block (left or right) on the system administration page for this item.',
  `weight` int(11) NOT NULL DEFAULT '0' COMMENT 'Weight of the element. Lighter weights are higher up, heavier weights go down.',
  `include_file` mediumtext COMMENT 'The file to include for this element, usually the page callback function lives in this file.',
  PRIMARY KEY (`path`),
  KEY `fit` (`fit`),
  KEY `tab_parent` (`tab_parent`(64),`weight`,`title`),
  KEY `tab_root_weight_title` (`tab_root`(64),`weight`,`title`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Maps paths to various callbacks (access, page and title)';

--
-- Dumping data for table 'menu_router'
--

/*!40000 ALTER TABLE menu_router DISABLE KEYS */;
INSERT INTO `menu_router` VALUES
('admin', '', '', 'user_access', 'a:1:{i:0;s:27:"access administration pages";}', 'system_admin_menu_block_page', 'a:0:{}', '', '1', 1, '0', '', 'admin', 'Administration', 't', '', '', 'a:0:{}', '6', '', '', '9', 'modules/system/system.admin.inc'),
('admin/appearance', '', '', 'user_access', 'a:1:{i:0;s:17:"administer themes";}', 'system_themes_page', 'a:0:{}', '', '3', 2, '0', '', 'admin/appearance', 'Appearance', 't', '', '', 'a:0:{}', '6', 'Select and configure your themes.', 'left', '-6', 'modules/system/system.admin.inc'),
('admin/appearance/default', '', '', 'user_access', 'a:1:{i:0;s:17:"administer themes";}', 'system_theme_default', 'a:0:{}', '', '7', 3, '0', '', 'admin/appearance/default', 'Set default theme', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/system/system.admin.inc'),
('admin/appearance/disable', '', '', 'user_access', 'a:1:{i:0;s:17:"administer themes";}', 'system_theme_disable', 'a:0:{}', '', '7', 3, '0', '', 'admin/appearance/disable', 'Disable theme', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/system/system.admin.inc'),
('admin/appearance/enable', '', '', 'user_access', 'a:1:{i:0;s:17:"administer themes";}', 'system_theme_enable', 'a:0:{}', '', '7', 3, '0', '', 'admin/appearance/enable', 'Enable theme', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/system/system.admin.inc'),
('admin/appearance/install', '', '', 'update_manager_access', 'a:0:{}', 'drupal_get_form', 'a:2:{i:0;s:27:"update_manager_install_form";i:1;s:5:"theme";}', '', '7', 3, '1', 'admin/appearance', 'admin/appearance', 'Install new theme', 't', '', '', 'a:0:{}', '388', '', '', '25', 'modules/update/update.manager.inc'),
('admin/appearance/list', '', '', 'user_access', 'a:1:{i:0;s:17:"administer themes";}', 'system_themes_page', 'a:0:{}', '', '7', 3, '1', 'admin/appearance', 'admin/appearance', 'List', 't', '', '', 'a:0:{}', '140', 'Select and configure your theme', '', '-1', 'modules/system/system.admin.inc'),
('admin/appearance/settings', '', '', 'user_access', 'a:1:{i:0;s:17:"administer themes";}', 'drupal_get_form', 'a:1:{i:0;s:21:"system_theme_settings";}', '', '7', 3, '1', 'admin/appearance', 'admin/appearance', 'Settings', 't', '', '', 'a:0:{}', '132', 'Configure default and theme specific settings.', '', '20', 'modules/system/system.admin.inc'),
('admin/appearance/settings/bartik', '', '', '_system_themes_access', 'a:1:{i:0;O:8:"stdClass":12:{s:8:"filename";s:25:"themes/bartik/bartik.info";s:4:"name";s:6:"bartik";s:4:"type";s:5:"theme";s:5:"owner";s:45:"themes/engines/phptemplate/phptemplate.engine";s:6:"status";s:1:"1";s:9:"bootstrap";s:1:"0";s:14:"schema_version";s:2:"-1";s:6:"weight";s:1:"0";s:4:"info";a:17:{s:4:"name";s:6:"Bartik";s:11:"description";s:48:"A flexible, recolorable theme with many regions.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:11:"stylesheets";a:2:{s:3:"all";a:3:{s:14:"css/layout.css";s:28:"themes/bartik/css/layout.css";s:13:"css/style.css";s:27:"themes/bartik/css/style.css";s:14:"css/colors.css";s:28:"themes/bartik/css/colors.css";}s:5:"print";a:1:{s:13:"css/print.css";s:27:"themes/bartik/css/print.css";}}s:7:"regions";a:17:{s:6:"header";s:6:"Header";s:4:"help";s:4:"Help";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";s:11:"highlighted";s:11:"Highlighted";s:8:"featured";s:8:"Featured";s:7:"content";s:7:"Content";s:13:"sidebar_first";s:13:"Sidebar first";s:14:"sidebar_second";s:14:"Sidebar second";s:14:"triptych_first";s:14:"Triptych first";s:15:"triptych_middle";s:15:"Triptych middle";s:13:"triptych_last";s:13:"Triptych last";s:18:"footer_firstcolumn";s:19:"Footer first column";s:19:"footer_secondcolumn";s:20:"Footer second column";s:18:"footer_thirdcolumn";s:19:"Footer third column";s:19:"footer_fourthcolumn";s:20:"Footer fourth column";s:6:"footer";s:6:"Footer";}s:8:"settings";a:1:{s:20:"shortcut_module_link";s:1:"0";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:6:"engine";s:11:"phptemplate";s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:10:"screenshot";s:28:"themes/bartik/screenshot.png";s:3:"php";s:5:"5.2.4";s:7:"scripts";a:0:{}s:14:"regions_hidden";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}s:28:"overlay_supplemental_regions";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}}s:6:"prefix";s:11:"phptemplate";s:11:"stylesheets";a:2:{s:3:"all";a:3:{s:14:"css/layout.css";s:28:"themes/bartik/css/layout.css";s:13:"css/style.css";s:27:"themes/bartik/css/style.css";s:14:"css/colors.css";s:28:"themes/bartik/css/colors.css";}s:5:"print";a:1:{s:13:"css/print.css";s:27:"themes/bartik/css/print.css";}}s:6:"engine";s:11:"phptemplate";}}', 'drupal_get_form', 'a:2:{i:0;s:21:"system_theme_settings";i:1;s:6:"bartik";}', '', '15', 4, '1', 'admin/appearance/settings', 'admin/appearance', 'Bartik', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/system/system.admin.inc'),
('admin/appearance/settings/garland', '', '', '_system_themes_access', 'a:1:{i:0;O:8:"stdClass":12:{s:8:"filename";s:27:"themes/garland/garland.info";s:4:"name";s:7:"garland";s:4:"type";s:5:"theme";s:5:"owner";s:45:"themes/engines/phptemplate/phptemplate.engine";s:6:"status";s:1:"0";s:9:"bootstrap";s:1:"0";s:14:"schema_version";s:2:"-1";s:6:"weight";s:1:"0";s:4:"info";a:17:{s:4:"name";s:7:"Garland";s:11:"description";s:111:"A multi-column theme which can be configured to modify colors and switch between fixed and fluid width layouts.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:11:"stylesheets";a:2:{s:3:"all";a:1:{s:9:"style.css";s:24:"themes/garland/style.css";}s:5:"print";a:1:{s:9:"print.css";s:24:"themes/garland/print.css";}}s:8:"settings";a:1:{s:13:"garland_width";s:5:"fluid";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:6:"engine";s:11:"phptemplate";s:7:"regions";a:9:{s:13:"sidebar_first";s:12:"Left sidebar";s:14:"sidebar_second";s:13:"Right sidebar";s:7:"content";s:7:"Content";s:6:"header";s:6:"Header";s:6:"footer";s:6:"Footer";s:11:"highlighted";s:11:"Highlighted";s:4:"help";s:4:"Help";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";}s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:10:"screenshot";s:29:"themes/garland/screenshot.png";s:3:"php";s:5:"5.2.4";s:7:"scripts";a:0:{}s:14:"regions_hidden";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}s:28:"overlay_supplemental_regions";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}}s:6:"prefix";s:11:"phptemplate";s:11:"stylesheets";a:2:{s:3:"all";a:1:{s:9:"style.css";s:24:"themes/garland/style.css";}s:5:"print";a:1:{s:9:"print.css";s:24:"themes/garland/print.css";}}s:6:"engine";s:11:"phptemplate";}}', 'drupal_get_form', 'a:2:{i:0;s:21:"system_theme_settings";i:1;s:7:"garland";}', '', '15', 4, '1', 'admin/appearance/settings', 'admin/appearance', 'Garland', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/system/system.admin.inc'),
('admin/appearance/settings/global', '', '', 'user_access', 'a:1:{i:0;s:17:"administer themes";}', 'drupal_get_form', 'a:1:{i:0;s:21:"system_theme_settings";}', '', '15', 4, '1', 'admin/appearance/settings', 'admin/appearance', 'Global settings', 't', '', '', 'a:0:{}', '140', '', '', '-1', 'modules/system/system.admin.inc'),
('admin/appearance/settings/seven', '', '', '_system_themes_access', 'a:1:{i:0;O:8:"stdClass":12:{s:8:"filename";s:23:"themes/seven/seven.info";s:4:"name";s:5:"seven";s:4:"type";s:5:"theme";s:5:"owner";s:45:"themes/engines/phptemplate/phptemplate.engine";s:6:"status";s:1:"1";s:9:"bootstrap";s:1:"0";s:14:"schema_version";s:2:"-1";s:6:"weight";s:1:"0";s:4:"info";a:17:{s:4:"name";s:5:"Seven";s:11:"description";s:65:"A simple one-column, tableless, fluid width administration theme.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:11:"stylesheets";a:1:{s:6:"screen";a:2:{s:9:"reset.css";s:22:"themes/seven/reset.css";s:9:"style.css";s:22:"themes/seven/style.css";}}s:8:"settings";a:1:{s:20:"shortcut_module_link";s:1:"1";}s:7:"regions";a:5:{s:7:"content";s:7:"Content";s:4:"help";s:4:"Help";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";s:13:"sidebar_first";s:13:"First sidebar";}s:14:"regions_hidden";a:3:{i:0;s:13:"sidebar_first";i:1;s:8:"page_top";i:2;s:11:"page_bottom";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:6:"engine";s:11:"phptemplate";s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:10:"screenshot";s:27:"themes/seven/screenshot.png";s:3:"php";s:5:"5.2.4";s:7:"scripts";a:0:{}s:28:"overlay_supplemental_regions";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}}s:6:"prefix";s:11:"phptemplate";s:11:"stylesheets";a:1:{s:6:"screen";a:2:{s:9:"reset.css";s:22:"themes/seven/reset.css";s:9:"style.css";s:22:"themes/seven/style.css";}}s:6:"engine";s:11:"phptemplate";}}', 'drupal_get_form', 'a:2:{i:0;s:21:"system_theme_settings";i:1;s:5:"seven";}', '', '15', 4, '1', 'admin/appearance/settings', 'admin/appearance', 'Seven', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/system/system.admin.inc'),
('admin/appearance/settings/stark', '', '', '_system_themes_access', 'a:1:{i:0;O:8:"stdClass":12:{s:8:"filename";s:23:"themes/stark/stark.info";s:4:"name";s:5:"stark";s:4:"type";s:5:"theme";s:5:"owner";s:45:"themes/engines/phptemplate/phptemplate.engine";s:6:"status";s:1:"0";s:9:"bootstrap";s:1:"0";s:14:"schema_version";s:2:"-1";s:6:"weight";s:1:"0";s:4:"info";a:16:{s:4:"name";s:5:"Stark";s:11:"description";s:208:"This theme demonstrates Drupal''s default HTML markup and CSS styles. To learn how to build your own theme and override Drupal''s default code, see the <a href="http://drupal.org/theme-guide">Theming Guide</a>.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:11:"stylesheets";a:1:{s:3:"all";a:1:{s:10:"layout.css";s:23:"themes/stark/layout.css";}}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:6:"engine";s:11:"phptemplate";s:7:"regions";a:9:{s:13:"sidebar_first";s:12:"Left sidebar";s:14:"sidebar_second";s:13:"Right sidebar";s:7:"content";s:7:"Content";s:6:"header";s:6:"Header";s:6:"footer";s:6:"Footer";s:11:"highlighted";s:11:"Highlighted";s:4:"help";s:4:"Help";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";}s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:10:"screenshot";s:27:"themes/stark/screenshot.png";s:3:"php";s:5:"5.2.4";s:7:"scripts";a:0:{}s:14:"regions_hidden";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}s:28:"overlay_supplemental_regions";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}}s:6:"prefix";s:11:"phptemplate";s:11:"stylesheets";a:1:{s:3:"all";a:1:{s:10:"layout.css";s:23:"themes/stark/layout.css";}}s:6:"engine";s:11:"phptemplate";}}', 'drupal_get_form', 'a:2:{i:0;s:21:"system_theme_settings";i:1;s:5:"stark";}', '', '15', 4, '1', 'admin/appearance/settings', 'admin/appearance', 'Stark', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/system/system.admin.inc'),
('admin/appearance/settings/theme822', '', '', '_system_themes_access', 'a:1:{i:0;O:8:"stdClass":13:{s:8:"filename";s:39:"sites/all/themes/theme822/theme822.info";s:4:"name";s:8:"theme822";s:4:"type";s:5:"theme";s:5:"owner";s:45:"themes/engines/phptemplate/phptemplate.engine";s:6:"status";s:1:"1";s:9:"bootstrap";s:1:"0";s:14:"schema_version";s:2:"-1";s:6:"weight";s:1:"0";s:4:"info";a:16:{s:4:"name";s:8:"theme822";s:11:"description";s:81:"This template is made by <a href="http://template-help.com">template-help.com</a>";s:10:"screenshot";s:40:"sites/all/themes/theme822/screenshot.png";s:4:"core";s:3:"7.x";s:6:"engine";s:11:"phptemplate";s:11:"stylesheets";a:1:{s:6:"screen";a:4:{s:19:"css/boilerplate.css";s:45:"sites/all/themes/theme822/css/boilerplate.css";s:13:"css/style.css";s:39:"sites/all/themes/theme822/css/style.css";s:24:"css/maintenance-page.css";s:50:"sites/all/themes/theme822/css/maintenance-page.css";s:16:"css/skeleton.css";s:42:"sites/all/themes/theme822/css/skeleton.css";}}s:7:"scripts";a:4:{s:19:"js/theme822.core.js";s:45:"sites/all/themes/theme822/js/theme822.core.js";s:19:"js/jquery.loader.js";s:45:"sites/all/themes/theme822/js/jquery.loader.js";s:28:"js/jquery.debouncedresize.js";s:54:"sites/all/themes/theme822/js/jquery.debouncedresize.js";s:23:"js/jquery.mobilemenu.js";s:49:"sites/all/themes/theme822/js/jquery.mobilemenu.js";}s:7:"regions";a:16:{s:10:"header_top";s:10:"Header top";s:6:"header";s:6:"Header";s:13:"header_bottom";s:13:"Header Bottom";s:4:"menu";s:4:"Menu";s:4:"help";s:4:"Help";s:11:"content_top";s:11:"Content top";s:7:"content";s:7:"Content";s:14:"content_bottom";s:14:"Content bottom";s:18:"sidebar_first_wide";s:18:"Sidebar first wide";s:20:"sidebar_first_narrow";s:20:"Sidebar first narrow";s:19:"sidebar_second_wide";s:19:"Sidebar second wide";s:21:"sidebar_second_narrow";s:21:"Sidebar second narrow";s:6:"footer";s:6:"Footer";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";s:11:"highlighted";s:11:"Highlighted";}s:8:"settings";a:8:{s:19:"theme822_feed_icons";s:1:"0";s:23:"theme822_clear_registry";s:1:"0";s:19:"theme822_tabs_float";s:1:"0";s:18:"theme822_tabs_node";s:1:"1";s:27:"theme822_breadcrumb_display";s:2:"no";s:33:"theme822_breadcrumb_hideonlyfront";s:1:"1";s:29:"theme822_breadcrumb_showtitle";s:1:"0";s:29:"theme822_breadcrumb_separator";s:2:"»";}s:7:"version";s:7:"7.x-1.0";s:7:"project";s:8:"theme822";s:9:"datestamp";s:10:"1320946536";s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:3:"php";s:5:"5.2.4";s:14:"regions_hidden";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}s:28:"overlay_supplemental_regions";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}}s:6:"prefix";s:11:"phptemplate";s:11:"stylesheets";a:1:{s:6:"screen";a:4:{s:19:"css/boilerplate.css";s:45:"sites/all/themes/theme822/css/boilerplate.css";s:13:"css/style.css";s:39:"sites/all/themes/theme822/css/style.css";s:24:"css/maintenance-page.css";s:50:"sites/all/themes/theme822/css/maintenance-page.css";s:16:"css/skeleton.css";s:42:"sites/all/themes/theme822/css/skeleton.css";}}s:7:"scripts";a:4:{s:19:"js/theme822.core.js";s:45:"sites/all/themes/theme822/js/theme822.core.js";s:19:"js/jquery.loader.js";s:45:"sites/all/themes/theme822/js/jquery.loader.js";s:28:"js/jquery.debouncedresize.js";s:54:"sites/all/themes/theme822/js/jquery.debouncedresize.js";s:23:"js/jquery.mobilemenu.js";s:49:"sites/all/themes/theme822/js/jquery.mobilemenu.js";}s:6:"engine";s:11:"phptemplate";}}', 'drupal_get_form', 'a:2:{i:0;s:21:"system_theme_settings";i:1;s:8:"theme822";}', '', '15', 4, '1', 'admin/appearance/settings', 'admin/appearance', 'theme822', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/system/system.admin.inc'),
('admin/appearance/settings/tipsy', '', '', '_system_themes_access', 'a:1:{i:0;O:8:"stdClass":11:{s:8:"filename";s:33:"sites/all/themes/tipsy/tipsy.info";s:4:"name";s:5:"tipsy";s:4:"type";s:5:"theme";s:5:"owner";s:45:"themes/engines/phptemplate/phptemplate.engine";s:6:"status";s:1:"0";s:9:"bootstrap";s:1:"0";s:14:"schema_version";s:1:"0";s:6:"weight";s:3:"999";s:4:"info";a:16:{s:4:"name";s:14:"Tipsy tooltips";s:11:"description";s:141:"Integrates <a href="http://onehackoranother.com/projects/jquery/tipsy/">Tipsy</a> jQuery plugin for creating a Facebook-like tooltips effect.";s:4:"core";s:3:"7.x";s:9:"configure";s:33:"admin/config/user-interface/tipsy";s:7:"version";s:11:"7.x-1.0-rc1";s:7:"project";s:5:"tipsy";s:9:"datestamp";s:10:"1307366519";s:6:"engine";s:11:"phptemplate";s:7:"regions";a:9:{s:13:"sidebar_first";s:12:"Left sidebar";s:14:"sidebar_second";s:13:"Right sidebar";s:7:"content";s:7:"Content";s:6:"header";s:6:"Header";s:6:"footer";s:6:"Footer";s:11:"highlighted";s:11:"Highlighted";s:4:"help";s:4:"Help";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";}s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:10:"screenshot";s:37:"sites/all/themes/tipsy/screenshot.png";s:3:"php";s:5:"5.2.4";s:11:"stylesheets";a:0:{}s:7:"scripts";a:0:{}s:14:"regions_hidden";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}s:28:"overlay_supplemental_regions";a:1:{i:0;s:8:"page_top";}}s:6:"prefix";s:11:"phptemplate";s:6:"engine";s:11:"phptemplate";}}', 'drupal_get_form', 'a:2:{i:0;s:21:"system_theme_settings";i:1;s:5:"tipsy";}', '', '15', 4, '1', 'admin/appearance/settings', 'admin/appearance', 'Tipsy tooltips', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/system/system.admin.inc'),
('admin/appearance/update', '', '', 'update_manager_access', 'a:0:{}', 'drupal_get_form', 'a:2:{i:0;s:26:"update_manager_update_form";i:1;s:5:"theme";}', '', '7', 3, '1', 'admin/appearance', 'admin/appearance', 'Update', 't', '', '', 'a:0:{}', '132', '', '', '10', 'modules/update/update.manager.inc'),
('admin/compact', '', '', 'user_access', 'a:1:{i:0;s:27:"access administration pages";}', 'system_admin_compact_page', 'a:0:{}', '', '3', 2, '0', '', 'admin/compact', 'Compact mode', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/system/system.admin.inc'),
('admin/config', '', '', 'user_access', 'a:1:{i:0;s:27:"access administration pages";}', 'system_admin_config_page', 'a:0:{}', '', '3', 2, '0', '', 'admin/config', 'Configuration', 't', '', '', 'a:0:{}', '6', 'Administer settings.', '', '0', 'modules/system/system.admin.inc'),
('admin/config/administration', '', '', 'user_access', 'a:1:{i:0;s:27:"access administration pages";}', 'system_admin_menu_block_page', 'a:0:{}', '', '7', 3, '0', '', 'admin/config/administration', 'Administration', 't', '', '', 'a:0:{}', '6', 'Administration tools.', '', '0', 'modules/system/system.admin.inc'),
('admin/config/administration/admin_menu', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:1:{i:0;s:25:"admin_menu_theme_settings";}', '', '15', 4, '0', '', 'admin/config/administration/admin_menu', 'Administration menu', 't', '', '', 'a:0:{}', '6', 'Adjust administration menu settings.', '', '0', 'sites/all/modules/admin_menu/admin_menu.inc'),
('admin/config/content', '', '', 'user_access', 'a:1:{i:0;s:27:"access administration pages";}', 'system_admin_menu_block_page', 'a:0:{}', '', '7', 3, '0', '', 'admin/config/content', 'Content authoring', 't', '', '', 'a:0:{}', '6', 'Settings related to formatting and authoring content.', 'left', '-15', 'modules/system/system.admin.inc'),
('admin/config/content/faq', '', '', 'user_access', 'a:1:{i:0;s:14:"administer faq";}', 'faq_settings_page', 'a:0:{}', '', '15', 4, '0', '', 'admin/config/content/faq', 'Frequently Asked Questions', 't', '', '', 'a:0:{}', '6', 'Allows the user to configure the layout of questions and answers on a FAQ page.', '', '0', 'sites/all/modules/faq/faq.admin.inc'),
('admin/config/content/faq/categories', '', '', 'user_access', 'a:1:{i:0;s:14:"administer faq";}', 'drupal_get_form', 'a:1:{i:0;s:28:"faq_categories_settings_form";}', '', '31', 5, '1', 'admin/config/content/faq', 'admin/config/content/faq', 'Categories', 't', '', '', 'a:0:{}', '132', 'Allows the user to configure the layout of questions and answers using categories on a FAQ page.', '', '-8', 'sites/all/modules/faq/faq.admin.inc'),
('admin/config/content/faq/general', '', '', 'user_access', 'a:1:{i:0;s:14:"administer faq";}', 'drupal_get_form', 'a:1:{i:0;s:25:"faq_general_settings_form";}', '', '31', 5, '1', 'admin/config/content/faq', 'admin/config/content/faq', 'General', 't', '', '', 'a:0:{}', '140', 'Allows the user to configure the header and descriptive text for the FAQ page.', '', '-10', 'sites/all/modules/faq/faq.admin.inc'),
('admin/config/content/faq/questions', '', '', 'user_access', 'a:1:{i:0;s:14:"administer faq";}', 'drupal_get_form', 'a:1:{i:0;s:27:"faq_questions_settings_form";}', '', '31', 5, '1', 'admin/config/content/faq', 'admin/config/content/faq', 'Questions', 't', '', '', 'a:0:{}', '132', 'Allows the user to configure the layout of questions and answers on a FAQ page.', '', '-9', 'sites/all/modules/faq/faq.admin.inc'),
('admin/config/content/formats', '', '', 'user_access', 'a:1:{i:0;s:18:"administer filters";}', 'drupal_get_form', 'a:1:{i:0;s:21:"filter_admin_overview";}', '', '15', 4, '0', '', 'admin/config/content/formats', 'Text formats', 't', '', '', 'a:0:{}', '6', 'Configure how content input by users is filtered, including allowed HTML tags. Also allows enabling of module-provided filters.', '', '0', 'modules/filter/filter.admin.inc'),
('admin/config/content/formats/%', 'a:1:{i:4;s:18:"filter_format_load";}', '', 'user_access', 'a:1:{i:0;s:18:"administer filters";}', 'filter_admin_format_page', 'a:1:{i:0;i:4;}', '', '30', 5, '0', '', 'admin/config/content/formats/%', '', 'filter_admin_format_title', 'a:1:{i:0;i:4;}', '', 'a:0:{}', '6', '', '', '0', 'modules/filter/filter.admin.inc'),
('admin/config/content/formats/%/disable', 'a:1:{i:4;s:18:"filter_format_load";}', '', '_filter_disable_format_access', 'a:1:{i:0;i:4;}', 'drupal_get_form', 'a:2:{i:0;s:20:"filter_admin_disable";i:1;i:4;}', '', '61', 6, '0', '', 'admin/config/content/formats/%/disable', 'Disable text format', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/filter/filter.admin.inc'),
('admin/config/content/formats/add', '', '', 'user_access', 'a:1:{i:0;s:18:"administer filters";}', 'filter_admin_format_page', 'a:0:{}', '', '31', 5, '1', 'admin/config/content/formats', 'admin/config/content/formats', 'Add text format', 't', '', '', 'a:0:{}', '388', '', '', '1', 'modules/filter/filter.admin.inc'),
('admin/config/content/formats/list', '', '', 'user_access', 'a:1:{i:0;s:18:"administer filters";}', 'drupal_get_form', 'a:1:{i:0;s:21:"filter_admin_overview";}', '', '31', 5, '1', 'admin/config/content/formats', 'admin/config/content/formats', 'List', 't', '', '', 'a:0:{}', '140', '', '', '0', 'modules/filter/filter.admin.inc'),
('admin/config/content/wysiwyg', '', '', 'user_access', 'a:1:{i:0;s:18:"administer filters";}', 'drupal_get_form', 'a:1:{i:0;s:24:"wysiwyg_profile_overview";}', '', '15', 4, '0', '', 'admin/config/content/wysiwyg', 'Wysiwyg profiles', 't', '', '', 'a:0:{}', '6', 'Configure client-side editors.', '', '0', 'sites/all/modules/wysiwyg/wysiwyg.admin.inc'),
('admin/config/content/wysiwyg/profile', '', '', 'user_access', 'a:1:{i:0;s:18:"administer filters";}', 'drupal_get_form', 'a:1:{i:0;s:24:"wysiwyg_profile_overview";}', '', '31', 5, '1', 'admin/config/content/wysiwyg', 'admin/config/content/wysiwyg', 'List', 't', '', '', 'a:0:{}', '140', '', '', '0', 'sites/all/modules/wysiwyg/wysiwyg.admin.inc'),
('admin/config/content/wysiwyg/profile/%/delete', 'a:1:{i:5;s:20:"wysiwyg_profile_load";}', '', 'user_access', 'a:1:{i:0;s:18:"administer filters";}', 'drupal_get_form', 'a:2:{i:0;s:30:"wysiwyg_profile_delete_confirm";i:1;i:5;}', '', '125', 7, '1', 'admin/config/content/wysiwyg/profile/%wysiwyg_profile', 'admin/config/content/wysiwyg/profile', 'Remove', 't', '', '', 'a:0:{}', '132', '', '', '10', 'sites/all/modules/wysiwyg/wysiwyg.admin.inc'),
('admin/config/content/wysiwyg/profile/%/edit', 'a:1:{i:5;s:20:"wysiwyg_profile_load";}', '', 'user_access', 'a:1:{i:0;s:18:"administer filters";}', 'drupal_get_form', 'a:2:{i:0;s:20:"wysiwyg_profile_form";i:1;i:5;}', '', '125', 7, '1', 'admin/config/content/wysiwyg/profile/%wysiwyg_profile', 'admin/config/content/wysiwyg/profile', 'Edit', 't', '', '', 'a:0:{}', '132', '', '', '0', 'sites/all/modules/wysiwyg/wysiwyg.admin.inc'),
('admin/config/development', '', '', 'user_access', 'a:1:{i:0;s:27:"access administration pages";}', 'system_admin_menu_block_page', 'a:0:{}', '', '7', 3, '0', '', 'admin/config/development', 'Development', 't', '', '', 'a:0:{}', '6', 'Development tools.', 'right', '-10', 'modules/system/system.admin.inc'),
('admin/config/development/jquery_update', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:1:{i:0;s:27:"jquery_update_settings_form";}', '', '15', 4, '0', '', 'admin/config/development/jquery_update', 'jQuery update', 't', '', '', 'a:0:{}', '6', 'Configure settings related to the jQuery upgrade, the library path and compression.', '', '0', ''),
('admin/config/development/logging', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:1:{i:0;s:23:"system_logging_settings";}', '', '15', 4, '0', '', 'admin/config/development/logging', 'Logging and errors', 't', '', '', 'a:0:{}', '6', 'Settings for logging and alerts modules. Various modules can route Drupal''s system events to different destinations, such as syslog, database, email, etc.', '', '-15', 'modules/system/system.admin.inc'),
('admin/config/development/maintenance', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:1:{i:0;s:28:"system_site_maintenance_mode";}', '', '15', 4, '0', '', 'admin/config/development/maintenance', 'Maintenance mode', 't', '', '', 'a:0:{}', '6', 'Take the site offline for maintenance or bring it back online.', '', '-10', 'modules/system/system.admin.inc'),
('admin/config/development/performance', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:1:{i:0;s:27:"system_performance_settings";}', '', '15', 4, '0', '', 'admin/config/development/performance', 'Performance', 't', '', '', 'a:0:{}', '6', 'Enable or disable page caching for anonymous users and set CSS and JS bandwidth optimization options.', '', '-20', 'modules/system/system.admin.inc'),
('admin/config/media', '', '', 'user_access', 'a:1:{i:0;s:27:"access administration pages";}', 'system_admin_menu_block_page', 'a:0:{}', '', '7', 3, '0', '', 'admin/config/media', 'Media', 't', '', '', 'a:0:{}', '6', 'Media tools.', 'left', '-10', 'modules/system/system.admin.inc'),
('admin/config/media/colorbox', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:1:{i:0;s:23:"colorbox_admin_settings";}', '', '15', 4, '0', '', 'admin/config/media/colorbox', 'Colorbox', 't', '', '', 'a:0:{}', '6', 'Adjust Colorbox settings.', '', '0', 'sites/all/modules/colorbox/colorbox.admin.inc'),
('admin/config/media/file-system', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:1:{i:0;s:27:"system_file_system_settings";}', '', '15', 4, '0', '', 'admin/config/media/file-system', 'File system', 't', '', '', 'a:0:{}', '6', 'Tell Drupal where to store uploaded files and how they are accessed.', '', '-10', 'modules/system/system.admin.inc'),
('admin/config/media/flexslider', '', '', 'ctools_export_ui_task_access', 'a:2:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:4:"list";}', 'ctools_export_ui_switcher_page', 'a:2:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:4:"list";}', '', '15', 4, '0', '', 'admin/config/media/flexslider', 'FlexSlider', 't', '', '', 'a:0:{}', '6', 'Administer FlexSlider presets.', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/config/media/flexslider/add', '', '', 'ctools_export_ui_task_access', 'a:2:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:3:"add";}', 'ctools_export_ui_switcher_page', 'a:2:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:3:"add";}', '', '31', 5, '1', 'admin/config/media/flexslider', 'admin/config/media/flexslider', 'Add', 't', '', '', 'a:0:{}', '388', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/config/media/flexslider/advanced', '', '', 'user_access', 'a:1:{i:0;s:21:"administer flexslider";}', 'drupal_get_form', 'a:1:{i:0;s:24:"flexslider_form_settings";}', '', '31', 5, '1', 'admin/config/media/flexslider', 'admin/config/media/flexslider', 'Advanced settings', 't', '', '', 'a:0:{}', '132', 'Configure the advanced flexslider module settings.', '', '2', 'sites/all/modules/flexslider/flexslider.admin.inc'),
('admin/config/media/flexslider/import', '', '', 'ctools_export_ui_task_access', 'a:2:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:6:"import";}', 'ctools_export_ui_switcher_page', 'a:2:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:6:"import";}', '', '31', 5, '1', 'admin/config/media/flexslider', 'admin/config/media/flexslider', 'Import', 't', '', '', 'a:0:{}', '388', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/config/media/flexslider/list', '', '', 'ctools_export_ui_task_access', 'a:2:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:4:"list";}', 'ctools_export_ui_switcher_page', 'a:2:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:4:"list";}', '', '31', 5, '1', 'admin/config/media/flexslider', 'admin/config/media/flexslider', 'List', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/config/media/flexslider/list/%', 'a:1:{i:5;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:27:"flexslider_ctools_export_ui";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:4:"edit";i:2;i:5;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:4:"edit";i:2;i:5;}', '', '62', 6, '0', '', 'admin/config/media/flexslider/list/%', '', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/config/media/flexslider/list/%/clone', 'a:1:{i:5;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:27:"flexslider_ctools_export_ui";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:5:"clone";i:2;i:5;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:5:"clone";i:2;i:5;}', '', '125', 7, '0', '', 'admin/config/media/flexslider/list/%/clone', 'Clone', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/config/media/flexslider/list/%/delete', 'a:1:{i:5;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:27:"flexslider_ctools_export_ui";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:6:"delete";i:2;i:5;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:6:"delete";i:2;i:5;}', '', '125', 7, '0', '', 'admin/config/media/flexslider/list/%/delete', 'Delete', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/config/media/flexslider/list/%/disable', 'a:1:{i:5;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:27:"flexslider_ctools_export_ui";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:7:"disable";i:2;i:5;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:7:"disable";i:2;i:5;}', '', '125', 7, '0', '', 'admin/config/media/flexslider/list/%/disable', 'Disable', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/config/media/flexslider/list/%/edit', 'a:1:{i:5;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:27:"flexslider_ctools_export_ui";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:4:"edit";i:2;i:5;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:4:"edit";i:2;i:5;}', '', '125', 7, '1', 'admin/config/media/flexslider/list/%', 'admin/config/media/flexslider/list/%', 'Edit', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/config/media/flexslider/list/%/enable', 'a:1:{i:5;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:27:"flexslider_ctools_export_ui";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:6:"enable";i:2;i:5;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:6:"enable";i:2;i:5;}', '', '125', 7, '0', '', 'admin/config/media/flexslider/list/%/enable', 'Enable', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/config/media/flexslider/list/%/export', 'a:1:{i:5;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:27:"flexslider_ctools_export_ui";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:6:"export";i:2;i:5;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:6:"export";i:2;i:5;}', '', '125', 7, '1', 'admin/config/media/flexslider/list/%', 'admin/config/media/flexslider/list/%', 'Export', 't', '', '', 'a:0:{}', '132', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/config/media/flexslider/list/%/revert', 'a:1:{i:5;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:27:"flexslider_ctools_export_ui";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:6:"revert";i:2;i:5;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:27:"flexslider_ctools_export_ui";i:1;s:6:"delete";i:2;i:5;}', '', '125', 7, '0', '', 'admin/config/media/flexslider/list/%/revert', 'Revert', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/config/media/image-styles', '', '', 'user_access', 'a:1:{i:0;s:23:"administer image styles";}', 'image_style_list', 'a:0:{}', '', '15', 4, '0', '', 'admin/config/media/image-styles', 'Image styles', 't', '', '', 'a:0:{}', '6', 'Configure styles that can be used for resizing or adjusting images on display.', '', '0', 'modules/image/image.admin.inc'),
('admin/config/media/image-styles/add', '', '', 'user_access', 'a:1:{i:0;s:23:"administer image styles";}', 'drupal_get_form', 'a:1:{i:0;s:20:"image_style_add_form";}', '', '31', 5, '1', 'admin/config/media/image-styles', 'admin/config/media/image-styles', 'Add style', 't', '', '', 'a:0:{}', '388', 'Add a new image style.', '', '2', 'modules/image/image.admin.inc'),
('admin/config/media/image-styles/delete/%', 'a:1:{i:5;a:1:{s:16:"image_style_load";a:2:{i:0;N;i:1;s:1:"1";}}}', '', 'user_access', 'a:1:{i:0;s:23:"administer image styles";}', 'drupal_get_form', 'a:2:{i:0;s:23:"image_style_delete_form";i:1;i:5;}', '', '62', 6, '0', '', 'admin/config/media/image-styles/delete/%', 'Delete style', 't', '', '', 'a:0:{}', '6', 'Delete an image style.', '', '0', 'modules/image/image.admin.inc'),
('admin/config/media/image-styles/edit/%', 'a:1:{i:5;s:16:"image_style_load";}', '', 'user_access', 'a:1:{i:0;s:23:"administer image styles";}', 'drupal_get_form', 'a:2:{i:0;s:16:"image_style_form";i:1;i:5;}', '', '62', 6, '0', '', 'admin/config/media/image-styles/edit/%', 'Edit style', 't', '', '', 'a:0:{}', '6', 'Configure an image style.', '', '0', 'modules/image/image.admin.inc'),
('admin/config/media/image-styles/edit/%/add/%', 'a:2:{i:5;a:1:{s:16:"image_style_load";a:1:{i:0;i:5;}}i:7;a:1:{s:28:"image_effect_definition_load";a:1:{i:0;i:5;}}}', '', 'user_access', 'a:1:{i:0;s:23:"administer image styles";}', 'drupal_get_form', 'a:3:{i:0;s:17:"image_effect_form";i:1;i:5;i:2;i:7;}', '', '250', 8, '0', '', 'admin/config/media/image-styles/edit/%/add/%', 'Add image effect', 't', '', '', 'a:0:{}', '6', 'Add a new effect to a style.', '', '0', 'modules/image/image.admin.inc'),
('admin/config/media/image-styles/edit/%/effects/%', 'a:2:{i:5;a:1:{s:16:"image_style_load";a:2:{i:0;i:5;i:1;s:1:"3";}}i:7;a:1:{s:17:"image_effect_load";a:2:{i:0;i:5;i:1;s:1:"3";}}}', '', 'user_access', 'a:1:{i:0;s:23:"administer image styles";}', 'drupal_get_form', 'a:3:{i:0;s:17:"image_effect_form";i:1;i:5;i:2;i:7;}', '', '250', 8, '0', '', 'admin/config/media/image-styles/edit/%/effects/%', 'Edit image effect', 't', '', '', 'a:0:{}', '6', 'Edit an existing effect within a style.', '', '0', 'modules/image/image.admin.inc'),
('admin/config/media/image-styles/edit/%/effects/%/delete', 'a:2:{i:5;a:1:{s:16:"image_style_load";a:2:{i:0;i:5;i:1;s:1:"3";}}i:7;a:1:{s:17:"image_effect_load";a:2:{i:0;i:5;i:1;s:1:"3";}}}', '', 'user_access', 'a:1:{i:0;s:23:"administer image styles";}', 'drupal_get_form', 'a:3:{i:0;s:24:"image_effect_delete_form";i:1;i:5;i:2;i:7;}', '', '501', 9, '0', '', 'admin/config/media/image-styles/edit/%/effects/%/delete', 'Delete image effect', 't', '', '', 'a:0:{}', '6', 'Delete an existing effect from a style.', '', '0', 'modules/image/image.admin.inc'),
('admin/config/media/image-styles/list', '', '', 'user_access', 'a:1:{i:0;s:23:"administer image styles";}', 'image_style_list', 'a:0:{}', '', '31', 5, '1', 'admin/config/media/image-styles', 'admin/config/media/image-styles', 'List', 't', '', '', 'a:0:{}', '140', 'List the current image styles on the site.', '', '1', 'modules/image/image.admin.inc'),
('admin/config/media/image-styles/retina_preview/%', 'a:1:{i:5;s:16:"image_style_load";}', '', 'user_access', 'a:1:{i:0;s:23:"administer image styles";}', 'retina_images_retina_style_preview', 'a:1:{i:0;i:5;}', '', '62', 6, '0', '', 'admin/config/media/image-styles/retina_preview/%', 'Preview retinafied style', 't', '', '', 'a:0:{}', '6', '', '', '0', ''),
('admin/config/media/image-styles/revert/%', 'a:1:{i:5;a:1:{s:16:"image_style_load";a:2:{i:0;N;i:1;s:1:"2";}}}', '', 'user_access', 'a:1:{i:0;s:23:"administer image styles";}', 'drupal_get_form', 'a:2:{i:0;s:23:"image_style_revert_form";i:1;i:5;}', '', '62', 6, '0', '', 'admin/config/media/image-styles/revert/%', 'Revert style', 't', '', '', 'a:0:{}', '6', 'Revert an image style.', '', '0', 'modules/image/image.admin.inc'),
('admin/config/media/image-toolkit', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:1:{i:0;s:29:"system_image_toolkit_settings";}', '', '15', 4, '0', '', 'admin/config/media/image-toolkit', 'Image toolkit', 't', '', '', 'a:0:{}', '6', 'Choose which image toolkit to use if you have installed optional toolkits.', '', '20', 'modules/system/system.admin.inc'),
('admin/config/people', '', '', 'user_access', 'a:1:{i:0;s:27:"access administration pages";}', 'system_admin_menu_block_page', 'a:0:{}', '', '7', 3, '0', '', 'admin/config/people', 'People', 't', '', '', 'a:0:{}', '6', 'Configure user accounts.', 'left', '-20', 'modules/system/system.admin.inc'),
('admin/config/people/accounts', '', '', 'user_access', 'a:1:{i:0;s:16:"administer users";}', 'drupal_get_form', 'a:1:{i:0;s:19:"user_admin_settings";}', '', '15', 4, '0', '', 'admin/config/people/accounts', 'Account settings', 't', '', '', 'a:0:{}', '6', 'Configure default behavior of users, including registration requirements, e-mails, fields, and user pictures.', '', '-10', 'modules/user/user.admin.inc'),
('admin/config/people/accounts/display', '', '', 'user_access', 'a:1:{i:0;s:16:"administer users";}', 'drupal_get_form', 'a:4:{i:0;s:30:"field_ui_display_overview_form";i:1;s:4:"user";i:2;s:4:"user";i:3;s:7:"default";}', '', '31', 5, '1', 'admin/config/people/accounts', 'admin/config/people/accounts', 'Manage display', 't', '', '', 'a:0:{}', '132', '', '', '2', 'modules/field_ui/field_ui.admin.inc'),
('admin/config/people/accounts/display/default', '', '', '_field_ui_view_mode_menu_access', 'a:5:{i:0;s:4:"user";i:1;s:4:"user";i:2;s:7:"default";i:3;s:11:"user_access";i:4;s:16:"administer users";}', 'drupal_get_form', 'a:4:{i:0;s:30:"field_ui_display_overview_form";i:1;s:4:"user";i:2;s:4:"user";i:3;s:7:"default";}', '', '63', 6, '1', 'admin/config/people/accounts/display', 'admin/config/people/accounts', 'Default', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'modules/field_ui/field_ui.admin.inc'),
('admin/config/people/accounts/display/full', '', '', '_field_ui_view_mode_menu_access', 'a:5:{i:0;s:4:"user";i:1;s:4:"user";i:2;s:4:"full";i:3;s:11:"user_access";i:4;s:16:"administer users";}', 'drupal_get_form', 'a:4:{i:0;s:30:"field_ui_display_overview_form";i:1;s:4:"user";i:2;s:4:"user";i:3;s:4:"full";}', '', '63', 6, '1', 'admin/config/people/accounts/display', 'admin/config/people/accounts', 'User account', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/field_ui/field_ui.admin.inc'),
('admin/config/people/accounts/fields', '', '', 'user_access', 'a:1:{i:0;s:16:"administer users";}', 'drupal_get_form', 'a:3:{i:0;s:28:"field_ui_field_overview_form";i:1;s:4:"user";i:2;s:4:"user";}', '', '31', 5, '1', 'admin/config/people/accounts', 'admin/config/people/accounts', 'Manage fields', 't', '', '', 'a:0:{}', '132', '', '', '1', 'modules/field_ui/field_ui.admin.inc'),
('admin/config/people/accounts/fields/%', 'a:1:{i:5;a:1:{s:18:"field_ui_menu_load";a:4:{i:0;s:4:"user";i:1;s:4:"user";i:2;s:1:"0";i:3;s:4:"%map";}}}', '', 'user_access', 'a:1:{i:0;s:16:"administer users";}', 'drupal_get_form', 'a:2:{i:0;s:24:"field_ui_field_edit_form";i:1;i:5;}', '', '62', 6, '0', '', 'admin/config/people/accounts/fields/%', '', 'field_ui_menu_title', 'a:1:{i:0;i:5;}', '', 'a:0:{}', '6', '', '', '0', 'modules/field_ui/field_ui.admin.inc'),
('admin/config/people/accounts/fields/%/delete', 'a:1:{i:5;a:1:{s:18:"field_ui_menu_load";a:4:{i:0;s:4:"user";i:1;s:4:"user";i:2;s:1:"0";i:3;s:4:"%map";}}}', '', 'user_access', 'a:1:{i:0;s:16:"administer users";}', 'drupal_get_form', 'a:2:{i:0;s:26:"field_ui_field_delete_form";i:1;i:5;}', '', '125', 7, '1', 'admin/config/people/accounts/fields/%', 'admin/config/people/accounts/fields/%', 'Delete', 't', '', '', 'a:0:{}', '132', '', '', '10', 'modules/field_ui/field_ui.admin.inc'),
('admin/config/people/accounts/fields/%/edit', 'a:1:{i:5;a:1:{s:18:"field_ui_menu_load";a:4:{i:0;s:4:"user";i:1;s:4:"user";i:2;s:1:"0";i:3;s:4:"%map";}}}', '', 'user_access', 'a:1:{i:0;s:16:"administer users";}', 'drupal_get_form', 'a:2:{i:0;s:24:"field_ui_field_edit_form";i:1;i:5;}', '', '125', 7, '1', 'admin/config/people/accounts/fields/%', 'admin/config/people/accounts/fields/%', 'Edit', 't', '', '', 'a:0:{}', '140', '', '', '0', 'modules/field_ui/field_ui.admin.inc'),
('admin/config/people/accounts/fields/%/field-settings', 'a:1:{i:5;a:1:{s:18:"field_ui_menu_load";a:4:{i:0;s:4:"user";i:1;s:4:"user";i:2;s:1:"0";i:3;s:4:"%map";}}}', '', 'user_access', 'a:1:{i:0;s:16:"administer users";}', 'drupal_get_form', 'a:2:{i:0;s:28:"field_ui_field_settings_form";i:1;i:5;}', '', '125', 7, '1', 'admin/config/people/accounts/fields/%', 'admin/config/people/accounts/fields/%', 'Field settings', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/field_ui/field_ui.admin.inc'),
('admin/config/people/accounts/fields/%/widget-type', 'a:1:{i:5;a:1:{s:18:"field_ui_menu_load";a:4:{i:0;s:4:"user";i:1;s:4:"user";i:2;s:1:"0";i:3;s:4:"%map";}}}', '', 'user_access', 'a:1:{i:0;s:16:"administer users";}', 'drupal_get_form', 'a:2:{i:0;s:25:"field_ui_widget_type_form";i:1;i:5;}', '', '125', 7, '1', 'admin/config/people/accounts/fields/%', 'admin/config/people/accounts/fields/%', 'Widget type', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/field_ui/field_ui.admin.inc'),
('admin/config/people/accounts/settings', '', '', 'user_access', 'a:1:{i:0;s:16:"administer users";}', 'drupal_get_form', 'a:1:{i:0;s:19:"user_admin_settings";}', '', '31', 5, '1', 'admin/config/people/accounts', 'admin/config/people/accounts', 'Settings', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'modules/user/user.admin.inc'),
('admin/config/people/ip-blocking', '', '', 'user_access', 'a:1:{i:0;s:18:"block IP addresses";}', 'system_ip_blocking', 'a:0:{}', '', '15', 4, '0', '', 'admin/config/people/ip-blocking', 'IP address blocking', 't', '', '', 'a:0:{}', '6', 'Manage blocked IP addresses.', '', '10', 'modules/system/system.admin.inc'),
('admin/config/people/ip-blocking/delete/%', 'a:1:{i:5;s:15:"blocked_ip_load";}', '', 'user_access', 'a:1:{i:0;s:18:"block IP addresses";}', 'drupal_get_form', 'a:2:{i:0;s:25:"system_ip_blocking_delete";i:1;i:5;}', '', '62', 6, '0', '', 'admin/config/people/ip-blocking/delete/%', 'Delete IP address', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/system/system.admin.inc'),
('admin/config/regional', '', '', 'user_access', 'a:1:{i:0;s:27:"access administration pages";}', 'system_admin_menu_block_page', 'a:0:{}', '', '7', 3, '0', '', 'admin/config/regional', 'Regional and language', 't', '', '', 'a:0:{}', '6', 'Regional settings, localization and translation.', 'left', '-5', 'modules/system/system.admin.inc'),
('admin/config/regional/date-time', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:1:{i:0;s:25:"system_date_time_settings";}', '', '15', 4, '0', '', 'admin/config/regional/date-time', 'Date and time', 't', '', '', 'a:0:{}', '6', 'Configure display formats for date and time.', '', '-15', 'modules/system/system.admin.inc'),
('admin/config/regional/date-time/formats', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'system_date_time_formats', 'a:0:{}', '', '31', 5, '1', 'admin/config/regional/date-time', 'admin/config/regional/date-time', 'Formats', 't', '', '', 'a:0:{}', '132', 'Configure display format strings for date and time.', '', '-9', 'modules/system/system.admin.inc'),
('admin/config/regional/date-time/formats/%/delete', 'a:1:{i:5;N;}', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:2:{i:0;s:30:"system_date_delete_format_form";i:1;i:5;}', '', '125', 7, '0', '', 'admin/config/regional/date-time/formats/%/delete', 'Delete date format', 't', '', '', 'a:0:{}', '6', 'Allow users to delete a configured date format.', '', '0', 'modules/system/system.admin.inc'),
('admin/config/regional/date-time/formats/%/edit', 'a:1:{i:5;N;}', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:2:{i:0;s:34:"system_configure_date_formats_form";i:1;i:5;}', '', '125', 7, '0', '', 'admin/config/regional/date-time/formats/%/edit', 'Edit date format', 't', '', '', 'a:0:{}', '6', 'Allow users to edit a configured date format.', '', '0', 'modules/system/system.admin.inc'),
('admin/config/regional/date-time/formats/add', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:1:{i:0;s:34:"system_configure_date_formats_form";}', '', '63', 6, '1', 'admin/config/regional/date-time/formats', 'admin/config/regional/date-time', 'Add format', 't', '', '', 'a:0:{}', '388', 'Allow users to add additional date formats.', '', '-10', 'modules/system/system.admin.inc'),
('admin/config/regional/date-time/formats/lookup', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'system_date_time_lookup', 'a:0:{}', '', '63', 6, '0', '', 'admin/config/regional/date-time/formats/lookup', 'Date and time lookup', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/system/system.admin.inc'),
('admin/config/regional/date-time/locale', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'locale_date_format_language_overview_page', 'a:0:{}', '', '31', 5, '1', 'admin/config/regional/date-time', 'admin/config/regional/date-time', 'Localize', 't', '', '', 'a:0:{}', '132', 'Configure date formats for each locale', '', '-8', 'modules/locale/locale.admin.inc'),
('admin/config/regional/date-time/locale/%/edit', 'a:1:{i:5;N;}', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:2:{i:0;s:23:"locale_date_format_form";i:1;i:5;}', '', '125', 7, '0', '', 'admin/config/regional/date-time/locale/%/edit', 'Localize date formats', 't', '', '', 'a:0:{}', '6', 'Configure date formats for each locale', '', '0', 'modules/locale/locale.admin.inc'),
('admin/config/regional/date-time/locale/%/reset', 'a:1:{i:5;N;}', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:2:{i:0;s:29:"locale_date_format_reset_form";i:1;i:5;}', '', '125', 7, '0', '', 'admin/config/regional/date-time/locale/%/reset', 'Reset date formats', 't', '', '', 'a:0:{}', '6', 'Reset localized date formats to global defaults', '', '0', 'modules/locale/locale.admin.inc'),
('admin/config/regional/date-time/types', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:1:{i:0;s:25:"system_date_time_settings";}', '', '31', 5, '1', 'admin/config/regional/date-time', 'admin/config/regional/date-time', 'Types', 't', '', '', 'a:0:{}', '140', 'Configure display formats for date and time.', '', '-10', 'modules/system/system.admin.inc'),
('admin/config/regional/date-time/types/%/delete', 'a:1:{i:5;N;}', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:2:{i:0;s:35:"system_delete_date_format_type_form";i:1;i:5;}', '', '125', 7, '0', '', 'admin/config/regional/date-time/types/%/delete', 'Delete date type', 't', '', '', 'a:0:{}', '6', 'Allow users to delete a configured date type.', '', '0', 'modules/system/system.admin.inc'),
('admin/config/regional/date-time/types/add', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:1:{i:0;s:32:"system_add_date_format_type_form";}', '', '63', 6, '1', 'admin/config/regional/date-time/types', 'admin/config/regional/date-time', 'Add date type', 't', '', '', 'a:0:{}', '388', 'Add new date type.', '', '-10', 'modules/system/system.admin.inc'),
('admin/config/regional/language', '', '', 'user_access', 'a:1:{i:0;s:20:"administer languages";}', 'drupal_get_form', 'a:1:{i:0;s:30:"locale_languages_overview_form";}', '', '15', 4, '0', '', 'admin/config/regional/language', 'Languages', 't', '', '', 'a:0:{}', '6', 'Configure languages for content and the user interface.', '', '-10', 'modules/locale/locale.admin.inc');
INSERT INTO `menu_router` VALUES
('admin/config/regional/language/add', '', '', 'user_access', 'a:1:{i:0;s:20:"administer languages";}', 'locale_languages_add_screen', 'a:0:{}', '', '31', 5, '1', 'admin/config/regional/language', 'admin/config/regional/language', 'Add language', 't', '', '', 'a:0:{}', '388', '', '', '5', 'modules/locale/locale.admin.inc'),
('admin/config/regional/language/configure', '', '', 'user_access', 'a:1:{i:0;s:20:"administer languages";}', 'drupal_get_form', 'a:1:{i:0;s:31:"locale_languages_configure_form";}', '', '31', 5, '1', 'admin/config/regional/language', 'admin/config/regional/language', 'Detection and selection', 't', '', '', 'a:0:{}', '132', '', '', '10', 'modules/locale/locale.admin.inc'),
('admin/config/regional/language/configure/session', '', '', 'user_access', 'a:1:{i:0;s:20:"administer languages";}', 'drupal_get_form', 'a:1:{i:0;s:38:"locale_language_providers_session_form";}', '', '63', 6, '0', '', 'admin/config/regional/language/configure/session', 'Session language detection configuration', 't', '', '', 'a:0:{}', '4', '', '', '0', 'modules/locale/locale.admin.inc'),
('admin/config/regional/language/configure/url', '', '', 'user_access', 'a:1:{i:0;s:20:"administer languages";}', 'drupal_get_form', 'a:1:{i:0;s:34:"locale_language_providers_url_form";}', '', '63', 6, '0', '', 'admin/config/regional/language/configure/url', 'URL language detection configuration', 't', '', '', 'a:0:{}', '4', '', '', '0', 'modules/locale/locale.admin.inc'),
('admin/config/regional/language/delete/%', 'a:1:{i:5;N;}', '', 'user_access', 'a:1:{i:0;s:20:"administer languages";}', 'drupal_get_form', 'a:2:{i:0;s:28:"locale_languages_delete_form";i:1;i:5;}', '', '62', 6, '0', '', 'admin/config/regional/language/delete/%', 'Confirm', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/locale/locale.admin.inc'),
('admin/config/regional/language/edit/%', 'a:1:{i:5;N;}', '', 'user_access', 'a:1:{i:0;s:20:"administer languages";}', 'drupal_get_form', 'a:2:{i:0;s:26:"locale_languages_edit_form";i:1;i:5;}', '', '62', 6, '0', '', 'admin/config/regional/language/edit/%', 'Edit language', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/locale/locale.admin.inc'),
('admin/config/regional/language/overview', '', '', 'user_access', 'a:1:{i:0;s:20:"administer languages";}', 'drupal_get_form', 'a:1:{i:0;s:30:"locale_languages_overview_form";}', '', '31', 5, '1', 'admin/config/regional/language', 'admin/config/regional/language', 'List', 't', '', '', 'a:0:{}', '140', '', '', '0', 'modules/locale/locale.admin.inc'),
('admin/config/regional/settings', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:1:{i:0;s:24:"system_regional_settings";}', '', '15', 4, '0', '', 'admin/config/regional/settings', 'Regional settings', 't', '', '', 'a:0:{}', '6', 'Settings for the site''s default time zone and country.', '', '-20', 'modules/system/system.admin.inc'),
('admin/config/regional/translate', '', '', 'user_access', 'a:1:{i:0;s:19:"translate interface";}', 'locale_translate_overview_screen', 'a:0:{}', '', '15', 4, '0', '', 'admin/config/regional/translate', 'Translate interface', 't', '', '', 'a:0:{}', '6', 'Translate the built in interface and optionally other text.', '', '-5', 'modules/locale/locale.admin.inc'),
('admin/config/regional/translate/delete/%', 'a:1:{i:5;N;}', '', 'user_access', 'a:1:{i:0;s:19:"translate interface";}', 'locale_translate_delete_page', 'a:1:{i:0;i:5;}', '', '62', 6, '0', '', 'admin/config/regional/translate/delete/%', 'Delete string', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/locale/locale.admin.inc'),
('admin/config/regional/translate/edit/%', 'a:1:{i:5;N;}', '', 'user_access', 'a:1:{i:0;s:19:"translate interface";}', 'drupal_get_form', 'a:2:{i:0;s:26:"locale_translate_edit_form";i:1;i:5;}', '', '62', 6, '0', '', 'admin/config/regional/translate/edit/%', 'Edit string', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/locale/locale.admin.inc'),
('admin/config/regional/translate/export', '', '', 'user_access', 'a:1:{i:0;s:19:"translate interface";}', 'locale_translate_export_screen', 'a:0:{}', '', '31', 5, '1', 'admin/config/regional/translate', 'admin/config/regional/translate', 'Export', 't', '', '', 'a:0:{}', '132', '', '', '30', 'modules/locale/locale.admin.inc'),
('admin/config/regional/translate/import', '', '', 'user_access', 'a:1:{i:0;s:19:"translate interface";}', 'drupal_get_form', 'a:1:{i:0;s:28:"locale_translate_import_form";}', '', '31', 5, '1', 'admin/config/regional/translate', 'admin/config/regional/translate', 'Import', 't', '', '', 'a:0:{}', '132', '', '', '20', 'modules/locale/locale.admin.inc'),
('admin/config/regional/translate/overview', '', '', 'user_access', 'a:1:{i:0;s:19:"translate interface";}', 'locale_translate_overview_screen', 'a:0:{}', '', '31', 5, '1', 'admin/config/regional/translate', 'admin/config/regional/translate', 'Overview', 't', '', '', 'a:0:{}', '140', '', '', '0', 'modules/locale/locale.admin.inc'),
('admin/config/regional/translate/translate', '', '', 'user_access', 'a:1:{i:0;s:19:"translate interface";}', 'locale_translate_seek_screen', 'a:0:{}', '', '31', 5, '1', 'admin/config/regional/translate', 'admin/config/regional/translate', 'Translate', 't', '', '', 'a:0:{}', '132', '', '', '10', 'modules/locale/locale.admin.inc'),
('admin/config/search', '', '', 'user_access', 'a:1:{i:0;s:27:"access administration pages";}', 'system_admin_menu_block_page', 'a:0:{}', '', '7', 3, '0', '', 'admin/config/search', 'Search and metadata', 't', '', '', 'a:0:{}', '6', 'Local site search, metadata and SEO.', 'left', '-10', 'modules/system/system.admin.inc'),
('admin/config/search/clean-urls', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:1:{i:0;s:25:"system_clean_url_settings";}', '', '15', 4, '0', '', 'admin/config/search/clean-urls', 'Clean URLs', 't', '', '', 'a:0:{}', '6', 'Enable or disable clean URLs for your site.', '', '5', 'modules/system/system.admin.inc'),
('admin/config/search/clean-urls/check', '', '', '1', 'a:0:{}', 'drupal_json_output', 'a:1:{i:0;a:1:{s:6:"status";b:1;}}', '', '31', 5, '0', '', 'admin/config/search/clean-urls/check', 'Clean URL check', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/system/system.admin.inc'),
('admin/config/search/path', '', '', 'user_access', 'a:1:{i:0;s:22:"administer url aliases";}', 'path_admin_overview', 'a:0:{}', '', '15', 4, '0', '', 'admin/config/search/path', 'URL aliases', 't', '', '', 'a:0:{}', '6', 'Change your site''s URL paths by aliasing them.', '', '-5', 'modules/path/path.admin.inc'),
('admin/config/search/path/add', '', '', 'user_access', 'a:1:{i:0;s:22:"administer url aliases";}', 'path_admin_edit', 'a:0:{}', '', '31', 5, '1', 'admin/config/search/path', 'admin/config/search/path', 'Add alias', 't', '', '', 'a:0:{}', '388', '', '', '0', 'modules/path/path.admin.inc'),
('admin/config/search/path/delete/%', 'a:1:{i:5;s:9:"path_load";}', '', 'user_access', 'a:1:{i:0;s:22:"administer url aliases";}', 'drupal_get_form', 'a:2:{i:0;s:25:"path_admin_delete_confirm";i:1;i:5;}', '', '62', 6, '0', '', 'admin/config/search/path/delete/%', 'Delete alias', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/path/path.admin.inc'),
('admin/config/search/path/edit/%', 'a:1:{i:5;s:9:"path_load";}', '', 'user_access', 'a:1:{i:0;s:22:"administer url aliases";}', 'path_admin_edit', 'a:1:{i:0;i:5;}', '', '62', 6, '0', '', 'admin/config/search/path/edit/%', 'Edit alias', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/path/path.admin.inc'),
('admin/config/search/path/list', '', '', 'user_access', 'a:1:{i:0;s:22:"administer url aliases";}', 'path_admin_overview', 'a:0:{}', '', '31', 5, '1', 'admin/config/search/path', 'admin/config/search/path', 'List', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'modules/path/path.admin.inc'),
('admin/config/search/settings', '', '', 'user_access', 'a:1:{i:0;s:17:"administer search";}', 'drupal_get_form', 'a:1:{i:0;s:21:"search_admin_settings";}', '', '15', 4, '0', '', 'admin/config/search/settings', 'Search settings', 't', '', '', 'a:0:{}', '6', 'Configure relevance settings for search and other indexing options.', '', '-10', 'modules/search/search.admin.inc'),
('admin/config/search/settings/reindex', '', '', 'user_access', 'a:1:{i:0;s:17:"administer search";}', 'drupal_get_form', 'a:1:{i:0;s:22:"search_reindex_confirm";}', '', '31', 5, '0', '', 'admin/config/search/settings/reindex', 'Clear index', 't', '', '', 'a:0:{}', '4', '', '', '0', 'modules/search/search.admin.inc'),
('admin/config/services', '', '', 'user_access', 'a:1:{i:0;s:27:"access administration pages";}', 'system_admin_menu_block_page', 'a:0:{}', '', '7', 3, '0', '', 'admin/config/services', 'Web services', 't', '', '', 'a:0:{}', '6', 'Tools related to web services.', 'right', '0', 'modules/system/system.admin.inc'),
('admin/config/services/aggregator', '', '', 'user_access', 'a:1:{i:0;s:21:"administer news feeds";}', 'aggregator_admin_overview', 'a:0:{}', '', '15', 4, '0', '', 'admin/config/services/aggregator', 'Feed aggregator', 't', '', '', 'a:0:{}', '6', 'Configure which content your site aggregates from other sites, how often it polls them, and how they''re categorized.', '', '10', 'modules/aggregator/aggregator.admin.inc'),
('admin/config/services/aggregator/add/category', '', '', 'user_access', 'a:1:{i:0;s:21:"administer news feeds";}', 'drupal_get_form', 'a:1:{i:0;s:24:"aggregator_form_category";}', '', '63', 6, '1', 'admin/config/services/aggregator', 'admin/config/services/aggregator', 'Add category', 't', '', '', 'a:0:{}', '388', '', '', '0', 'modules/aggregator/aggregator.admin.inc'),
('admin/config/services/aggregator/add/feed', '', '', 'user_access', 'a:1:{i:0;s:21:"administer news feeds";}', 'drupal_get_form', 'a:1:{i:0;s:20:"aggregator_form_feed";}', '', '63', 6, '1', 'admin/config/services/aggregator', 'admin/config/services/aggregator', 'Add feed', 't', '', '', 'a:0:{}', '388', '', '', '0', 'modules/aggregator/aggregator.admin.inc'),
('admin/config/services/aggregator/add/opml', '', '', 'user_access', 'a:1:{i:0;s:21:"administer news feeds";}', 'drupal_get_form', 'a:1:{i:0;s:20:"aggregator_form_opml";}', '', '63', 6, '1', 'admin/config/services/aggregator', 'admin/config/services/aggregator', 'Import OPML', 't', '', '', 'a:0:{}', '388', '', '', '0', 'modules/aggregator/aggregator.admin.inc'),
('admin/config/services/aggregator/edit/category/%', 'a:1:{i:6;s:24:"aggregator_category_load";}', '', 'user_access', 'a:1:{i:0;s:21:"administer news feeds";}', 'drupal_get_form', 'a:2:{i:0;s:24:"aggregator_form_category";i:1;i:6;}', '', '126', 7, '0', '', 'admin/config/services/aggregator/edit/category/%', 'Edit category', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/aggregator/aggregator.admin.inc'),
('admin/config/services/aggregator/edit/feed/%', 'a:1:{i:6;s:20:"aggregator_feed_load";}', '', 'user_access', 'a:1:{i:0;s:21:"administer news feeds";}', 'drupal_get_form', 'a:2:{i:0;s:20:"aggregator_form_feed";i:1;i:6;}', '', '126', 7, '0', '', 'admin/config/services/aggregator/edit/feed/%', 'Edit feed', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/aggregator/aggregator.admin.inc'),
('admin/config/services/aggregator/list', '', '', 'user_access', 'a:1:{i:0;s:21:"administer news feeds";}', 'aggregator_admin_overview', 'a:0:{}', '', '31', 5, '1', 'admin/config/services/aggregator', 'admin/config/services/aggregator', 'List', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'modules/aggregator/aggregator.admin.inc'),
('admin/config/services/aggregator/remove/%', 'a:1:{i:5;s:20:"aggregator_feed_load";}', '', 'user_access', 'a:1:{i:0;s:21:"administer news feeds";}', 'drupal_get_form', 'a:2:{i:0;s:28:"aggregator_admin_remove_feed";i:1;i:5;}', '', '62', 6, '0', '', 'admin/config/services/aggregator/remove/%', 'Remove items', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/aggregator/aggregator.admin.inc'),
('admin/config/services/aggregator/settings', '', '', 'user_access', 'a:1:{i:0;s:21:"administer news feeds";}', 'drupal_get_form', 'a:1:{i:0;s:21:"aggregator_admin_form";}', '', '31', 5, '1', 'admin/config/services/aggregator', 'admin/config/services/aggregator', 'Settings', 't', '', '', 'a:0:{}', '132', 'Configure the behavior of the feed aggregator, including when to discard feed items and how to present feed items and categories.', '', '0', 'modules/aggregator/aggregator.admin.inc'),
('admin/config/services/aggregator/update/%', 'a:1:{i:5;s:20:"aggregator_feed_load";}', '', 'user_access', 'a:1:{i:0;s:21:"administer news feeds";}', 'aggregator_admin_refresh_feed', 'a:1:{i:0;i:5;}', '', '62', 6, '0', '', 'admin/config/services/aggregator/update/%', 'Update items', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/aggregator/aggregator.admin.inc'),
('admin/config/services/follow', '', '', 'user_access', 'a:1:{i:0;s:22:"edit site follow links";}', 'drupal_get_form', 'a:1:{i:0;s:17:"follow_links_form";}', '', '15', 4, '0', '', 'admin/config/services/follow', 'Follow', 't', '', '', 'a:0:{}', '6', 'Configure the site-wide web service follow links.', '', '0', ''),
('admin/config/services/getlocations', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:1:{i:0;s:26:"getlocations_settings_form";}', '', '15', 4, '0', '', 'admin/config/services/getlocations', 'Get locations', 't', '', '', 'a:0:{}', '6', 'Configure Get locations', '', '0', 'sites/all/modules/getlocations/getlocations.admin.inc'),
('admin/config/services/getlocations_fields', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:1:{i:0;s:33:"getlocations_fields_settings_form";}', '', '15', 4, '0', '', 'admin/config/services/getlocations_fields', 'Getlocations fields', 't', '', '', 'a:0:{}', '6', 'Configure Getlocations fields', '', '0', 'sites/all/modules/getlocations/modules/getlocations_fields/getlocations_fields.admin.inc'),
('admin/config/services/rss-publishing', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:1:{i:0;s:25:"system_rss_feeds_settings";}', '', '15', 4, '0', '', 'admin/config/services/rss-publishing', 'RSS publishing', 't', '', '', 'a:0:{}', '6', 'Configure the site description, the number of items per feed and whether feeds should be titles/teasers/full-text.', '', '0', 'modules/system/system.admin.inc'),
('admin/config/system', '', '', 'user_access', 'a:1:{i:0;s:27:"access administration pages";}', 'system_admin_menu_block_page', 'a:0:{}', '', '7', 3, '0', '', 'admin/config/system', 'System', 't', '', '', 'a:0:{}', '6', 'General system related configuration.', 'right', '-20', 'modules/system/system.admin.inc'),
('admin/config/system/actions', '', '', 'user_access', 'a:1:{i:0;s:18:"administer actions";}', 'system_actions_manage', 'a:0:{}', '', '15', 4, '0', '', 'admin/config/system/actions', 'Actions', 't', '', '', 'a:0:{}', '6', 'Manage the actions defined for your site.', '', '0', 'modules/system/system.admin.inc'),
('admin/config/system/actions/configure', '', '', 'user_access', 'a:1:{i:0;s:18:"administer actions";}', 'drupal_get_form', 'a:1:{i:0;s:24:"system_actions_configure";}', '', '31', 5, '0', '', 'admin/config/system/actions/configure', 'Configure an advanced action', 't', '', '', 'a:0:{}', '4', '', '', '0', 'modules/system/system.admin.inc'),
('admin/config/system/actions/delete/%', 'a:1:{i:5;s:12:"actions_load";}', '', 'user_access', 'a:1:{i:0;s:18:"administer actions";}', 'drupal_get_form', 'a:2:{i:0;s:26:"system_actions_delete_form";i:1;i:5;}', '', '62', 6, '0', '', 'admin/config/system/actions/delete/%', 'Delete action', 't', '', '', 'a:0:{}', '6', 'Delete an action.', '', '0', 'modules/system/system.admin.inc'),
('admin/config/system/actions/manage', '', '', 'user_access', 'a:1:{i:0;s:18:"administer actions";}', 'system_actions_manage', 'a:0:{}', '', '31', 5, '1', 'admin/config/system/actions', 'admin/config/system/actions', 'Manage actions', 't', '', '', 'a:0:{}', '140', 'Manage the actions defined for your site.', '', '-2', 'modules/system/system.admin.inc'),
('admin/config/system/actions/orphan', '', '', 'user_access', 'a:1:{i:0;s:18:"administer actions";}', 'system_actions_remove_orphans', 'a:0:{}', '', '31', 5, '0', '', 'admin/config/system/actions/orphan', 'Remove orphans', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/system/system.admin.inc'),
('admin/config/system/cron', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:1:{i:0;s:20:"system_cron_settings";}', '', '15', 4, '0', '', 'admin/config/system/cron', 'Cron', 't', '', '', 'a:0:{}', '6', 'Manage automatic site maintenance tasks.', '', '20', 'modules/system/system.admin.inc'),
('admin/config/system/site-information', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:1:{i:0;s:32:"system_site_information_settings";}', '', '15', 4, '0', '', 'admin/config/system/site-information', 'Site information', 't', '', '', 'a:0:{}', '6', 'Change site name, e-mail address, slogan, default front page, and number of posts per page, error pages.', '', '-20', 'modules/system/system.admin.inc'),
('admin/config/user-interface', '', '', 'user_access', 'a:1:{i:0;s:27:"access administration pages";}', 'system_admin_menu_block_page', 'a:0:{}', '', '7', 3, '0', '', 'admin/config/user-interface', 'User interface', 't', '', '', 'a:0:{}', '6', 'Tools that enhance the user interface.', 'right', '-15', 'modules/system/system.admin.inc'),
('admin/config/user-interface/addthis', '', '', 'user_access', 'a:1:{i:0;s:18:"administer addthis";}', 'drupal_get_form', 'a:1:{i:0;s:27:"addthis_admin_settings_form";}', '', '15', 4, '0', '', 'admin/config/user-interface/addthis', 'AddThis', 't', '', '', 'a:0:{}', '6', 'Configure AddThis settings.', '', '0', 'sites/all/modules/addthis/includes/addthis.admin.inc'),
('admin/config/user-interface/addthis/advanced', '', '', 'user_access', 'a:1:{i:0;s:18:"administer addthis";}', 'drupal_get_form', 'a:1:{i:0;s:36:"addthis_admin_settings_advanced_form";}', '', '31', 5, '1', 'admin/config/user-interface/addthis', 'admin/config/user-interface/addthis', 'Advanced settings', 't', '', '', 'a:0:{}', '132', '', '', '10', 'sites/all/modules/addthis/includes/addthis.admin.inc'),
('admin/config/user-interface/addthis/basic', '', '', 'user_access', 'a:1:{i:0;s:18:"administer addthis";}', 'drupal_get_form', 'a:1:{i:0;s:27:"addthis_admin_settings_form";}', '', '31', 5, '1', 'admin/config/user-interface/addthis', 'admin/config/user-interface/addthis', 'Basic settings', 't', '', '', 'a:0:{}', '140', '', '', '0', 'sites/all/modules/addthis/includes/addthis.admin.inc'),
('admin/config/user-interface/back_to_top', '', '', 'user_access', 'a:1:{i:0;s:27:"access administration pages";}', 'drupal_get_form', 'a:1:{i:0;s:20:"back_to_top_settings";}', '', '15', 4, '0', '', 'admin/config/user-interface/back_to_top', 'Back To Top', 't', '', '', 'a:0:{}', '6', 'Administer Back To Top settings', '', '0', 'sites/all/modules/back_to_top/back_to_top.admin.inc'),
('admin/config/user-interface/modulefilter', '', '', 'user_access', 'a:1:{i:0;s:24:"administer module filter";}', 'drupal_get_form', 'a:1:{i:0;s:22:"module_filter_settings";}', '', '15', 4, '0', '', 'admin/config/user-interface/modulefilter', 'Module filter', 't', '', '', 'a:0:{}', '6', 'Configure settings for Module Filter.', '', '0', 'sites/all/modules/module_filter/module_filter.admin.inc'),
('admin/config/user-interface/shortcut', '', '', 'user_access', 'a:1:{i:0;s:20:"administer shortcuts";}', 'shortcut_set_admin', 'a:0:{}', '', '15', 4, '0', '', 'admin/config/user-interface/shortcut', 'Shortcuts', 't', '', '', 'a:0:{}', '6', 'Add and modify shortcut sets.', '', '0', 'modules/shortcut/shortcut.admin.inc'),
('admin/config/user-interface/shortcut/%', 'a:1:{i:4;s:17:"shortcut_set_load";}', '', 'shortcut_set_edit_access', 'a:1:{i:0;i:4;}', 'drupal_get_form', 'a:2:{i:0;s:22:"shortcut_set_customize";i:1;i:4;}', '', '30', 5, '0', '', 'admin/config/user-interface/shortcut/%', 'Edit shortcuts', 'shortcut_set_title_callback', 'a:1:{i:0;i:4;}', '', 'a:0:{}', '6', '', '', '0', 'modules/shortcut/shortcut.admin.inc'),
('admin/config/user-interface/shortcut/%/add-link', 'a:1:{i:4;s:17:"shortcut_set_load";}', '', 'shortcut_set_edit_access', 'a:1:{i:0;i:4;}', 'drupal_get_form', 'a:2:{i:0;s:17:"shortcut_link_add";i:1;i:4;}', '', '61', 6, '1', 'admin/config/user-interface/shortcut/%', 'admin/config/user-interface/shortcut/%', 'Add shortcut', 't', '', '', 'a:0:{}', '388', '', '', '0', 'modules/shortcut/shortcut.admin.inc'),
('admin/config/user-interface/shortcut/%/add-link-inline', 'a:1:{i:4;s:17:"shortcut_set_load";}', '', 'shortcut_set_edit_access', 'a:1:{i:0;i:4;}', 'shortcut_link_add_inline', 'a:1:{i:0;i:4;}', '', '61', 6, '0', '', 'admin/config/user-interface/shortcut/%/add-link-inline', 'Add shortcut', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/shortcut/shortcut.admin.inc'),
('admin/config/user-interface/shortcut/%/delete', 'a:1:{i:4;s:17:"shortcut_set_load";}', '', 'shortcut_set_delete_access', 'a:1:{i:0;i:4;}', 'drupal_get_form', 'a:2:{i:0;s:24:"shortcut_set_delete_form";i:1;i:4;}', '', '61', 6, '0', '', 'admin/config/user-interface/shortcut/%/delete', 'Delete shortcut set', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/shortcut/shortcut.admin.inc'),
('admin/config/user-interface/shortcut/%/edit', 'a:1:{i:4;s:17:"shortcut_set_load";}', '', 'shortcut_set_edit_access', 'a:1:{i:0;i:4;}', 'drupal_get_form', 'a:2:{i:0;s:22:"shortcut_set_edit_form";i:1;i:4;}', '', '61', 6, '1', 'admin/config/user-interface/shortcut/%', 'admin/config/user-interface/shortcut/%', 'Edit set name', 't', '', '', 'a:0:{}', '132', '', '', '10', 'modules/shortcut/shortcut.admin.inc'),
('admin/config/user-interface/shortcut/%/links', 'a:1:{i:4;s:17:"shortcut_set_load";}', '', 'shortcut_set_edit_access', 'a:1:{i:0;i:4;}', 'drupal_get_form', 'a:2:{i:0;s:22:"shortcut_set_customize";i:1;i:4;}', '', '61', 6, '1', 'admin/config/user-interface/shortcut/%', 'admin/config/user-interface/shortcut/%', 'List links', 't', '', '', 'a:0:{}', '140', '', '', '0', 'modules/shortcut/shortcut.admin.inc'),
('admin/config/user-interface/shortcut/add-set', '', '', 'user_access', 'a:1:{i:0;s:20:"administer shortcuts";}', 'drupal_get_form', 'a:1:{i:0;s:21:"shortcut_set_add_form";}', '', '31', 5, '1', 'admin/config/user-interface/shortcut', 'admin/config/user-interface/shortcut', 'Add shortcut set', 't', '', '', 'a:0:{}', '388', '', '', '0', 'modules/shortcut/shortcut.admin.inc'),
('admin/config/user-interface/shortcut/link/%', 'a:1:{i:5;s:14:"menu_link_load";}', '', 'shortcut_link_access', 'a:1:{i:0;i:5;}', 'drupal_get_form', 'a:2:{i:0;s:18:"shortcut_link_edit";i:1;i:5;}', '', '62', 6, '0', '', 'admin/config/user-interface/shortcut/link/%', 'Edit shortcut', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/shortcut/shortcut.admin.inc'),
('admin/config/user-interface/shortcut/link/%/delete', 'a:1:{i:5;s:14:"menu_link_load";}', '', 'shortcut_link_access', 'a:1:{i:0;i:5;}', 'drupal_get_form', 'a:2:{i:0;s:20:"shortcut_link_delete";i:1;i:5;}', '', '125', 7, '0', '', 'admin/config/user-interface/shortcut/link/%/delete', 'Delete shortcut', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/shortcut/shortcut.admin.inc'),
('admin/config/user-interface/superfish', '', '', 'user_access', 'a:1:{i:0;s:20:"administer superfish";}', 'drupal_get_form', 'a:1:{i:0;s:24:"superfish_admin_settings";}', '', '15', 4, '0', '', 'admin/config/user-interface/superfish', 'Superfish', 't', '', '', 'a:0:{}', '6', 'Configure Superfish Menus', '', '0', 'sites/all/modules/superfish/superfish.admin.inc'),
('admin/config/workflow', '', '', 'user_access', 'a:1:{i:0;s:27:"access administration pages";}', 'system_admin_menu_block_page', 'a:0:{}', '', '7', 3, '0', '', 'admin/config/workflow', 'Workflow', 't', '', '', 'a:0:{}', '6', 'Content workflow, editorial workflow tools.', 'right', '5', 'modules/system/system.admin.inc'),
('admin/content', '', '', 'user_access', 'a:1:{i:0;s:23:"access content overview";}', 'drupal_get_form', 'a:1:{i:0;s:18:"node_admin_content";}', '', '3', 2, '0', '', 'admin/content', 'Content', 't', '', '', 'a:0:{}', '6', 'Administer content and comments.', '', '-10', 'modules/node/node.admin.inc'),
('admin/content/book', '', '', 'user_access', 'a:1:{i:0;s:24:"administer book outlines";}', 'book_admin_overview', 'a:0:{}', '', '7', 3, '1', 'admin/content', 'admin/content', 'Books', 't', '', '', 'a:0:{}', '132', 'Manage your site''s book outlines.', '', '0', 'modules/book/book.admin.inc'),
('admin/content/book/%', 'a:1:{i:3;s:9:"node_load";}', '', '_book_outline_access', 'a:1:{i:0;i:3;}', 'drupal_get_form', 'a:2:{i:0;s:15:"book_admin_edit";i:1;i:3;}', '', '14', 4, '0', '', 'admin/content/book/%', 'Re-order book pages and change titles', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/book/book.admin.inc'),
('admin/content/book/list', '', '', 'user_access', 'a:1:{i:0;s:24:"administer book outlines";}', 'book_admin_overview', 'a:0:{}', '', '15', 4, '1', 'admin/content/book', 'admin/content', 'List', 't', '', '', 'a:0:{}', '140', '', '', '0', 'modules/book/book.admin.inc'),
('admin/content/book/settings', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:1:{i:0;s:19:"book_admin_settings";}', '', '15', 4, '1', 'admin/content/book', 'admin/content', 'Settings', 't', '', '', 'a:0:{}', '132', '', '', '8', 'modules/book/book.admin.inc'),
('admin/content/comment', '', '', 'user_access', 'a:1:{i:0;s:19:"administer comments";}', 'comment_admin', 'a:0:{}', '', '7', 3, '1', 'admin/content', 'admin/content', 'Comments', 't', '', '', 'a:0:{}', '134', 'List and edit site comments and the comment approval queue.', '', '0', 'modules/comment/comment.admin.inc'),
('admin/content/comment/approval', '', '', 'user_access', 'a:1:{i:0;s:19:"administer comments";}', 'comment_admin', 'a:1:{i:0;s:8:"approval";}', '', '15', 4, '1', 'admin/content/comment', 'admin/content', 'Unapproved comments', 'comment_count_unpublished', '', '', 'a:0:{}', '132', '', '', '0', 'modules/comment/comment.admin.inc'),
('admin/content/comment/new', '', '', 'user_access', 'a:1:{i:0;s:19:"administer comments";}', 'comment_admin', 'a:0:{}', '', '15', 4, '1', 'admin/content/comment', 'admin/content', 'Published comments', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'modules/comment/comment.admin.inc'),
('admin/content/node', '', '', 'user_access', 'a:1:{i:0;s:23:"access content overview";}', 'drupal_get_form', 'a:1:{i:0;s:18:"node_admin_content";}', '', '7', 3, '1', 'admin/content', 'admin/content', 'Content', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'modules/node/node.admin.inc'),
('admin/index', '', '', 'user_access', 'a:1:{i:0;s:27:"access administration pages";}', 'system_admin_index', 'a:0:{}', '', '3', 2, '1', 'admin', 'admin', 'Index', 't', '', '', 'a:0:{}', '132', '', '', '-18', 'modules/system/system.admin.inc'),
('admin/modules', '', '', 'user_access', 'a:1:{i:0;s:18:"administer modules";}', 'drupal_get_form', 'a:1:{i:0;s:14:"system_modules";}', '', '3', 2, '0', '', 'admin/modules', 'Modules', 't', '', '', 'a:0:{}', '6', 'Extend site functionality.', '', '-2', 'modules/system/system.admin.inc'),
('admin/modules/install', '', '', 'update_manager_access', 'a:0:{}', 'drupal_get_form', 'a:2:{i:0;s:27:"update_manager_install_form";i:1;s:6:"module";}', '', '7', 3, '1', 'admin/modules', 'admin/modules', 'Install new module', 't', '', '', 'a:0:{}', '388', '', '', '25', 'modules/update/update.manager.inc'),
('admin/modules/list', '', '', 'user_access', 'a:1:{i:0;s:18:"administer modules";}', 'drupal_get_form', 'a:1:{i:0;s:14:"system_modules";}', '', '7', 3, '1', 'admin/modules', 'admin/modules', 'List', 't', '', '', 'a:0:{}', '140', '', '', '0', 'modules/system/system.admin.inc'),
('admin/modules/list/confirm', '', '', 'user_access', 'a:1:{i:0;s:18:"administer modules";}', 'drupal_get_form', 'a:1:{i:0;s:14:"system_modules";}', '', '15', 4, '0', '', 'admin/modules/list/confirm', 'List', 't', '', '', 'a:0:{}', '4', '', '', '0', 'modules/system/system.admin.inc'),
('admin/modules/uninstall', '', '', 'user_access', 'a:1:{i:0;s:18:"administer modules";}', 'drupal_get_form', 'a:1:{i:0;s:24:"system_modules_uninstall";}', '', '7', 3, '1', 'admin/modules', 'admin/modules', 'Uninstall', 't', '', '', 'a:0:{}', '132', '', '', '20', 'modules/system/system.admin.inc'),
('admin/modules/uninstall/confirm', '', '', 'user_access', 'a:1:{i:0;s:18:"administer modules";}', 'drupal_get_form', 'a:1:{i:0;s:24:"system_modules_uninstall";}', '', '15', 4, '0', '', 'admin/modules/uninstall/confirm', 'Uninstall', 't', '', '', 'a:0:{}', '4', '', '', '0', 'modules/system/system.admin.inc'),
('admin/modules/update', '', '', 'update_manager_access', 'a:0:{}', 'drupal_get_form', 'a:2:{i:0;s:26:"update_manager_update_form";i:1;s:6:"module";}', '', '7', 3, '1', 'admin/modules', 'admin/modules', 'Update', 't', '', '', 'a:0:{}', '132', '', '', '10', 'modules/update/update.manager.inc'),
('admin/people', '', '', 'user_access', 'a:1:{i:0;s:16:"administer users";}', 'user_admin', 'a:1:{i:0;s:4:"list";}', '', '3', 2, '0', '', 'admin/people', 'People', 't', '', '', 'a:0:{}', '6', 'Manage user accounts, roles, and permissions.', 'left', '-4', 'modules/user/user.admin.inc'),
('admin/people/create', '', '', 'user_access', 'a:1:{i:0;s:16:"administer users";}', 'user_admin', 'a:1:{i:0;s:6:"create";}', '', '7', 3, '1', 'admin/people', 'admin/people', 'Add user', 't', '', '', 'a:0:{}', '388', '', '', '0', 'modules/user/user.admin.inc'),
('admin/people/people', '', '', 'user_access', 'a:1:{i:0;s:16:"administer users";}', 'user_admin', 'a:1:{i:0;s:4:"list";}', '', '7', 3, '1', 'admin/people', 'admin/people', 'List', 't', '', '', 'a:0:{}', '140', 'Find and manage people interacting with your site.', '', '-10', 'modules/user/user.admin.inc'),
('admin/people/permissions', '', '', 'user_access', 'a:1:{i:0;s:22:"administer permissions";}', 'drupal_get_form', 'a:1:{i:0;s:22:"user_admin_permissions";}', '', '7', 3, '1', 'admin/people', 'admin/people', 'Permissions', 't', '', '', 'a:0:{}', '132', 'Determine access to features by selecting permissions for roles.', '', '0', 'modules/user/user.admin.inc'),
('admin/people/permissions/list', '', '', 'user_access', 'a:1:{i:0;s:22:"administer permissions";}', 'drupal_get_form', 'a:1:{i:0;s:22:"user_admin_permissions";}', '', '15', 4, '1', 'admin/people/permissions', 'admin/people', 'Permissions', 't', '', '', 'a:0:{}', '140', 'Determine access to features by selecting permissions for roles.', '', '-8', 'modules/user/user.admin.inc'),
('admin/people/permissions/roles', '', '', 'user_access', 'a:1:{i:0;s:22:"administer permissions";}', 'drupal_get_form', 'a:1:{i:0;s:16:"user_admin_roles";}', '', '15', 4, '1', 'admin/people/permissions', 'admin/people', 'Roles', 't', '', '', 'a:0:{}', '132', 'List, edit, or add user roles.', '', '-5', 'modules/user/user.admin.inc'),
('admin/people/permissions/roles/delete/%', 'a:1:{i:5;s:14:"user_role_load";}', '', 'user_role_edit_access', 'a:1:{i:0;i:5;}', 'drupal_get_form', 'a:2:{i:0;s:30:"user_admin_role_delete_confirm";i:1;i:5;}', '', '62', 6, '0', '', 'admin/people/permissions/roles/delete/%', 'Delete role', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/user/user.admin.inc'),
('admin/people/permissions/roles/edit/%', 'a:1:{i:5;s:14:"user_role_load";}', '', 'user_role_edit_access', 'a:1:{i:0;i:5;}', 'drupal_get_form', 'a:2:{i:0;s:15:"user_admin_role";i:1;i:5;}', '', '62', 6, '0', '', 'admin/people/permissions/roles/edit/%', 'Edit role', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/user/user.admin.inc'),
('admin/reports', '', '', 'user_access', 'a:1:{i:0;s:19:"access site reports";}', 'system_admin_menu_block_page', 'a:0:{}', '', '3', 2, '0', '', 'admin/reports', 'Reports', 't', '', '', 'a:0:{}', '6', 'View reports, updates, and errors.', 'left', '5', 'modules/system/system.admin.inc'),
('admin/reports/fields', '', '', 'user_access', 'a:1:{i:0;s:24:"administer content types";}', 'field_ui_fields_list', 'a:0:{}', '', '7', 3, '0', '', 'admin/reports/fields', 'Field list', 't', '', '', 'a:0:{}', '6', 'Overview of fields on all entity types.', '', '0', 'modules/field_ui/field_ui.admin.inc'),
('admin/reports/fields/list', '', '', 'user_access', 'a:1:{i:0;s:24:"administer content types";}', 'field_ui_fields_list', 'a:0:{}', '', '15', 4, '1', 'admin/reports/fields', 'admin/reports/fields', 'List', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'modules/field_ui/field_ui.admin.inc'),
('admin/reports/fields/views-fields', '', '', 'user_access', 'a:1:{i:0;s:16:"administer views";}', 'views_ui_field_list', 'a:0:{}', '', '15', 4, '1', 'admin/reports/fields', 'admin/reports/fields', 'Used in views', 't', '', '', 'a:0:{}', '132', 'Overview of fields used in all views.', '', '0', 'sites/all/modules/views/includes/admin.inc'),
('admin/reports/status', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'system_status', 'a:0:{}', '', '7', 3, '0', '', 'admin/reports/status', 'Status report', 't', '', '', 'a:0:{}', '6', 'Get a status report about your site''s operation and any detected problems.', '', '-60', 'modules/system/system.admin.inc'),
('admin/reports/status/php', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'system_php', 'a:0:{}', '', '15', 4, '0', '', 'admin/reports/status/php', 'PHP', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/system/system.admin.inc'),
('admin/reports/status/rebuild', '', '', 'user_access', 'a:1:{i:0;s:27:"access administration pages";}', 'drupal_get_form', 'a:1:{i:0;s:30:"node_configure_rebuild_confirm";}', '', '15', 4, '0', '', 'admin/reports/status/rebuild', 'Rebuild permissions', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/node/node.admin.inc'),
('admin/reports/status/run-cron', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'system_run_cron', 'a:0:{}', '', '15', 4, '0', '', 'admin/reports/status/run-cron', 'Run cron', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/system/system.admin.inc'),
('admin/reports/updates', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'update_status', 'a:0:{}', '', '7', 3, '0', '', 'admin/reports/updates', 'Available updates', 't', '', '', 'a:0:{}', '6', 'Get a status report about available updates for your installed modules and themes.', '', '-50', 'modules/update/update.report.inc'),
('admin/reports/updates/check', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'update_manual_status', 'a:0:{}', '', '15', 4, '0', '', 'admin/reports/updates/check', 'Manual update check', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/update/update.fetch.inc'),
('admin/reports/updates/install', '', '', 'update_manager_access', 'a:0:{}', 'drupal_get_form', 'a:2:{i:0;s:27:"update_manager_install_form";i:1;s:6:"report";}', '', '15', 4, '1', 'admin/reports/updates', 'admin/reports/updates', 'Install new module or theme', 't', '', '', 'a:0:{}', '388', '', '', '25', 'modules/update/update.manager.inc'),
('admin/reports/updates/list', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'update_status', 'a:0:{}', '', '15', 4, '1', 'admin/reports/updates', 'admin/reports/updates', 'List', 't', '', '', 'a:0:{}', '140', '', '', '0', 'modules/update/update.report.inc'),
('admin/reports/updates/settings', '', '', 'user_access', 'a:1:{i:0;s:29:"administer site configuration";}', 'drupal_get_form', 'a:1:{i:0;s:15:"update_settings";}', '', '15', 4, '1', 'admin/reports/updates', 'admin/reports/updates', 'Settings', 't', '', '', 'a:0:{}', '132', '', '', '50', 'modules/update/update.settings.inc'),
('admin/reports/updates/update', '', '', 'update_manager_access', 'a:0:{}', 'drupal_get_form', 'a:2:{i:0;s:26:"update_manager_update_form";i:1;s:6:"report";}', '', '15', 4, '1', 'admin/reports/updates', 'admin/reports/updates', 'Update', 't', '', '', 'a:0:{}', '132', '', '', '10', 'modules/update/update.manager.inc'),
('admin/reports/views-plugins', '', '', 'user_access', 'a:1:{i:0;s:16:"administer views";}', 'views_ui_plugin_list', 'a:0:{}', '', '7', 3, '0', '', 'admin/reports/views-plugins', 'Views plugins', 't', '', '', 'a:0:{}', '6', 'Overview of plugins used in all views.', '', '0', 'sites/all/modules/views/includes/admin.inc'),
('admin/structure', '', '', 'user_access', 'a:1:{i:0;s:27:"access administration pages";}', 'system_admin_menu_block_page', 'a:0:{}', '', '3', 2, '0', '', 'admin/structure', 'Structure', 't', '', '', 'a:0:{}', '6', 'Administer blocks, content types, menus, etc.', 'right', '-8', 'modules/system/system.admin.inc'),
('admin/structure/block', '', '', 'user_access', 'a:1:{i:0;s:17:"administer blocks";}', 'block_admin_display', 'a:1:{i:0;s:8:"theme822";}', '', '7', 3, '0', '', 'admin/structure/block', 'Blocks', 't', '', '', 'a:0:{}', '6', 'Configure what block content appears in your site''s sidebars and other regions.', '', '0', 'modules/block/block.admin.inc'),
('admin/structure/block/add', '', '', 'user_access', 'a:1:{i:0;s:17:"administer blocks";}', 'drupal_get_form', 'a:1:{i:0;s:20:"block_add_block_form";}', '', '15', 4, '1', 'admin/structure/block', 'admin/structure/block', 'Add block', 't', '', '', 'a:0:{}', '388', '', '', '0', 'modules/block/block.admin.inc'),
('admin/structure/block/demo/bartik', '', '', '_block_themes_access', 'a:1:{i:0;O:8:"stdClass":12:{s:8:"filename";s:25:"themes/bartik/bartik.info";s:4:"name";s:6:"bartik";s:4:"type";s:5:"theme";s:5:"owner";s:45:"themes/engines/phptemplate/phptemplate.engine";s:6:"status";s:1:"1";s:9:"bootstrap";s:1:"0";s:14:"schema_version";s:2:"-1";s:6:"weight";s:1:"0";s:4:"info";a:17:{s:4:"name";s:6:"Bartik";s:11:"description";s:48:"A flexible, recolorable theme with many regions.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:11:"stylesheets";a:2:{s:3:"all";a:3:{s:14:"css/layout.css";s:28:"themes/bartik/css/layout.css";s:13:"css/style.css";s:27:"themes/bartik/css/style.css";s:14:"css/colors.css";s:28:"themes/bartik/css/colors.css";}s:5:"print";a:1:{s:13:"css/print.css";s:27:"themes/bartik/css/print.css";}}s:7:"regions";a:17:{s:6:"header";s:6:"Header";s:4:"help";s:4:"Help";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";s:11:"highlighted";s:11:"Highlighted";s:8:"featured";s:8:"Featured";s:7:"content";s:7:"Content";s:13:"sidebar_first";s:13:"Sidebar first";s:14:"sidebar_second";s:14:"Sidebar second";s:14:"triptych_first";s:14:"Triptych first";s:15:"triptych_middle";s:15:"Triptych middle";s:13:"triptych_last";s:13:"Triptych last";s:18:"footer_firstcolumn";s:19:"Footer first column";s:19:"footer_secondcolumn";s:20:"Footer second column";s:18:"footer_thirdcolumn";s:19:"Footer third column";s:19:"footer_fourthcolumn";s:20:"Footer fourth column";s:6:"footer";s:6:"Footer";}s:8:"settings";a:1:{s:20:"shortcut_module_link";s:1:"0";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:6:"engine";s:11:"phptemplate";s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:10:"screenshot";s:28:"themes/bartik/screenshot.png";s:3:"php";s:5:"5.2.4";s:7:"scripts";a:0:{}s:14:"regions_hidden";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}s:28:"overlay_supplemental_regions";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}}s:6:"prefix";s:11:"phptemplate";s:11:"stylesheets";a:2:{s:3:"all";a:3:{s:14:"css/layout.css";s:28:"themes/bartik/css/layout.css";s:13:"css/style.css";s:27:"themes/bartik/css/style.css";s:14:"css/colors.css";s:28:"themes/bartik/css/colors.css";}s:5:"print";a:1:{s:13:"css/print.css";s:27:"themes/bartik/css/print.css";}}s:6:"engine";s:11:"phptemplate";}}', 'block_admin_demo', 'a:1:{i:0;s:6:"bartik";}', '', '31', 5, '0', '', 'admin/structure/block/demo/bartik', 'Bartik', 't', '', '_block_custom_theme', 'a:1:{i:0;s:6:"bartik";}', '0', '', '', '0', 'modules/block/block.admin.inc'),
('admin/structure/block/demo/garland', '', '', '_block_themes_access', 'a:1:{i:0;O:8:"stdClass":12:{s:8:"filename";s:27:"themes/garland/garland.info";s:4:"name";s:7:"garland";s:4:"type";s:5:"theme";s:5:"owner";s:45:"themes/engines/phptemplate/phptemplate.engine";s:6:"status";s:1:"0";s:9:"bootstrap";s:1:"0";s:14:"schema_version";s:2:"-1";s:6:"weight";s:1:"0";s:4:"info";a:17:{s:4:"name";s:7:"Garland";s:11:"description";s:111:"A multi-column theme which can be configured to modify colors and switch between fixed and fluid width layouts.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:11:"stylesheets";a:2:{s:3:"all";a:1:{s:9:"style.css";s:24:"themes/garland/style.css";}s:5:"print";a:1:{s:9:"print.css";s:24:"themes/garland/print.css";}}s:8:"settings";a:1:{s:13:"garland_width";s:5:"fluid";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:6:"engine";s:11:"phptemplate";s:7:"regions";a:9:{s:13:"sidebar_first";s:12:"Left sidebar";s:14:"sidebar_second";s:13:"Right sidebar";s:7:"content";s:7:"Content";s:6:"header";s:6:"Header";s:6:"footer";s:6:"Footer";s:11:"highlighted";s:11:"Highlighted";s:4:"help";s:4:"Help";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";}s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:10:"screenshot";s:29:"themes/garland/screenshot.png";s:3:"php";s:5:"5.2.4";s:7:"scripts";a:0:{}s:14:"regions_hidden";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}s:28:"overlay_supplemental_regions";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}}s:6:"prefix";s:11:"phptemplate";s:11:"stylesheets";a:2:{s:3:"all";a:1:{s:9:"style.css";s:24:"themes/garland/style.css";}s:5:"print";a:1:{s:9:"print.css";s:24:"themes/garland/print.css";}}s:6:"engine";s:11:"phptemplate";}}', 'block_admin_demo', 'a:1:{i:0;s:7:"garland";}', '', '31', 5, '0', '', 'admin/structure/block/demo/garland', 'Garland', 't', '', '_block_custom_theme', 'a:1:{i:0;s:7:"garland";}', '0', '', '', '0', 'modules/block/block.admin.inc'),
('admin/structure/block/demo/seven', '', '', '_block_themes_access', 'a:1:{i:0;O:8:"stdClass":12:{s:8:"filename";s:23:"themes/seven/seven.info";s:4:"name";s:5:"seven";s:4:"type";s:5:"theme";s:5:"owner";s:45:"themes/engines/phptemplate/phptemplate.engine";s:6:"status";s:1:"1";s:9:"bootstrap";s:1:"0";s:14:"schema_version";s:2:"-1";s:6:"weight";s:1:"0";s:4:"info";a:17:{s:4:"name";s:5:"Seven";s:11:"description";s:65:"A simple one-column, tableless, fluid width administration theme.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:11:"stylesheets";a:1:{s:6:"screen";a:2:{s:9:"reset.css";s:22:"themes/seven/reset.css";s:9:"style.css";s:22:"themes/seven/style.css";}}s:8:"settings";a:1:{s:20:"shortcut_module_link";s:1:"1";}s:7:"regions";a:5:{s:7:"content";s:7:"Content";s:4:"help";s:4:"Help";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";s:13:"sidebar_first";s:13:"First sidebar";}s:14:"regions_hidden";a:3:{i:0;s:13:"sidebar_first";i:1;s:8:"page_top";i:2;s:11:"page_bottom";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:6:"engine";s:11:"phptemplate";s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:10:"screenshot";s:27:"themes/seven/screenshot.png";s:3:"php";s:5:"5.2.4";s:7:"scripts";a:0:{}s:28:"overlay_supplemental_regions";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}}s:6:"prefix";s:11:"phptemplate";s:11:"stylesheets";a:1:{s:6:"screen";a:2:{s:9:"reset.css";s:22:"themes/seven/reset.css";s:9:"style.css";s:22:"themes/seven/style.css";}}s:6:"engine";s:11:"phptemplate";}}', 'block_admin_demo', 'a:1:{i:0;s:5:"seven";}', '', '31', 5, '0', '', 'admin/structure/block/demo/seven', 'Seven', 't', '', '_block_custom_theme', 'a:1:{i:0;s:5:"seven";}', '0', '', '', '0', 'modules/block/block.admin.inc'),
('admin/structure/block/demo/stark', '', '', '_block_themes_access', 'a:1:{i:0;O:8:"stdClass":12:{s:8:"filename";s:23:"themes/stark/stark.info";s:4:"name";s:5:"stark";s:4:"type";s:5:"theme";s:5:"owner";s:45:"themes/engines/phptemplate/phptemplate.engine";s:6:"status";s:1:"0";s:9:"bootstrap";s:1:"0";s:14:"schema_version";s:2:"-1";s:6:"weight";s:1:"0";s:4:"info";a:16:{s:4:"name";s:5:"Stark";s:11:"description";s:208:"This theme demonstrates Drupal''s default HTML markup and CSS styles. To learn how to build your own theme and override Drupal''s default code, see the <a href="http://drupal.org/theme-guide">Theming Guide</a>.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:11:"stylesheets";a:1:{s:3:"all";a:1:{s:10:"layout.css";s:23:"themes/stark/layout.css";}}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:6:"engine";s:11:"phptemplate";s:7:"regions";a:9:{s:13:"sidebar_first";s:12:"Left sidebar";s:14:"sidebar_second";s:13:"Right sidebar";s:7:"content";s:7:"Content";s:6:"header";s:6:"Header";s:6:"footer";s:6:"Footer";s:11:"highlighted";s:11:"Highlighted";s:4:"help";s:4:"Help";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";}s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:10:"screenshot";s:27:"themes/stark/screenshot.png";s:3:"php";s:5:"5.2.4";s:7:"scripts";a:0:{}s:14:"regions_hidden";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}s:28:"overlay_supplemental_regions";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}}s:6:"prefix";s:11:"phptemplate";s:11:"stylesheets";a:1:{s:3:"all";a:1:{s:10:"layout.css";s:23:"themes/stark/layout.css";}}s:6:"engine";s:11:"phptemplate";}}', 'block_admin_demo', 'a:1:{i:0;s:5:"stark";}', '', '31', 5, '0', '', 'admin/structure/block/demo/stark', 'Stark', 't', '', '_block_custom_theme', 'a:1:{i:0;s:5:"stark";}', '0', '', '', '0', 'modules/block/block.admin.inc'),
('admin/structure/block/demo/theme822', '', '', '_block_themes_access', 'a:1:{i:0;O:8:"stdClass":13:{s:8:"filename";s:39:"sites/all/themes/theme822/theme822.info";s:4:"name";s:8:"theme822";s:4:"type";s:5:"theme";s:5:"owner";s:45:"themes/engines/phptemplate/phptemplate.engine";s:6:"status";s:1:"1";s:9:"bootstrap";s:1:"0";s:14:"schema_version";s:2:"-1";s:6:"weight";s:1:"0";s:4:"info";a:16:{s:4:"name";s:8:"theme822";s:11:"description";s:81:"This template is made by <a href="http://template-help.com">template-help.com</a>";s:10:"screenshot";s:40:"sites/all/themes/theme822/screenshot.png";s:4:"core";s:3:"7.x";s:6:"engine";s:11:"phptemplate";s:11:"stylesheets";a:1:{s:6:"screen";a:4:{s:19:"css/boilerplate.css";s:45:"sites/all/themes/theme822/css/boilerplate.css";s:13:"css/style.css";s:39:"sites/all/themes/theme822/css/style.css";s:24:"css/maintenance-page.css";s:50:"sites/all/themes/theme822/css/maintenance-page.css";s:16:"css/skeleton.css";s:42:"sites/all/themes/theme822/css/skeleton.css";}}s:7:"scripts";a:4:{s:19:"js/theme822.core.js";s:45:"sites/all/themes/theme822/js/theme822.core.js";s:19:"js/jquery.loader.js";s:45:"sites/all/themes/theme822/js/jquery.loader.js";s:28:"js/jquery.debouncedresize.js";s:54:"sites/all/themes/theme822/js/jquery.debouncedresize.js";s:23:"js/jquery.mobilemenu.js";s:49:"sites/all/themes/theme822/js/jquery.mobilemenu.js";}s:7:"regions";a:16:{s:10:"header_top";s:10:"Header top";s:6:"header";s:6:"Header";s:13:"header_bottom";s:13:"Header Bottom";s:4:"menu";s:4:"Menu";s:4:"help";s:4:"Help";s:11:"content_top";s:11:"Content top";s:7:"content";s:7:"Content";s:14:"content_bottom";s:14:"Content bottom";s:18:"sidebar_first_wide";s:18:"Sidebar first wide";s:20:"sidebar_first_narrow";s:20:"Sidebar first narrow";s:19:"sidebar_second_wide";s:19:"Sidebar second wide";s:21:"sidebar_second_narrow";s:21:"Sidebar second narrow";s:6:"footer";s:6:"Footer";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";s:11:"highlighted";s:11:"Highlighted";}s:8:"settings";a:8:{s:19:"theme822_feed_icons";s:1:"0";s:23:"theme822_clear_registry";s:1:"0";s:19:"theme822_tabs_float";s:1:"0";s:18:"theme822_tabs_node";s:1:"1";s:27:"theme822_breadcrumb_display";s:2:"no";s:33:"theme822_breadcrumb_hideonlyfront";s:1:"1";s:29:"theme822_breadcrumb_showtitle";s:1:"0";s:29:"theme822_breadcrumb_separator";s:2:"»";}s:7:"version";s:7:"7.x-1.0";s:7:"project";s:8:"theme822";s:9:"datestamp";s:10:"1320946536";s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:3:"php";s:5:"5.2.4";s:14:"regions_hidden";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}s:28:"overlay_supplemental_regions";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}}s:6:"prefix";s:11:"phptemplate";s:11:"stylesheets";a:1:{s:6:"screen";a:4:{s:19:"css/boilerplate.css";s:45:"sites/all/themes/theme822/css/boilerplate.css";s:13:"css/style.css";s:39:"sites/all/themes/theme822/css/style.css";s:24:"css/maintenance-page.css";s:50:"sites/all/themes/theme822/css/maintenance-page.css";s:16:"css/skeleton.css";s:42:"sites/all/themes/theme822/css/skeleton.css";}}s:7:"scripts";a:4:{s:19:"js/theme822.core.js";s:45:"sites/all/themes/theme822/js/theme822.core.js";s:19:"js/jquery.loader.js";s:45:"sites/all/themes/theme822/js/jquery.loader.js";s:28:"js/jquery.debouncedresize.js";s:54:"sites/all/themes/theme822/js/jquery.debouncedresize.js";s:23:"js/jquery.mobilemenu.js";s:49:"sites/all/themes/theme822/js/jquery.mobilemenu.js";}s:6:"engine";s:11:"phptemplate";}}', 'block_admin_demo', 'a:1:{i:0;s:8:"theme822";}', '', '31', 5, '0', '', 'admin/structure/block/demo/theme822', 'theme822', 't', '', '_block_custom_theme', 'a:1:{i:0;s:8:"theme822";}', '0', '', '', '0', 'modules/block/block.admin.inc');
INSERT INTO `menu_router` VALUES
('admin/structure/block/demo/tipsy', '', '', '_block_themes_access', 'a:1:{i:0;O:8:"stdClass":11:{s:8:"filename";s:33:"sites/all/themes/tipsy/tipsy.info";s:4:"name";s:5:"tipsy";s:4:"type";s:5:"theme";s:5:"owner";s:45:"themes/engines/phptemplate/phptemplate.engine";s:6:"status";s:1:"0";s:9:"bootstrap";s:1:"0";s:14:"schema_version";s:1:"0";s:6:"weight";s:3:"999";s:4:"info";a:16:{s:4:"name";s:14:"Tipsy tooltips";s:11:"description";s:141:"Integrates <a href="http://onehackoranother.com/projects/jquery/tipsy/">Tipsy</a> jQuery plugin for creating a Facebook-like tooltips effect.";s:4:"core";s:3:"7.x";s:9:"configure";s:33:"admin/config/user-interface/tipsy";s:7:"version";s:11:"7.x-1.0-rc1";s:7:"project";s:5:"tipsy";s:9:"datestamp";s:10:"1307366519";s:6:"engine";s:11:"phptemplate";s:7:"regions";a:9:{s:13:"sidebar_first";s:12:"Left sidebar";s:14:"sidebar_second";s:13:"Right sidebar";s:7:"content";s:7:"Content";s:6:"header";s:6:"Header";s:6:"footer";s:6:"Footer";s:11:"highlighted";s:11:"Highlighted";s:4:"help";s:4:"Help";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";}s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:10:"screenshot";s:37:"sites/all/themes/tipsy/screenshot.png";s:3:"php";s:5:"5.2.4";s:11:"stylesheets";a:0:{}s:7:"scripts";a:0:{}s:14:"regions_hidden";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}s:28:"overlay_supplemental_regions";a:1:{i:0;s:8:"page_top";}}s:6:"prefix";s:11:"phptemplate";s:6:"engine";s:11:"phptemplate";}}', 'block_admin_demo', 'a:1:{i:0;s:5:"tipsy";}', '', '31', 5, '0', '', 'admin/structure/block/demo/tipsy', 'Tipsy tooltips', 't', '', '_block_custom_theme', 'a:1:{i:0;s:5:"tipsy";}', '0', '', '', '0', 'modules/block/block.admin.inc'),
('admin/structure/block/list/bartik', '', '', '_block_themes_access', 'a:1:{i:0;O:8:"stdClass":12:{s:8:"filename";s:25:"themes/bartik/bartik.info";s:4:"name";s:6:"bartik";s:4:"type";s:5:"theme";s:5:"owner";s:45:"themes/engines/phptemplate/phptemplate.engine";s:6:"status";s:1:"1";s:9:"bootstrap";s:1:"0";s:14:"schema_version";s:2:"-1";s:6:"weight";s:1:"0";s:4:"info";a:17:{s:4:"name";s:6:"Bartik";s:11:"description";s:48:"A flexible, recolorable theme with many regions.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:11:"stylesheets";a:2:{s:3:"all";a:3:{s:14:"css/layout.css";s:28:"themes/bartik/css/layout.css";s:13:"css/style.css";s:27:"themes/bartik/css/style.css";s:14:"css/colors.css";s:28:"themes/bartik/css/colors.css";}s:5:"print";a:1:{s:13:"css/print.css";s:27:"themes/bartik/css/print.css";}}s:7:"regions";a:17:{s:6:"header";s:6:"Header";s:4:"help";s:4:"Help";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";s:11:"highlighted";s:11:"Highlighted";s:8:"featured";s:8:"Featured";s:7:"content";s:7:"Content";s:13:"sidebar_first";s:13:"Sidebar first";s:14:"sidebar_second";s:14:"Sidebar second";s:14:"triptych_first";s:14:"Triptych first";s:15:"triptych_middle";s:15:"Triptych middle";s:13:"triptych_last";s:13:"Triptych last";s:18:"footer_firstcolumn";s:19:"Footer first column";s:19:"footer_secondcolumn";s:20:"Footer second column";s:18:"footer_thirdcolumn";s:19:"Footer third column";s:19:"footer_fourthcolumn";s:20:"Footer fourth column";s:6:"footer";s:6:"Footer";}s:8:"settings";a:1:{s:20:"shortcut_module_link";s:1:"0";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:6:"engine";s:11:"phptemplate";s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:10:"screenshot";s:28:"themes/bartik/screenshot.png";s:3:"php";s:5:"5.2.4";s:7:"scripts";a:0:{}s:14:"regions_hidden";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}s:28:"overlay_supplemental_regions";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}}s:6:"prefix";s:11:"phptemplate";s:11:"stylesheets";a:2:{s:3:"all";a:3:{s:14:"css/layout.css";s:28:"themes/bartik/css/layout.css";s:13:"css/style.css";s:27:"themes/bartik/css/style.css";s:14:"css/colors.css";s:28:"themes/bartik/css/colors.css";}s:5:"print";a:1:{s:13:"css/print.css";s:27:"themes/bartik/css/print.css";}}s:6:"engine";s:11:"phptemplate";}}', 'block_admin_display', 'a:1:{i:0;s:6:"bartik";}', '', '31', 5, '1', 'admin/structure/block', 'admin/structure/block', 'Bartik', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/block/block.admin.inc'),
('admin/structure/block/list/bartik/add', '', '', 'user_access', 'a:1:{i:0;s:17:"administer blocks";}', 'drupal_get_form', 'a:1:{i:0;s:20:"block_add_block_form";}', '', '63', 6, '1', 'admin/structure/block/list/bartik', 'admin/structure/block', 'Add block', 't', '', '', 'a:0:{}', '388', '', '', '0', 'modules/block/block.admin.inc'),
('admin/structure/block/list/garland', '', '', '_block_themes_access', 'a:1:{i:0;O:8:"stdClass":12:{s:8:"filename";s:27:"themes/garland/garland.info";s:4:"name";s:7:"garland";s:4:"type";s:5:"theme";s:5:"owner";s:45:"themes/engines/phptemplate/phptemplate.engine";s:6:"status";s:1:"0";s:9:"bootstrap";s:1:"0";s:14:"schema_version";s:2:"-1";s:6:"weight";s:1:"0";s:4:"info";a:17:{s:4:"name";s:7:"Garland";s:11:"description";s:111:"A multi-column theme which can be configured to modify colors and switch between fixed and fluid width layouts.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:11:"stylesheets";a:2:{s:3:"all";a:1:{s:9:"style.css";s:24:"themes/garland/style.css";}s:5:"print";a:1:{s:9:"print.css";s:24:"themes/garland/print.css";}}s:8:"settings";a:1:{s:13:"garland_width";s:5:"fluid";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:6:"engine";s:11:"phptemplate";s:7:"regions";a:9:{s:13:"sidebar_first";s:12:"Left sidebar";s:14:"sidebar_second";s:13:"Right sidebar";s:7:"content";s:7:"Content";s:6:"header";s:6:"Header";s:6:"footer";s:6:"Footer";s:11:"highlighted";s:11:"Highlighted";s:4:"help";s:4:"Help";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";}s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:10:"screenshot";s:29:"themes/garland/screenshot.png";s:3:"php";s:5:"5.2.4";s:7:"scripts";a:0:{}s:14:"regions_hidden";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}s:28:"overlay_supplemental_regions";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}}s:6:"prefix";s:11:"phptemplate";s:11:"stylesheets";a:2:{s:3:"all";a:1:{s:9:"style.css";s:24:"themes/garland/style.css";}s:5:"print";a:1:{s:9:"print.css";s:24:"themes/garland/print.css";}}s:6:"engine";s:11:"phptemplate";}}', 'block_admin_display', 'a:1:{i:0;s:7:"garland";}', '', '31', 5, '1', 'admin/structure/block', 'admin/structure/block', 'Garland', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/block/block.admin.inc'),
('admin/structure/block/list/garland/add', '', '', 'user_access', 'a:1:{i:0;s:17:"administer blocks";}', 'drupal_get_form', 'a:1:{i:0;s:20:"block_add_block_form";}', '', '63', 6, '1', 'admin/structure/block/list/garland', 'admin/structure/block', 'Add block', 't', '', '', 'a:0:{}', '388', '', '', '0', 'modules/block/block.admin.inc'),
('admin/structure/block/list/seven', '', '', '_block_themes_access', 'a:1:{i:0;O:8:"stdClass":12:{s:8:"filename";s:23:"themes/seven/seven.info";s:4:"name";s:5:"seven";s:4:"type";s:5:"theme";s:5:"owner";s:45:"themes/engines/phptemplate/phptemplate.engine";s:6:"status";s:1:"1";s:9:"bootstrap";s:1:"0";s:14:"schema_version";s:2:"-1";s:6:"weight";s:1:"0";s:4:"info";a:17:{s:4:"name";s:5:"Seven";s:11:"description";s:65:"A simple one-column, tableless, fluid width administration theme.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:11:"stylesheets";a:1:{s:6:"screen";a:2:{s:9:"reset.css";s:22:"themes/seven/reset.css";s:9:"style.css";s:22:"themes/seven/style.css";}}s:8:"settings";a:1:{s:20:"shortcut_module_link";s:1:"1";}s:7:"regions";a:5:{s:7:"content";s:7:"Content";s:4:"help";s:4:"Help";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";s:13:"sidebar_first";s:13:"First sidebar";}s:14:"regions_hidden";a:3:{i:0;s:13:"sidebar_first";i:1;s:8:"page_top";i:2;s:11:"page_bottom";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:6:"engine";s:11:"phptemplate";s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:10:"screenshot";s:27:"themes/seven/screenshot.png";s:3:"php";s:5:"5.2.4";s:7:"scripts";a:0:{}s:28:"overlay_supplemental_regions";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}}s:6:"prefix";s:11:"phptemplate";s:11:"stylesheets";a:1:{s:6:"screen";a:2:{s:9:"reset.css";s:22:"themes/seven/reset.css";s:9:"style.css";s:22:"themes/seven/style.css";}}s:6:"engine";s:11:"phptemplate";}}', 'block_admin_display', 'a:1:{i:0;s:5:"seven";}', '', '31', 5, '1', 'admin/structure/block', 'admin/structure/block', 'Seven', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/block/block.admin.inc'),
('admin/structure/block/list/seven/add', '', '', 'user_access', 'a:1:{i:0;s:17:"administer blocks";}', 'drupal_get_form', 'a:1:{i:0;s:20:"block_add_block_form";}', '', '63', 6, '1', 'admin/structure/block/list/seven', 'admin/structure/block', 'Add block', 't', '', '', 'a:0:{}', '388', '', '', '0', 'modules/block/block.admin.inc'),
('admin/structure/block/list/stark', '', '', '_block_themes_access', 'a:1:{i:0;O:8:"stdClass":12:{s:8:"filename";s:23:"themes/stark/stark.info";s:4:"name";s:5:"stark";s:4:"type";s:5:"theme";s:5:"owner";s:45:"themes/engines/phptemplate/phptemplate.engine";s:6:"status";s:1:"0";s:9:"bootstrap";s:1:"0";s:14:"schema_version";s:2:"-1";s:6:"weight";s:1:"0";s:4:"info";a:16:{s:4:"name";s:5:"Stark";s:11:"description";s:208:"This theme demonstrates Drupal''s default HTML markup and CSS styles. To learn how to build your own theme and override Drupal''s default code, see the <a href="http://drupal.org/theme-guide">Theming Guide</a>.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:11:"stylesheets";a:1:{s:3:"all";a:1:{s:10:"layout.css";s:23:"themes/stark/layout.css";}}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:6:"engine";s:11:"phptemplate";s:7:"regions";a:9:{s:13:"sidebar_first";s:12:"Left sidebar";s:14:"sidebar_second";s:13:"Right sidebar";s:7:"content";s:7:"Content";s:6:"header";s:6:"Header";s:6:"footer";s:6:"Footer";s:11:"highlighted";s:11:"Highlighted";s:4:"help";s:4:"Help";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";}s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:10:"screenshot";s:27:"themes/stark/screenshot.png";s:3:"php";s:5:"5.2.4";s:7:"scripts";a:0:{}s:14:"regions_hidden";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}s:28:"overlay_supplemental_regions";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}}s:6:"prefix";s:11:"phptemplate";s:11:"stylesheets";a:1:{s:3:"all";a:1:{s:10:"layout.css";s:23:"themes/stark/layout.css";}}s:6:"engine";s:11:"phptemplate";}}', 'block_admin_display', 'a:1:{i:0;s:5:"stark";}', '', '31', 5, '1', 'admin/structure/block', 'admin/structure/block', 'Stark', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/block/block.admin.inc'),
('admin/structure/block/list/stark/add', '', '', 'user_access', 'a:1:{i:0;s:17:"administer blocks";}', 'drupal_get_form', 'a:1:{i:0;s:20:"block_add_block_form";}', '', '63', 6, '1', 'admin/structure/block/list/stark', 'admin/structure/block', 'Add block', 't', '', '', 'a:0:{}', '388', '', '', '0', 'modules/block/block.admin.inc'),
('admin/structure/block/list/theme822', '', '', '_block_themes_access', 'a:1:{i:0;O:8:"stdClass":13:{s:8:"filename";s:39:"sites/all/themes/theme822/theme822.info";s:4:"name";s:8:"theme822";s:4:"type";s:5:"theme";s:5:"owner";s:45:"themes/engines/phptemplate/phptemplate.engine";s:6:"status";s:1:"1";s:9:"bootstrap";s:1:"0";s:14:"schema_version";s:2:"-1";s:6:"weight";s:1:"0";s:4:"info";a:16:{s:4:"name";s:8:"theme822";s:11:"description";s:81:"This template is made by <a href="http://template-help.com">template-help.com</a>";s:10:"screenshot";s:40:"sites/all/themes/theme822/screenshot.png";s:4:"core";s:3:"7.x";s:6:"engine";s:11:"phptemplate";s:11:"stylesheets";a:1:{s:6:"screen";a:4:{s:19:"css/boilerplate.css";s:45:"sites/all/themes/theme822/css/boilerplate.css";s:13:"css/style.css";s:39:"sites/all/themes/theme822/css/style.css";s:24:"css/maintenance-page.css";s:50:"sites/all/themes/theme822/css/maintenance-page.css";s:16:"css/skeleton.css";s:42:"sites/all/themes/theme822/css/skeleton.css";}}s:7:"scripts";a:4:{s:19:"js/theme822.core.js";s:45:"sites/all/themes/theme822/js/theme822.core.js";s:19:"js/jquery.loader.js";s:45:"sites/all/themes/theme822/js/jquery.loader.js";s:28:"js/jquery.debouncedresize.js";s:54:"sites/all/themes/theme822/js/jquery.debouncedresize.js";s:23:"js/jquery.mobilemenu.js";s:49:"sites/all/themes/theme822/js/jquery.mobilemenu.js";}s:7:"regions";a:16:{s:10:"header_top";s:10:"Header top";s:6:"header";s:6:"Header";s:13:"header_bottom";s:13:"Header Bottom";s:4:"menu";s:4:"Menu";s:4:"help";s:4:"Help";s:11:"content_top";s:11:"Content top";s:7:"content";s:7:"Content";s:14:"content_bottom";s:14:"Content bottom";s:18:"sidebar_first_wide";s:18:"Sidebar first wide";s:20:"sidebar_first_narrow";s:20:"Sidebar first narrow";s:19:"sidebar_second_wide";s:19:"Sidebar second wide";s:21:"sidebar_second_narrow";s:21:"Sidebar second narrow";s:6:"footer";s:6:"Footer";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";s:11:"highlighted";s:11:"Highlighted";}s:8:"settings";a:8:{s:19:"theme822_feed_icons";s:1:"0";s:23:"theme822_clear_registry";s:1:"0";s:19:"theme822_tabs_float";s:1:"0";s:18:"theme822_tabs_node";s:1:"1";s:27:"theme822_breadcrumb_display";s:2:"no";s:33:"theme822_breadcrumb_hideonlyfront";s:1:"1";s:29:"theme822_breadcrumb_showtitle";s:1:"0";s:29:"theme822_breadcrumb_separator";s:2:"»";}s:7:"version";s:7:"7.x-1.0";s:7:"project";s:8:"theme822";s:9:"datestamp";s:10:"1320946536";s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:3:"php";s:5:"5.2.4";s:14:"regions_hidden";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}s:28:"overlay_supplemental_regions";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}}s:6:"prefix";s:11:"phptemplate";s:11:"stylesheets";a:1:{s:6:"screen";a:4:{s:19:"css/boilerplate.css";s:45:"sites/all/themes/theme822/css/boilerplate.css";s:13:"css/style.css";s:39:"sites/all/themes/theme822/css/style.css";s:24:"css/maintenance-page.css";s:50:"sites/all/themes/theme822/css/maintenance-page.css";s:16:"css/skeleton.css";s:42:"sites/all/themes/theme822/css/skeleton.css";}}s:7:"scripts";a:4:{s:19:"js/theme822.core.js";s:45:"sites/all/themes/theme822/js/theme822.core.js";s:19:"js/jquery.loader.js";s:45:"sites/all/themes/theme822/js/jquery.loader.js";s:28:"js/jquery.debouncedresize.js";s:54:"sites/all/themes/theme822/js/jquery.debouncedresize.js";s:23:"js/jquery.mobilemenu.js";s:49:"sites/all/themes/theme822/js/jquery.mobilemenu.js";}s:6:"engine";s:11:"phptemplate";}}', 'block_admin_display', 'a:1:{i:0;s:8:"theme822";}', '', '31', 5, '1', 'admin/structure/block', 'admin/structure/block', 'theme822', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'modules/block/block.admin.inc'),
('admin/structure/block/list/tipsy', '', '', '_block_themes_access', 'a:1:{i:0;O:8:"stdClass":11:{s:8:"filename";s:33:"sites/all/themes/tipsy/tipsy.info";s:4:"name";s:5:"tipsy";s:4:"type";s:5:"theme";s:5:"owner";s:45:"themes/engines/phptemplate/phptemplate.engine";s:6:"status";s:1:"0";s:9:"bootstrap";s:1:"0";s:14:"schema_version";s:1:"0";s:6:"weight";s:3:"999";s:4:"info";a:16:{s:4:"name";s:14:"Tipsy tooltips";s:11:"description";s:141:"Integrates <a href="http://onehackoranother.com/projects/jquery/tipsy/">Tipsy</a> jQuery plugin for creating a Facebook-like tooltips effect.";s:4:"core";s:3:"7.x";s:9:"configure";s:33:"admin/config/user-interface/tipsy";s:7:"version";s:11:"7.x-1.0-rc1";s:7:"project";s:5:"tipsy";s:9:"datestamp";s:10:"1307366519";s:6:"engine";s:11:"phptemplate";s:7:"regions";a:9:{s:13:"sidebar_first";s:12:"Left sidebar";s:14:"sidebar_second";s:13:"Right sidebar";s:7:"content";s:7:"Content";s:6:"header";s:6:"Header";s:6:"footer";s:6:"Footer";s:11:"highlighted";s:11:"Highlighted";s:4:"help";s:4:"Help";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";}s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:10:"screenshot";s:37:"sites/all/themes/tipsy/screenshot.png";s:3:"php";s:5:"5.2.4";s:11:"stylesheets";a:0:{}s:7:"scripts";a:0:{}s:14:"regions_hidden";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}s:28:"overlay_supplemental_regions";a:1:{i:0;s:8:"page_top";}}s:6:"prefix";s:11:"phptemplate";s:6:"engine";s:11:"phptemplate";}}', 'block_admin_display', 'a:1:{i:0;s:5:"tipsy";}', '', '31', 5, '1', 'admin/structure/block', 'admin/structure/block', 'Tipsy tooltips', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/block/block.admin.inc'),
('admin/structure/block/list/tipsy/add', '', '', 'user_access', 'a:1:{i:0;s:17:"administer blocks";}', 'drupal_get_form', 'a:1:{i:0;s:20:"block_add_block_form";}', '', '63', 6, '1', 'admin/structure/block/list/tipsy', 'admin/structure/block', 'Add block', 't', '', '', 'a:0:{}', '388', '', '', '0', 'modules/block/block.admin.inc'),
('admin/structure/block/manage/%/%', 'a:2:{i:4;N;i:5;N;}', '', 'user_access', 'a:1:{i:0;s:17:"administer blocks";}', 'drupal_get_form', 'a:3:{i:0;s:21:"block_admin_configure";i:1;i:4;i:2;i:5;}', '', '60', 6, '0', '', 'admin/structure/block/manage/%/%', 'Configure block', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/block/block.admin.inc'),
('admin/structure/block/manage/%/%/configure', 'a:2:{i:4;N;i:5;N;}', '', 'user_access', 'a:1:{i:0;s:17:"administer blocks";}', 'drupal_get_form', 'a:3:{i:0;s:21:"block_admin_configure";i:1;i:4;i:2;i:5;}', '', '121', 7, '2', 'admin/structure/block/manage/%/%', 'admin/structure/block/manage/%/%', 'Configure block', 't', '', '', 'a:0:{}', '140', '', '', '0', 'modules/block/block.admin.inc'),
('admin/structure/block/manage/%/%/delete', 'a:2:{i:4;N;i:5;N;}', '', 'user_access', 'a:1:{i:0;s:17:"administer blocks";}', 'drupal_get_form', 'a:3:{i:0;s:25:"block_custom_block_delete";i:1;i:4;i:2;i:5;}', '', '121', 7, '0', 'admin/structure/block/manage/%/%', 'admin/structure/block/manage/%/%', 'Delete block', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/block/block.admin.inc'),
('admin/structure/contact', '', '', 'user_access', 'a:1:{i:0;s:24:"administer contact forms";}', 'contact_category_list', 'a:0:{}', '', '7', 3, '0', '', 'admin/structure/contact', 'Contact form', 't', '', '', 'a:0:{}', '6', 'Create a system contact form and set up categories for the form to use.', '', '0', 'modules/contact/contact.admin.inc'),
('admin/structure/contact/add', '', '', 'user_access', 'a:1:{i:0;s:24:"administer contact forms";}', 'drupal_get_form', 'a:1:{i:0;s:26:"contact_category_edit_form";}', '', '15', 4, '1', 'admin/structure/contact', 'admin/structure/contact', 'Add category', 't', '', '', 'a:0:{}', '388', '', '', '1', 'modules/contact/contact.admin.inc'),
('admin/structure/contact/delete/%', 'a:1:{i:4;s:12:"contact_load";}', '', 'user_access', 'a:1:{i:0;s:24:"administer contact forms";}', 'drupal_get_form', 'a:2:{i:0;s:28:"contact_category_delete_form";i:1;i:4;}', '', '30', 5, '0', '', 'admin/structure/contact/delete/%', 'Delete contact', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/contact/contact.admin.inc'),
('admin/structure/contact/edit/%', 'a:1:{i:4;s:12:"contact_load";}', '', 'user_access', 'a:1:{i:0;s:24:"administer contact forms";}', 'drupal_get_form', 'a:2:{i:0;s:26:"contact_category_edit_form";i:1;i:4;}', '', '30', 5, '0', '', 'admin/structure/contact/edit/%', 'Edit contact category', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/contact/contact.admin.inc'),
('admin/structure/demo', '', '', 'user_access', 'a:1:{i:0;s:24:"administer demo settings";}', 'drupal_get_form', 'a:1:{i:0;s:16:"demo_manage_form";}', '', '7', 3, '0', '', 'admin/structure/demo', 'Snapshots', 't', '', '', 'a:0:{}', '6', 'Create snapshots and reset the site.', '', '0', 'sites/all/modules/demo/demo.admin.inc'),
('admin/structure/demo/delete/%', 'a:1:{i:4;N;}', '', 'user_access', 'a:1:{i:0;s:24:"administer demo settings";}', 'drupal_get_form', 'a:2:{i:0;s:19:"demo_delete_confirm";i:1;i:4;}', '', '30', 5, '0', '', 'admin/structure/demo/delete/%', 'Delete snapshot', 't', '', '', 'a:0:{}', '4', '', '', '0', 'sites/all/modules/demo/demo.admin.inc'),
('admin/structure/demo/dump', '', '', 'user_access', 'a:1:{i:0;s:24:"administer demo settings";}', 'drupal_get_form', 'a:1:{i:0;s:14:"demo_dump_form";}', '', '15', 4, '1', 'admin/structure/demo', 'admin/structure/demo', 'Create snapshot', 't', '', '', 'a:0:{}', '388', '', '', '0', 'sites/all/modules/demo/demo.admin.inc'),
('admin/structure/demo/list', '', '', 'user_access', 'a:1:{i:0;s:24:"administer demo settings";}', 'drupal_get_form', 'a:1:{i:0;s:16:"demo_manage_form";}', '', '15', 4, '1', 'admin/structure/demo', 'admin/structure/demo', 'List', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'sites/all/modules/demo/demo.admin.inc'),
('admin/structure/demo/reset', '', '', 'user_access', 'a:1:{i:0;s:24:"administer demo settings";}', 'drupal_get_form', 'a:1:{i:0;s:18:"demo_reset_confirm";}', '', '15', 4, '1', 'admin/structure/demo', 'admin/structure/demo', 'Reset', 't', '', '', 'a:0:{}', '132', '', '', '3', 'sites/all/modules/demo/demo.admin.inc'),
('admin/structure/demo/settings', '', '', 'user_access', 'a:1:{i:0;s:24:"administer demo settings";}', 'drupal_get_form', 'a:1:{i:0;s:19:"demo_admin_settings";}', '', '15', 4, '1', 'admin/structure/demo', 'admin/structure/demo', 'Settings', 't', '', '', 'a:0:{}', '132', '', '', '10', 'sites/all/modules/demo/demo.admin.inc'),
('admin/structure/forum', '', '', 'user_access', 'a:1:{i:0;s:17:"administer forums";}', 'drupal_get_form', 'a:1:{i:0;s:14:"forum_overview";}', '', '7', 3, '0', '', 'admin/structure/forum', 'Forums', 't', '', '', 'a:0:{}', '6', 'Control forum hierarchy settings.', '', '0', 'modules/forum/forum.admin.inc'),
('admin/structure/forum/add/container', '', '', 'user_access', 'a:1:{i:0;s:17:"administer forums";}', 'forum_form_main', 'a:1:{i:0;s:9:"container";}', '', '31', 5, '1', 'admin/structure/forum', 'admin/structure/forum', 'Add container', 't', '', '', 'a:0:{}', '388', '', '', '0', 'modules/forum/forum.admin.inc'),
('admin/structure/forum/add/forum', '', '', 'user_access', 'a:1:{i:0;s:17:"administer forums";}', 'forum_form_main', 'a:1:{i:0;s:5:"forum";}', '', '31', 5, '1', 'admin/structure/forum', 'admin/structure/forum', 'Add forum', 't', '', '', 'a:0:{}', '388', '', '', '0', 'modules/forum/forum.admin.inc'),
('admin/structure/forum/edit/container/%', 'a:1:{i:5;s:18:"taxonomy_term_load";}', '', 'user_access', 'a:1:{i:0;s:17:"administer forums";}', 'forum_form_main', 'a:2:{i:0;s:9:"container";i:1;i:5;}', '', '62', 6, '0', '', 'admin/structure/forum/edit/container/%', 'Edit container', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/forum/forum.admin.inc'),
('admin/structure/forum/edit/forum/%', 'a:1:{i:5;s:18:"taxonomy_term_load";}', '', 'user_access', 'a:1:{i:0;s:17:"administer forums";}', 'forum_form_main', 'a:2:{i:0;s:5:"forum";i:1;i:5;}', '', '62', 6, '0', '', 'admin/structure/forum/edit/forum/%', 'Edit forum', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/forum/forum.admin.inc'),
('admin/structure/forum/list', '', '', 'user_access', 'a:1:{i:0;s:17:"administer forums";}', 'drupal_get_form', 'a:1:{i:0;s:14:"forum_overview";}', '', '15', 4, '1', 'admin/structure/forum', 'admin/structure/forum', 'List', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'modules/forum/forum.admin.inc'),
('admin/structure/forum/settings', '', '', 'user_access', 'a:1:{i:0;s:17:"administer forums";}', 'drupal_get_form', 'a:1:{i:0;s:20:"forum_admin_settings";}', '', '15', 4, '1', 'admin/structure/forum', 'admin/structure/forum', 'Settings', 't', '', '', 'a:0:{}', '132', '', '', '5', 'modules/forum/forum.admin.inc'),
('admin/structure/menu', '', '', 'user_access', 'a:1:{i:0;s:15:"administer menu";}', 'menu_overview_page', 'a:0:{}', '', '7', 3, '0', '', 'admin/structure/menu', 'Menus', 't', '', '', 'a:0:{}', '6', 'Add new menus to your site, edit existing menus, and rename and reorganize menu links.', '', '0', 'modules/menu/menu.admin.inc'),
('admin/structure/menu/add', '', '', 'user_access', 'a:1:{i:0;s:15:"administer menu";}', 'drupal_get_form', 'a:2:{i:0;s:14:"menu_edit_menu";i:1;s:3:"add";}', '', '15', 4, '1', 'admin/structure/menu', 'admin/structure/menu', 'Add menu', 't', '', '', 'a:0:{}', '388', '', '', '0', 'modules/menu/menu.admin.inc'),
('admin/structure/menu/item/%/delete', 'a:1:{i:4;s:14:"menu_link_load";}', '', 'user_access', 'a:1:{i:0;s:15:"administer menu";}', 'menu_item_delete_page', 'a:1:{i:0;i:4;}', '', '61', 6, '0', '', 'admin/structure/menu/item/%/delete', 'Delete menu link', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/menu/menu.admin.inc'),
('admin/structure/menu/item/%/edit', 'a:1:{i:4;s:14:"menu_link_load";}', '', 'user_access', 'a:1:{i:0;s:15:"administer menu";}', 'drupal_get_form', 'a:4:{i:0;s:14:"menu_edit_item";i:1;s:4:"edit";i:2;i:4;i:3;N;}', '', '61', 6, '0', '', 'admin/structure/menu/item/%/edit', 'Edit menu link', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/menu/menu.admin.inc'),
('admin/structure/menu/item/%/reset', 'a:1:{i:4;s:14:"menu_link_load";}', '', 'user_access', 'a:1:{i:0;s:15:"administer menu";}', 'drupal_get_form', 'a:2:{i:0;s:23:"menu_reset_item_confirm";i:1;i:4;}', '', '61', 6, '0', '', 'admin/structure/menu/item/%/reset', 'Reset menu link', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/menu/menu.admin.inc'),
('admin/structure/menu/list', '', '', 'user_access', 'a:1:{i:0;s:15:"administer menu";}', 'menu_overview_page', 'a:0:{}', '', '15', 4, '1', 'admin/structure/menu', 'admin/structure/menu', 'List menus', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'modules/menu/menu.admin.inc'),
('admin/structure/menu/manage/%', 'a:1:{i:4;s:9:"menu_load";}', '', 'user_access', 'a:1:{i:0;s:15:"administer menu";}', 'drupal_get_form', 'a:2:{i:0;s:18:"menu_overview_form";i:1;i:4;}', '', '30', 5, '0', '', 'admin/structure/menu/manage/%', 'Customize menu', 'menu_overview_title', 'a:1:{i:0;i:4;}', '', 'a:0:{}', '6', '', '', '0', 'modules/menu/menu.admin.inc'),
('admin/structure/menu/manage/%/add', 'a:1:{i:4;s:9:"menu_load";}', '', 'user_access', 'a:1:{i:0;s:15:"administer menu";}', 'drupal_get_form', 'a:4:{i:0;s:14:"menu_edit_item";i:1;s:3:"add";i:2;N;i:3;i:4;}', '', '61', 6, '1', 'admin/structure/menu/manage/%', 'admin/structure/menu/manage/%', 'Add link', 't', '', '', 'a:0:{}', '388', '', '', '0', 'modules/menu/menu.admin.inc'),
('admin/structure/menu/manage/%/delete', 'a:1:{i:4;s:9:"menu_load";}', '', 'user_access', 'a:1:{i:0;s:15:"administer menu";}', 'menu_delete_menu_page', 'a:1:{i:0;i:4;}', '', '61', 6, '0', '', 'admin/structure/menu/manage/%/delete', 'Delete menu', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/menu/menu.admin.inc'),
('admin/structure/menu/manage/%/edit', 'a:1:{i:4;s:9:"menu_load";}', '', 'user_access', 'a:1:{i:0;s:15:"administer menu";}', 'drupal_get_form', 'a:3:{i:0;s:14:"menu_edit_menu";i:1;s:4:"edit";i:2;i:4;}', '', '61', 6, '3', 'admin/structure/menu/manage/%', 'admin/structure/menu/manage/%', 'Edit menu', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/menu/menu.admin.inc'),
('admin/structure/menu/manage/%/list', 'a:1:{i:4;s:9:"menu_load";}', '', 'user_access', 'a:1:{i:0;s:15:"administer menu";}', 'drupal_get_form', 'a:2:{i:0;s:18:"menu_overview_form";i:1;i:4;}', '', '61', 6, '3', 'admin/structure/menu/manage/%', 'admin/structure/menu/manage/%', 'List links', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'modules/menu/menu.admin.inc'),
('admin/structure/menu/parents', '', '', 'user_access', 'a:1:{i:0;b:1;}', 'menu_parent_options_js', 'a:0:{}', '', '15', 4, '0', '', 'admin/structure/menu/parents', 'Parent menu items', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('admin/structure/menu/settings', '', '', 'user_access', 'a:1:{i:0;s:15:"administer menu";}', 'drupal_get_form', 'a:1:{i:0;s:14:"menu_configure";}', '', '15', 4, '1', 'admin/structure/menu', 'admin/structure/menu', 'Settings', 't', '', '', 'a:0:{}', '132', '', '', '5', 'modules/menu/menu.admin.inc'),
('admin/structure/mini-panels', '', '', 'ctools_export_ui_task_access', 'a:2:{i:0;s:11:"panels_mini";i:1;s:4:"list";}', 'ctools_export_ui_switcher_page', 'a:2:{i:0;s:11:"panels_mini";i:1;s:4:"list";}', '', '7', 3, '0', '', 'admin/structure/mini-panels', 'Mini panels', 't', '', '', 'a:0:{}', '6', 'Add, edit or delete mini panels, which can be used as blocks or content panes in other panels.', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/mini-panels/add', '', '', 'ctools_export_ui_task_access', 'a:2:{i:0;s:11:"panels_mini";i:1;s:3:"add";}', 'ctools_export_ui_switcher_page', 'a:2:{i:0;s:11:"panels_mini";i:1;s:3:"add";}', '', '15', 4, '1', 'admin/structure/mini-panels', 'admin/structure/mini-panels', 'Add', 't', '', '', 'a:0:{}', '388', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/mini-panels/import', '', '', 'ctools_export_ui_task_access', 'a:2:{i:0;s:11:"panels_mini";i:1;s:6:"import";}', 'ctools_export_ui_switcher_page', 'a:2:{i:0;s:11:"panels_mini";i:1;s:6:"import";}', '', '15', 4, '1', 'admin/structure/mini-panels', 'admin/structure/mini-panels', 'Import', 't', '', '', 'a:0:{}', '388', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/mini-panels/list', '', '', 'ctools_export_ui_task_access', 'a:2:{i:0;s:11:"panels_mini";i:1;s:4:"list";}', 'ctools_export_ui_switcher_page', 'a:2:{i:0;s:11:"panels_mini";i:1;s:4:"list";}', '', '15', 4, '1', 'admin/structure/mini-panels', 'admin/structure/mini-panels', 'List', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/mini-panels/list/%', 'a:1:{i:4;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:11:"panels_mini";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:11:"panels_mini";i:1;s:4:"edit";i:2;i:4;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:11:"panels_mini";i:1;s:4:"edit";i:2;i:4;}', '', '30', 5, '0', '', 'admin/structure/mini-panels/list/%', '', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/mini-panels/list/%/clone', 'a:1:{i:4;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:11:"panels_mini";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:11:"panels_mini";i:1;s:5:"clone";i:2;i:4;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:11:"panels_mini";i:1;s:5:"clone";i:2;i:4;}', '', '61', 6, '0', '', 'admin/structure/mini-panels/list/%/clone', 'Clone', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/mini-panels/list/%/delete', 'a:1:{i:4;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:11:"panels_mini";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:11:"panels_mini";i:1;s:6:"delete";i:2;i:4;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:11:"panels_mini";i:1;s:6:"delete";i:2;i:4;}', '', '61', 6, '0', '', 'admin/structure/mini-panels/list/%/delete', 'Delete', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/mini-panels/list/%/disable', 'a:1:{i:4;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:11:"panels_mini";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:11:"panels_mini";i:1;s:7:"disable";i:2;i:4;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:11:"panels_mini";i:1;s:7:"disable";i:2;i:4;}', '', '61', 6, '0', '', 'admin/structure/mini-panels/list/%/disable', 'Disable', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/mini-panels/list/%/edit', 'a:1:{i:4;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:11:"panels_mini";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:11:"panels_mini";i:1;s:4:"edit";i:2;i:4;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:11:"panels_mini";i:1;s:4:"edit";i:2;i:4;}', '', '61', 6, '1', 'admin/structure/mini-panels/list/%', 'admin/structure/mini-panels/list/%', 'Edit', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/mini-panels/list/%/enable', 'a:1:{i:4;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:11:"panels_mini";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:11:"panels_mini";i:1;s:6:"enable";i:2;i:4;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:11:"panels_mini";i:1;s:6:"enable";i:2;i:4;}', '', '61', 6, '0', '', 'admin/structure/mini-panels/list/%/enable', 'Enable', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/mini-panels/list/%/export', 'a:1:{i:4;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:11:"panels_mini";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:11:"panels_mini";i:1;s:6:"export";i:2;i:4;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:11:"panels_mini";i:1;s:6:"export";i:2;i:4;}', '', '61', 6, '1', 'admin/structure/mini-panels/list/%', 'admin/structure/mini-panels/list/%', 'Export', 't', '', '', 'a:0:{}', '132', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/mini-panels/list/%/revert', 'a:1:{i:4;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:11:"panels_mini";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:11:"panels_mini";i:1;s:6:"revert";i:2;i:4;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:11:"panels_mini";i:1;s:6:"delete";i:2;i:4;}', '', '61', 6, '0', '', 'admin/structure/mini-panels/list/%/revert', 'Revert', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/mini-panels/settings', '', '', 'user_access', 'a:1:{i:0;s:18:"create mini panels";}', 'panels_mini_settings', 'a:0:{}', '', '15', 4, '1', 'admin/structure/mini-panels', 'admin/structure/mini-panels', 'Settings', 't', '', '', 'a:0:{}', '132', '', '', '0', ''),
('admin/structure/pages', '', '', 'user_access', 'a:1:{i:0;s:16:"use page manager";}', 'page_manager_list_page', 'a:0:{}', '', '7', 3, '0', '', 'admin/structure/pages', 'Pages', 't', '', 'ajax_base_page_theme', 'a:0:{}', '6', 'Add, edit and remove overridden system pages and user defined pages from the system.', '', '0', 'sites/all/modules/ctools/page_manager/page_manager.admin.inc'),
('admin/structure/pages/%/disable/%', 'a:2:{i:3;s:14:"ctools_js_load";i:5;s:23:"page_manager_cache_load";}', '', 'user_access', 'a:1:{i:0;s:16:"use page manager";}', 'page_manager_enable_page', 'a:3:{i:0;b:1;i:1;i:3;i:2;i:5;}', '', '58', 6, '0', '', 'admin/structure/pages/%/disable/%', '', 't', '', 'ajax_base_page_theme', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/page_manager/page_manager.admin.inc'),
('admin/structure/pages/%/enable/%', 'a:2:{i:3;s:14:"ctools_js_load";i:5;s:23:"page_manager_cache_load";}', '', 'user_access', 'a:1:{i:0;s:16:"use page manager";}', 'page_manager_enable_page', 'a:3:{i:0;b:0;i:1;i:3;i:2;i:5;}', '', '58', 6, '0', '', 'admin/structure/pages/%/enable/%', '', 't', '', 'ajax_base_page_theme', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/page_manager/page_manager.admin.inc'),
('admin/structure/pages/%/operation/%', 'a:2:{i:3;s:14:"ctools_js_load";i:5;s:23:"page_manager_cache_load";}', '', 'user_access', 'a:1:{i:0;s:16:"use page manager";}', 'page_manager_edit_page_operation', 'a:2:{i:0;i:3;i:1;i:5;}', '', '58', 6, '0', '', 'admin/structure/pages/%/operation/%', '', 't', '', 'ajax_base_page_theme', 'a:0:{}', '6', '', '', '0', 'sites/all/modules/ctools/page_manager/page_manager.admin.inc'),
('admin/structure/pages/add', '', '', 'user_access', 'a:1:{i:0;s:23:"administer page manager";}', 'page_manager_page_add_subtask', 'a:0:{}', '', '15', 4, '1', 'admin/structure/pages', 'admin/structure/pages', 'Add custom page', 't', '', 'ajax_base_page_theme', 'a:0:{}', '388', '', '', '0', 'sites/all/modules/ctools/page_manager/plugins/tasks/page.admin.inc'),
('admin/structure/pages/argument', '', '', 'user_access', 'a:1:{i:0;s:23:"administer page manager";}', 'page_manager_page_subtask_argument_ajax', 'a:0:{}', '', '15', 4, '0', '', 'admin/structure/pages/argument', '', 't', '', 'ajax_base_page_theme', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/page_manager/plugins/tasks/page.admin.inc'),
('admin/structure/pages/edit/%', 'a:1:{i:4;s:23:"page_manager_cache_load";}', '', 'user_access', 'a:1:{i:0;s:16:"use page manager";}', 'page_manager_edit_page', 'a:1:{i:0;i:4;}', '', '30', 5, '0', '', 'admin/structure/pages/edit/%', 'Edit', 't', '', 'ajax_base_page_theme', 'a:0:{}', '6', '', '', '0', 'sites/all/modules/ctools/page_manager/page_manager.admin.inc'),
('admin/structure/pages/import', '', '', 'ctools_access_multiperm', 'a:2:{i:0;s:23:"administer page manager";i:1;s:20:"use PHP for settings";}', 'drupal_get_form', 'a:2:{i:0;s:32:"page_manager_page_import_subtask";i:1;s:4:"page";}', '', '15', 4, '1', 'admin/structure/pages', 'admin/structure/pages', 'Import page', 't', '', 'ajax_base_page_theme', 'a:0:{}', '388', '', '', '0', 'sites/all/modules/ctools/page_manager/plugins/tasks/page.admin.inc'),
('admin/structure/pages/list', '', '', 'user_access', 'a:1:{i:0;s:16:"use page manager";}', 'page_manager_list_page', 'a:0:{}', '', '15', 4, '1', 'admin/structure/pages', 'admin/structure/pages', 'List', 't', '', 'ajax_base_page_theme', 'a:0:{}', '140', '', '', '-10', 'sites/all/modules/ctools/page_manager/page_manager.admin.inc'),
('admin/structure/pages/wizard', '', '', 'user_access', 'a:1:{i:0;s:16:"use page manager";}', 'page_manager_page_wizard_list', 'a:1:{i:0;i:4;}', '', '15', 4, '1', 'admin/structure/pages', 'admin/structure/pages', 'Wizards', 't', '', 'ajax_base_page_theme', 'a:0:{}', '132', '', '', '-5', 'sites/all/modules/ctools/includes/page-wizard.inc'),
('admin/structure/pages/wizard/%', 'a:1:{i:4;N;}', '', 'user_access', 'a:1:{i:0;s:16:"use page manager";}', 'page_manager_page_wizard', 'a:1:{i:0;i:4;}', '', '30', 5, '0', '', 'admin/structure/pages/wizard/%', 'Wizard', 't', '', 'ajax_base_page_theme', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/page-wizard.inc'),
('admin/structure/panels', '', '', 'user_access', 'a:1:{i:0;s:20:"use panels dashboard";}', 'panels_admin_page', 'a:0:{}', '', '7', 3, '0', '', 'admin/structure/panels', 'Panels', 't', '', '', 'a:0:{}', '6', 'Get a bird''s eye view of items related to Panels.', '', '0', 'sites/all/modules/panels/includes/callbacks.inc'),
('admin/structure/panels/dashboard', '', '', 'user_access', 'a:1:{i:0;s:20:"use panels dashboard";}', 'panels_admin_page', 'a:0:{}', '', '15', 4, '1', 'admin/structure/panels', 'admin/structure/panels', 'Dashboard', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'sites/all/modules/panels/includes/callbacks.inc'),
('admin/structure/panels/layouts', '', '', 'ctools_export_ui_task_access', 'a:2:{i:0;s:14:"panels_layouts";i:1;s:4:"list";}', 'ctools_export_ui_switcher_page', 'a:2:{i:0;s:14:"panels_layouts";i:1;s:4:"list";}', '', '15', 4, '1', 'admin/structure/panels', 'admin/structure/panels', 'Layouts', 't', '', '', 'a:0:{}', '132', 'Add, edit or delete custom content layouts.', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/panels/layouts/add-flexible', '', '', 'ctools_export_ui_task_access', 'a:2:{i:0;s:14:"panels_layouts";i:1;s:3:"add";}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:14:"panels_layouts";i:1;s:3:"add";i:2;s:8:"flexible";}', '', '31', 5, '1', 'admin/structure/panels/layouts', 'admin/structure/panels', 'Add flexible layout', 't', '', '', 'a:0:{}', '388', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/panels/layouts/import', '', '', 'ctools_export_ui_task_access', 'a:2:{i:0;s:14:"panels_layouts";i:1;s:6:"import";}', 'ctools_export_ui_switcher_page', 'a:2:{i:0;s:14:"panels_layouts";i:1;s:6:"import";}', '', '31', 5, '1', 'admin/structure/panels/layouts', 'admin/structure/panels', 'Import', 't', '', '', 'a:0:{}', '388', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/panels/layouts/list', '', '', 'ctools_export_ui_task_access', 'a:2:{i:0;s:14:"panels_layouts";i:1;s:4:"list";}', 'ctools_export_ui_switcher_page', 'a:2:{i:0;s:14:"panels_layouts";i:1;s:4:"list";}', '', '31', 5, '1', 'admin/structure/panels/layouts', 'admin/structure/panels', 'List', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/panels/layouts/list/%', 'a:1:{i:5;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:14:"panels_layouts";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:14:"panels_layouts";i:1;s:4:"edit";i:2;i:5;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:14:"panels_layouts";i:1;s:4:"edit";i:2;i:5;}', '', '62', 6, '0', '', 'admin/structure/panels/layouts/list/%', '', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/panels/layouts/list/%/clone', 'a:1:{i:5;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:14:"panels_layouts";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:14:"panels_layouts";i:1;s:5:"clone";i:2;i:5;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:14:"panels_layouts";i:1;s:5:"clone";i:2;i:5;}', '', '125', 7, '0', '', 'admin/structure/panels/layouts/list/%/clone', 'Clone', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/panels/layouts/list/%/delete', 'a:1:{i:5;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:14:"panels_layouts";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:14:"panels_layouts";i:1;s:6:"delete";i:2;i:5;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:14:"panels_layouts";i:1;s:6:"delete";i:2;i:5;}', '', '125', 7, '0', '', 'admin/structure/panels/layouts/list/%/delete', 'Delete', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/panels/layouts/list/%/disable', 'a:1:{i:5;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:14:"panels_layouts";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:14:"panels_layouts";i:1;s:7:"disable";i:2;i:5;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:14:"panels_layouts";i:1;s:7:"disable";i:2;i:5;}', '', '125', 7, '0', '', 'admin/structure/panels/layouts/list/%/disable', 'Disable', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/panels/layouts/list/%/edit', 'a:1:{i:5;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:14:"panels_layouts";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:14:"panels_layouts";i:1;s:4:"edit";i:2;i:5;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:14:"panels_layouts";i:1;s:4:"edit";i:2;i:5;}', '', '125', 7, '1', 'admin/structure/panels/layouts/list/%', 'admin/structure/panels/layouts/list/%', 'Edit', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/panels/layouts/list/%/enable', 'a:1:{i:5;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:14:"panels_layouts";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:14:"panels_layouts";i:1;s:6:"enable";i:2;i:5;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:14:"panels_layouts";i:1;s:6:"enable";i:2;i:5;}', '', '125', 7, '0', '', 'admin/structure/panels/layouts/list/%/enable', 'Enable', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/panels/layouts/list/%/export', 'a:1:{i:5;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:14:"panels_layouts";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:14:"panels_layouts";i:1;s:6:"export";i:2;i:5;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:14:"panels_layouts";i:1;s:6:"export";i:2;i:5;}', '', '125', 7, '1', 'admin/structure/panels/layouts/list/%', 'admin/structure/panels/layouts/list/%', 'Export', 't', '', '', 'a:0:{}', '132', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/panels/layouts/list/%/revert', 'a:1:{i:5;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:14:"panels_layouts";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:14:"panels_layouts";i:1;s:6:"revert";i:2;i:5;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:14:"panels_layouts";i:1;s:6:"delete";i:2;i:5;}', '', '125', 7, '0', '', 'admin/structure/panels/layouts/list/%/revert', 'Revert', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/panels/settings', '', '', 'user_access', 'a:1:{i:0;s:20:"use panels dashboard";}', 'drupal_get_form', 'a:1:{i:0;s:26:"panels_admin_settings_page";}', '', '15', 4, '1', 'admin/structure/panels', 'admin/structure/panels', 'Settings', 't', '', '', 'a:0:{}', '132', '', '', '0', 'sites/all/modules/panels/includes/callbacks.inc'),
('admin/structure/panels/settings/general', '', '', 'user_access', 'a:1:{i:0;s:23:"administer page manager";}', 'drupal_get_form', 'a:1:{i:0;s:26:"panels_admin_settings_page";}', '', '31', 5, '1', 'admin/structure/panels/settings', 'admin/structure/panels', 'General', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'sites/all/modules/panels/includes/callbacks.inc'),
('admin/structure/panels/settings/panel-node', '', '', 'user_access', 'a:1:{i:0;s:22:"administer panel-nodes";}', 'panels_node_settings', 'a:0:{}', '', '31', 5, '1', 'admin/structure/panels/settings', 'admin/structure/panels', 'Panel nodes', 't', '', '', 'a:0:{}', '132', 'Configure which content is available to add to panel node displays.', '', '0', ''),
('admin/structure/panels/settings/panel-page', '', '', 'user_access', 'a:1:{i:0;s:20:"use panels dashboard";}', 'panels_admin_panel_context_page', 'a:0:{}', '', '31', 5, '1', 'admin/structure/panels/settings', 'admin/structure/panels', 'Panel pages', 't', '', '', 'a:0:{}', '132', '', '', '-10', 'sites/all/modules/panels/includes/callbacks.inc'),
('admin/structure/panels/settings/panels-mini', '', '', 'user_access', 'a:1:{i:0;s:18:"create mini panels";}', 'panels_mini_settings', 'a:0:{}', '', '31', 5, '1', 'admin/structure/panels/settings', 'admin/structure/panels', 'Mini panels', 't', '', '', 'a:0:{}', '132', '', '', '0', ''),
('admin/structure/taxonomy', '', '', 'user_access', 'a:1:{i:0;s:19:"administer taxonomy";}', 'drupal_get_form', 'a:1:{i:0;s:30:"taxonomy_overview_vocabularies";}', '', '7', 3, '0', '', 'admin/structure/taxonomy', 'Taxonomy', 't', '', '', 'a:0:{}', '6', 'Manage tagging, categorization, and classification of your content.', '', '0', 'modules/taxonomy/taxonomy.admin.inc'),
('admin/structure/taxonomy/%', 'a:1:{i:3;s:37:"taxonomy_vocabulary_machine_name_load";}', '', 'user_access', 'a:1:{i:0;s:19:"administer taxonomy";}', 'drupal_get_form', 'a:2:{i:0;s:23:"taxonomy_overview_terms";i:1;i:3;}', '', '14', 4, '0', '', 'admin/structure/taxonomy/%', '', 'entity_label', 'a:2:{i:0;s:19:"taxonomy_vocabulary";i:1;i:3;}', '', 'a:0:{}', '6', '', '', '0', 'modules/taxonomy/taxonomy.admin.inc'),
('admin/structure/taxonomy/%/add', 'a:1:{i:3;s:37:"taxonomy_vocabulary_machine_name_load";}', '', 'user_access', 'a:1:{i:0;s:19:"administer taxonomy";}', 'drupal_get_form', 'a:3:{i:0;s:18:"taxonomy_form_term";i:1;a:0:{}i:2;i:3;}', '', '29', 5, '1', 'admin/structure/taxonomy/%', 'admin/structure/taxonomy/%', 'Add term', 't', '', '', 'a:0:{}', '388', '', '', '0', 'modules/taxonomy/taxonomy.admin.inc'),
('admin/structure/taxonomy/%/display', 'a:1:{i:3;s:37:"taxonomy_vocabulary_machine_name_load";}', '', 'user_access', 'a:1:{i:0;s:19:"administer taxonomy";}', 'drupal_get_form', 'a:4:{i:0;s:30:"field_ui_display_overview_form";i:1;s:13:"taxonomy_term";i:2;i:3;i:3;s:7:"default";}', '', '29', 5, '1', 'admin/structure/taxonomy/%', 'admin/structure/taxonomy/%', 'Manage display', 't', '', '', 'a:0:{}', '132', '', '', '2', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/taxonomy/%/display/default', 'a:1:{i:3;s:37:"taxonomy_vocabulary_machine_name_load";}', '', '_field_ui_view_mode_menu_access', 'a:5:{i:0;s:13:"taxonomy_term";i:1;i:3;i:2;s:7:"default";i:3;s:11:"user_access";i:4;s:19:"administer taxonomy";}', 'drupal_get_form', 'a:4:{i:0;s:30:"field_ui_display_overview_form";i:1;s:13:"taxonomy_term";i:2;i:3;i:3;s:7:"default";}', '', '59', 6, '1', 'admin/structure/taxonomy/%/display', 'admin/structure/taxonomy/%', 'Default', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/taxonomy/%/display/full', 'a:1:{i:3;s:37:"taxonomy_vocabulary_machine_name_load";}', '', '_field_ui_view_mode_menu_access', 'a:5:{i:0;s:13:"taxonomy_term";i:1;i:3;i:2;s:4:"full";i:3;s:11:"user_access";i:4;s:19:"administer taxonomy";}', 'drupal_get_form', 'a:4:{i:0;s:30:"field_ui_display_overview_form";i:1;s:13:"taxonomy_term";i:2;i:3;i:3;s:4:"full";}', '', '59', 6, '1', 'admin/structure/taxonomy/%/display', 'admin/structure/taxonomy/%', 'Taxonomy term page', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/field_ui/field_ui.admin.inc');
INSERT INTO `menu_router` VALUES
('admin/structure/taxonomy/%/edit', 'a:1:{i:3;s:37:"taxonomy_vocabulary_machine_name_load";}', '', 'user_access', 'a:1:{i:0;s:19:"administer taxonomy";}', 'drupal_get_form', 'a:2:{i:0;s:24:"taxonomy_form_vocabulary";i:1;i:3;}', '', '29', 5, '1', 'admin/structure/taxonomy/%', 'admin/structure/taxonomy/%', 'Edit', 't', '', '', 'a:0:{}', '132', '', '', '-10', 'modules/taxonomy/taxonomy.admin.inc'),
('admin/structure/taxonomy/%/fields', 'a:1:{i:3;s:37:"taxonomy_vocabulary_machine_name_load";}', '', 'user_access', 'a:1:{i:0;s:19:"administer taxonomy";}', 'drupal_get_form', 'a:3:{i:0;s:28:"field_ui_field_overview_form";i:1;s:13:"taxonomy_term";i:2;i:3;}', '', '29', 5, '1', 'admin/structure/taxonomy/%', 'admin/structure/taxonomy/%', 'Manage fields', 't', '', '', 'a:0:{}', '132', '', '', '1', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/taxonomy/%/fields/%', 'a:2:{i:3;a:1:{s:37:"taxonomy_vocabulary_machine_name_load";a:4:{i:0;s:13:"taxonomy_term";i:1;i:3;i:2;s:1:"3";i:3;s:4:"%map";}}i:5;a:1:{s:18:"field_ui_menu_load";a:4:{i:0;s:13:"taxonomy_term";i:1;i:3;i:2;s:1:"3";i:3;s:4:"%map";}}}', '', 'user_access', 'a:1:{i:0;s:19:"administer taxonomy";}', 'drupal_get_form', 'a:2:{i:0;s:24:"field_ui_field_edit_form";i:1;i:5;}', '', '58', 6, '0', '', 'admin/structure/taxonomy/%/fields/%', '', 'field_ui_menu_title', 'a:1:{i:0;i:5;}', '', 'a:0:{}', '6', '', '', '0', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/taxonomy/%/fields/%/delete', 'a:2:{i:3;a:1:{s:37:"taxonomy_vocabulary_machine_name_load";a:4:{i:0;s:13:"taxonomy_term";i:1;i:3;i:2;s:1:"3";i:3;s:4:"%map";}}i:5;a:1:{s:18:"field_ui_menu_load";a:4:{i:0;s:13:"taxonomy_term";i:1;i:3;i:2;s:1:"3";i:3;s:4:"%map";}}}', '', 'user_access', 'a:1:{i:0;s:19:"administer taxonomy";}', 'drupal_get_form', 'a:2:{i:0;s:26:"field_ui_field_delete_form";i:1;i:5;}', '', '117', 7, '1', 'admin/structure/taxonomy/%/fields/%', 'admin/structure/taxonomy/%/fields/%', 'Delete', 't', '', '', 'a:0:{}', '132', '', '', '10', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/taxonomy/%/fields/%/edit', 'a:2:{i:3;a:1:{s:37:"taxonomy_vocabulary_machine_name_load";a:4:{i:0;s:13:"taxonomy_term";i:1;i:3;i:2;s:1:"3";i:3;s:4:"%map";}}i:5;a:1:{s:18:"field_ui_menu_load";a:4:{i:0;s:13:"taxonomy_term";i:1;i:3;i:2;s:1:"3";i:3;s:4:"%map";}}}', '', 'user_access', 'a:1:{i:0;s:19:"administer taxonomy";}', 'drupal_get_form', 'a:2:{i:0;s:24:"field_ui_field_edit_form";i:1;i:5;}', '', '117', 7, '1', 'admin/structure/taxonomy/%/fields/%', 'admin/structure/taxonomy/%/fields/%', 'Edit', 't', '', '', 'a:0:{}', '140', '', '', '0', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/taxonomy/%/fields/%/field-settings', 'a:2:{i:3;a:1:{s:37:"taxonomy_vocabulary_machine_name_load";a:4:{i:0;s:13:"taxonomy_term";i:1;i:3;i:2;s:1:"3";i:3;s:4:"%map";}}i:5;a:1:{s:18:"field_ui_menu_load";a:4:{i:0;s:13:"taxonomy_term";i:1;i:3;i:2;s:1:"3";i:3;s:4:"%map";}}}', '', 'user_access', 'a:1:{i:0;s:19:"administer taxonomy";}', 'drupal_get_form', 'a:2:{i:0;s:28:"field_ui_field_settings_form";i:1;i:5;}', '', '117', 7, '1', 'admin/structure/taxonomy/%/fields/%', 'admin/structure/taxonomy/%/fields/%', 'Field settings', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/taxonomy/%/fields/%/widget-type', 'a:2:{i:3;a:1:{s:37:"taxonomy_vocabulary_machine_name_load";a:4:{i:0;s:13:"taxonomy_term";i:1;i:3;i:2;s:1:"3";i:3;s:4:"%map";}}i:5;a:1:{s:18:"field_ui_menu_load";a:4:{i:0;s:13:"taxonomy_term";i:1;i:3;i:2;s:1:"3";i:3;s:4:"%map";}}}', '', 'user_access', 'a:1:{i:0;s:19:"administer taxonomy";}', 'drupal_get_form', 'a:2:{i:0;s:25:"field_ui_widget_type_form";i:1;i:5;}', '', '117', 7, '1', 'admin/structure/taxonomy/%/fields/%', 'admin/structure/taxonomy/%/fields/%', 'Widget type', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/taxonomy/%/list', 'a:1:{i:3;s:37:"taxonomy_vocabulary_machine_name_load";}', '', 'user_access', 'a:1:{i:0;s:19:"administer taxonomy";}', 'drupal_get_form', 'a:2:{i:0;s:23:"taxonomy_overview_terms";i:1;i:3;}', '', '29', 5, '1', 'admin/structure/taxonomy/%', 'admin/structure/taxonomy/%', 'List', 't', '', '', 'a:0:{}', '140', '', '', '-20', 'modules/taxonomy/taxonomy.admin.inc'),
('admin/structure/taxonomy/add', '', '', 'user_access', 'a:1:{i:0;s:19:"administer taxonomy";}', 'drupal_get_form', 'a:1:{i:0;s:24:"taxonomy_form_vocabulary";}', '', '15', 4, '1', 'admin/structure/taxonomy', 'admin/structure/taxonomy', 'Add vocabulary', 't', '', '', 'a:0:{}', '388', '', '', '0', 'modules/taxonomy/taxonomy.admin.inc'),
('admin/structure/taxonomy/list', '', '', 'user_access', 'a:1:{i:0;s:19:"administer taxonomy";}', 'drupal_get_form', 'a:1:{i:0;s:30:"taxonomy_overview_vocabularies";}', '', '15', 4, '1', 'admin/structure/taxonomy', 'admin/structure/taxonomy', 'List', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'modules/taxonomy/taxonomy.admin.inc'),
('admin/structure/trigger', '', '', 'user_access', 'a:1:{i:0;s:18:"administer actions";}', 'trigger_assign', 'a:0:{}', '', '7', 3, '0', '', 'admin/structure/trigger', 'Triggers', 't', '', '', 'a:0:{}', '6', 'Configure when to execute actions.', '', '0', 'modules/trigger/trigger.admin.inc'),
('admin/structure/trigger/comment', '', '', 'user_access', 'a:1:{i:0;s:18:"administer actions";}', 'trigger_assign', 'a:1:{i:0;s:7:"comment";}', '', '15', 4, '1', 'admin/structure/trigger', 'admin/structure/trigger', 'Comment', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/trigger/trigger.admin.inc'),
('admin/structure/trigger/node', '', '', 'user_access', 'a:1:{i:0;s:18:"administer actions";}', 'trigger_assign', 'a:1:{i:0;s:4:"node";}', '', '15', 4, '1', 'admin/structure/trigger', 'admin/structure/trigger', 'Node', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/trigger/trigger.admin.inc'),
('admin/structure/trigger/system', '', '', 'user_access', 'a:1:{i:0;s:18:"administer actions";}', 'trigger_assign', 'a:1:{i:0;s:6:"system";}', '', '15', 4, '1', 'admin/structure/trigger', 'admin/structure/trigger', 'System', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/trigger/trigger.admin.inc'),
('admin/structure/trigger/taxonomy', '', '', 'user_access', 'a:1:{i:0;s:18:"administer actions";}', 'trigger_assign', 'a:1:{i:0;s:8:"taxonomy";}', '', '15', 4, '1', 'admin/structure/trigger', 'admin/structure/trigger', 'Taxonomy', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/trigger/trigger.admin.inc'),
('admin/structure/trigger/unassign', '', '', 'trigger_menu_unassign_access', 'a:0:{}', 'drupal_get_form', 'a:1:{i:0;s:16:"trigger_unassign";}', '', '15', 4, '0', '', 'admin/structure/trigger/unassign', 'Unassign', 't', '', '', 'a:0:{}', '4', 'Unassign an action from a trigger.', '', '0', 'modules/trigger/trigger.admin.inc'),
('admin/structure/trigger/user', '', '', 'user_access', 'a:1:{i:0;s:18:"administer actions";}', 'trigger_assign', 'a:1:{i:0;s:4:"user";}', '', '15', 4, '1', 'admin/structure/trigger', 'admin/structure/trigger', 'User', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/trigger/trigger.admin.inc'),
('admin/structure/types', '', '', 'user_access', 'a:1:{i:0;s:24:"administer content types";}', 'node_overview_types', 'a:0:{}', '', '7', 3, '0', '', 'admin/structure/types', 'Content types', 't', '', '', 'a:0:{}', '6', 'Manage content types, including default status, front page promotion, comment settings, etc.', '', '0', 'modules/node/content_types.inc'),
('admin/structure/types/add', '', '', 'user_access', 'a:1:{i:0;s:24:"administer content types";}', 'drupal_get_form', 'a:1:{i:0;s:14:"node_type_form";}', '', '15', 4, '1', 'admin/structure/types', 'admin/structure/types', 'Add content type', 't', '', '', 'a:0:{}', '388', '', '', '0', 'modules/node/content_types.inc'),
('admin/structure/types/list', '', '', 'user_access', 'a:1:{i:0;s:24:"administer content types";}', 'node_overview_types', 'a:0:{}', '', '15', 4, '1', 'admin/structure/types', 'admin/structure/types', 'List', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'modules/node/content_types.inc'),
('admin/structure/types/manage/%', 'a:1:{i:4;s:14:"node_type_load";}', '', 'user_access', 'a:1:{i:0;s:24:"administer content types";}', 'drupal_get_form', 'a:2:{i:0;s:14:"node_type_form";i:1;i:4;}', '', '30', 5, '0', '', 'admin/structure/types/manage/%', 'Edit content type', 'node_type_page_title', 'a:1:{i:0;i:4;}', '', 'a:0:{}', '6', '', '', '0', 'modules/node/content_types.inc'),
('admin/structure/types/manage/%/comment/display', 'a:1:{i:4;s:22:"comment_node_type_load";}', '', 'user_access', 'a:1:{i:0;s:24:"administer content types";}', 'drupal_get_form', 'a:4:{i:0;s:30:"field_ui_display_overview_form";i:1;s:7:"comment";i:2;i:4;i:3;s:7:"default";}', '', '123', 7, '1', 'admin/structure/types/manage/%', 'admin/structure/types/manage/%', 'Comment display', 't', '', '', 'a:0:{}', '132', '', '', '4', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/types/manage/%/comment/display/default', 'a:1:{i:4;s:22:"comment_node_type_load";}', '', '_field_ui_view_mode_menu_access', 'a:5:{i:0;s:7:"comment";i:1;i:4;i:2;s:7:"default";i:3;s:11:"user_access";i:4;s:24:"administer content types";}', 'drupal_get_form', 'a:4:{i:0;s:30:"field_ui_display_overview_form";i:1;s:7:"comment";i:2;i:4;i:3;s:7:"default";}', '', '247', 8, '1', 'admin/structure/types/manage/%/comment/display', 'admin/structure/types/manage/%', 'Default', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/types/manage/%/comment/display/full', 'a:1:{i:4;s:22:"comment_node_type_load";}', '', '_field_ui_view_mode_menu_access', 'a:5:{i:0;s:7:"comment";i:1;i:4;i:2;s:4:"full";i:3;s:11:"user_access";i:4;s:24:"administer content types";}', 'drupal_get_form', 'a:4:{i:0;s:30:"field_ui_display_overview_form";i:1;s:7:"comment";i:2;i:4;i:3;s:4:"full";}', '', '247', 8, '1', 'admin/structure/types/manage/%/comment/display', 'admin/structure/types/manage/%', 'Full comment', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/types/manage/%/comment/fields', 'a:1:{i:4;s:22:"comment_node_type_load";}', '', 'user_access', 'a:1:{i:0;s:24:"administer content types";}', 'drupal_get_form', 'a:3:{i:0;s:28:"field_ui_field_overview_form";i:1;s:7:"comment";i:2;i:4;}', '', '123', 7, '1', 'admin/structure/types/manage/%', 'admin/structure/types/manage/%', 'Comment fields', 't', '', '', 'a:0:{}', '132', '', '', '3', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/types/manage/%/comment/fields/%', 'a:2:{i:4;a:1:{s:22:"comment_node_type_load";a:4:{i:0;s:7:"comment";i:1;i:4;i:2;s:1:"4";i:3;s:4:"%map";}}i:7;a:1:{s:18:"field_ui_menu_load";a:4:{i:0;s:7:"comment";i:1;i:4;i:2;s:1:"4";i:3;s:4:"%map";}}}', '', 'user_access', 'a:1:{i:0;s:24:"administer content types";}', 'drupal_get_form', 'a:2:{i:0;s:24:"field_ui_field_edit_form";i:1;i:7;}', '', '246', 8, '0', '', 'admin/structure/types/manage/%/comment/fields/%', '', 'field_ui_menu_title', 'a:1:{i:0;i:7;}', '', 'a:0:{}', '6', '', '', '0', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/types/manage/%/comment/fields/%/delete', 'a:2:{i:4;a:1:{s:22:"comment_node_type_load";a:4:{i:0;s:7:"comment";i:1;i:4;i:2;s:1:"4";i:3;s:4:"%map";}}i:7;a:1:{s:18:"field_ui_menu_load";a:4:{i:0;s:7:"comment";i:1;i:4;i:2;s:1:"4";i:3;s:4:"%map";}}}', '', 'user_access', 'a:1:{i:0;s:24:"administer content types";}', 'drupal_get_form', 'a:2:{i:0;s:26:"field_ui_field_delete_form";i:1;i:7;}', '', '493', 9, '1', 'admin/structure/types/manage/%/comment/fields/%', 'admin/structure/types/manage/%/comment/fields/%', 'Delete', 't', '', '', 'a:0:{}', '132', '', '', '10', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/types/manage/%/comment/fields/%/edit', 'a:2:{i:4;a:1:{s:22:"comment_node_type_load";a:4:{i:0;s:7:"comment";i:1;i:4;i:2;s:1:"4";i:3;s:4:"%map";}}i:7;a:1:{s:18:"field_ui_menu_load";a:4:{i:0;s:7:"comment";i:1;i:4;i:2;s:1:"4";i:3;s:4:"%map";}}}', '', 'user_access', 'a:1:{i:0;s:24:"administer content types";}', 'drupal_get_form', 'a:2:{i:0;s:24:"field_ui_field_edit_form";i:1;i:7;}', '', '493', 9, '1', 'admin/structure/types/manage/%/comment/fields/%', 'admin/structure/types/manage/%/comment/fields/%', 'Edit', 't', '', '', 'a:0:{}', '140', '', '', '0', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/types/manage/%/comment/fields/%/field-settings', 'a:2:{i:4;a:1:{s:22:"comment_node_type_load";a:4:{i:0;s:7:"comment";i:1;i:4;i:2;s:1:"4";i:3;s:4:"%map";}}i:7;a:1:{s:18:"field_ui_menu_load";a:4:{i:0;s:7:"comment";i:1;i:4;i:2;s:1:"4";i:3;s:4:"%map";}}}', '', 'user_access', 'a:1:{i:0;s:24:"administer content types";}', 'drupal_get_form', 'a:2:{i:0;s:28:"field_ui_field_settings_form";i:1;i:7;}', '', '493', 9, '1', 'admin/structure/types/manage/%/comment/fields/%', 'admin/structure/types/manage/%/comment/fields/%', 'Field settings', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/types/manage/%/comment/fields/%/widget-type', 'a:2:{i:4;a:1:{s:22:"comment_node_type_load";a:4:{i:0;s:7:"comment";i:1;i:4;i:2;s:1:"4";i:3;s:4:"%map";}}i:7;a:1:{s:18:"field_ui_menu_load";a:4:{i:0;s:7:"comment";i:1;i:4;i:2;s:1:"4";i:3;s:4:"%map";}}}', '', 'user_access', 'a:1:{i:0;s:24:"administer content types";}', 'drupal_get_form', 'a:2:{i:0;s:25:"field_ui_widget_type_form";i:1;i:7;}', '', '493', 9, '1', 'admin/structure/types/manage/%/comment/fields/%', 'admin/structure/types/manage/%/comment/fields/%', 'Widget type', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/types/manage/%/delete', 'a:1:{i:4;s:14:"node_type_load";}', '', 'user_access', 'a:1:{i:0;s:24:"administer content types";}', 'drupal_get_form', 'a:2:{i:0;s:24:"node_type_delete_confirm";i:1;i:4;}', '', '61', 6, '0', '', 'admin/structure/types/manage/%/delete', 'Delete', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/node/content_types.inc'),
('admin/structure/types/manage/%/display', 'a:1:{i:4;s:14:"node_type_load";}', '', 'user_access', 'a:1:{i:0;s:24:"administer content types";}', 'drupal_get_form', 'a:4:{i:0;s:30:"field_ui_display_overview_form";i:1;s:4:"node";i:2;i:4;i:3;s:7:"default";}', '', '61', 6, '1', 'admin/structure/types/manage/%', 'admin/structure/types/manage/%', 'Manage display', 't', '', '', 'a:0:{}', '132', '', '', '2', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/types/manage/%/display/default', 'a:1:{i:4;s:14:"node_type_load";}', '', '_field_ui_view_mode_menu_access', 'a:5:{i:0;s:4:"node";i:1;i:4;i:2;s:7:"default";i:3;s:11:"user_access";i:4;s:24:"administer content types";}', 'drupal_get_form', 'a:4:{i:0;s:30:"field_ui_display_overview_form";i:1;s:4:"node";i:2;i:4;i:3;s:7:"default";}', '', '123', 7, '1', 'admin/structure/types/manage/%/display', 'admin/structure/types/manage/%', 'Default', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/types/manage/%/display/full', 'a:1:{i:4;s:14:"node_type_load";}', '', '_field_ui_view_mode_menu_access', 'a:5:{i:0;s:4:"node";i:1;i:4;i:2;s:4:"full";i:3;s:11:"user_access";i:4;s:24:"administer content types";}', 'drupal_get_form', 'a:4:{i:0;s:30:"field_ui_display_overview_form";i:1;s:4:"node";i:2;i:4;i:3;s:4:"full";}', '', '123', 7, '1', 'admin/structure/types/manage/%/display', 'admin/structure/types/manage/%', 'Full content', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/types/manage/%/display/print', 'a:1:{i:4;s:14:"node_type_load";}', '', '_field_ui_view_mode_menu_access', 'a:5:{i:0;s:4:"node";i:1;i:4;i:2;s:5:"print";i:3;s:11:"user_access";i:4;s:24:"administer content types";}', 'drupal_get_form', 'a:4:{i:0;s:30:"field_ui_display_overview_form";i:1;s:4:"node";i:2;i:4;i:3;s:5:"print";}', '', '123', 7, '1', 'admin/structure/types/manage/%/display', 'admin/structure/types/manage/%', 'Print', 't', '', '', 'a:0:{}', '132', '', '', '5', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/types/manage/%/display/rss', 'a:1:{i:4;s:14:"node_type_load";}', '', '_field_ui_view_mode_menu_access', 'a:5:{i:0;s:4:"node";i:1;i:4;i:2;s:3:"rss";i:3;s:11:"user_access";i:4;s:24:"administer content types";}', 'drupal_get_form', 'a:4:{i:0;s:30:"field_ui_display_overview_form";i:1;s:4:"node";i:2;i:4;i:3;s:3:"rss";}', '', '123', 7, '1', 'admin/structure/types/manage/%/display', 'admin/structure/types/manage/%', 'RSS', 't', '', '', 'a:0:{}', '132', '', '', '2', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/types/manage/%/display/search_index', 'a:1:{i:4;s:14:"node_type_load";}', '', '_field_ui_view_mode_menu_access', 'a:5:{i:0;s:4:"node";i:1;i:4;i:2;s:12:"search_index";i:3;s:11:"user_access";i:4;s:24:"administer content types";}', 'drupal_get_form', 'a:4:{i:0;s:30:"field_ui_display_overview_form";i:1;s:4:"node";i:2;i:4;i:3;s:12:"search_index";}', '', '123', 7, '1', 'admin/structure/types/manage/%/display', 'admin/structure/types/manage/%', 'Search index', 't', '', '', 'a:0:{}', '132', '', '', '3', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/types/manage/%/display/search_result', 'a:1:{i:4;s:14:"node_type_load";}', '', '_field_ui_view_mode_menu_access', 'a:5:{i:0;s:4:"node";i:1;i:4;i:2;s:13:"search_result";i:3;s:11:"user_access";i:4;s:24:"administer content types";}', 'drupal_get_form', 'a:4:{i:0;s:30:"field_ui_display_overview_form";i:1;s:4:"node";i:2;i:4;i:3;s:13:"search_result";}', '', '123', 7, '1', 'admin/structure/types/manage/%/display', 'admin/structure/types/manage/%', 'Search result', 't', '', '', 'a:0:{}', '132', '', '', '4', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/types/manage/%/display/teaser', 'a:1:{i:4;s:14:"node_type_load";}', '', '_field_ui_view_mode_menu_access', 'a:5:{i:0;s:4:"node";i:1;i:4;i:2;s:6:"teaser";i:3;s:11:"user_access";i:4;s:24:"administer content types";}', 'drupal_get_form', 'a:4:{i:0;s:30:"field_ui_display_overview_form";i:1;s:4:"node";i:2;i:4;i:3;s:6:"teaser";}', '', '123', 7, '1', 'admin/structure/types/manage/%/display', 'admin/structure/types/manage/%', 'Teaser', 't', '', '', 'a:0:{}', '132', '', '', '1', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/types/manage/%/edit', 'a:1:{i:4;s:14:"node_type_load";}', '', 'user_access', 'a:1:{i:0;s:24:"administer content types";}', 'drupal_get_form', 'a:2:{i:0;s:14:"node_type_form";i:1;i:4;}', '', '61', 6, '1', 'admin/structure/types/manage/%', 'admin/structure/types/manage/%', 'Edit', 't', '', '', 'a:0:{}', '140', '', '', '0', 'modules/node/content_types.inc'),
('admin/structure/types/manage/%/fields', 'a:1:{i:4;s:14:"node_type_load";}', '', 'user_access', 'a:1:{i:0;s:24:"administer content types";}', 'drupal_get_form', 'a:3:{i:0;s:28:"field_ui_field_overview_form";i:1;s:4:"node";i:2;i:4;}', '', '61', 6, '1', 'admin/structure/types/manage/%', 'admin/structure/types/manage/%', 'Manage fields', 't', '', '', 'a:0:{}', '132', '', '', '1', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/types/manage/%/fields/%', 'a:2:{i:4;a:1:{s:14:"node_type_load";a:4:{i:0;s:4:"node";i:1;i:4;i:2;s:1:"4";i:3;s:4:"%map";}}i:6;a:1:{s:18:"field_ui_menu_load";a:4:{i:0;s:4:"node";i:1;i:4;i:2;s:1:"4";i:3;s:4:"%map";}}}', '', 'user_access', 'a:1:{i:0;s:24:"administer content types";}', 'drupal_get_form', 'a:2:{i:0;s:24:"field_ui_field_edit_form";i:1;i:6;}', '', '122', 7, '0', '', 'admin/structure/types/manage/%/fields/%', '', 'field_ui_menu_title', 'a:1:{i:0;i:6;}', '', 'a:0:{}', '6', '', '', '0', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/types/manage/%/fields/%/delete', 'a:2:{i:4;a:1:{s:14:"node_type_load";a:4:{i:0;s:4:"node";i:1;i:4;i:2;s:1:"4";i:3;s:4:"%map";}}i:6;a:1:{s:18:"field_ui_menu_load";a:4:{i:0;s:4:"node";i:1;i:4;i:2;s:1:"4";i:3;s:4:"%map";}}}', '', 'user_access', 'a:1:{i:0;s:24:"administer content types";}', 'drupal_get_form', 'a:2:{i:0;s:26:"field_ui_field_delete_form";i:1;i:6;}', '', '245', 8, '1', 'admin/structure/types/manage/%/fields/%', 'admin/structure/types/manage/%/fields/%', 'Delete', 't', '', '', 'a:0:{}', '132', '', '', '10', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/types/manage/%/fields/%/edit', 'a:2:{i:4;a:1:{s:14:"node_type_load";a:4:{i:0;s:4:"node";i:1;i:4;i:2;s:1:"4";i:3;s:4:"%map";}}i:6;a:1:{s:18:"field_ui_menu_load";a:4:{i:0;s:4:"node";i:1;i:4;i:2;s:1:"4";i:3;s:4:"%map";}}}', '', 'user_access', 'a:1:{i:0;s:24:"administer content types";}', 'drupal_get_form', 'a:2:{i:0;s:24:"field_ui_field_edit_form";i:1;i:6;}', '', '245', 8, '1', 'admin/structure/types/manage/%/fields/%', 'admin/structure/types/manage/%/fields/%', 'Edit', 't', '', '', 'a:0:{}', '140', '', '', '0', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/types/manage/%/fields/%/field-settings', 'a:2:{i:4;a:1:{s:14:"node_type_load";a:4:{i:0;s:4:"node";i:1;i:4;i:2;s:1:"4";i:3;s:4:"%map";}}i:6;a:1:{s:18:"field_ui_menu_load";a:4:{i:0;s:4:"node";i:1;i:4;i:2;s:1:"4";i:3;s:4:"%map";}}}', '', 'user_access', 'a:1:{i:0;s:24:"administer content types";}', 'drupal_get_form', 'a:2:{i:0;s:28:"field_ui_field_settings_form";i:1;i:6;}', '', '245', 8, '1', 'admin/structure/types/manage/%/fields/%', 'admin/structure/types/manage/%/fields/%', 'Field settings', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/types/manage/%/fields/%/widget-type', 'a:2:{i:4;a:1:{s:14:"node_type_load";a:4:{i:0;s:4:"node";i:1;i:4;i:2;s:1:"4";i:3;s:4:"%map";}}i:6;a:1:{s:18:"field_ui_menu_load";a:4:{i:0;s:4:"node";i:1;i:4;i:2;s:1:"4";i:3;s:4:"%map";}}}', '', 'user_access', 'a:1:{i:0;s:24:"administer content types";}', 'drupal_get_form', 'a:2:{i:0;s:25:"field_ui_widget_type_form";i:1;i:6;}', '', '245', 8, '1', 'admin/structure/types/manage/%/fields/%', 'admin/structure/types/manage/%/fields/%', 'Widget type', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/field_ui/field_ui.admin.inc'),
('admin/structure/views', '', '', 'ctools_export_ui_task_access', 'a:2:{i:0;s:8:"views_ui";i:1;s:4:"list";}', 'ctools_export_ui_switcher_page', 'a:2:{i:0;s:8:"views_ui";i:1;s:4:"list";}', '', '7', 3, '0', '', 'admin/structure/views', 'Views', 't', '', '', 'a:0:{}', '6', 'Manage customized lists of content.', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/views/add', '', '', 'user_access', 'a:1:{i:0;s:16:"administer views";}', 'views_ui_add_page', 'a:0:{}', '', '15', 4, '1', 'admin/structure/views', 'admin/structure/views', 'Add new view', 't', '', '', 'a:0:{}', '388', '', '', '0', 'sites/all/modules/views/includes/admin.inc'),
('admin/structure/views/add-template', '', '', 'user_access', 'a:1:{i:0;s:16:"administer views";}', 'views_ui_add_template_page', 'a:0:{}', '', '15', 4, '0', '', 'admin/structure/views/add-template', 'Add view from template', 't', '', '', 'a:0:{}', '4', '', '', '0', 'sites/all/modules/views/includes/admin.inc'),
('admin/structure/views/ajax/%/%', 'a:2:{i:4;N;i:5;s:19:"views_ui_cache_load";}', '', 'user_access', 'a:1:{i:0;s:16:"administer views";}', 'views_ui_ajax_form', 'a:3:{i:0;b:1;i:1;i:4;i:2;i:5;}', 'ajax_deliver', '60', 6, '0', '', 'admin/structure/views/ajax/%/%', '', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/views/includes/admin.inc'),
('admin/structure/views/ajax/preview/%/%', 'a:2:{i:5;s:19:"views_ui_cache_load";i:6;N;}', '', 'user_access', 'a:1:{i:0;s:16:"administer views";}', 'views_ui_preview', 'a:2:{i:0;i:5;i:1;i:6;}', 'ajax_deliver', '124', 7, '0', '', 'admin/structure/views/ajax/preview/%/%', '', 't', '', '', 'a:0:{}', '6', '', '', '0', 'sites/all/modules/views/includes/admin.inc'),
('admin/structure/views/import', '', '', 'views_import_access', 'a:1:{i:0;s:16:"administer views";}', 'drupal_get_form', 'a:1:{i:0;s:20:"views_ui_import_page";}', '', '15', 4, '1', 'admin/structure/views', 'admin/structure/views', 'Import', 't', '', '', 'a:0:{}', '388', '', '', '0', 'sites/all/modules/views/includes/admin.inc'),
('admin/structure/views/list', '', '', 'ctools_export_ui_task_access', 'a:2:{i:0;s:8:"views_ui";i:1;s:4:"list";}', 'ctools_export_ui_switcher_page', 'a:2:{i:0;s:8:"views_ui";i:1;s:4:"list";}', '', '15', 4, '1', 'admin/structure/views', 'admin/structure/views', 'List', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/views/nojs/%/%', 'a:2:{i:4;N;i:5;s:19:"views_ui_cache_load";}', '', 'user_access', 'a:1:{i:0;s:16:"administer views";}', 'views_ui_ajax_form', 'a:3:{i:0;b:0;i:1;i:4;i:2;i:5;}', '', '60', 6, '0', '', 'admin/structure/views/nojs/%/%', '', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/views/includes/admin.inc'),
('admin/structure/views/nojs/preview/%/%', 'a:2:{i:5;s:19:"views_ui_cache_load";i:6;N;}', '', 'user_access', 'a:1:{i:0;s:16:"administer views";}', 'views_ui_preview', 'a:2:{i:0;i:5;i:1;i:6;}', '', '124', 7, '0', '', 'admin/structure/views/nojs/preview/%/%', '', 't', '', '', 'a:0:{}', '6', '', '', '0', 'sites/all/modules/views/includes/admin.inc'),
('admin/structure/views/settings', '', '', 'user_access', 'a:1:{i:0;s:16:"administer views";}', 'drupal_get_form', 'a:1:{i:0;s:29:"views_ui_admin_settings_basic";}', '', '15', 4, '1', 'admin/structure/views', 'admin/structure/views', 'Settings', 't', '', '', 'a:0:{}', '132', '', '', '0', 'sites/all/modules/views/includes/admin.inc'),
('admin/structure/views/settings/advanced', '', '', 'user_access', 'a:1:{i:0;s:16:"administer views";}', 'drupal_get_form', 'a:1:{i:0;s:32:"views_ui_admin_settings_advanced";}', '', '31', 5, '1', 'admin/structure/views/settings', 'admin/structure/views', 'Advanced', 't', '', '', 'a:0:{}', '132', '', '', '1', 'sites/all/modules/views/includes/admin.inc'),
('admin/structure/views/settings/basic', '', '', 'user_access', 'a:1:{i:0;s:16:"administer views";}', 'drupal_get_form', 'a:1:{i:0;s:29:"views_ui_admin_settings_basic";}', '', '31', 5, '1', 'admin/structure/views/settings', 'admin/structure/views', 'Basic', 't', '', '', 'a:0:{}', '140', '', '', '0', 'sites/all/modules/views/includes/admin.inc'),
('admin/structure/views/template/%/add', 'a:1:{i:4;N;}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:8:"views_ui";i:1;s:12:"add_template";i:2;i:4;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:8:"views_ui";i:1;s:12:"add_template";i:2;i:4;}', '', '61', 6, '0', '', 'admin/structure/views/template/%/add', 'Add from template', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/views/view/%', 'a:1:{i:4;s:19:"views_ui_cache_load";}', '', 'user_access', 'a:1:{i:0;s:16:"administer views";}', 'views_ui_edit_page', 'a:1:{i:0;i:4;}', '', '30', 5, '0', '', 'admin/structure/views/view/%', '', 'views_ui_edit_page_title', 'a:1:{i:0;i:4;}', '', 'a:0:{}', '6', '', '', '0', 'sites/all/modules/views/includes/admin.inc'),
('admin/structure/views/view/%/break-lock', 'a:1:{i:4;s:19:"views_ui_cache_load";}', '', 'user_access', 'a:1:{i:0;s:16:"administer views";}', 'drupal_get_form', 'a:2:{i:0;s:27:"views_ui_break_lock_confirm";i:1;i:4;}', '', '61', 6, '0', '', 'admin/structure/views/view/%/break-lock', 'Break lock', 't', '', '', 'a:0:{}', '4', '', '', '0', 'sites/all/modules/views/includes/admin.inc'),
('admin/structure/views/view/%/clone', 'a:1:{i:4;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:8:"views_ui";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:8:"views_ui";i:1;s:5:"clone";i:2;i:4;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:8:"views_ui";i:1;s:5:"clone";i:2;i:4;}', '', '61', 6, '0', '', 'admin/structure/views/view/%/clone', 'Clone', 't', '', '', 'a:0:{}', '4', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/views/view/%/delete', 'a:1:{i:4;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:8:"views_ui";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:8:"views_ui";i:1;s:6:"delete";i:2;i:4;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:8:"views_ui";i:1;s:6:"delete";i:2;i:4;}', '', '61', 6, '0', '', 'admin/structure/views/view/%/delete', 'Delete', 't', '', '', 'a:0:{}', '4', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/views/view/%/disable', 'a:1:{i:4;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:8:"views_ui";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:8:"views_ui";i:1;s:7:"disable";i:2;i:4;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:8:"views_ui";i:1;s:7:"disable";i:2;i:4;}', '', '61', 6, '0', '', 'admin/structure/views/view/%/disable', 'Disable', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/views/view/%/edit', 'a:1:{i:4;s:19:"views_ui_cache_load";}', '', 'user_access', 'a:1:{i:0;s:16:"administer views";}', 'views_ui_edit_page', 'a:1:{i:0;i:4;}', '', '61', 6, '3', 'admin/structure/views/view/%', 'admin/structure/views/view/%', 'Edit view', 't', '', 'ajax_base_page_theme', 'a:0:{}', '140', '', '', '-10', 'sites/all/modules/views/includes/admin.inc'),
('admin/structure/views/view/%/edit/%/ajax', 'a:2:{i:4;s:19:"views_ui_cache_load";i:6;N;}', '', 'user_access', 'a:1:{i:0;s:16:"administer views";}', 'views_ui_ajax_get_form', 'a:3:{i:0;s:18:"views_ui_edit_form";i:1;i:4;i:2;i:6;}', 'ajax_deliver', '245', 8, '0', '', 'admin/structure/views/view/%/edit/%/ajax', '', 't', '', 'ajax_base_page_theme', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/views/includes/admin.inc'),
('admin/structure/views/view/%/enable', 'a:1:{i:4;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:8:"views_ui";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:8:"views_ui";i:1;s:6:"enable";i:2;i:4;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:8:"views_ui";i:1;s:6:"enable";i:2;i:4;}', '', '61', 6, '0', '', 'admin/structure/views/view/%/enable', 'Enable', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/views/view/%/export', 'a:1:{i:4;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:8:"views_ui";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:8:"views_ui";i:1;s:6:"export";i:2;i:4;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:8:"views_ui";i:1;s:6:"export";i:2;i:4;}', '', '61', 6, '0', '', 'admin/structure/views/view/%/export', 'Export', 't', '', '', 'a:0:{}', '4', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/structure/views/view/%/preview/%', 'a:2:{i:4;s:19:"views_ui_cache_load";i:6;N;}', '', 'user_access', 'a:1:{i:0;s:16:"administer views";}', 'views_ui_build_preview', 'a:2:{i:0;i:4;i:1;i:6;}', '', '122', 7, '3', '', 'admin/structure/views/view/%/preview/%', '', 't', '', '', 'a:0:{}', '4', '', '', '0', 'sites/all/modules/views/includes/admin.inc'),
('admin/structure/views/view/%/preview/%/ajax', 'a:2:{i:4;s:19:"views_ui_cache_load";i:6;N;}', '', 'user_access', 'a:1:{i:0;s:16:"administer views";}', 'views_ui_build_preview', 'a:2:{i:0;i:4;i:1;i:6;}', 'ajax_deliver', '245', 8, '0', '', 'admin/structure/views/view/%/preview/%/ajax', '', 't', '', 'ajax_base_page_theme', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/views/includes/admin.inc'),
('admin/structure/views/view/%/revert', 'a:1:{i:4;a:1:{s:21:"ctools_export_ui_load";a:1:{i:0;s:8:"views_ui";}}}', '', 'ctools_export_ui_task_access', 'a:3:{i:0;s:8:"views_ui";i:1;s:6:"revert";i:2;i:4;}', 'ctools_export_ui_switcher_page', 'a:3:{i:0;s:8:"views_ui";i:1;s:6:"delete";i:2;i:4;}', '', '61', 6, '0', '', 'admin/structure/views/view/%/revert', 'Revert', 't', '', '', 'a:0:{}', '4', '', '', '0', 'sites/all/modules/ctools/includes/export-ui.inc'),
('admin/tasks', '', '', 'user_access', 'a:1:{i:0;s:27:"access administration pages";}', 'system_admin_menu_block_page', 'a:0:{}', '', '3', 2, '1', 'admin', 'admin', 'Tasks', 't', '', '', 'a:0:{}', '140', '', '', '-20', 'modules/system/system.admin.inc'),
('admin/update/ready', '', '', 'update_manager_access', 'a:0:{}', 'drupal_get_form', 'a:1:{i:0;s:32:"update_manager_update_ready_form";}', '', '7', 3, '0', '', 'admin/update/ready', 'Ready to update', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/update/update.manager.inc'),
('admin/views/ajax/autocomplete/tag', '', '', 'user_access', 'a:1:{i:0;s:16:"administer views";}', 'views_ui_autocomplete_tag', 'a:0:{}', '', '31', 5, '0', '', 'admin/views/ajax/autocomplete/tag', '', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/views/includes/admin.inc'),
('admin/views/ajax/autocomplete/taxonomy', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'views_ajax_autocomplete_taxonomy', 'a:0:{}', '', '31', 5, '0', '', 'admin/views/ajax/autocomplete/taxonomy', '', 't', '', 'ajax_base_page_theme', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/views/includes/ajax.inc'),
('admin/views/ajax/autocomplete/user', '', '', 'user_access', 'a:1:{i:0;s:20:"access user profiles";}', 'views_ajax_autocomplete_user', 'a:0:{}', '', '31', 5, '0', '', 'admin/views/ajax/autocomplete/user', '', 't', '', 'ajax_base_page_theme', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/views/includes/ajax.inc'),
('admin_menu/flush-cache', '', '', 'user_access', 'a:1:{i:0;s:12:"flush caches";}', 'admin_menu_flush_cache', 'a:0:{}', '', '3', 2, '0', '', 'admin_menu/flush-cache', '', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/admin_menu/admin_menu.inc'),
('admin_menu/toggle-modules', '', '', 'user_access', 'a:1:{i:0;s:18:"administer modules";}', 'admin_menu_toggle_modules', 'a:0:{}', '', '3', 2, '0', '', 'admin_menu/toggle-modules', '', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/admin_menu/admin_menu.inc'),
('aggregator', '', '', 'user_access', 'a:1:{i:0;s:17:"access news feeds";}', 'aggregator_page_last', 'a:0:{}', '', '1', 1, '0', '', 'aggregator', 'Feed aggregator', 't', '', '', 'a:0:{}', '6', '', '', '5', 'modules/aggregator/aggregator.pages.inc'),
('aggregator/categories', '', '', '_aggregator_has_categories', 'a:0:{}', 'aggregator_page_categories', 'a:0:{}', '', '3', 2, '0', '', 'aggregator/categories', 'Categories', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/aggregator/aggregator.pages.inc'),
('aggregator/categories/%', 'a:1:{i:2;s:24:"aggregator_category_load";}', '', 'user_access', 'a:1:{i:0;s:17:"access news feeds";}', 'aggregator_page_category', 'a:1:{i:0;i:2;}', '', '6', 3, '0', '', 'aggregator/categories/%', '', '_aggregator_category_title', 'a:1:{i:0;i:2;}', '', 'a:0:{}', '6', '', '', '0', 'modules/aggregator/aggregator.pages.inc'),
('aggregator/categories/%/categorize', 'a:1:{i:2;s:24:"aggregator_category_load";}', '', 'user_access', 'a:1:{i:0;s:21:"administer news feeds";}', 'drupal_get_form', 'a:2:{i:0;s:29:"aggregator_page_category_form";i:1;i:2;}', '', '13', 4, '1', 'aggregator/categories/%', 'aggregator/categories/%', 'Categorize', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/aggregator/aggregator.pages.inc'),
('aggregator/categories/%/configure', 'a:1:{i:2;s:24:"aggregator_category_load";}', '', 'user_access', 'a:1:{i:0;s:21:"administer news feeds";}', 'drupal_get_form', 'a:2:{i:0;s:24:"aggregator_form_category";i:1;i:2;}', '', '13', 4, '1', 'aggregator/categories/%', 'aggregator/categories/%', 'Configure', 't', '', '', 'a:0:{}', '132', '', '', '1', 'modules/aggregator/aggregator.admin.inc'),
('aggregator/categories/%/view', 'a:1:{i:2;s:24:"aggregator_category_load";}', '', 'user_access', 'a:1:{i:0;s:17:"access news feeds";}', 'aggregator_page_category', 'a:1:{i:0;i:2;}', '', '13', 4, '1', 'aggregator/categories/%', 'aggregator/categories/%', 'View', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'modules/aggregator/aggregator.pages.inc'),
('aggregator/opml', '', '', 'user_access', 'a:1:{i:0;s:17:"access news feeds";}', 'aggregator_page_opml', 'a:0:{}', '', '3', 2, '0', '', 'aggregator/opml', 'OPML feed', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/aggregator/aggregator.pages.inc'),
('aggregator/rss', '', '', 'user_access', 'a:1:{i:0;s:17:"access news feeds";}', 'aggregator_page_rss', 'a:0:{}', '', '3', 2, '0', '', 'aggregator/rss', 'RSS feed', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/aggregator/aggregator.pages.inc'),
('aggregator/sources', '', '', 'user_access', 'a:1:{i:0;s:17:"access news feeds";}', 'aggregator_page_sources', 'a:0:{}', '', '3', 2, '0', '', 'aggregator/sources', 'Sources', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/aggregator/aggregator.pages.inc'),
('aggregator/sources/%', 'a:1:{i:2;s:20:"aggregator_feed_load";}', '', 'user_access', 'a:1:{i:0;s:17:"access news feeds";}', 'aggregator_page_source', 'a:1:{i:0;i:2;}', '', '6', 3, '0', '', 'aggregator/sources/%', '', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/aggregator/aggregator.pages.inc'),
('aggregator/sources/%/categorize', 'a:1:{i:2;s:20:"aggregator_feed_load";}', '', 'user_access', 'a:1:{i:0;s:21:"administer news feeds";}', 'drupal_get_form', 'a:2:{i:0;s:27:"aggregator_page_source_form";i:1;i:2;}', '', '13', 4, '1', 'aggregator/sources/%', 'aggregator/sources/%', 'Categorize', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/aggregator/aggregator.pages.inc'),
('aggregator/sources/%/configure', 'a:1:{i:2;s:20:"aggregator_feed_load";}', '', 'user_access', 'a:1:{i:0;s:21:"administer news feeds";}', 'drupal_get_form', 'a:2:{i:0;s:20:"aggregator_form_feed";i:1;i:2;}', '', '13', 4, '1', 'aggregator/sources/%', 'aggregator/sources/%', 'Configure', 't', '', '', 'a:0:{}', '132', '', '', '1', 'modules/aggregator/aggregator.admin.inc'),
('aggregator/sources/%/view', 'a:1:{i:2;s:20:"aggregator_feed_load";}', '', 'user_access', 'a:1:{i:0;s:17:"access news feeds";}', 'aggregator_page_source', 'a:1:{i:0;i:2;}', '', '13', 4, '1', 'aggregator/sources/%', 'aggregator/sources/%', 'View', 't', '', '', 'a:0:{}', '140', '', '', '-10', 'modules/aggregator/aggregator.pages.inc'),
('archive', '', '', 'views_access', 'a:1:{i:0;b:1;}', 'views_page', 'a:2:{i:0;s:7:"archive";i:1;s:4:"page";}', '', '1', 1, '0', '', 'archive', '', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('batch', '', '', '1', 'a:0:{}', 'system_batch_page', 'a:0:{}', '', '1', 1, '0', '', 'batch', '', 't', '', '_system_batch_theme', 'a:0:{}', '0', '', '', '0', 'modules/system/system.admin.inc'),
('blog', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'blog_page_last', 'a:0:{}', '', '1', 1, '0', '', 'blog', 'Blogs', 't', '', '', 'a:0:{}', '20', '', '', '0', 'modules/blog/blog.pages.inc'),
('blog/%', 'a:1:{i:1;s:22:"user_uid_optional_load";}', 'a:1:{i:1;s:24:"user_uid_optional_to_arg";}', 'blog_page_user_access', 'a:1:{i:0;i:1;}', 'blog_page_user', 'a:1:{i:0;i:1;}', '', '2', 2, '0', '', 'blog/%', 'My blog', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/blog/blog.pages.inc'),
('blog/%/feed', 'a:1:{i:1;s:9:"user_load";}', '', 'blog_page_user_access', 'a:1:{i:0;i:1;}', 'blog_feed_user', 'a:1:{i:0;i:1;}', '', '5', 3, '0', '', 'blog/%/feed', 'Blogs', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/blog/blog.pages.inc'),
('blog/feed', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'blog_feed_last', 'a:0:{}', '', '3', 2, '0', '', 'blog/feed', 'Blogs', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/blog/blog.pages.inc'),
('book', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'book_render', 'a:0:{}', '', '1', 1, '0', '', 'book', 'Books', 't', '', '', 'a:0:{}', '20', '', '', '0', 'modules/book/book.pages.inc'),
('book/export/%/%', 'a:2:{i:2;N;i:3;N;}', '', 'user_access', 'a:1:{i:0;s:31:"access printer-friendly version";}', 'book_export', 'a:2:{i:0;i:2;i:1;i:3;}', '', '12', 4, '0', '', 'book/export/%/%', '', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/book/book.pages.inc'),
('comment/%', 'a:1:{i:1;N;}', '', 'user_access', 'a:1:{i:0;s:15:"access comments";}', 'comment_permalink', 'a:1:{i:0;i:1;}', '', '2', 2, '0', '', 'comment/%', 'Comment permalink', 't', '', '', 'a:0:{}', '6', '', '', '0', ''),
('comment/%/approve', 'a:1:{i:1;N;}', '', 'user_access', 'a:1:{i:0;s:19:"administer comments";}', 'comment_approve', 'a:1:{i:0;i:1;}', '', '5', 3, '0', '', 'comment/%/approve', 'Approve', 't', '', '', 'a:0:{}', '6', '', '', '1', 'modules/comment/comment.pages.inc'),
('comment/%/delete', 'a:1:{i:1;N;}', '', 'user_access', 'a:1:{i:0;s:19:"administer comments";}', 'comment_confirm_delete_page', 'a:1:{i:0;i:1;}', '', '5', 3, '1', 'comment/%', 'comment/%', 'Delete', 't', '', '', 'a:0:{}', '132', '', '', '2', 'modules/comment/comment.admin.inc'),
('comment/%/edit', 'a:1:{i:1;s:12:"comment_load";}', '', 'comment_access', 'a:2:{i:0;s:4:"edit";i:1;i:1;}', 'comment_edit_page', 'a:1:{i:0;i:1;}', '', '5', 3, '1', 'comment/%', 'comment/%', 'Edit', 't', '', '', 'a:0:{}', '132', '', '', '0', ''),
('comment/%/view', 'a:1:{i:1;N;}', '', 'user_access', 'a:1:{i:0;s:15:"access comments";}', 'comment_permalink', 'a:1:{i:0;i:1;}', '', '5', 3, '1', 'comment/%', 'comment/%', 'View comment', 't', '', '', 'a:0:{}', '140', '', '', '-10', ''),
('comment/reply/%', 'a:1:{i:2;s:9:"node_load";}', '', 'node_access', 'a:2:{i:0;s:4:"view";i:1;i:2;}', 'comment_reply', 'a:1:{i:0;i:2;}', '', '6', 3, '0', '', 'comment/reply/%', 'Add new comment', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/comment/comment.pages.inc'),
('comments/recent', '', '', 'views_access', 'a:1:{i:0;b:1;}', 'views_page', 'a:2:{i:0;s:15:"comments_recent";i:1;s:4:"page";}', '', '3', 2, '0', '', 'comments/recent', '', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('contact', '', '', 'user_access', 'a:1:{i:0;s:29:"access site-wide contact form";}', 'drupal_get_form', 'a:1:{i:0;s:17:"contact_site_form";}', '', '1', 1, '0', '', 'contact', 'Contact', 't', '', '', 'a:0:{}', '20', '', '', '0', 'modules/contact/contact.pages.inc'),
('contacts', '', '', 'ctools_access_menu', 'a:1:{i:0;a:2:{s:4:"type";s:4:"none";s:8:"settings";N;}}', 'page_manager_page_execute', 'a:1:{i:0;s:8:"contacts";}', '', '1', 1, '0', '', 'contacts', '', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/page_manager/plugins/tasks/page.inc'),
('ctools/autocomplete/%', 'a:1:{i:2;N;}', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'ctools_content_autocomplete_entity', 'a:1:{i:0;i:2;}', '', '6', 3, '0', '', 'ctools/autocomplete/%', '', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/content.menu.inc'),
('ctools/context/ajax/access/add', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'ctools_access_ajax_add', 'a:0:{}', '', '31', 5, '0', '', 'ctools/context/ajax/access/add', '', 't', '', 'ajax_base_page_theme', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/context-access-admin.inc'),
('ctools/context/ajax/access/configure', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'ctools_access_ajax_edit', 'a:0:{}', '', '31', 5, '0', '', 'ctools/context/ajax/access/configure', '', 't', '', 'ajax_base_page_theme', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/context-access-admin.inc'),
('ctools/context/ajax/access/delete', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'ctools_access_ajax_delete', 'a:0:{}', '', '31', 5, '0', '', 'ctools/context/ajax/access/delete', '', 't', '', 'ajax_base_page_theme', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/context-access-admin.inc'),
('ctools/context/ajax/add', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'ctools_context_ajax_item_add', 'a:0:{}', '', '15', 4, '0', '', 'ctools/context/ajax/add', '', 't', '', 'ajax_base_page_theme', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/context-admin.inc'),
('ctools/context/ajax/configure', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'ctools_context_ajax_item_edit', 'a:0:{}', '', '15', 4, '0', '', 'ctools/context/ajax/configure', '', 't', '', 'ajax_base_page_theme', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/context-admin.inc'),
('ctools/context/ajax/delete', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'ctools_context_ajax_item_delete', 'a:0:{}', '', '15', 4, '0', '', 'ctools/context/ajax/delete', '', 't', '', 'ajax_base_page_theme', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/includes/context-admin.inc'),
('demo/autocomplete', '', '', 'user_access', 'a:1:{i:0;s:24:"administer demo settings";}', 'demo_autocomplete', 'a:0:{}', '', '3', 2, '0', '', 'demo/autocomplete', '', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/demo/demo.admin.inc'),
('demo/download', '', '', 'user_access', 'a:1:{i:0;s:24:"administer demo settings";}', 'demo_download', 'a:0:{}', '', '3', 2, '0', '', 'demo/download', '', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/demo/demo.admin.inc'),
('faq-page', '', '', 'user_access', 'a:1:{i:0;s:13:"view faq page";}', 'faq_page', 'a:0:{}', '', '1', 1, '0', '', 'faq-page', 'Frequently Asked Questions', 't', '', '', 'a:0:{}', '20', '', '', '1', ''),
('faq-page/%', 'a:1:{i:1;N;}', '', 'user_access', 'a:1:{i:0;s:13:"view faq page";}', 'faq_page', 'a:1:{i:0;i:1;}', '', '2', 2, '0', '', 'faq-page/%', 'Frequently Asked Questions', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('faq-page/%/list', 'a:1:{i:1;N;}', '', 'user_access', 'a:1:{i:0;s:13:"view faq page";}', 'faq_page', 'a:1:{i:0;i:1;}', '', '5', 3, '1', 'faq-page/%', 'faq-page/%', 'List', 't', '', '', 'a:0:{}', '140', '', '', '-10', ''),
('faq-page/%/order', 'a:1:{i:1;N;}', '', 'user_access', 'a:1:{i:0;s:20:"administer faq order";}', 'drupal_get_form', 'a:2:{i:0;s:23:"faq_order_settings_form";i:1;i:1;}', '', '5', 3, '1', 'faq-page/%', 'faq-page/%', 'Order', 't', '', '', 'a:0:{}', '132', 'Allows the user to configure the order of questions and answers on a FAQ page.', '', '-8', 'sites/all/modules/faq/faq.admin.inc'),
('faq-page/list', '', '', 'user_access', 'a:1:{i:0;s:13:"view faq page";}', 'faq_page', 'a:0:{}', '', '3', 2, '1', 'faq-page', 'faq-page', 'List', 't', '', '', 'a:0:{}', '140', '', '', '-10', ''),
('faq-page/order', '', '', 'user_access', 'a:1:{i:0;s:20:"administer faq order";}', 'drupal_get_form', 'a:1:{i:0;s:23:"faq_order_settings_form";}', '', '3', 2, '1', 'faq-page', 'faq-page', 'Order', 't', '', '', 'a:0:{}', '132', 'Allows the user to configure the order of questions and answers on a FAQ page.', '', '-8', 'sites/all/modules/faq/faq.admin.inc'),
('faq-questions-top', '', '', 'views_access', 'a:1:{i:0;a:2:{i:0;s:16:"views_check_perm";i:1;a:1:{i:0;s:14:"access content";}}}', 'views_page', 'a:2:{i:0;s:3:"faq";i:1;s:6:"page_1";}', '', '1', 1, '0', '', 'faq-questions-top', 'FAQ', 't', '', '', 'a:0:{}', '6', '', '', '0', ''),
('file/ajax', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'file_ajax_upload', 'a:0:{}', 'ajax_deliver', '3', 2, '0', '', 'file/ajax', '', 't', '', 'ajax_base_page_theme', 'a:0:{}', '0', '', '', '0', ''),
('file/progress', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'file_ajax_progress', 'a:0:{}', '', '3', 2, '0', '', 'file/progress', '', 't', '', 'ajax_base_page_theme', 'a:0:{}', '0', '', '', '0', ''),
('filter/tips', '', '', '1', 'a:0:{}', 'filter_tips_long', 'a:0:{}', '', '3', 2, '0', '', 'filter/tips', 'Compose tips', 't', '', '', 'a:0:{}', '20', '', '', '0', 'modules/filter/filter.pages.inc'),
('forum', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'forum_page', 'a:0:{}', '', '1', 1, '0', '', 'forum', 'Forums', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/forum/forum.pages.inc'),
('forum/%', 'a:1:{i:1;s:16:"forum_forum_load";}', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'forum_page', 'a:1:{i:0;i:1;}', '', '2', 2, '0', '', 'forum/%', 'Forums', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/forum/forum.pages.inc'),
('getlocations/info', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'getlocations_adinfo', 'a:0:{}', '', '3', 2, '0', '', 'getlocations/info', '', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('getlocations/lidinfo', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'getlocations_lidinfo', 'a:0:{}', '', '3', 2, '0', '', 'getlocations/lidinfo', '', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('getlocations/lids/%', 'a:1:{i:2;s:24:"getlocations_cdints_load";}', '', 'getlocations_access_location', 'a:0:{}', 'getlocations_lids', 'a:1:{i:0;i:2;}', '', '6', 3, '0', '', 'getlocations/lids/%', 'Get locations', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('getlocations/markerinfo', '', '', '1', 'a:0:{}', 'getlocations_markerinfo', 'a:0:{}', '', '3', 2, '0', '', 'getlocations/markerinfo', '', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('getlocations/nids/%', 'a:1:{i:2;s:24:"getlocations_cdints_load";}', '', 'getlocations_access_location', 'a:0:{}', 'getlocations_nids', 'a:1:{i:0;i:2;}', '', '6', 3, '0', '', 'getlocations/nids/%', 'Get locations', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('getlocations/node/%', 'a:1:{i:2;s:20:"getlocations_id_load";}', '', 'getlocations_access_location', 'a:0:{}', 'getlocations_nodemap', 'a:1:{i:0;i:2;}', '', '6', 3, '0', '', 'getlocations/node/%', 'Get locations', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('getlocations/term/%', 'a:1:{i:2;s:20:"getlocations_id_load";}', '', 'getlocations_access_location', 'a:0:{}', 'getlocations_termmap', 'a:1:{i:0;i:2;}', '', '6', 3, '0', '', 'getlocations/term/%', 'Get term locations', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('getlocations/type/%', 'a:1:{i:2;s:22:"getlocations_type_load";}', '', 'getlocations_access_location', 'a:0:{}', 'getlocations_typemap', 'a:3:{i:0;i:2;i:1;i:3;i:2;i:4;}', '', '6', 3, '0', '', 'getlocations/type/%', 'Get locations', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('getlocations_box', '', '', 'user_access', 'a:1:{i:0;s:19:"access getlocations";}', 'getlocations_box', 'a:0:{}', '', '1', 1, '0', '', 'getlocations_box', 'Get locations', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('getlocations_fields/city_autocomplete', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'getlocations_fields_city_autocomplete', 'a:0:{}', '', '3', 2, '0', '', 'getlocations_fields/city_autocomplete', '', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('getlocations_fields/country_autocomplete', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'getlocations_fields_country_autocomplete', 'a:0:{}', '', '3', 2, '0', '', 'getlocations_fields/country_autocomplete', '', 't', '', '', 'a:0:{}', '0', '', '', '0', '');
INSERT INTO `menu_router` VALUES
('getlocations_fields/province_autocomplete', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'getlocations_fields_province_autocomplete', 'a:0:{}', '', '3', 2, '0', '', 'getlocations_fields/province_autocomplete', '', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('js/admin_menu/cache', '', '', 'user_access', 'a:1:{i:0;s:26:"access administration menu";}', 'admin_menu_js_cache', 'a:0:{}', 'admin_menu_deliver', '7', 3, '0', '', 'js/admin_menu/cache', '', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('node', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'node_page_default', 'a:0:{}', '', '1', 1, '0', '', 'node', '', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('node/%', 'a:1:{i:1;s:9:"node_load";}', '', 'node_access', 'a:2:{i:0;s:4:"view";i:1;i:1;}', 'node_page_view', 'a:1:{i:0;i:1;}', '', '2', 2, '0', '', 'node/%', '', 'node_page_title', 'a:1:{i:0;i:1;}', '', 'a:0:{}', '6', '', '', '0', ''),
('node/%/delete', 'a:1:{i:1;s:9:"node_load";}', '', 'node_access', 'a:2:{i:0;s:6:"delete";i:1;i:1;}', 'drupal_get_form', 'a:2:{i:0;s:19:"node_delete_confirm";i:1;i:1;}', '', '5', 3, '2', 'node/%', 'node/%', 'Delete', 't', '', '', 'a:0:{}', '132', '', '', '1', 'modules/node/node.pages.inc'),
('node/%/edit', 'a:1:{i:1;s:9:"node_load";}', '', 'node_access', 'a:2:{i:0;s:6:"update";i:1;i:1;}', 'node_page_edit', 'a:1:{i:0;i:1;}', '', '5', 3, '3', 'node/%', 'node/%', 'Edit', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/node/node.pages.inc'),
('node/%/outline', 'a:1:{i:1;s:9:"node_load";}', '', '_book_outline_access', 'a:1:{i:0;i:1;}', 'book_outline', 'a:1:{i:0;i:1;}', '', '5', 3, '1', 'node/%', 'node/%', 'Outline', 't', '', '', 'a:0:{}', '132', '', '', '2', 'modules/book/book.pages.inc'),
('node/%/outline/remove', 'a:1:{i:1;s:9:"node_load";}', '', '_book_outline_remove_access', 'a:1:{i:0;i:1;}', 'drupal_get_form', 'a:2:{i:0;s:16:"book_remove_form";i:1;i:1;}', '', '11', 4, '0', '', 'node/%/outline/remove', 'Remove from outline', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/book/book.pages.inc'),
('node/%/panel_content', 'a:1:{i:1;s:9:"node_load";}', '', 'panels_node_edit_node', 'a:1:{i:0;i:1;}', 'panels_node_edit_content', 'a:1:{i:0;i:1;}', '', '5', 3, '1', 'node/%', 'node/%', 'Panel content', 't', '', '', 'a:0:{}', '132', '', '', '3', ''),
('node/%/panel_layout', 'a:1:{i:1;s:9:"node_load";}', '', 'panels_node_edit_node', 'a:1:{i:0;i:1;}', 'panels_node_edit_layout', 'a:1:{i:0;i:1;}', '', '5', 3, '1', 'node/%', 'node/%', 'Panel layout', 't', '', '', 'a:0:{}', '132', '', '', '2', ''),
('node/%/results', 'a:1:{i:1;s:9:"node_load";}', '', '_poll_menu_access', 'a:3:{i:0;i:1;i:1;s:14:"access content";i:2;b:1;}', 'poll_results', 'a:1:{i:0;i:1;}', '', '5', 3, '1', 'node/%', 'node/%', 'Results', 't', '', '', 'a:0:{}', '132', '', '', '3', 'modules/poll/poll.pages.inc'),
('node/%/revisions', 'a:1:{i:1;s:9:"node_load";}', '', '_node_revision_access', 'a:1:{i:0;i:1;}', 'node_revision_overview', 'a:1:{i:0;i:1;}', '', '5', 3, '1', 'node/%', 'node/%', 'Revisions', 't', '', '', 'a:0:{}', '132', '', '', '2', 'modules/node/node.pages.inc'),
('node/%/revisions/%/delete', 'a:2:{i:1;a:1:{s:9:"node_load";a:1:{i:0;i:3;}}i:3;N;}', '', '_node_revision_access', 'a:2:{i:0;i:1;i:1;s:6:"delete";}', 'drupal_get_form', 'a:2:{i:0;s:28:"node_revision_delete_confirm";i:1;i:1;}', '', '21', 5, '0', '', 'node/%/revisions/%/delete', 'Delete earlier revision', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/node/node.pages.inc'),
('node/%/revisions/%/revert', 'a:2:{i:1;a:1:{s:9:"node_load";a:1:{i:0;i:3;}}i:3;N;}', '', '_node_revision_access', 'a:2:{i:0;i:1;i:1;s:6:"update";}', 'drupal_get_form', 'a:2:{i:0;s:28:"node_revision_revert_confirm";i:1;i:1;}', '', '21', 5, '0', '', 'node/%/revisions/%/revert', 'Revert to earlier revision', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/node/node.pages.inc'),
('node/%/revisions/%/view', 'a:2:{i:1;a:1:{s:9:"node_load";a:1:{i:0;i:3;}}i:3;N;}', '', '_node_revision_access', 'a:1:{i:0;i:1;}', 'node_show', 'a:2:{i:0;i:1;i:1;b:1;}', '', '21', 5, '0', '', 'node/%/revisions/%/view', 'Revisions', 't', '', '', 'a:0:{}', '6', '', '', '0', ''),
('node/%/view', 'a:1:{i:1;s:9:"node_load";}', '', 'node_access', 'a:2:{i:0;s:4:"view";i:1;i:1;}', 'node_page_view', 'a:1:{i:0;i:1;}', '', '5', 3, '1', 'node/%', 'node/%', 'View', 't', '', '', 'a:0:{}', '140', '', '', '-10', ''),
('node/%/votes', 'a:1:{i:1;s:9:"node_load";}', '', '_poll_menu_access', 'a:3:{i:0;i:1;i:1;s:17:"inspect all votes";i:2;b:0;}', 'poll_votes', 'a:1:{i:0;i:1;}', '', '5', 3, '1', 'node/%', 'node/%', 'Votes', 't', '', '', 'a:0:{}', '132', '', '', '3', 'modules/poll/poll.pages.inc'),
('node/add', '', '', '_node_add_access', 'a:0:{}', 'node_add_page', 'a:0:{}', '', '3', 2, '0', '', 'node/add', 'Add content', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/node/node.pages.inc'),
('node/add/article', '', '', 'node_access', 'a:2:{i:0;s:6:"create";i:1;s:7:"article";}', 'node_add', 'a:1:{i:0;s:7:"article";}', '', '7', 3, '0', '', 'node/add/article', 'Article', 'check_plain', '', '', 'a:0:{}', '6', 'Use <em>articles</em> for time-sensitive content like news, press releases or blog posts.', '', '0', 'modules/node/node.pages.inc'),
('node/add/blog', '', '', 'node_access', 'a:2:{i:0;s:6:"create";i:1;s:4:"blog";}', 'node_add', 'a:1:{i:0;s:4:"blog";}', '', '7', 3, '0', '', 'node/add/blog', 'Blog entry', 'check_plain', '', '', 'a:0:{}', '6', 'Use for multi-user blogs. Every user gets a personal blog.', '', '0', 'modules/node/node.pages.inc'),
('node/add/book', '', '', 'node_access', 'a:2:{i:0;s:6:"create";i:1;s:4:"book";}', 'node_add', 'a:1:{i:0;s:4:"book";}', '', '7', 3, '0', '', 'node/add/book', 'Book page', 'check_plain', '', '', 'a:0:{}', '6', '<em>Books</em> have a built-in hierarchical navigation. Use for handbooks or tutorials.', '', '0', 'modules/node/node.pages.inc'),
('node/add/employee', '', '', 'node_access', 'a:2:{i:0;s:6:"create";i:1;s:8:"employee";}', 'node_add', 'a:1:{i:0;s:8:"employee";}', '', '7', 3, '0', '', 'node/add/employee', 'Employee', 'check_plain', '', '', 'a:0:{}', '6', 'Add staff', '', '0', 'modules/node/node.pages.inc'),
('node/add/faq', '', '', 'node_access', 'a:2:{i:0;s:6:"create";i:1;s:3:"faq";}', 'node_add', 'a:1:{i:0;s:3:"faq";}', '', '7', 3, '0', '', 'node/add/faq', 'FAQ', 'check_plain', '', '', 'a:0:{}', '6', 'A frequently asked question and its answer.', '', '0', 'modules/node/node.pages.inc'),
('node/add/forum', '', '', 'node_access', 'a:2:{i:0;s:6:"create";i:1;s:5:"forum";}', 'node_add', 'a:1:{i:0;s:5:"forum";}', '', '7', 3, '0', '', 'node/add/forum', 'Forum topic', 'check_plain', '', '', 'a:0:{}', '6', 'A <em>forum topic</em> starts a new discussion thread within a forum.', '', '0', 'modules/node/node.pages.inc'),
('node/add/maps', '', '', 'node_access', 'a:2:{i:0;s:6:"create";i:1;s:4:"maps";}', 'node_add', 'a:1:{i:0;s:4:"maps";}', '', '7', 3, '0', '', 'node/add/maps', 'Maps', 'check_plain', '', '', 'a:0:{}', '6', '', '', '0', 'modules/node/node.pages.inc'),
('node/add/page', '', '', 'node_access', 'a:2:{i:0;s:6:"create";i:1;s:4:"page";}', 'node_add', 'a:1:{i:0;s:4:"page";}', '', '7', 3, '0', '', 'node/add/page', 'Basic page', 'check_plain', '', '', 'a:0:{}', '6', 'Use <em>basic pages</em> for your static content, such as an ''About us'' page.', '', '0', 'modules/node/node.pages.inc'),
('node/add/panel', '', '', 'node_access', 'a:2:{i:0;s:6:"create";i:1;s:5:"panel";}', 'node_add', 'a:1:{i:0;s:5:"panel";}', '', '7', 3, '0', '', 'node/add/panel', 'Panel', 'check_plain', '', '', 'a:0:{}', '6', 'A panel layout broken up into rows and columns.', '', '0', 'modules/node/node.pages.inc'),
('node/add/panel/choose-layout', '', '', 'user_access', 'a:1:{i:0;s:18:"create panel-nodes";}', 'panels_node_add', 'a:0:{}', '', '15', 4, '0', '', 'node/add/panel/choose-layout', 'Choose layout', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('node/add/partners', '', '', 'node_access', 'a:2:{i:0;s:6:"create";i:1;s:8:"partners";}', 'node_add', 'a:1:{i:0;s:8:"partners";}', '', '7', 3, '0', '', 'node/add/partners', 'Partners', 'check_plain', '', '', 'a:0:{}', '6', '', '', '0', 'modules/node/node.pages.inc'),
('node/add/poll', '', '', 'node_access', 'a:2:{i:0;s:6:"create";i:1;s:4:"poll";}', 'node_add', 'a:1:{i:0;s:4:"poll";}', '', '7', 3, '0', '', 'node/add/poll', 'Poll', 'check_plain', '', '', 'a:0:{}', '6', 'A <em>poll</em> is a question with a set of possible responses. A <em>poll</em>, once created, automatically provides a simple running count of the number of votes received for each response.', '', '0', 'modules/node/node.pages.inc'),
('node/add/popular-services', '', '', 'node_access', 'a:2:{i:0;s:6:"create";i:1;s:16:"popular_services";}', 'node_add', 'a:1:{i:0;s:16:"popular_services";}', '', '7', 3, '0', '', 'node/add/popular-services', 'Popular services', 'check_plain', '', '', 'a:0:{}', '6', '', '', '0', 'modules/node/node.pages.inc'),
('node/add/portfolio', '', '', 'node_access', 'a:2:{i:0;s:6:"create";i:1;s:9:"portfolio";}', 'node_add', 'a:1:{i:0;s:9:"portfolio";}', '', '7', 3, '0', '', 'node/add/portfolio', 'Portfolio', 'check_plain', '', '', 'a:0:{}', '6', '', '', '0', 'modules/node/node.pages.inc'),
('node/add/services', '', '', 'node_access', 'a:2:{i:0;s:6:"create";i:1;s:8:"services";}', 'node_add', 'a:1:{i:0;s:8:"services";}', '', '7', 3, '0', '', 'node/add/services', 'Services', 'check_plain', '', '', 'a:0:{}', '6', '', '', '0', 'modules/node/node.pages.inc'),
('node/add/slider', '', '', 'node_access', 'a:2:{i:0;s:6:"create";i:1;s:6:"slider";}', 'node_add', 'a:1:{i:0;s:6:"slider";}', '', '7', 3, '0', '', 'node/add/slider', 'Slider', 'check_plain', '', '', 'a:0:{}', '6', 'Use to create slides in header-slider.', '', '0', 'modules/node/node.pages.inc'),
('node/add/testimonials', '', '', 'node_access', 'a:2:{i:0;s:6:"create";i:1;s:12:"testimonials";}', 'node_add', 'a:1:{i:0;s:12:"testimonials";}', '', '7', 3, '0', '', 'node/add/testimonials', 'Testimonials', 'check_plain', '', '', 'a:0:{}', '6', '', '', '0', 'modules/node/node.pages.inc'),
('page-404', '', '', 'ctools_access_menu', 'a:1:{i:0;a:2:{s:4:"type";s:4:"none";s:8:"settings";N;}}', 'page_manager_page_execute', 'a:1:{i:0;s:8:"page_404";}', '', '1', 1, '0', '', 'page-404', '', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/ctools/page_manager/plugins/tasks/page.inc'),
('panels/ajax', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'panels_ajax_router', 'a:0:{}', 'ajax_deliver', '3', 2, '0', '', 'panels/ajax', '', 't', '', 'ajax_base_page_theme', 'a:0:{}', '0', '', '', '0', ''),
('poll', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'poll_page', 'a:0:{}', '', '1', 1, '0', '', 'poll', 'Polls', 't', '', '', 'a:0:{}', '20', '', '', '0', 'modules/poll/poll.pages.inc'),
('portfolio', '', '', 'views_access', 'a:1:{i:0;a:2:{i:0;s:16:"views_check_perm";i:1;a:1:{i:0;s:14:"access content";}}}', 'views_page', 'a:2:{i:0;s:9:"portfolio";i:1;s:6:"page_1";}', '', '1', 1, '0', '', 'portfolio', 'Portfolio', 't', '', '', 'a:0:{}', '6', '', '', '0', ''),
('portfolio-2', '', '', 'views_access', 'a:1:{i:0;a:2:{i:0;s:16:"views_check_perm";i:1;a:1:{i:0;s:14:"access content";}}}', 'views_page', 'a:2:{i:0;s:9:"portfolio";i:1;s:6:"page_2";}', '', '1', 1, '0', '', 'portfolio-2', 'Portfolio 2', 't', '', '', 'a:0:{}', '6', '', '', '0', ''),
('portfolio-3', '', '', 'views_access', 'a:1:{i:0;a:2:{i:0;s:16:"views_check_perm";i:1;a:1:{i:0;s:14:"access content";}}}', 'views_page', 'a:2:{i:0;s:9:"portfolio";i:1;s:6:"page_3";}', '', '1', 1, '0', '', 'portfolio-3', 'Portfolio 3', 't', '', '', 'a:0:{}', '6', '', '', '0', ''),
('portfolio-4', '', '', 'views_access', 'a:1:{i:0;a:2:{i:0;s:16:"views_check_perm";i:1;a:1:{i:0;s:14:"access content";}}}', 'views_page', 'a:2:{i:0;s:9:"portfolio";i:1;s:4:"page";}', '', '1', 1, '0', '', 'portfolio-4', 'Portfolio 4', 't', '', '', 'a:0:{}', '6', '', '', '0', ''),
('rss.xml', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'node_feed', 'a:2:{i:0;b:0;i:1;a:0:{}}', '', '1', 1, '0', '', 'rss.xml', 'RSS feed', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('search', '', '', 'search_is_active', 'a:0:{}', 'search_view', 'a:0:{}', '', '1', 1, '0', '', 'search', 'Search', 't', '', '', 'a:0:{}', '20', '', '', '0', 'modules/search/search.pages.inc'),
('search/node', '', '', '_search_menu_access', 'a:1:{i:0;s:4:"node";}', 'search_view', 'a:2:{i:0;s:4:"node";i:1;s:0:"";}', '', '3', 2, '1', 'search', 'search', 'Content', 't', '', '', 'a:0:{}', '132', '', '', '-10', 'modules/search/search.pages.inc'),
('search/node/%', 'a:1:{i:2;a:1:{s:14:"menu_tail_load";a:2:{i:0;s:4:"%map";i:1;s:6:"%index";}}}', 'a:1:{i:2;s:16:"menu_tail_to_arg";}', '_search_menu_access', 'a:1:{i:0;s:4:"node";}', 'search_view', 'a:2:{i:0;s:4:"node";i:1;i:2;}', '', '6', 3, '1', 'search/node', 'search/node/%', 'Content', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/search/search.pages.inc'),
('search/user', '', '', '_search_menu_access', 'a:1:{i:0;s:4:"user";}', 'search_view', 'a:2:{i:0;s:4:"user";i:1;s:0:"";}', '', '3', 2, '1', 'search', 'search', 'Users', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/search/search.pages.inc'),
('search/user/%', 'a:1:{i:2;a:1:{s:14:"menu_tail_load";a:2:{i:0;s:4:"%map";i:1;s:6:"%index";}}}', 'a:1:{i:2;s:16:"menu_tail_to_arg";}', '_search_menu_access', 'a:1:{i:0;s:4:"user";}', 'search_view', 'a:2:{i:0;s:4:"user";i:1;i:2;}', '', '6', 3, '1', 'search/node', 'search/node/%', 'Users', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/search/search.pages.inc'),
('semantic-views-demo', '', '', 'views_access', 'a:1:{i:0;b:1;}', 'views_page', 'a:2:{i:0;s:13:"semantic_demo";i:1;s:6:"page_1";}', '', '1', 1, '0', '', 'semantic-views-demo', 'Semantic Views demo', 't', '', '', 'a:0:{}', '6', '', '', '0', ''),
('semantic-views-demo/grid', '', '', 'views_access', 'a:1:{i:0;b:1;}', 'views_page', 'a:2:{i:0;s:13:"semantic_demo";i:1;s:6:"page_2";}', '', '3', 2, '1', 'semantic-views-demo', 'semantic-views-demo', 'Grid', 't', '', '', 'a:0:{}', '132', '', '', '1', ''),
('semantic-views-demo/grid-semantic', '', '', 'views_access', 'a:1:{i:0;b:1;}', 'views_page', 'a:2:{i:0;s:13:"semantic_demo";i:1;s:6:"page_5";}', '', '3', 2, '1', 'semantic-views-demo', 'semantic-views-demo', 'Grid (semantic)', 't', '', '', 'a:0:{}', '132', '', '', '1', ''),
('semantic-views-demo/list', '', '', 'views_access', 'a:1:{i:0;b:1;}', 'views_page', 'a:2:{i:0;s:13:"semantic_demo";i:1;s:6:"page_3";}', '', '3', 2, '1', 'semantic-views-demo', 'semantic-views-demo', 'List', 't', '', '', 'a:0:{}', '132', '', '', '2', ''),
('semantic-views-demo/list-semantic', '', '', 'views_access', 'a:1:{i:0;b:1;}', 'views_page', 'a:2:{i:0;s:13:"semantic_demo";i:1;s:6:"page_6";}', '', '3', 2, '1', 'semantic-views-demo', 'semantic-views-demo', 'List (semantic)', 't', '', '', 'a:0:{}', '132', '', '', '2', ''),
('semantic-views-demo/unformatted', '', '', 'views_access', 'a:1:{i:0;b:1;}', 'views_page', 'a:2:{i:0;s:13:"semantic_demo";i:1;s:6:"page_1";}', '', '3', 2, '1', 'semantic-views-demo', 'semantic-views-demo', 'Unformatted', 't', '', '', 'a:0:{}', '140', '', '', '0', ''),
('semantic-views-demo/unformatted-semantic', '', '', 'views_access', 'a:1:{i:0;b:1;}', 'views_page', 'a:2:{i:0;s:13:"semantic_demo";i:1;s:6:"page_4";}', '', '3', 2, '1', 'semantic-views-demo', 'semantic-views-demo', 'Unformatted (semantic)', 't', '', '', 'a:0:{}', '132', '', '', '0', ''),
('services', '', '', 'ctools_access_menu', 'a:1:{i:0;a:2:{s:4:"type";s:4:"none";s:8:"settings";N;}}', 'page_manager_page_execute', 'a:1:{i:0;s:8:"services";}', '', '1', 1, '0', '', 'services', 'Services', 't', '', '', 'a:0:{}', '6', '', '', '0', 'sites/all/modules/ctools/page_manager/plugins/tasks/page.inc'),
('sites/default/files/css/follow.css', '', '', '1', 'a:0:{}', 'follow_css', 'a:0:{}', '', '31', 5, '0', '', 'sites/default/files/css/follow.css', 'Generate Follow CSS', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('sites/default/files/styles/%', 'a:1:{i:4;s:16:"image_style_load";}', '', '1', 'a:0:{}', 'image_style_deliver', 'a:1:{i:0;i:4;}', '', '30', 5, '0', '', 'sites/default/files/styles/%', 'Generate image style', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('system/ajax', '', '', '1', 'a:0:{}', 'ajax_form_callback', 'a:0:{}', 'ajax_deliver', '3', 2, '0', '', 'system/ajax', 'AHAH callback', 't', '', 'ajax_base_page_theme', 'a:0:{}', '0', '', '', '0', 'includes/form.inc'),
('system/files', '', '', '1', 'a:0:{}', 'file_download', 'a:1:{i:0;s:7:"private";}', '', '3', 2, '0', '', 'system/files', 'File download', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('system/files/styles/%', 'a:1:{i:3;s:16:"image_style_load";}', '', '1', 'a:0:{}', 'image_style_deliver', 'a:1:{i:0;i:3;}', '', '14', 4, '0', '', 'system/files/styles/%', 'Generate image style', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('system/temporary', '', '', '1', 'a:0:{}', 'file_download', 'a:1:{i:0;s:9:"temporary";}', '', '3', 2, '0', '', 'system/temporary', 'Temporary files', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('system/timezone', '', '', '1', 'a:0:{}', 'system_timezone', 'a:0:{}', '', '3', 2, '0', '', 'system/timezone', 'Time zone', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/system/system.admin.inc'),
('taxonomy/autocomplete', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'taxonomy_autocomplete', 'a:0:{}', '', '3', 2, '0', '', 'taxonomy/autocomplete', 'Autocomplete taxonomy', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/taxonomy/taxonomy.pages.inc'),
('taxonomy/term/%', 'a:1:{i:2;s:18:"taxonomy_term_load";}', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'taxonomy_term_page', 'a:1:{i:0;i:2;}', '', '6', 3, '0', '', 'taxonomy/term/%', 'Taxonomy term', 'taxonomy_term_title', 'a:1:{i:0;i:2;}', '', 'a:0:{}', '6', '', '', '0', 'modules/taxonomy/taxonomy.pages.inc'),
('taxonomy/term/%/edit', 'a:1:{i:2;s:18:"taxonomy_term_load";}', '', 'taxonomy_term_edit_access', 'a:1:{i:0;i:2;}', 'drupal_get_form', 'a:3:{i:0;s:18:"taxonomy_form_term";i:1;i:2;i:2;N;}', '', '13', 4, '1', 'taxonomy/term/%', 'taxonomy/term/%', 'Edit', 't', '', '', 'a:0:{}', '132', '', '', '10', 'modules/taxonomy/taxonomy.admin.inc'),
('taxonomy/term/%/feed', 'a:1:{i:2;s:18:"taxonomy_term_load";}', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'taxonomy_term_feed', 'a:1:{i:0;i:2;}', '', '13', 4, '0', '', 'taxonomy/term/%/feed', 'Taxonomy term', 'taxonomy_term_title', 'a:1:{i:0;i:2;}', '', 'a:0:{}', '0', '', '', '0', 'modules/taxonomy/taxonomy.pages.inc'),
('taxonomy/term/%/view', 'a:1:{i:2;s:18:"taxonomy_term_load";}', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'taxonomy_term_page', 'a:1:{i:0;i:2;}', '', '13', 4, '1', 'taxonomy/term/%', 'taxonomy/term/%', 'View', 't', '', '', 'a:0:{}', '140', '', '', '0', 'modules/taxonomy/taxonomy.pages.inc'),
('toolbar/toggle', '', '', 'user_access', 'a:1:{i:0;s:14:"access toolbar";}', 'toolbar_toggle_page', 'a:0:{}', '', '3', 2, '0', '', 'toolbar/toggle', 'Toggle drawer visibility', 't', '', '', 'a:0:{}', '0', '', '', '0', ''),
('tracker', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'tracker_page', 'a:0:{}', '', '1', 1, '0', '', 'tracker', 'Recent content', 't', '', '', 'a:0:{}', '6', '', '', '1', 'modules/tracker/tracker.pages.inc'),
('tracker/%', 'a:1:{i:1;s:22:"user_uid_optional_load";}', 'a:1:{i:1;s:24:"user_uid_optional_to_arg";}', '_tracker_myrecent_access', 'a:1:{i:0;i:1;}', 'tracker_page', 'a:1:{i:0;i:1;}', '', '2', 2, '1', 'tracker', 'tracker', 'My recent content', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/tracker/tracker.pages.inc'),
('tracker/all', '', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'tracker_page', 'a:0:{}', '', '3', 2, '1', 'tracker', 'tracker', 'All recent content', 't', '', '', 'a:0:{}', '140', '', '', '0', 'modules/tracker/tracker.pages.inc'),
('user', '', '', '1', 'a:0:{}', 'user_page', 'a:0:{}', '', '1', 1, '0', '', 'user', 'User account', 'user_menu_title', '', '', 'a:0:{}', '6', '', '', '-10', 'modules/user/user.pages.inc'),
('user/%', 'a:1:{i:1;s:9:"user_load";}', '', 'user_view_access', 'a:1:{i:0;i:1;}', 'user_view_page', 'a:1:{i:0;i:1;}', '', '2', 2, '0', '', 'user/%', 'My account', 'user_page_title', 'a:1:{i:0;i:1;}', '', 'a:0:{}', '6', '', '', '0', ''),
('user/%/cancel', 'a:1:{i:1;s:9:"user_load";}', '', 'user_cancel_access', 'a:1:{i:0;i:1;}', 'drupal_get_form', 'a:2:{i:0;s:24:"user_cancel_confirm_form";i:1;i:1;}', '', '5', 3, '0', '', 'user/%/cancel', 'Cancel account', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/user/user.pages.inc'),
('user/%/cancel/confirm/%/%', 'a:3:{i:1;s:9:"user_load";i:4;N;i:5;N;}', '', 'user_cancel_access', 'a:1:{i:0;i:1;}', 'user_cancel_confirm', 'a:3:{i:0;i:1;i:1;i:4;i:2;i:5;}', '', '44', 6, '0', '', 'user/%/cancel/confirm/%/%', 'Confirm account cancellation', 't', '', '', 'a:0:{}', '6', '', '', '0', 'modules/user/user.pages.inc'),
('user/%/contact', 'a:1:{i:1;s:9:"user_load";}', '', '_contact_personal_tab_access', 'a:1:{i:0;i:1;}', 'drupal_get_form', 'a:2:{i:0;s:21:"contact_personal_form";i:1;i:1;}', '', '5', 3, '1', 'user/%', 'user/%', 'Contact', 't', '', '', 'a:0:{}', '132', '', '', '2', 'modules/contact/contact.pages.inc'),
('user/%/edit', 'a:1:{i:1;s:9:"user_load";}', '', 'user_edit_access', 'a:1:{i:0;i:1;}', 'drupal_get_form', 'a:2:{i:0;s:17:"user_profile_form";i:1;i:1;}', '', '5', 3, '1', 'user/%', 'user/%', 'Edit', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/user/user.pages.inc'),
('user/%/edit/account', 'a:1:{i:1;a:1:{s:18:"user_category_load";a:2:{i:0;s:4:"%map";i:1;s:6:"%index";}}}', '', 'user_edit_access', 'a:1:{i:0;i:1;}', 'drupal_get_form', 'a:2:{i:0;s:17:"user_profile_form";i:1;i:1;}', '', '11', 4, '1', 'user/%/edit', 'user/%', 'Account', 't', '', '', 'a:0:{}', '140', '', '', '0', 'modules/user/user.pages.inc'),
('user/%/follow', 'a:1:{i:1;N;}', '', 'follow_links_user_access', 'a:1:{i:0;i:1;}', 'drupal_get_form', 'a:2:{i:0;s:17:"follow_links_form";i:1;i:1;}', '', '5', 3, '1', 'user/%', 'user/%', 'Follow', 't', '', '', 'a:0:{}', '132', 'Update the associated web service follow links.', '', '0', ''),
('user/%/shortcuts', 'a:1:{i:1;s:9:"user_load";}', '', 'shortcut_set_switch_access', 'a:1:{i:0;i:1;}', 'drupal_get_form', 'a:2:{i:0;s:19:"shortcut_set_switch";i:1;i:1;}', '', '5', 3, '1', 'user/%', 'user/%', 'Shortcuts', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/shortcut/shortcut.admin.inc'),
('user/%/track', 'a:1:{i:1;s:9:"user_load";}', '', '_tracker_user_access', 'a:1:{i:0;i:1;}', 'tracker_page', 'a:2:{i:0;i:1;i:1;b:1;}', '', '5', 3, '1', 'user/%', 'user/%', 'Track', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/tracker/tracker.pages.inc'),
('user/%/track/content', 'a:1:{i:1;s:9:"user_load";}', '', '_tracker_user_access', 'a:1:{i:0;i:1;}', 'tracker_page', 'a:2:{i:0;i:1;i:1;b:1;}', '', '11', 4, '1', 'user/%/track', 'user/%', 'Track content', 't', '', '', 'a:0:{}', '140', '', '', '0', 'modules/tracker/tracker.pages.inc'),
('user/%/view', 'a:1:{i:1;s:9:"user_load";}', '', 'user_view_access', 'a:1:{i:0;i:1;}', 'user_view_page', 'a:1:{i:0;i:1;}', '', '5', 3, '1', 'user/%', 'user/%', 'View', 't', '', '', 'a:0:{}', '140', '', '', '-10', ''),
('user/autocomplete', '', '', 'user_access', 'a:1:{i:0;s:20:"access user profiles";}', 'user_autocomplete', 'a:0:{}', '', '3', 2, '0', '', 'user/autocomplete', 'User autocomplete', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/user/user.pages.inc'),
('user/login', '', '', 'user_is_anonymous', 'a:0:{}', 'user_page', 'a:0:{}', '', '3', 2, '1', 'user', 'user', 'Log in', 't', '', '', 'a:0:{}', '140', '', '', '0', 'modules/user/user.pages.inc'),
('user/logout', '', '', 'user_is_logged_in', 'a:0:{}', 'user_logout', 'a:0:{}', '', '3', 2, '0', '', 'user/logout', 'Log out', 't', '', '', 'a:0:{}', '6', '', '', '10', 'modules/user/user.pages.inc'),
('user/password', '', '', '1', 'a:0:{}', 'drupal_get_form', 'a:1:{i:0;s:9:"user_pass";}', '', '3', 2, '1', 'user', 'user', 'Request new password', 't', '', '', 'a:0:{}', '132', '', '', '0', 'modules/user/user.pages.inc'),
('user/register', '', '', 'user_register_access', 'a:0:{}', 'drupal_get_form', 'a:1:{i:0;s:18:"user_register_form";}', '', '3', 2, '1', 'user', 'user', 'Create new account', 't', '', '', 'a:0:{}', '132', '', '', '0', ''),
('user/reset/%/%/%', 'a:3:{i:2;N;i:3;N;i:4;N;}', '', '1', 'a:0:{}', 'drupal_get_form', 'a:4:{i:0;s:15:"user_pass_reset";i:1;i:2;i:2;i:3;i:3;i:4;}', '', '24', 5, '0', '', 'user/reset/%/%/%', 'Reset password', 't', '', '', 'a:0:{}', '0', '', '', '0', 'modules/user/user.pages.inc'),
('views/ajax', '', '', '1', 'a:0:{}', 'views_ajax', 'a:0:{}', 'ajax_deliver', '3', 2, '0', '', 'views/ajax', 'Views', 't', '', 'ajax_base_page_theme', 'a:0:{}', '0', 'Ajax callback for view loading.', '', '0', 'sites/all/modules/views/includes/ajax.inc'),
('wysiwyg/%', 'a:1:{i:1;N;}', '', 'user_access', 'a:1:{i:0;s:14:"access content";}', 'wysiwyg_dialog', 'a:1:{i:0;i:1;}', 'wysiwyg_deliver_dialog_page', '2', 2, '0', '', 'wysiwyg/%', '', 't', '', '', 'a:0:{}', '0', '', '', '0', 'sites/all/modules/wysiwyg/wysiwyg.dialog.inc');
/*!40000 ALTER TABLE menu_router ENABLE KEYS */;

--
-- Table structure for table 'node'
--

CREATE TABLE IF NOT EXISTS `node` (
  `nid` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'The primary identifier for a node.',
  `vid` int(10) unsigned DEFAULT NULL COMMENT 'The current node_revision.vid version identifier.',
  `type` varchar(32) NOT NULL DEFAULT '' COMMENT 'The node_type.type of this node.',
  `language` varchar(12) NOT NULL DEFAULT '' COMMENT 'The languages.language of this node.',
  `title` varchar(255) NOT NULL DEFAULT '' COMMENT 'The title of this node, always treated as non-markup plain text.',
  `uid` int(11) NOT NULL DEFAULT '0' COMMENT 'The users.uid that owns this node; initially, this is the user that created it.',
  `status` int(11) NOT NULL DEFAULT '1' COMMENT 'Boolean indicating whether the node is published (visible to non-administrators).',
  `created` int(11) NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp when the node was created.',
  `changed` int(11) NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp when the node was most recently saved.',
  `comment` int(11) NOT NULL DEFAULT '0' COMMENT 'Whether comments are allowed on this node: 0 = no, 1 = closed (read only), 2 = open (read/write).',
  `promote` int(11) NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether the node should be displayed on the front page.',
  `sticky` int(11) NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether the node should be displayed at the top of lists in which it appears.',
  `tnid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The translation set id for this node, which equals the node id of the source post in each set.',
  `translate` int(11) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this translation page needs to be updated.',
  PRIMARY KEY (`nid`),
  UNIQUE KEY `vid` (`vid`),
  KEY `node_changed` (`changed`),
  KEY `node_created` (`created`),
  KEY `node_frontpage` (`promote`,`status`,`sticky`,`created`),
  KEY `node_status_type` (`status`,`type`,`nid`),
  KEY `node_title_type` (`title`,`type`(4)),
  KEY `node_type` (`type`(4)),
  KEY `uid` (`uid`),
  KEY `tnid` (`tnid`),
  KEY `translate` (`translate`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='The base table for nodes.';

--
-- Dumping data for table 'node'
--

/*!40000 ALTER TABLE node DISABLE KEYS */;
INSERT INTO `node` VALUES
('11', '11', 'poll', 'en', 'What do you think about us?', '1', '1', '1333107995', '1333107995', '1', '0', '0', '0', '0'),
('12', '12', 'forum', 'en', 'Lorem ipsum dolor sit amet', '1', '1', '1305117326', '1305117326', '2', '0', '0', '0', '0'),
('13', '13', 'forum', 'en', 'In pellentesque facilisis iaculis.', '1', '1', '1305117431', '1305117431', '2', '0', '0', '0', '0'),
('14', '14', 'forum', 'en', 'Mauris porta magna eget dolor vestibulum dapibus', '1', '1', '1305117493', '1305117493', '2', '0', '0', '0', '0'),
('15', '15', 'forum', 'en', 'Suspendisse potenti', '1', '1', '1305117558', '1305117558', '2', '0', '0', '0', '0'),
('16', '16', 'forum', 'en', 'Pellentesque habitant morbi tristique senectus', '1', '1', '1305117592', '1305117592', '2', '0', '0', '0', '0'),
('17', '17', 'forum', 'en', 'Ut vehicula, quam aliquam fringilla', '1', '1', '1305117638', '1305117638', '2', '0', '0', '0', '0'),
('18', '18', 'forum', 'en', 'Nam nec est a nulla pulvinar dignissim', '1', '1', '1305117661', '1305117661', '2', '0', '0', '0', '0'),
('19', '19', 'forum', 'en', 'In ac lectus massa. Pellentesque eros ligula', '1', '1', '1305117686', '1305117686', '2', '0', '0', '0', '0'),
('20', '20', 'forum', 'en', 'Suspendisse vulputate hendrerit nulla', '1', '1', '1305117721', '1305117721', '2', '0', '0', '0', '0'),
('21', '21', 'forum', 'en', 'Lorem ipsum dolor sit amet', '1', '1', '1305117759', '1305117759', '2', '0', '0', '0', '0'),
('22', '22', 'forum', 'en', 'Cras euismod aliquet massa scelerisque euismo', '1', '1', '1305117790', '1305117790', '2', '0', '0', '0', '0'),
('23', '23', 'forum', 'en', 'Cras euismod aliquet massa scelerisque', '1', '1', '1305117828', '1305117828', '2', '0', '0', '0', '0'),
('24', '24', 'forum', 'en', 'Praesent non mauris eget nisi', '1', '1', '1305117855', '1305117855', '2', '0', '0', '0', '0'),
('25', '25', 'forum', 'en', 'Suspendisse tempor libero sed ip', '1', '1', '1305117888', '1305117888', '2', '0', '0', '0', '0'),
('26', '26', 'forum', 'en', 'Fusce ac lacus metu', '1', '1', '1305117913', '1305117913', '2', '0', '0', '0', '0'),
('27', '27', 'forum', 'en', 'Curabitur feugiat ornare pul', '1', '1', '1305117944', '1305117944', '2', '0', '0', '0', '0'),
('28', '28', 'forum', 'en', 'Suspendisse potenti', '1', '1', '1305117979', '1305117979', '2', '0', '0', '0', '0'),
('29', '29', 'forum', 'en', 'Curabitur feugiat ornare pulv', '1', '1', '1305118002', '1305118002', '2', '0', '0', '0', '0'),
('30', '30', 'forum', 'en', 'entesque tempus hend', '1', '1', '1305118030', '1305118030', '2', '0', '0', '0', '0'),
('31', '31', 'forum', 'en', 'rius metus, consequat sollicit', '1', '1', '1305118075', '1305118075', '2', '0', '0', '0', '0'),
('32', '32', 'forum', 'en', 'Aliquam vitae nunc metus', '1', '1', '1305118101', '1305118101', '2', '0', '0', '0', '0'),
('33', '33', 'forum', 'en', 'Aliquam lacinia iaculis leo', '1', '1', '1305118138', '1305118138', '2', '0', '0', '0', '0'),
('34', '34', 'forum', 'en', 'Lorem ipsum dolor sit am', '1', '1', '1305118163', '1305118163', '2', '0', '0', '0', '0'),
('35', '35', 'forum', 'en', 'Nullam eu erat nibh', '1', '1', '1305118193', '1305118193', '2', '0', '0', '0', '0'),
('36', '36', 'article', 'en', 'Lorem ipsum dolor sit amet, consectetur adipisicing elit', '1', '1', '1333108028', '1374828279', '2', '0', '0', '0', '0'),
('37', '37', 'blog', 'en', 'Donece pellente', '1', '1', '1333108059', '1378991808', '2', '0', '0', '0', '0'),
('38', '38', 'blog', 'en', 'Donece pellente', '1', '1', '1333108072', '1378991809', '2', '0', '0', '0', '0'),
('39', '39', 'blog', 'en', 'Donece pellente', '1', '1', '1333108052', '1378991807', '2', '0', '0', '0', '0'),
('40', '40', 'blog', 'en', 'Donece pellente', '1', '1', '1333108045', '1378991805', '2', '0', '0', '0', '0'),
('41', '41', 'blog', 'en', 'Donece pellente', '1', '1', '1333108079', '1378991811', '2', '0', '0', '0', '0'),
('42', '42', 'faq', 'en', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit?', '1', '1', '1311001382', '1311001382', '1', '0', '0', '0', '0'),
('43', '43', 'faq', 'en', 'Phasellus non dui magna, sit amet elementum lectus. Nullam ipsum ipsum, bibendum id mollis a, malesuada sit amet turpis?', '1', '1', '1311001570', '1311001570', '1', '0', '0', '0', '0'),
('44', '44', 'faq', 'en', 'Nunc commodo nisi ultricies nulla convallis et facilisis enim cursus. Ut purus ligula, consequat a posuere at, ultricies in quam?', '1', '1', '1311001635', '1311001635', '1', '0', '0', '0', '0'),
('45', '45', 'faq', 'en', 'Aliquam erat volutpat. Phasellus ac est velit. Proin sit amet urna dui, sed volutpat orci. Nam molestie viverra eros, eu lacinia nunc facilisis sed?', '1', '1', '1311001697', '1311001697', '1', '0', '0', '0', '0'),
('46', '46', 'faq', 'en', 'Sed vitae orci enim, ut accumsan sem. Donec orci risus, porta in tempor a, blandit ut risus. Donec vitae velit neque, nec adipiscing ipsum?', '1', '1', '1311001731', '1311001731', '1', '0', '0', '0', '0'),
('47', '47', 'slider', 'en', 'Quality', '1', '1', '1333108174', '1378907751', '1', '0', '0', '0', '0'),
('50', '50', 'slider', 'en', 'Style', '1', '1', '1333108167', '1378907811', '1', '0', '0', '0', '0'),
('51', '51', 'slider', 'en', 'Comfort', '1', '1', '1333108158', '1378907850', '1', '0', '0', '0', '0'),
('52', '52', 'portfolio', 'en', 'Lorem ipsum dolor sit amet', '1', '1', '1333107871', '1378992221', '1', '0', '0', '0', '0'),
('53', '53', 'portfolio', 'en', 'Fusce suscipit varius', '1', '1', '1333107913', '1378992222', '1', '0', '0', '0', '0'),
('54', '54', 'portfolio', 'en', 'Ut enim ad minima veniam', '1', '1', '1333107906', '1378992224', '1', '0', '0', '0', '0'),
('55', '55', 'portfolio', 'en', 'Sed utem perspiciatis', '1', '1', '1333107899', '1378992225', '1', '0', '0', '0', '0'),
('56', '56', 'portfolio', 'en', 'Vestibulum libero nislum', '1', '1', '1333107886', '1378992228', '1', '0', '0', '0', '0'),
('57', '57', 'portfolio', 'en', 'Praesent vestibulum', '1', '1', '1333107892', '1378992218', '1', '0', '0', '0', '0'),
('58', '58', 'portfolio', 'en', 'Praesent vestibulum', '1', '1', '1333107878', '1378992230', '1', '0', '0', '0', '0'),
('65', '65', 'employee', 'en', 'John Franklin', '1', '1', '1315211393', '1354540903', '1', '0', '0', '0', '0'),
('67', '67', 'employee', 'en', 'Samantha Jacobs', '1', '1', '1315211704', '1354540838', '1', '0', '0', '0', '0'),
('68', '68', 'employee', 'en', 'Sarah Conor', '1', '1', '1315211741', '1354540862', '1', '0', '0', '0', '0'),
('69', '69', 'employee', 'en', 'Jessica Parker', '1', '1', '1315211790', '1354540870', '1', '0', '0', '0', '0'),
('71', '71', 'employee', 'en', 'David Johnson', '1', '1', '1315211916', '1354540885', '1', '0', '0', '0', '0'),
('73', '73', 'employee', 'en', 'Sam Kronshtain', '1', '1', '1315214872', '1354540936', '1', '0', '0', '0', '0'),
('76', '76', 'services', 'en', 'Interior Design', '1', '1', '1333108122', '1378991299', '2', '0', '0', '0', '0'),
('77', '77', 'services', 'en', 'Our Team', '1', '1', '1333108115', '1378991290', '2', '0', '0', '0', '0'),
('78', '78', 'services', 'en', 'Design Ideas', '1', '1', '1333108108', '1378991281', '2', '0', '0', '0', '0'),
('79', '79', 'page', 'en', 'Privacy policy', '1', '1', '1322324835', '1322324835', '1', '0', '0', '0', '0'),
('81', '81', 'maps', 'en', 'Our location', '1', '1', '1353943550', '1353943550', '1', '0', '0', '0', '0'),
('82', '82', 'portfolio', 'en', 'Lorem ipsum dolor sit', '1', '1', '1358522809', '1379064099', '1', '0', '0', '0', '0'),
('83', '83', 'popular_services', 'en', 'Praesent vestibulum', '1', '1', '1374841095', '1378992001', '1', '0', '0', '0', '0'),
('84', '84', 'popular_services', 'en', 'Lorem ipsum dolor sit amet', '1', '1', '1374841097', '1378992051', '1', '0', '0', '0', '0'),
('85', '85', 'popular_services', 'en', 'Ut enim ad minima veniam', '1', '1', '1374841099', '1378991996', '1', '0', '0', '0', '0'),
('86', '86', 'popular_services', 'en', 'Sed ut perspiciatis unde', '1', '1', '1374841101', '1378991997', '1', '0', '0', '0', '0'),
('87', '87', 'popular_services', 'en', 'Vestibulum iaculis lacinia', '1', '1', '1374841104', '1378991999', '1', '0', '0', '0', '0'),
('88', '88', 'testimonials', 'en', 'Jack Smith', '157', '1', '1375101293', '1375101468', '1', '0', '0', '0', '0'),
('89', '89', 'testimonials', 'en', 'Lisa cole', '158', '1', '1375101372', '1375101372', '1', '0', '0', '0', '0');
/*!40000 ALTER TABLE node ENABLE KEYS */;

--
-- Table structure for table 'node_access'
--

CREATE TABLE IF NOT EXISTS `node_access` (
  `nid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The node.nid this record affects.',
  `gid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The grant ID a user must possess in the specified realm to gain this row’s privileges on the node.',
  `realm` varchar(255) NOT NULL DEFAULT '' COMMENT 'The realm in which the user must possess the grant ID. Each node access node can define one or more realms.',
  `grant_view` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether a user with the realm/grant pair can view this node.',
  `grant_update` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether a user with the realm/grant pair can edit this node.',
  `grant_delete` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether a user with the realm/grant pair can delete this node.',
  PRIMARY KEY (`nid`,`gid`,`realm`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Identifies which realm/grant pairs a user must possess in...';

--
-- Dumping data for table 'node_access'
--

/*!40000 ALTER TABLE node_access DISABLE KEYS */;
INSERT INTO `node_access` VALUES
('0', '0', 'all', '1', '0', '0');
/*!40000 ALTER TABLE node_access ENABLE KEYS */;

--
-- Table structure for table 'node_comment_statistics'
--

CREATE TABLE IF NOT EXISTS `node_comment_statistics` (
  `nid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The node.nid for which the statistics are compiled.',
  `cid` int(11) NOT NULL DEFAULT '0' COMMENT 'The comment.cid of the last comment.',
  `last_comment_timestamp` int(11) NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp of the last comment that was posted within this node, from comment.changed.',
  `last_comment_name` varchar(60) DEFAULT NULL COMMENT 'The name of the latest author to post a comment on this node, from comment.name.',
  `last_comment_uid` int(11) NOT NULL DEFAULT '0' COMMENT 'The user ID of the latest author to post a comment on this node, from comment.uid.',
  `comment_count` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The total number of comments on this node.',
  PRIMARY KEY (`nid`),
  KEY `node_comment_timestamp` (`last_comment_timestamp`),
  KEY `comment_count` (`comment_count`),
  KEY `last_comment_uid` (`last_comment_uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Maintains statistics of node and comments posts to show ...';

--
-- Dumping data for table 'node_comment_statistics'
--

/*!40000 ALTER TABLE node_comment_statistics DISABLE KEYS */;
INSERT INTO `node_comment_statistics` VALUES
('11', '0', '1305116486', NULL, '1', '0'),
('12', '3', '1305117353', '', '1', '3'),
('13', '4', '1305117437', '', '1', '1'),
('14', '9', '1305117530', '', '1', '5'),
('15', '0', '1305117558', NULL, '1', '0'),
('16', '11', '1305117601', '', '1', '2'),
('17', '0', '1305117638', NULL, '1', '0'),
('18', '0', '1305117661', NULL, '1', '0'),
('19', '0', '1305117686', NULL, '1', '0'),
('20', '0', '1305117721', NULL, '1', '0'),
('21', '0', '1305117759', NULL, '1', '0'),
('22', '0', '1305117790', NULL, '1', '0'),
('23', '0', '1305117828', NULL, '1', '0'),
('24', '0', '1305117855', NULL, '1', '0'),
('25', '0', '1305117888', NULL, '1', '0'),
('26', '0', '1305117913', NULL, '1', '0'),
('27', '0', '1305117944', NULL, '1', '0'),
('28', '0', '1305117979', NULL, '1', '0'),
('29', '0', '1305118002', NULL, '1', '0'),
('30', '0', '1305118030', NULL, '1', '0'),
('31', '0', '1305118075', NULL, '1', '0'),
('32', '0', '1305118101', NULL, '1', '0'),
('33', '0', '1305118138', NULL, '1', '0'),
('34', '0', '1305118163', NULL, '1', '0'),
('35', '0', '1305118193', NULL, '1', '0'),
('36', '15', '1316532236', '', '1', '3'),
('37', '0', '1305118353', NULL, '1', '0'),
('38', '0', '1305118384', NULL, '1', '0'),
('39', '0', '1305118430', NULL, '1', '0'),
('40', '0', '1305118475', NULL, '1', '0'),
('41', '16', '1374076608', '', '1', '1'),
('42', '0', '1311001382', NULL, '1', '0'),
('43', '0', '1311001570', NULL, '1', '0'),
('44', '0', '1311001635', NULL, '1', '0'),
('45', '0', '1311001697', NULL, '1', '0'),
('46', '0', '1311001731', NULL, '1', '0'),
('47', '0', '1311343066', NULL, '1', '0'),
('50', '0', '1311343535', NULL, '1', '0'),
('51', '0', '1311343561', NULL, '1', '0'),
('52', '0', '1312795936', NULL, '1', '0'),
('53', '0', '1312796336', NULL, '1', '0'),
('54', '0', '1312796361', NULL, '1', '0'),
('55', '0', '1312796388', NULL, '1', '0'),
('56', '0', '1312796430', NULL, '1', '0'),
('57', '0', '1312796469', NULL, '1', '0'),
('58', '0', '1312796503', NULL, '1', '0'),
('65', '0', '1315211393', NULL, '1', '0'),
('67', '0', '1315211704', NULL, '1', '0'),
('68', '0', '1315211741', NULL, '1', '0'),
('69', '0', '1315211790', NULL, '1', '0'),
('71', '0', '1315211916', NULL, '1', '0'),
('73', '0', '1315214872', NULL, '1', '0'),
('76', '0', '1319666214', NULL, '1', '0'),
('77', '0', '1319666389', NULL, '1', '0'),
('78', '0', '1319666448', NULL, '1', '0'),
('79', '0', '1322324835', NULL, '1', '0'),
('81', '0', '1353943550', NULL, '1', '0'),
('82', '0', '1358522809', NULL, '1', '0'),
('83', '0', '1374841095', NULL, '1', '0'),
('84', '0', '1374841097', NULL, '1', '0'),
('85', '0', '1374841099', NULL, '1', '0'),
('86', '0', '1374841101', NULL, '1', '0'),
('87', '0', '1374841104', NULL, '1', '0'),
('88', '0', '1375101293', NULL, '157', '0'),
('89', '0', '1375101372', NULL, '158', '0');
/*!40000 ALTER TABLE node_comment_statistics ENABLE KEYS */;

--
-- Table structure for table 'node_counter'
--

CREATE TABLE IF NOT EXISTS `node_counter` (
  `nid` int(11) NOT NULL DEFAULT '0' COMMENT 'The node.nid for these statistics.',
  `totalcount` bigint(20) unsigned NOT NULL DEFAULT '0' COMMENT 'The total number of times the node has been viewed.',
  `daycount` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT 'The total number of times the node has been viewed today.',
  `timestamp` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The most recent time the node has been viewed.',
  PRIMARY KEY (`nid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Access statistics for nodes.';

--
-- Dumping data for table 'node_counter'
--

/*!40000 ALTER TABLE node_counter DISABLE KEYS */;
/*!40000 ALTER TABLE node_counter ENABLE KEYS */;

--
-- Table structure for table 'node_revision'
--

CREATE TABLE IF NOT EXISTS `node_revision` (
  `nid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The node this version belongs to.',
  `vid` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'The primary identifier for this version.',
  `uid` int(11) NOT NULL DEFAULT '0' COMMENT 'The users.uid that created this version.',
  `title` varchar(255) NOT NULL DEFAULT '' COMMENT 'The title of this version.',
  `log` longtext NOT NULL COMMENT 'The log entry explaining the changes in this version.',
  `timestamp` int(11) NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when this version was created.',
  `status` int(11) NOT NULL DEFAULT '1',
  `comment` int(11) NOT NULL DEFAULT '0' COMMENT 'Whether comments are allowed on this node (at the time of this revision): 0 = no, 1 = closed (read only), 2 = open (read/write).',
  `promote` int(11) NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether the node (at the time of this revision) should be displayed on the front page.',
  `sticky` int(11) NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether the node (at the time of this revision) should be displayed at the top of lists in which it appears.',
  PRIMARY KEY (`vid`),
  KEY `nid` (`nid`),
  KEY `uid` (`uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores information about each saved version of a node.';

--
-- Dumping data for table 'node_revision'
--

/*!40000 ALTER TABLE node_revision DISABLE KEYS */;
INSERT INTO `node_revision` VALUES
('11', '11', '1', 'What do you think about us?', '', '1333107995', '1', '1', '0', '0'),
('12', '12', '1', 'Lorem ipsum dolor sit amet', '', '1305117326', '1', '2', '0', '0'),
('13', '13', '1', 'In pellentesque facilisis iaculis.', '', '1305117431', '1', '2', '0', '0'),
('14', '14', '1', 'Mauris porta magna eget dolor vestibulum dapibus', '', '1305117493', '1', '2', '0', '0'),
('15', '15', '1', 'Suspendisse potenti', '', '1305117558', '1', '2', '0', '0'),
('16', '16', '1', 'Pellentesque habitant morbi tristique senectus', '', '1305117592', '1', '2', '0', '0'),
('17', '17', '1', 'Ut vehicula, quam aliquam fringilla', '', '1305117638', '1', '2', '0', '0'),
('18', '18', '1', 'Nam nec est a nulla pulvinar dignissim', '', '1305117661', '1', '2', '0', '0'),
('19', '19', '1', 'In ac lectus massa. Pellentesque eros ligula', '', '1305117686', '1', '2', '0', '0'),
('20', '20', '1', 'Suspendisse vulputate hendrerit nulla', '', '1305117721', '1', '2', '0', '0'),
('21', '21', '1', 'Lorem ipsum dolor sit amet', '', '1305117759', '1', '2', '0', '0'),
('22', '22', '1', 'Cras euismod aliquet massa scelerisque euismo', '', '1305117790', '1', '2', '0', '0'),
('23', '23', '1', 'Cras euismod aliquet massa scelerisque', '', '1305117828', '1', '2', '0', '0'),
('24', '24', '1', 'Praesent non mauris eget nisi', '', '1305117855', '1', '2', '0', '0'),
('25', '25', '1', 'Suspendisse tempor libero sed ip', '', '1305117888', '1', '2', '0', '0'),
('26', '26', '1', 'Fusce ac lacus metu', '', '1305117913', '1', '2', '0', '0'),
('27', '27', '1', 'Curabitur feugiat ornare pul', '', '1305117944', '1', '2', '0', '0'),
('28', '28', '1', 'Suspendisse potenti', '', '1305117979', '1', '2', '0', '0'),
('29', '29', '1', 'Curabitur feugiat ornare pulv', '', '1305118002', '1', '2', '0', '0'),
('30', '30', '1', 'entesque tempus hend', '', '1305118030', '1', '2', '0', '0'),
('31', '31', '1', 'rius metus, consequat sollicit', '', '1305118075', '1', '2', '0', '0'),
('32', '32', '1', 'Aliquam vitae nunc metus', '', '1305118101', '1', '2', '0', '0'),
('33', '33', '1', 'Aliquam lacinia iaculis leo', '', '1305118138', '1', '2', '0', '0'),
('34', '34', '1', 'Lorem ipsum dolor sit am', '', '1305118163', '1', '2', '0', '0'),
('35', '35', '1', 'Nullam eu erat nibh', '', '1305118193', '1', '2', '0', '0'),
('36', '36', '1', 'Lorem ipsum dolor sit amet, consectetur adipisicing elit', '', '1374828279', '1', '2', '0', '0'),
('37', '37', '1', 'Donece pellente', '', '1378991808', '1', '2', '0', '0'),
('38', '38', '1', 'Donece pellente', '', '1378991809', '1', '2', '0', '0'),
('39', '39', '1', 'Donece pellente', '', '1378991807', '1', '2', '0', '0'),
('40', '40', '1', 'Donece pellente', '', '1378991805', '1', '2', '0', '0'),
('41', '41', '1', 'Donece pellente', '', '1378991811', '1', '2', '0', '0'),
('42', '42', '1', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit?', '', '1311001382', '1', '1', '0', '0'),
('43', '43', '1', 'Phasellus non dui magna, sit amet elementum lectus. Nullam ipsum ipsum, bibendum id mollis a, malesuada sit amet turpis?', '', '1311001570', '1', '1', '0', '0'),
('44', '44', '1', 'Nunc commodo nisi ultricies nulla convallis et facilisis enim cursus. Ut purus ligula, consequat a posuere at, ultricies in quam?', '', '1311001635', '1', '1', '0', '0'),
('45', '45', '1', 'Aliquam erat volutpat. Phasellus ac est velit. Proin sit amet urna dui, sed volutpat orci. Nam molestie viverra eros, eu lacinia nunc facilisis sed?', '', '1311001697', '1', '1', '0', '0'),
('46', '46', '1', 'Sed vitae orci enim, ut accumsan sem. Donec orci risus, porta in tempor a, blandit ut risus. Donec vitae velit neque, nec adipiscing ipsum?', '', '1311001731', '1', '1', '0', '0'),
('47', '47', '1', 'Quality', '', '1378907751', '1', '1', '0', '0'),
('50', '50', '1', 'Style', '', '1378907811', '1', '1', '0', '0'),
('51', '51', '1', 'Comfort', '', '1378907850', '1', '1', '0', '0'),
('52', '52', '1', 'Lorem ipsum dolor sit amet', '', '1378992221', '1', '1', '0', '0'),
('53', '53', '1', 'Fusce suscipit varius', '', '1378992222', '1', '1', '0', '0'),
('54', '54', '1', 'Ut enim ad minima veniam', '', '1378992224', '1', '1', '0', '0'),
('55', '55', '1', 'Sed utem perspiciatis', '', '1378992225', '1', '1', '0', '0'),
('56', '56', '1', 'Vestibulum libero nislum', '', '1378992228', '1', '1', '0', '0'),
('57', '57', '1', 'Praesent vestibulum', '', '1378992218', '1', '1', '0', '0'),
('58', '58', '1', 'Praesent vestibulum', '', '1378992230', '1', '1', '0', '0'),
('65', '65', '1', 'John Franklin', '', '1354540903', '1', '1', '0', '0'),
('67', '67', '1', 'Samantha Jacobs', '', '1354540838', '1', '1', '0', '0'),
('68', '68', '1', 'Sarah Conor', '', '1354540862', '1', '1', '0', '0'),
('69', '69', '1', 'Jessica Parker', '', '1354540870', '1', '1', '0', '0'),
('71', '71', '1', 'David Johnson', '', '1354540885', '1', '1', '0', '0'),
('73', '73', '1', 'Sam Kronshtain', '', '1354540936', '1', '1', '0', '0'),
('76', '76', '1', 'Interior Design', '', '1378991299', '1', '2', '0', '0'),
('77', '77', '1', 'Our Team', '', '1378991290', '1', '2', '0', '0'),
('78', '78', '1', 'Design Ideas', '', '1378991281', '1', '2', '0', '0'),
('79', '79', '1', 'Privacy policy', '', '1322324835', '1', '1', '0', '0'),
('81', '81', '1', 'Our location', '', '1353943550', '1', '1', '0', '0'),
('82', '82', '1', 'Lorem ipsum dolor sit', '', '1379064099', '1', '1', '0', '0'),
('83', '83', '1', 'Praesent vestibulum', '', '1378992001', '1', '1', '0', '0'),
('84', '84', '1', 'Lorem ipsum dolor sit amet', '', '1378992051', '1', '1', '0', '0'),
('85', '85', '1', 'Ut enim ad minima veniam', '', '1378991996', '1', '1', '0', '0'),
('86', '86', '1', 'Sed ut perspiciatis unde', '', '1378991997', '1', '1', '0', '0'),
('87', '87', '1', 'Vestibulum iaculis lacinia', '', '1378991999', '1', '1', '0', '0'),
('88', '88', '1', 'Jack Smith', '', '1375101468', '1', '1', '0', '0'),
('89', '89', '1', 'Lisa cole', '', '1375101372', '1', '1', '0', '0');
/*!40000 ALTER TABLE node_revision ENABLE KEYS */;

--
-- Table structure for table 'node_type'
--

CREATE TABLE IF NOT EXISTS `node_type` (
  `type` varchar(32) NOT NULL COMMENT 'The machine-readable name of this type.',
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT 'The human-readable name of this type.',
  `base` varchar(255) NOT NULL COMMENT 'The base string used to construct callbacks corresponding to this node type.',
  `module` varchar(255) NOT NULL,
  `description` mediumtext NOT NULL COMMENT 'A brief description of this type.',
  `help` mediumtext NOT NULL COMMENT 'Help information shown to the user when creating a node of this type.',
  `has_title` tinyint(3) unsigned NOT NULL COMMENT 'Boolean indicating whether this type uses the node.title field.',
  `title_label` varchar(255) NOT NULL DEFAULT '' COMMENT 'The label displayed for the title field on the edit form.',
  `custom` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this type is defined by a module (FALSE) or by a user via Add content type (TRUE).',
  `modified` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this type has been modified by an administrator; currently not used in any way.',
  `locked` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether the administrator can change the machine name of this type.',
  `disabled` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether the node type is disabled.',
  `orig_type` varchar(255) NOT NULL DEFAULT '' COMMENT 'The original machine-readable name of this node type. This may be different from the current type name if the locked field is 0.',
  PRIMARY KEY (`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores information about all defined node types.';

--
-- Dumping data for table 'node_type'
--

/*!40000 ALTER TABLE node_type DISABLE KEYS */;
INSERT INTO `node_type` VALUES
('article', 'Article', 'node_content', 'node', 'Use <em>articles</em> for time-sensitive content like news, press releases or blog posts.', '', '1', 'Title', '1', '1', '0', '0', 'article'),
('blog', 'Blog entry', 'blog', 'blog', 'Use for multi-user blogs. Every user gets a personal blog.', '', '1', 'Title', '0', '0', '1', '0', 'blog'),
('book', 'Book page', 'node_content', 'node', '<em>Books</em> have a built-in hierarchical navigation. Use for handbooks or tutorials.', '', '1', 'Title', '1', '1', '0', '0', 'book'),
('employee', 'Employee', 'node_content', 'node', 'Add staff', '', '1', 'Title', '1', '1', '0', '0', 'employee'),
('faq', 'FAQ', 'faq', 'faq', 'A frequently asked question and its answer.', '', '1', 'Question', '0', '1', '1', '0', 'faq'),
('forum', 'Forum topic', 'forum', 'forum', 'A <em>forum topic</em> starts a new discussion thread within a forum.', '', '1', 'Subject', '0', '0', '1', '0', 'forum'),
('maps', 'Maps', 'node_content', 'node', '', '', '1', 'Title', '1', '1', '0', '0', 'maps'),
('page', 'Basic page', 'node_content', 'node', 'Use <em>basic pages</em> for your static content, such as an ''About us'' page.', '', '1', 'Title', '1', '1', '0', '0', 'page'),
('panel', 'Panel', 'panels_node_hook', 'panels_node', 'A panel layout broken up into rows and columns.', '', '1', 'Title', '0', '0', '1', '0', 'panel'),
('partners', 'Partners', 'node_content', 'node', '', '', '1', 'Title', '1', '1', '0', '0', 'partners'),
('poll', 'Poll', 'poll', 'poll', 'A <em>poll</em> is a question with a set of possible responses. A <em>poll</em>, once created, automatically provides a simple running count of the number of votes received for each response.', '', '1', 'Question', '0', '0', '1', '0', 'poll'),
('popular_services', 'Popular services', 'node_content', 'node', '', '', '1', 'Title', '1', '1', '0', '0', 'popular_services'),
('portfolio', 'Portfolio', 'node_content', 'node', '', '', '1', 'Title', '1', '1', '0', '0', 'portfolio'),
('quotes', 'Quotes', 'quotes', 'quotes', 'A quote is a famous, infamous, humorous, witty, or otherwise noteworthy quotation or fortune file entry. Users can maintain personal lists of quotations and display quotes in one or more blocks. Quotes can be entered one at a time or mass imported in either tab-separated text or fortune file format.', '', '1', 'Title', '0', '0', '1', '1', 'quotes'),
('services', 'Services', 'node_content', 'node', '', '', '1', 'Title', '1', '1', '0', '0', 'services'),
('slider', 'Slider', 'node_content', 'node', 'Use to create slides in header-slider.', '', '1', 'Title', '1', '1', '0', '0', 'slider'),
('testimonials', 'Testimonials', 'node_content', 'node', '', '', '1', 'Title', '1', '1', '0', '0', 'testimonials');
/*!40000 ALTER TABLE node_type ENABLE KEYS */;

--
-- Table structure for table 'page_manager_handlers'
--

CREATE TABLE IF NOT EXISTS `page_manager_handlers` (
  `did` int(11) NOT NULL AUTO_INCREMENT COMMENT 'Primary ID field for the table. Not used for anything except internal lookups.',
  `name` varchar(255) DEFAULT NULL COMMENT 'Unique ID for this task handler. Used to identify it programmatically.',
  `task` varchar(64) DEFAULT NULL COMMENT 'ID of the task this handler is for.',
  `subtask` varchar(64) NOT NULL DEFAULT '' COMMENT 'ID of the subtask this handler is for.',
  `handler` varchar(64) DEFAULT NULL COMMENT 'ID of the task handler being used.',
  `weight` int(11) DEFAULT NULL COMMENT 'The order in which this handler appears. Lower numbers go first.',
  `conf` longtext NOT NULL COMMENT 'Serialized configuration of the handler, if needed.',
  PRIMARY KEY (`did`),
  UNIQUE KEY `name` (`name`),
  KEY `fulltask` (`task`,`subtask`,`weight`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='InnoDB free: 7168 kB';

--
-- Dumping data for table 'page_manager_handlers'
--

/*!40000 ALTER TABLE page_manager_handlers DISABLE KEYS */;
INSERT INTO `page_manager_handlers` VALUES
('1', 'page_contacts_panel_context', 'page', 'contacts', 'panel_context', '0', 'a:11:{s:5:"title";s:5:"Panel";s:9:"no_blocks";i:1;s:8:"pipeline";s:8:"standard";s:6:"css_id";s:8:"contacts";s:3:"css";s:0:"";s:8:"contexts";a:0:{}s:13:"relationships";a:0:{}s:3:"did";s:1:"1";s:22:"body_classes_to_remove";s:0:"";s:19:"body_classes_to_add";s:0:"";s:11:"temp_layout";s:8:"flexible";}'),
('3', 'page_page_404_panel_context', 'page', 'page_404', 'panel_context', '0', 'a:10:{s:5:"title";s:5:"Panel";s:9:"no_blocks";i:1;s:8:"pipeline";s:8:"standard";s:22:"body_classes_to_remove";s:0:"";s:19:"body_classes_to_add";s:0:"";s:6:"css_id";s:0:"";s:3:"css";s:0:"";s:8:"contexts";a:0:{}s:13:"relationships";a:0:{}s:3:"did";s:1:"3";}'),
('4', 'page_services_panel_context', 'page', 'services', 'panel_context', '0', 'a:10:{s:5:"title";s:5:"Panel";s:9:"no_blocks";i:0;s:8:"pipeline";s:8:"standard";s:22:"body_classes_to_remove";s:0:"";s:19:"body_classes_to_add";s:0:"";s:6:"css_id";s:0:"";s:3:"css";s:0:"";s:8:"contexts";a:0:{}s:13:"relationships";a:0:{}s:3:"did";s:1:"4";}');
/*!40000 ALTER TABLE page_manager_handlers ENABLE KEYS */;

--
-- Table structure for table 'page_manager_pages'
--

CREATE TABLE IF NOT EXISTS `page_manager_pages` (
  `pid` int(11) NOT NULL AUTO_INCREMENT COMMENT 'Primary ID field for the table. Not used for anything except internal lookups.',
  `name` varchar(255) DEFAULT NULL COMMENT 'Unique ID for this subtask. Used to identify it programmatically.',
  `task` varchar(64) DEFAULT 'page' COMMENT 'What type of page this is, so that we can use the same mechanism for creating tighter UIs for targeted pages.',
  `admin_title` varchar(255) DEFAULT NULL COMMENT 'Human readable title for this page subtask.',
  `admin_description` longtext COMMENT 'Administrative description of this item.',
  `path` varchar(255) DEFAULT NULL COMMENT 'The menu path that will invoke this task.',
  `access` longtext NOT NULL COMMENT 'Access configuration for this path.',
  `menu` longtext NOT NULL COMMENT 'Serialized configuration of Drupal menu visibility settings for this item.',
  `arguments` longtext NOT NULL COMMENT 'Configuration of arguments for this menu item.',
  `conf` longtext NOT NULL COMMENT 'Serialized configuration of the page, if needed.',
  PRIMARY KEY (`pid`),
  UNIQUE KEY `name` (`name`),
  KEY `task` (`task`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Contains page subtasks for implementing pages with...';

--
-- Dumping data for table 'page_manager_pages'
--

/*!40000 ALTER TABLE page_manager_pages DISABLE KEYS */;
INSERT INTO `page_manager_pages` VALUES
('1', 'contacts', 'page', 'Contacts', '', 'contacts', 'a:0:{}', 'a:0:{}', 'a:0:{}', 'a:1:{s:11:"admin_paths";b:0;}'),
('3', 'page_404', 'page', 'page-404', '', 'page-404', 'a:0:{}', 'a:0:{}', 'a:0:{}', 'a:1:{s:11:"admin_paths";b:0;}'),
('4', 'services', 'page', 'Services', '', 'services', 'a:0:{}', 'a:5:{s:4:"type";s:6:"normal";s:5:"title";s:8:"Services";s:4:"name";s:9:"main-menu";s:6:"weight";s:1:"0";s:6:"parent";a:4:{s:4:"type";s:4:"none";s:5:"title";s:0:"";s:4:"name";s:10:"navigation";s:6:"weight";s:1:"0";}}', 'a:0:{}', 'a:1:{s:11:"admin_paths";b:0;}');
/*!40000 ALTER TABLE page_manager_pages ENABLE KEYS */;

--
-- Table structure for table 'page_manager_weights'
--

CREATE TABLE IF NOT EXISTS `page_manager_weights` (
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT 'Unique ID for this task handler. Used to identify it programmatically.',
  `weight` int(11) DEFAULT NULL COMMENT 'The order in which this handler appears. Lower numbers go first.',
  PRIMARY KEY (`name`),
  KEY `weights` (`name`,`weight`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Contains override weights for page_manager handlers that...';

--
-- Dumping data for table 'page_manager_weights'
--

/*!40000 ALTER TABLE page_manager_weights DISABLE KEYS */;
/*!40000 ALTER TABLE page_manager_weights ENABLE KEYS */;

--
-- Table structure for table 'panels_display'
--

CREATE TABLE IF NOT EXISTS `panels_display` (
  `did` int(11) NOT NULL AUTO_INCREMENT,
  `layout` varchar(255) DEFAULT '',
  `layout_settings` longtext,
  `panel_settings` longtext,
  `cache` text,
  `title` varchar(255) DEFAULT '',
  `hide_title` tinyint(4) DEFAULT '0',
  `title_pane` int(11) DEFAULT '0',
  PRIMARY KEY (`did`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='InnoDB free: 7168 kB';

--
-- Dumping data for table 'panels_display'
--

/*!40000 ALTER TABLE panels_display DISABLE KEYS */;
INSERT INTO `panels_display` VALUES
('1', 'flexible', 'a:1:{s:5:"items";a:6:{s:6:"canvas";a:4:{s:4:"type";s:3:"row";s:8:"contains";s:6:"column";s:8:"children";a:1:{i:0;s:4:"main";}s:6:"parent";N;}s:4:"main";a:5:{s:4:"type";s:6:"column";s:5:"width";i:100;s:10:"width_type";s:1:"%";s:8:"children";a:2:{i:0;s:8:"main-row";i:1;i:1;}s:6:"parent";s:6:"canvas";}s:8:"main-row";a:4:{s:4:"type";s:3:"row";s:8:"contains";s:6:"region";s:8:"children";a:1:{i:0;s:6:"center";}s:6:"parent";s:4:"main";}s:6:"center";a:5:{s:4:"type";s:6:"region";s:5:"title";s:6:"Center";s:5:"width";i:100;s:10:"width_type";s:1:"%";s:6:"parent";s:8:"main-row";}i:1;a:5:{s:4:"type";s:3:"row";s:8:"contains";s:6:"region";s:8:"children";a:1:{i:0;s:15:"contacts_region";}s:6:"parent";s:4:"main";s:5:"class";s:0:"";}s:15:"contacts_region";a:6:{s:4:"type";s:6:"region";s:5:"title";s:15:"Contacts region";s:5:"width";i:100;s:10:"width_type";s:1:"%";s:6:"parent";s:1:"1";s:5:"class";s:15:"contacts-region";}}}', 'a:1:{s:14:"style_settings";a:5:{s:7:"default";N;s:6:"center";N;s:12:"column_right";N;s:13:"second_column";N;s:15:"contacts_region";N;}}', 'a:0:{}', '', '1', '1'),
('3', 'flexible', 'a:0:{}', 'a:1:{s:14:"style_settings";a:2:{s:7:"default";N;s:6:"center";N;}}', 'a:0:{}', '', '1', '6'),
('4', 'flexible', 'a:1:{s:5:"items";a:4:{s:6:"canvas";a:13:{s:4:"type";s:3:"row";s:8:"contains";s:6:"column";s:8:"children";a:1:{i:0;s:4:"main";}s:6:"parent";N;s:5:"class";s:0:"";s:12:"column_class";s:0:"";s:9:"row_class";s:0:"";s:12:"region_class";s:0:"";s:8:"no_scale";b:1;s:11:"fixed_width";s:0:"";s:17:"column_separation";s:1:"0";s:17:"region_separation";s:1:"0";s:14:"row_separation";s:1:"0";}s:4:"main";a:5:{s:4:"type";s:6:"column";s:5:"width";i:100;s:10:"width_type";s:1:"%";s:8:"children";a:1:{i:0;s:8:"main-row";}s:6:"parent";s:6:"canvas";}s:8:"main-row";a:4:{s:4:"type";s:3:"row";s:8:"contains";s:6:"region";s:8:"children";a:1:{i:0;s:6:"center";}s:6:"parent";s:4:"main";}s:6:"center";a:5:{s:4:"type";s:6:"region";s:5:"title";s:6:"Center";s:5:"width";i:100;s:10:"width_type";s:1:"%";s:6:"parent";s:8:"main-row";}}}', 'a:1:{s:14:"style_settings";a:2:{s:7:"default";N;s:6:"center";N;}}', 'a:0:{}', '', '1', '0');
/*!40000 ALTER TABLE panels_display ENABLE KEYS */;

--
-- Table structure for table 'panels_layout'
--

CREATE TABLE IF NOT EXISTS `panels_layout` (
  `lid` int(11) NOT NULL AUTO_INCREMENT COMMENT 'A database primary key to ensure uniqueness.',
  `name` varchar(255) DEFAULT NULL COMMENT 'Unique ID for this content. Used to identify it programmatically.',
  `admin_title` varchar(255) DEFAULT NULL COMMENT 'Administrative title for this layout.',
  `admin_description` longtext COMMENT 'Administrative description for this layout.',
  `category` varchar(255) DEFAULT NULL COMMENT 'Administrative category for this layout.',
  `plugin` varchar(255) DEFAULT NULL COMMENT 'The layout plugin that owns this layout.',
  `settings` longtext COMMENT 'Serialized settings for the actual layout. The contents of this field are up to the plugin that uses it.',
  PRIMARY KEY (`lid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Contains exportable customized layouts for this site.';

--
-- Dumping data for table 'panels_layout'
--

/*!40000 ALTER TABLE panels_layout DISABLE KEYS */;
INSERT INTO `panels_layout` VALUES
('1', 'two_columns', '', '', 'custom', 'flexible', 'a:1:{s:5:"items";a:5:{s:6:"canvas";a:13:{s:4:"type";s:3:"row";s:8:"contains";s:6:"column";s:8:"children";a:1:{i:0;s:4:"main";}s:6:"parent";N;s:5:"class";s:0:"";s:12:"column_class";s:0:"";s:9:"row_class";s:0:"";s:12:"region_class";s:0:"";s:8:"no_scale";b:1;s:11:"fixed_width";s:0:"";s:17:"column_separation";s:5:"0.5em";s:17:"region_separation";s:5:"0.5em";s:14:"row_separation";s:5:"0.5em";}s:4:"main";a:5:{s:4:"type";s:6:"column";s:5:"width";i:100;s:10:"width_type";s:1:"%";s:8:"children";a:1:{i:0;s:8:"main-row";}s:6:"parent";s:6:"canvas";}s:8:"main-row";a:4:{s:4:"type";s:3:"row";s:8:"contains";s:6:"region";s:8:"children";a:2:{i:0;s:6:"center";i:1;s:13:"second_column";}s:6:"parent";s:4:"main";}s:6:"center";a:5:{s:4:"type";s:6:"region";s:5:"title";s:6:"Center";s:5:"width";s:17:"67.92299411347031";s:10:"width_type";s:1:"%";s:6:"parent";s:8:"main-row";}s:13:"second_column";a:6:{s:4:"type";s:6:"region";s:5:"title";s:13:"Second column";s:5:"width";s:16:"32.0770058865297";s:10:"width_type";s:1:"%";s:6:"parent";s:8:"main-row";s:5:"class";s:0:"";}}}');
/*!40000 ALTER TABLE panels_layout ENABLE KEYS */;

--
-- Table structure for table 'panels_mini'
--

CREATE TABLE IF NOT EXISTS `panels_mini` (
  `pid` int(11) NOT NULL AUTO_INCREMENT COMMENT 'The primary key for uniqueness.',
  `name` varchar(255) DEFAULT NULL COMMENT 'The unique name of the mini panel.',
  `category` varchar(64) DEFAULT NULL COMMENT 'The category this mini panel appears in on the add content pane.',
  `did` int(11) DEFAULT NULL COMMENT 'The display ID of the panel.',
  `admin_title` varchar(128) DEFAULT NULL COMMENT 'The administrative title of the mini panel.',
  `admin_description` longtext COMMENT 'Administrative title of this mini panel.',
  `requiredcontexts` longtext COMMENT 'An array of required contexts.',
  `contexts` longtext COMMENT 'An array of contexts embedded into the panel.',
  `relationships` longtext COMMENT 'An array of relationships embedded into the panel.',
  PRIMARY KEY (`pid`),
  UNIQUE KEY `name` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='InnoDB free: 7168 kB';

--
-- Dumping data for table 'panels_mini'
--

/*!40000 ALTER TABLE panels_mini DISABLE KEYS */;
/*!40000 ALTER TABLE panels_mini ENABLE KEYS */;

--
-- Table structure for table 'panels_node'
--

CREATE TABLE IF NOT EXISTS `panels_node` (
  `nid` int(11) NOT NULL DEFAULT '0',
  `css_id` varchar(255) DEFAULT NULL,
  `did` int(11) NOT NULL,
  `pipeline` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`did`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='InnoDB free: 7168 kB';

--
-- Dumping data for table 'panels_node'
--

/*!40000 ALTER TABLE panels_node DISABLE KEYS */;
/*!40000 ALTER TABLE panels_node ENABLE KEYS */;

--
-- Table structure for table 'panels_pane'
--

CREATE TABLE IF NOT EXISTS `panels_pane` (
  `pid` int(11) NOT NULL AUTO_INCREMENT,
  `did` int(11) NOT NULL DEFAULT '0',
  `panel` varchar(32) DEFAULT '',
  `type` varchar(32) DEFAULT '',
  `subtype` varchar(64) DEFAULT '',
  `shown` tinyint(4) DEFAULT '1',
  `access` longtext,
  `configuration` longtext,
  `cache` longtext,
  `style` longtext,
  `css` longtext,
  `extras` longtext,
  `position` smallint(6) DEFAULT '0',
  `locks` longtext,
  PRIMARY KEY (`pid`),
  KEY `did_idx` (`did`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='InnoDB free: 7168 kB';

--
-- Dumping data for table 'panels_pane'
--

/*!40000 ALTER TABLE panels_pane DISABLE KEYS */;
INSERT INTO `panels_pane` VALUES
('1', '1', 'contacts_region', 'contact', 'contact', '1', 'a:0:{}', 'a:2:{s:14:"override_title";i:1;s:19:"override_title_text";s:12:"Contact Form";}', 'a:0:{}', 'a:1:{s:8:"settings";N;}', 'a:2:{s:6:"css_id";s:0:"";s:9:"css_class";s:12:"grid-6 alpha";}', 'a:0:{}', 0, 'N;'),
('6', '3', 'center', 'custom', 'custom', '1', 'a:0:{}', 'a:5:{s:11:"admin_title";s:0:"";s:5:"title";s:0:"";s:4:"body";s:252:"<span class="err">404</span><div class="extra">\n<strong class="err-title">SORRY!</strong>\n<strong class="err-body">PAGE NOT FOUND</strong>\nThe page you are looking for might have been removed, had its name changed, or is temporarily unavailable.\n</div>";s:6:"format";s:8:"php_code";s:10:"substitute";b:1;}', 'a:0:{}', 'a:1:{s:8:"settings";N;}', 'a:2:{s:6:"css_id";s:0:"";s:9:"css_class";s:10:"error-page";}', 'a:0:{}', 0, 'a:0:{}'),
('7', '3', 'center', 'block', 'search-form', '1', 'a:0:{}', 'a:2:{s:14:"override_title";i:0;s:19:"override_title_text";s:0:"";}', 'a:0:{}', 'a:1:{s:8:"settings";N;}', 'a:0:{}', 'a:0:{}', 1, 'a:0:{}'),
('8', '1', 'contacts_region', 'custom', 'custom', '1', 'a:0:{}', 'a:5:{s:11:"admin_title";s:19:"Contact information";s:5:"title";s:19:"Contact information";s:4:"body";s:759:"<p><strong>Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque.</strong>\nSed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque et quasi architecto beatae vitae dicta sunt explicabo. Mornunc odio gravida atcursus neus a lorem. Maecenas tristique orci ac sem. Duis ultric pharetra magna. Donec accumsan malesuada orcic sit amet eros. Lorem ipsum dolor sit amet onsectetuer adipiscing elit. Mauris fermentum dictum magna. Sed laoreet aliquam leo. Ut tellus dolor dapibus eget.</p>\n\nThe Company Name Inc.<br />\n9870 St Vincent Place,<br />\nGlasgow, DC 45 Fr 45.<br />\n<br />\nTelephone:+1 800 603 6035<br />\nFAX:+1 800 889 9898<br />\nE-mail: <a href="mailto:mail@demolink.org">mail@demolink.org</a>";s:6:"format";s:9:"full_html";s:10:"substitute";b:1;}', 'a:0:{}', 'a:1:{s:8:"settings";N;}', 'a:2:{s:6:"css_id";s:0:"";s:9:"css_class";s:32:"contact-information grid-6 omega";}', 'a:0:{}', 1, 'a:0:{}'),
('9', '1', 'center', 'node', 'node', '1', 'a:0:{}', 'a:8:{s:3:"nid";s:2:"81";s:5:"links";i:0;s:16:"leave_node_title";i:0;s:10:"identifier";s:0:"";s:10:"build_mode";s:4:"full";s:15:"link_node_title";i:0;s:14:"override_title";i:0;s:19:"override_title_text";s:0:"";}', 'a:0:{}', 'a:1:{s:8:"settings";N;}', 'a:0:{}', 'a:0:{}', 0, 'a:0:{}');
/*!40000 ALTER TABLE panels_pane ENABLE KEYS */;

--
-- Table structure for table 'panels_renderer_pipeline'
--

CREATE TABLE IF NOT EXISTS `panels_renderer_pipeline` (
  `rpid` int(11) NOT NULL AUTO_INCREMENT COMMENT 'A database primary key to ensure uniqueness.',
  `name` varchar(255) DEFAULT NULL COMMENT 'Unique ID for this content. Used to identify it programmatically.',
  `admin_title` varchar(255) DEFAULT NULL COMMENT 'Administrative title for this pipeline.',
  `admin_description` longtext COMMENT 'Administrative description for this pipeline.',
  `weight` smallint(6) DEFAULT '0',
  `settings` longtext COMMENT 'Serialized settings for the actual pipeline. The contents of this field are up to the plugin that uses it.',
  PRIMARY KEY (`rpid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Contains renderer pipelines for Panels. Each pipeline...';

--
-- Dumping data for table 'panels_renderer_pipeline'
--

/*!40000 ALTER TABLE panels_renderer_pipeline DISABLE KEYS */;
/*!40000 ALTER TABLE panels_renderer_pipeline ENABLE KEYS */;

--
-- Table structure for table 'poll'
--

CREATE TABLE IF NOT EXISTS `poll` (
  `nid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The poll’s node.nid.',
  `runtime` int(11) NOT NULL DEFAULT '0' COMMENT 'The number of seconds past node.created during which the poll is open.',
  `active` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether or not the poll is open.',
  PRIMARY KEY (`nid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores poll-specific information for poll nodes.';

--
-- Dumping data for table 'poll'
--

/*!40000 ALTER TABLE poll DISABLE KEYS */;
INSERT INTO `poll` VALUES
('11', '0', '1');
/*!40000 ALTER TABLE poll ENABLE KEYS */;

--
-- Table structure for table 'poll_choice'
--

CREATE TABLE IF NOT EXISTS `poll_choice` (
  `chid` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Unique identifier for a poll choice.',
  `nid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The node.nid this choice belongs to.',
  `chtext` varchar(128) NOT NULL DEFAULT '' COMMENT 'The text for this choice.',
  `chvotes` int(11) NOT NULL DEFAULT '0' COMMENT 'The total number of votes this choice has received by all users.',
  `weight` int(11) NOT NULL DEFAULT '0' COMMENT 'The sort order of this choice among all choices for the same node.',
  PRIMARY KEY (`chid`),
  KEY `nid` (`nid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores information about all choices for all polls.';

--
-- Dumping data for table 'poll_choice'
--

/*!40000 ALTER TABLE poll_choice DISABLE KEYS */;
INSERT INTO `poll_choice` VALUES
('1', '11', 'Super', '847', '1'),
('2', '11', 'Good', '678', '1'),
('3', '11', 'Normal', '432', '2'),
('4', '11', 'Bad', '235', '3');
/*!40000 ALTER TABLE poll_choice ENABLE KEYS */;

--
-- Table structure for table 'poll_vote'
--

CREATE TABLE IF NOT EXISTS `poll_vote` (
  `chid` int(10) unsigned NOT NULL,
  `nid` int(10) unsigned NOT NULL COMMENT 'The poll node this vote is for.',
  `uid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The users.uid this vote is from unless the voter was anonymous.',
  `hostname` varchar(128) NOT NULL DEFAULT '' COMMENT 'The IP address this vote is from unless the voter was logged in.',
  `timestamp` int(11) NOT NULL DEFAULT '0' COMMENT 'The timestamp of the vote creation.',
  PRIMARY KEY (`nid`,`uid`,`hostname`),
  KEY `chid` (`chid`),
  KEY `hostname` (`hostname`),
  KEY `uid` (`uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores per-users votes for each poll.';

--
-- Dumping data for table 'poll_vote'
--

/*!40000 ALTER TABLE poll_vote DISABLE KEYS */;
INSERT INTO `poll_vote` VALUES
('1', '11', '1', '192.168.9.7', '1305118518');
/*!40000 ALTER TABLE poll_vote ENABLE KEYS */;

--
-- Table structure for table 'queue'
--

CREATE TABLE IF NOT EXISTS `queue` (
  `item_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique item ID.',
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT 'The queue name.',
  `data` longblob COMMENT 'The arbitrary data for the item.',
  `expire` int(11) NOT NULL DEFAULT '0' COMMENT 'Timestamp when the claim lease expires on the item.',
  `created` int(11) NOT NULL DEFAULT '0' COMMENT 'Timestamp when the item was created.',
  PRIMARY KEY (`item_id`),
  KEY `name_created` (`name`,`created`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores items in queues.';

--
-- Dumping data for table 'queue'
--

/*!40000 ALTER TABLE queue DISABLE KEYS */;
INSERT INTO `queue` VALUES
('437', 'update_fetch_tasks', 'a:8:{s:4:"name";s:8:"theme822";s:4:"info";a:5:{s:4:"name";s:8:"theme822";s:7:"version";s:7:"7.x-1.0";s:7:"project";s:8:"theme822";s:9:"datestamp";s:10:"1320946536";s:16:"_info_file_ctime";i:1378904202;}s:9:"datestamp";s:10:"1320946536";s:8:"includes";a:1:{s:8:"theme822";s:8:"theme822";}s:12:"project_type";s:5:"theme";s:14:"project_status";b:1;s:10:"sub_themes";a:0:{}s:11:"base_themes";a:0:{}}', '1379063771', '1378992434');
/*!40000 ALTER TABLE queue ENABLE KEYS */;

--
-- Table structure for table 'quicktabs'
--

CREATE TABLE IF NOT EXISTS `quicktabs` (
  `machine_name` varchar(255) NOT NULL COMMENT 'The primary identifier for a qt block.',
  `ajax` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'Whether this is an ajax views block.',
  `hide_empty_tabs` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT 'Whether this tabset hides empty tabs.',
  `default_tab` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'Default tab.',
  `title` varchar(255) NOT NULL COMMENT 'The title of this quicktabs block.',
  `tabs` mediumtext NOT NULL COMMENT 'A serialized array of the contents of this qt block.',
  `renderer` varchar(255) NOT NULL COMMENT 'The rendering mechanism.',
  `style` varchar(255) NOT NULL COMMENT 'The tab style.',
  `options` mediumtext COMMENT 'A serialized array of the options for this qt instance.',
  PRIMARY KEY (`machine_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='The quicktabs table.';

--
-- Dumping data for table 'quicktabs'
--

/*!40000 ALTER TABLE quicktabs DISABLE KEYS */;
INSERT INTO `quicktabs` VALUES
('accordion', '0', '1', '0', 'Accordion', 'a:2:{i:0;a:5:{s:3:"bid";s:17:"poll_delta_recent";s:10:"hide_title";i:1;s:5:"title";s:5:"First";s:6:"weight";s:4:"-100";s:4:"type";s:5:"block";}i:1;a:5:{s:3:"bid";s:13:"block_delta_1";s:10:"hide_title";i:1;s:5:"title";s:6:"Second";s:6:"weight";s:3:"-99";s:4:"type";s:5:"block";}}', 'accordion', 'default', 'a:1:{s:10:"autoHeight";i:0;}'),
('default_tabs', '0', '0', '0', 'Default tabs', 'a:2:{i:0;a:6:{s:3:"nid";s:2:"49";s:6:"teaser";i:1;s:10:"hide_title";i:0;s:5:"title";s:9:"First tab";s:6:"weight";s:4:"-100";s:4:"type";s:4:"node";}i:1;a:6:{s:3:"nid";s:2:"50";s:6:"teaser";i:1;s:10:"hide_title";i:0;s:5:"title";s:10:"Second tab";s:6:"weight";s:3:"-99";s:4:"type";s:4:"node";}}', 'quicktabs', 'Arrows', 'a:0:{}');
/*!40000 ALTER TABLE quicktabs ENABLE KEYS */;

--
-- Table structure for table 'quotes'
--

CREATE TABLE IF NOT EXISTS `quotes` (
  `nid` int(10) unsigned NOT NULL COMMENT 'Node identifier.',
  `vid` int(10) unsigned NOT NULL COMMENT 'Version identifier.',
  `aid` int(10) unsigned NOT NULL COMMENT 'Author identifier.',
  `citation` text COMMENT 'Source of the quote.',
  `promote` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT 'Status.',
  PRIMARY KEY (`vid`),
  KEY `quotes_nid` (`nid`),
  KEY `quotes_promote` (`promote`),
  KEY `quotes_aid` (`aid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Extra node data.';

--
-- Dumping data for table 'quotes'
--

/*!40000 ALTER TABLE quotes DISABLE KEYS */;
/*!40000 ALTER TABLE quotes ENABLE KEYS */;

--
-- Table structure for table 'quotes_authors'
--

CREATE TABLE IF NOT EXISTS `quotes_authors` (
  `aid` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Author identifier.',
  `name` text NOT NULL COMMENT 'Author of the quote.',
  `bio` text COMMENT 'Author’s biography.',
  PRIMARY KEY (`aid`),
  UNIQUE KEY `name` (`name`(255))
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Quotes authors data.';

--
-- Dumping data for table 'quotes_authors'
--

/*!40000 ALTER TABLE quotes_authors DISABLE KEYS */;
/*!40000 ALTER TABLE quotes_authors ENABLE KEYS */;

--
-- Table structure for table 'quotes_blocks'
--

CREATE TABLE IF NOT EXISTS `quotes_blocks` (
  `bid` int(11) NOT NULL AUTO_INCREMENT COMMENT 'Block number',
  `block_type` tinyint(4) NOT NULL COMMENT 'Type of block',
  `vid` int(11) NOT NULL COMMENT 'Version id',
  `count` int(11) DEFAULT '1' COMMENT 'Number of quotes in the block.',
  `cron_interval` int(11) NOT NULL COMMENT 'Cron frequency',
  `cron_step` int(11) NOT NULL COMMENT 'Cron step',
  `cron_last` int(11) NOT NULL COMMENT 'Last Cron run time',
  `show_titles` smallint(6) DEFAULT '0' COMMENT 'Show titles.',
  `show_citation` smallint(6) DEFAULT '0' COMMENT 'Show citation.',
  `max_length` int(11) DEFAULT '0' COMMENT 'Maximum length of quote in block.',
  `rand_freq` int(11) NOT NULL DEFAULT '100' COMMENT 'Display frequency for random blocks.',
  `name` varchar(255) NOT NULL COMMENT 'Name of this block',
  `nid_filter` text NOT NULL COMMENT 'Node filter',
  `aid_filter` text NOT NULL COMMENT 'Author filter',
  `rid_filter` text NOT NULL COMMENT 'Role filter',
  `uid_filter` text NOT NULL COMMENT 'User filter',
  `tid_filter` text NOT NULL COMMENT 'Term filter',
  `view_text` varchar(64) DEFAULT NULL COMMENT 'Text for the `view` link.',
  `more_text` varchar(64) DEFAULT NULL COMMENT 'Text for the `more` link.',
  PRIMARY KEY (`bid`),
  UNIQUE KEY `name` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Quotes blocks data.';

--
-- Dumping data for table 'quotes_blocks'
--

/*!40000 ALTER TABLE quotes_blocks DISABLE KEYS */;
/*!40000 ALTER TABLE quotes_blocks ENABLE KEYS */;

--
-- Table structure for table 'rdf_mapping'
--

CREATE TABLE IF NOT EXISTS `rdf_mapping` (
  `type` varchar(128) NOT NULL COMMENT 'The name of the entity type a mapping applies to (node, user, comment, etc.).',
  `bundle` varchar(128) NOT NULL COMMENT 'The name of the bundle a mapping applies to.',
  `mapping` longblob COMMENT 'The serialized mapping of the bundle type and fields to RDF terms.',
  PRIMARY KEY (`type`,`bundle`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores custom RDF mappings for user defined content types...';

--
-- Dumping data for table 'rdf_mapping'
--

/*!40000 ALTER TABLE rdf_mapping DISABLE KEYS */;
INSERT INTO `rdf_mapping` VALUES
('node', 'article', 'a:11:{s:11:"field_image";a:2:{s:10:"predicates";a:2:{i:0;s:8:"og:image";i:1;s:12:"rdfs:seeAlso";}s:4:"type";s:3:"rel";}s:10:"field_tags";a:2:{s:10:"predicates";a:1:{i:0;s:10:"dc:subject";}s:4:"type";s:3:"rel";}s:7:"rdftype";a:2:{i:0;s:9:"sioc:Item";i:1;s:13:"foaf:Document";}s:5:"title";a:1:{s:10:"predicates";a:1:{i:0;s:8:"dc:title";}}s:7:"created";a:3:{s:10:"predicates";a:2:{i:0;s:7:"dc:date";i:1;s:10:"dc:created";}s:8:"datatype";s:12:"xsd:dateTime";s:8:"callback";s:12:"date_iso8601";}s:7:"changed";a:3:{s:10:"predicates";a:1:{i:0;s:11:"dc:modified";}s:8:"datatype";s:12:"xsd:dateTime";s:8:"callback";s:12:"date_iso8601";}s:4:"body";a:1:{s:10:"predicates";a:1:{i:0;s:15:"content:encoded";}}s:3:"uid";a:2:{s:10:"predicates";a:1:{i:0;s:16:"sioc:has_creator";}s:4:"type";s:3:"rel";}s:4:"name";a:1:{s:10:"predicates";a:1:{i:0;s:9:"foaf:name";}}s:13:"comment_count";a:2:{s:10:"predicates";a:1:{i:0;s:16:"sioc:num_replies";}s:8:"datatype";s:11:"xsd:integer";}s:13:"last_activity";a:3:{s:10:"predicates";a:1:{i:0;s:23:"sioc:last_activity_date";}s:8:"datatype";s:12:"xsd:dateTime";s:8:"callback";s:12:"date_iso8601";}}'),
('node', 'blog', 'a:9:{s:7:"rdftype";a:2:{i:0;s:9:"sioc:Post";i:1;s:14:"sioct:BlogPost";}s:5:"title";a:1:{s:10:"predicates";a:1:{i:0;s:8:"dc:title";}}s:7:"created";a:3:{s:10:"predicates";a:2:{i:0;s:7:"dc:date";i:1;s:10:"dc:created";}s:8:"datatype";s:12:"xsd:dateTime";s:8:"callback";s:12:"date_iso8601";}s:7:"changed";a:3:{s:10:"predicates";a:1:{i:0;s:11:"dc:modified";}s:8:"datatype";s:12:"xsd:dateTime";s:8:"callback";s:12:"date_iso8601";}s:4:"body";a:1:{s:10:"predicates";a:1:{i:0;s:15:"content:encoded";}}s:3:"uid";a:2:{s:10:"predicates";a:1:{i:0;s:16:"sioc:has_creator";}s:4:"type";s:3:"rel";}s:4:"name";a:1:{s:10:"predicates";a:1:{i:0;s:9:"foaf:name";}}s:13:"comment_count";a:2:{s:10:"predicates";a:1:{i:0;s:16:"sioc:num_replies";}s:8:"datatype";s:11:"xsd:integer";}s:13:"last_activity";a:3:{s:10:"predicates";a:1:{i:0;s:23:"sioc:last_activity_date";}s:8:"datatype";s:12:"xsd:dateTime";s:8:"callback";s:12:"date_iso8601";}}'),
('node', 'forum', 'a:10:{s:7:"rdftype";a:2:{i:0;s:9:"sioc:Post";i:1;s:15:"sioct:BoardPost";}s:15:"taxonomy_forums";a:2:{s:10:"predicates";a:1:{i:0;s:18:"sioc:has_container";}s:4:"type";s:3:"rel";}s:5:"title";a:1:{s:10:"predicates";a:1:{i:0;s:8:"dc:title";}}s:7:"created";a:3:{s:10:"predicates";a:2:{i:0;s:7:"dc:date";i:1;s:10:"dc:created";}s:8:"datatype";s:12:"xsd:dateTime";s:8:"callback";s:12:"date_iso8601";}s:7:"changed";a:3:{s:10:"predicates";a:1:{i:0;s:11:"dc:modified";}s:8:"datatype";s:12:"xsd:dateTime";s:8:"callback";s:12:"date_iso8601";}s:4:"body";a:1:{s:10:"predicates";a:1:{i:0;s:15:"content:encoded";}}s:3:"uid";a:2:{s:10:"predicates";a:1:{i:0;s:16:"sioc:has_creator";}s:4:"type";s:3:"rel";}s:4:"name";a:1:{s:10:"predicates";a:1:{i:0;s:9:"foaf:name";}}s:13:"comment_count";a:2:{s:10:"predicates";a:1:{i:0;s:16:"sioc:num_replies";}s:8:"datatype";s:11:"xsd:integer";}s:13:"last_activity";a:3:{s:10:"predicates";a:1:{i:0;s:23:"sioc:last_activity_date";}s:8:"datatype";s:12:"xsd:dateTime";s:8:"callback";s:12:"date_iso8601";}}'),
('node', 'page', 'a:9:{s:7:"rdftype";a:1:{i:0;s:13:"foaf:Document";}s:5:"title";a:1:{s:10:"predicates";a:1:{i:0;s:8:"dc:title";}}s:7:"created";a:3:{s:10:"predicates";a:2:{i:0;s:7:"dc:date";i:1;s:10:"dc:created";}s:8:"datatype";s:12:"xsd:dateTime";s:8:"callback";s:12:"date_iso8601";}s:7:"changed";a:3:{s:10:"predicates";a:1:{i:0;s:11:"dc:modified";}s:8:"datatype";s:12:"xsd:dateTime";s:8:"callback";s:12:"date_iso8601";}s:4:"body";a:1:{s:10:"predicates";a:1:{i:0;s:15:"content:encoded";}}s:3:"uid";a:2:{s:10:"predicates";a:1:{i:0;s:16:"sioc:has_creator";}s:4:"type";s:3:"rel";}s:4:"name";a:1:{s:10:"predicates";a:1:{i:0;s:9:"foaf:name";}}s:13:"comment_count";a:2:{s:10:"predicates";a:1:{i:0;s:16:"sioc:num_replies";}s:8:"datatype";s:11:"xsd:integer";}s:13:"last_activity";a:3:{s:10:"predicates";a:1:{i:0;s:23:"sioc:last_activity_date";}s:8:"datatype";s:12:"xsd:dateTime";s:8:"callback";s:12:"date_iso8601";}}'),
('node', 'poll', 'a:9:{s:7:"rdftype";a:2:{i:0;s:9:"sioc:Post";i:1;s:10:"sioct:Poll";}s:5:"title";a:1:{s:10:"predicates";a:1:{i:0;s:8:"dc:title";}}s:7:"created";a:3:{s:10:"predicates";a:2:{i:0;s:7:"dc:date";i:1;s:10:"dc:created";}s:8:"datatype";s:12:"xsd:dateTime";s:8:"callback";s:12:"date_iso8601";}s:7:"changed";a:3:{s:10:"predicates";a:1:{i:0;s:11:"dc:modified";}s:8:"datatype";s:12:"xsd:dateTime";s:8:"callback";s:12:"date_iso8601";}s:4:"body";a:1:{s:10:"predicates";a:1:{i:0;s:15:"content:encoded";}}s:3:"uid";a:2:{s:10:"predicates";a:1:{i:0;s:16:"sioc:has_creator";}s:4:"type";s:3:"rel";}s:4:"name";a:1:{s:10:"predicates";a:1:{i:0;s:9:"foaf:name";}}s:13:"comment_count";a:2:{s:10:"predicates";a:1:{i:0;s:16:"sioc:num_replies";}s:8:"datatype";s:11:"xsd:integer";}s:13:"last_activity";a:3:{s:10:"predicates";a:1:{i:0;s:23:"sioc:last_activity_date";}s:8:"datatype";s:12:"xsd:dateTime";s:8:"callback";s:12:"date_iso8601";}}'),
('taxonomy_term', 'forums', 'a:5:{s:7:"rdftype";a:2:{i:0;s:14:"sioc:Container";i:1;s:10:"sioc:Forum";}s:4:"name";a:1:{s:10:"predicates";a:2:{i:0;s:10:"rdfs:label";i:1;s:14:"skos:prefLabel";}}s:11:"description";a:1:{s:10:"predicates";a:1:{i:0;s:15:"skos:definition";}}s:3:"vid";a:2:{s:10:"predicates";a:1:{i:0;s:13:"skos:inScheme";}s:4:"type";s:3:"rel";}s:6:"parent";a:2:{s:10:"predicates";a:1:{i:0;s:12:"skos:broader";}s:4:"type";s:3:"rel";}}');
/*!40000 ALTER TABLE rdf_mapping ENABLE KEYS */;

--
-- Table structure for table 'registry'
--

CREATE TABLE IF NOT EXISTS `registry` (
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT 'The name of the function, class, or interface.',
  `type` varchar(9) NOT NULL DEFAULT '' COMMENT 'Either function or class or interface.',
  `filename` varchar(255) NOT NULL,
  `module` varchar(255) NOT NULL DEFAULT '' COMMENT 'Name of the module the file belongs to.',
  `weight` int(11) NOT NULL DEFAULT '0' COMMENT 'The order in which this module’s hooks should be invoked relative to other modules. Equal-weighted modules are ordered by name.',
  PRIMARY KEY (`name`,`type`),
  KEY `hook` (`type`,`weight`,`module`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Each record is a function, class, or interface name and...';

--
-- Dumping data for table 'registry'
--

/*!40000 ALTER TABLE registry DISABLE KEYS */;
INSERT INTO `registry` VALUES
('AccessDeniedTestCase', 'class', 'modules/system/system.test', 'system', '0'),
('AddFeedTestCase', 'class', 'modules/aggregator/aggregator.test', 'aggregator', '0'),
('AddThis', 'class', 'sites/all/modules/addthis/classes/AddThis.php', 'addthis', '0'),
('AddThisFunctionalityTestCase', 'class', 'sites/all/modules/addthis/addthis.test', 'addthis', '0'),
('AddThisJson', 'class', 'sites/all/modules/addthis/classes/AddThisJson.php', 'addthis', '0'),
('AddThisPermissionsTestCase', 'class', 'sites/all/modules/addthis/addthis.test', 'addthis', '0'),
('AdminMenuCustomizedTestCase', 'class', 'sites/all/modules/admin_menu/tests/admin_menu.test', 'admin_menu', '0'),
('AdminMenuDynamicLinksTestCase', 'class', 'sites/all/modules/admin_menu/tests/admin_menu.test', 'admin_menu', '0'),
('AdminMenuLinkTypesTestCase', 'class', 'sites/all/modules/admin_menu/tests/admin_menu.test', 'admin_menu', '0'),
('AdminMenuPermissionsTestCase', 'class', 'sites/all/modules/admin_menu/tests/admin_menu.test', 'admin_menu', '0'),
('AdminMenuWebTestCase', 'class', 'sites/all/modules/admin_menu/tests/admin_menu.test', 'admin_menu', '0'),
('AdminMetaTagTestCase', 'class', 'modules/system/system.test', 'system', '0'),
('AggregatorConfigurationTestCase', 'class', 'modules/aggregator/aggregator.test', 'aggregator', '0'),
('AggregatorCronTestCase', 'class', 'modules/aggregator/aggregator.test', 'aggregator', '0'),
('AggregatorRenderingTestCase', 'class', 'modules/aggregator/aggregator.test', 'aggregator', '0'),
('AggregatorTestCase', 'class', 'modules/aggregator/aggregator.test', 'aggregator', '0'),
('ArchiverInterface', 'interface', 'includes/archiver.inc', '', '0'),
('ArchiverTar', 'class', 'modules/system/system.archiver.inc', 'system', '0'),
('ArchiverZip', 'class', 'modules/system/system.archiver.inc', 'system', '0'),
('Archive_Tar', 'class', 'modules/system/system.tar.inc', 'system', '0'),
('BatchMemoryQueue', 'class', 'includes/batch.queue.inc', '', '0'),
('BatchQueue', 'class', 'includes/batch.queue.inc', '', '0'),
('BlockAdminThemeTestCase', 'class', 'modules/block/block.test', 'block', '-5'),
('BlockCacheTestCase', 'class', 'modules/block/block.test', 'block', '-5'),
('BlockClassContextTestCase', 'class', 'sites/all/modules/block_class/block_class.test', 'block_class', '0'),
('BlockClassPermissionTestCase', 'class', 'sites/all/modules/block_class/block_class.test', 'block_class', '0'),
('BlockClassTestCase', 'class', 'sites/all/modules/block_class/block_class.test', 'block_class', '0'),
('BlockClassUpdateDisplayTestCase', 'class', 'sites/all/modules/block_class/block_class.test', 'block_class', '0'),
('BlockHiddenRegionTestCase', 'class', 'modules/block/block.test', 'block', '-5'),
('BlockHTMLIdTestCase', 'class', 'modules/block/block.test', 'block', '-5'),
('BlockInvalidRegionTestCase', 'class', 'modules/block/block.test', 'block', '-5'),
('BlockTemplateSuggestionsUnitTest', 'class', 'modules/block/block.test', 'block', '-5'),
('BlockTestCase', 'class', 'modules/block/block.test', 'block', '-5'),
('BlogTestCase', 'class', 'modules/blog/blog.test', 'blog', '0'),
('BookTestCase', 'class', 'modules/book/book.test', 'book', '0'),
('CategorizeFeedItemTestCase', 'class', 'modules/aggregator/aggregator.test', 'aggregator', '0'),
('CategorizeFeedTestCase', 'class', 'modules/aggregator/aggregator.test', 'aggregator', '0'),
('colorbox_handler_field_colorbox', 'class', 'sites/all/modules/colorbox/views/colorbox_handler_field_colorbox.inc', 'colorbox', '0'),
('CommentActionsTestCase', 'class', 'modules/comment/comment.test', 'comment', '0'),
('CommentAnonymous', 'class', 'modules/comment/comment.test', 'comment', '0'),
('CommentApprovalTest', 'class', 'modules/comment/comment.test', 'comment', '0'),
('CommentBlockFunctionalTest', 'class', 'modules/comment/comment.test', 'comment', '0'),
('CommentContentRebuild', 'class', 'modules/comment/comment.test', 'comment', '0'),
('CommentController', 'class', 'modules/comment/comment.module', 'comment', '0'),
('CommentFieldsTest', 'class', 'modules/comment/comment.test', 'comment', '0'),
('CommentHelperCase', 'class', 'modules/comment/comment.test', 'comment', '0'),
('CommentInterfaceTest', 'class', 'modules/comment/comment.test', 'comment', '0'),
('CommentNodeAccessTest', 'class', 'modules/comment/comment.test', 'comment', '0'),
('CommentNodeChangesTestCase', 'class', 'modules/comment/comment.test', 'comment', '0'),
('CommentPagerTest', 'class', 'modules/comment/comment.test', 'comment', '0'),
('CommentPreviewTest', 'class', 'modules/comment/comment.test', 'comment', '0'),
('CommentRSSUnitTest', 'class', 'modules/comment/comment.test', 'comment', '0'),
('CommentThreadingTestCase', 'class', 'modules/comment/comment.test', 'comment', '0'),
('CommentTokenReplaceTestCase', 'class', 'modules/comment/comment.test', 'comment', '0'),
('ContactPersonalTestCase', 'class', 'modules/contact/contact.test', 'contact', '0'),
('ContactSitewideTestCase', 'class', 'modules/contact/contact.test', 'contact', '0'),
('ContextualDynamicContextTestCase', 'class', 'modules/contextual/contextual.test', 'contextual', '0'),
('CRAUDFaqTestCase', 'class', 'sites/all/modules/faq/faq.test', 'faq', '0'),
('CreateFaqTestCase', 'class', 'sites/all/modules/faq/faq.test', 'faq', '0'),
('CronRunTestCase', 'class', 'modules/system/system.test', 'system', '0'),
('ctools_context', 'class', 'sites/all/modules/ctools/includes/context.inc', 'ctools', '0'),
('ctools_context_optional', 'class', 'sites/all/modules/ctools/includes/context.inc', 'ctools', '0'),
('ctools_context_required', 'class', 'sites/all/modules/ctools/includes/context.inc', 'ctools', '0'),
('ctools_export_ui', 'class', 'sites/all/modules/ctools/plugins/export_ui/ctools_export_ui.class.php', 'ctools', '0'),
('ctools_math_expr', 'class', 'sites/all/modules/ctools/includes/math-expr.inc', 'ctools', '0'),
('ctools_math_expr_stack', 'class', 'sites/all/modules/ctools/includes/math-expr.inc', 'ctools', '0'),
('ctools_stylizer_image_processor', 'class', 'sites/all/modules/ctools/includes/stylizer.inc', 'ctools', '0'),
('Database', 'class', 'includes/database/database.inc', '', '0'),
('DatabaseCondition', 'class', 'includes/database/query.inc', '', '0'),
('DatabaseConnection', 'class', 'includes/database/database.inc', '', '0'),
('DatabaseConnectionNotDefinedException', 'class', 'includes/database/database.inc', '', '0'),
('DatabaseConnection_mysql', 'class', 'includes/database/mysql/database.inc', '', '0'),
('DatabaseConnection_pgsql', 'class', 'includes/database/pgsql/database.inc', '', '0'),
('DatabaseConnection_sqlite', 'class', 'includes/database/sqlite/database.inc', '', '0'),
('DatabaseDriverNotSpecifiedException', 'class', 'includes/database/database.inc', '', '0'),
('DatabaseLog', 'class', 'includes/database/log.inc', '', '0'),
('DatabaseSchema', 'class', 'includes/database/schema.inc', '', '0'),
('DatabaseSchemaObjectDoesNotExistException', 'class', 'includes/database/schema.inc', '', '0'),
('DatabaseSchemaObjectExistsException', 'class', 'includes/database/schema.inc', '', '0'),
('DatabaseSchema_mysql', 'class', 'includes/database/mysql/schema.inc', '', '0'),
('DatabaseSchema_pgsql', 'class', 'includes/database/pgsql/schema.inc', '', '0'),
('DatabaseSchema_sqlite', 'class', 'includes/database/sqlite/schema.inc', '', '0'),
('DatabaseStatementBase', 'class', 'includes/database/database.inc', '', '0'),
('DatabaseStatementEmpty', 'class', 'includes/database/database.inc', '', '0'),
('DatabaseStatementInterface', 'interface', 'includes/database/database.inc', '', '0'),
('DatabaseStatementPrefetch', 'class', 'includes/database/prefetch.inc', '', '0'),
('DatabaseStatement_sqlite', 'class', 'includes/database/sqlite/database.inc', '', '0'),
('DatabaseTaskException', 'class', 'includes/install.inc', '', '0'),
('DatabaseTasks', 'class', 'includes/install.inc', '', '0'),
('DatabaseTasks_mysql', 'class', 'includes/database/mysql/install.inc', '', '0'),
('DatabaseTasks_pgsql', 'class', 'includes/database/pgsql/install.inc', '', '0'),
('DatabaseTasks_sqlite', 'class', 'includes/database/sqlite/install.inc', '', '0'),
('DatabaseTransaction', 'class', 'includes/database/database.inc', '', '0'),
('DatabaseTransactionCommitFailedException', 'class', 'includes/database/database.inc', '', '0'),
('DatabaseTransactionExplicitCommitNotAllowedException', 'class', 'includes/database/database.inc', '', '0'),
('DatabaseTransactionNameNonUniqueException', 'class', 'includes/database/database.inc', '', '0'),
('DatabaseTransactionNoActiveException', 'class', 'includes/database/database.inc', '', '0'),
('DatabaseTransactionOutOfOrderException', 'class', 'includes/database/database.inc', '', '0'),
('DateTimeFunctionalTest', 'class', 'modules/system/system.test', 'system', '0'),
('DefaultMailSystem', 'class', 'modules/system/system.mail.inc', 'system', '0'),
('DeleteQuery', 'class', 'includes/database/query.inc', '', '0'),
('DeleteQuery_sqlite', 'class', 'includes/database/sqlite/query.inc', '', '0'),
('DrupalCacheArray', 'class', 'includes/bootstrap.inc', '', '0'),
('DrupalCacheInterface', 'interface', 'includes/cache.inc', '', '0'),
('DrupalDatabaseCache', 'class', 'includes/cache.inc', '', '0'),
('DrupalDefaultEntityController', 'class', 'includes/entity.inc', '', '0'),
('DrupalEntityControllerInterface', 'interface', 'includes/entity.inc', '', '0'),
('DrupalFakeCache', 'class', 'includes/cache-install.inc', '', '0'),
('DrupalLocalStreamWrapper', 'class', 'includes/stream_wrappers.inc', '', '0'),
('DrupalPrivateStreamWrapper', 'class', 'includes/stream_wrappers.inc', '', '0'),
('DrupalPublicStreamWrapper', 'class', 'includes/stream_wrappers.inc', '', '0'),
('DrupalQueue', 'class', 'modules/system/system.queue.inc', 'system', '0'),
('DrupalQueueInterface', 'interface', 'modules/system/system.queue.inc', 'system', '0'),
('DrupalReliableQueueInterface', 'interface', 'modules/system/system.queue.inc', 'system', '0'),
('DrupalStreamWrapperInterface', 'interface', 'includes/stream_wrappers.inc', '', '0'),
('DrupalTemporaryStreamWrapper', 'class', 'includes/stream_wrappers.inc', '', '0'),
('DrupalUpdateException', 'class', 'includes/update.inc', '', '0'),
('DrupalUpdaterInterface', 'interface', 'includes/updater.inc', '', '0'),
('EnableDisableTestCase', 'class', 'modules/system/system.test', 'system', '0'),
('EntityFieldQuery', 'class', 'includes/entity.inc', '', '0'),
('EntityFieldQueryException', 'class', 'includes/entity.inc', '', '0'),
('EntityMalformedException', 'class', 'includes/entity.inc', '', '0'),
('EntityPropertiesTestCase', 'class', 'modules/field/tests/field.test', 'field', '0'),
('FaqAccessTestClass', 'class', 'sites/all/modules/faq/faq.test', 'faq', '0'),
('FaqTestCase', 'class', 'sites/all/modules/faq/faq.test', 'faq', '0'),
('FeedParserTestCase', 'class', 'modules/aggregator/aggregator.test', 'aggregator', '0'),
('FieldAttachOtherTestCase', 'class', 'modules/field/tests/field.test', 'field', '0'),
('FieldAttachStorageTestCase', 'class', 'modules/field/tests/field.test', 'field', '0'),
('FieldAttachTestCase', 'class', 'modules/field/tests/field.test', 'field', '0'),
('FieldBulkDeleteTestCase', 'class', 'modules/field/tests/field.test', 'field', '0'),
('FieldCrudTestCase', 'class', 'modules/field/tests/field.test', 'field', '0'),
('FieldDisplayAPITestCase', 'class', 'modules/field/tests/field.test', 'field', '0'),
('FieldException', 'class', 'modules/field/field.module', 'field', '0'),
('FieldFormTestCase', 'class', 'modules/field/tests/field.test', 'field', '0'),
('FieldInfo', 'class', 'modules/field/field.info.class.inc', 'field', '0'),
('FieldInfoTestCase', 'class', 'modules/field/tests/field.test', 'field', '0'),
('FieldInstanceCrudTestCase', 'class', 'modules/field/tests/field.test', 'field', '0'),
('FieldsOverlapException', 'class', 'includes/database/database.inc', '', '0'),
('FieldSqlStorageTestCase', 'class', 'modules/field/modules/field_sql_storage/field_sql_storage.test', 'field_sql_storage', '0'),
('FieldTestCase', 'class', 'modules/field/tests/field.test', 'field', '0'),
('FieldTranslationsTestCase', 'class', 'modules/field/tests/field.test', 'field', '0'),
('FieldUIAlterTestCase', 'class', 'modules/field_ui/field_ui.test', 'field_ui', '0'),
('FieldUIManageDisplayTestCase', 'class', 'modules/field_ui/field_ui.test', 'field_ui', '0'),
('FieldUIManageFieldsTestCase', 'class', 'modules/field_ui/field_ui.test', 'field_ui', '0'),
('FieldUITestCase', 'class', 'modules/field_ui/field_ui.test', 'field_ui', '0'),
('FieldUpdateForbiddenException', 'class', 'modules/field/field.module', 'field', '0'),
('FieldValidationException', 'class', 'modules/field/field.attach.inc', 'field', '0'),
('FileFieldDisplayTestCase', 'class', 'modules/file/tests/file.test', 'file', '0'),
('FileFieldPathTestCase', 'class', 'modules/file/tests/file.test', 'file', '0'),
('FileFieldRevisionTestCase', 'class', 'modules/file/tests/file.test', 'file', '0'),
('FileFieldTestCase', 'class', 'modules/file/tests/file.test', 'file', '0'),
('FileFieldValidateTestCase', 'class', 'modules/file/tests/file.test', 'file', '0'),
('FileFieldWidgetTestCase', 'class', 'modules/file/tests/file.test', 'file', '0'),
('FileManagedFileElementTestCase', 'class', 'modules/file/tests/file.test', 'file', '0'),
('FilePrivateTestCase', 'class', 'modules/file/tests/file.test', 'file', '0'),
('FileTokenReplaceTestCase', 'class', 'modules/file/tests/file.test', 'file', '0'),
('FileTransfer', 'class', 'includes/filetransfer/filetransfer.inc', '', '0'),
('FileTransferChmodInterface', 'interface', 'includes/filetransfer/filetransfer.inc', '', '0'),
('FileTransferException', 'class', 'includes/filetransfer/filetransfer.inc', '', '0'),
('FileTransferFTP', 'class', 'includes/filetransfer/ftp.inc', '', '0'),
('FileTransferFTPExtension', 'class', 'includes/filetransfer/ftp.inc', '', '0'),
('FileTransferLocal', 'class', 'includes/filetransfer/local.inc', '', '0'),
('FileTransferSSH', 'class', 'includes/filetransfer/ssh.inc', '', '0'),
('FilterAdminTestCase', 'class', 'modules/filter/filter.test', 'filter', '0'),
('FilterCRUDTestCase', 'class', 'modules/filter/filter.test', 'filter', '0'),
('FilterDefaultFormatTestCase', 'class', 'modules/filter/filter.test', 'filter', '0'),
('FilterFormatAccessTestCase', 'class', 'modules/filter/filter.test', 'filter', '0'),
('FilterHooksTestCase', 'class', 'modules/filter/filter.test', 'filter', '0'),
('FilterNoFormatTestCase', 'class', 'modules/filter/filter.test', 'filter', '0'),
('FilterSecurityTestCase', 'class', 'modules/filter/filter.test', 'filter', '0'),
('FilterSettingsTestCase', 'class', 'modules/filter/filter.test', 'filter', '0'),
('FilterUnitTestCase', 'class', 'modules/filter/filter.test', 'filter', '0'),
('FlexsliderTestCase', 'class', 'sites/all/modules/flexslider/flexslider.test', 'flexslider', '0'),
('flexslider_views_plugin_style_flexslider', 'class', 'sites/all/modules/flexslider/flexslider_views/flexslider_views_plugin_style_flexslider.inc', 'flexslider_views', '0'),
('FloodFunctionalTest', 'class', 'modules/system/system.test', 'system', '0'),
('FollowTestCase', 'class', 'sites/all/modules/follow/tests/follow.test', 'follow', '0'),
('ForumIndexTestCase', 'class', 'modules/forum/forum.test', 'forum', '1'),
('ForumTestCase', 'class', 'modules/forum/forum.test', 'forum', '1'),
('FrontPageTestCase', 'class', 'modules/system/system.test', 'system', '0'),
('getlocations_fields_handler_argument_city', 'class', 'sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_argument_city.inc', 'getlocations_fields', '0'),
('getlocations_fields_handler_argument_country', 'class', 'sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_argument_country.inc', 'getlocations_fields', '0'),
('getlocations_fields_handler_argument_distance', 'class', 'sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_argument_distance.inc', 'getlocations_fields', '0'),
('getlocations_fields_handler_argument_glid', 'class', 'sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_argument_glid.inc', 'getlocations_fields', '0'),
('getlocations_fields_handler_argument_postcode', 'class', 'sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_argument_postcode.inc', 'getlocations_fields', '0'),
('getlocations_fields_handler_argument_province', 'class', 'sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_argument_province.inc', 'getlocations_fields', '0'),
('getlocations_fields_handler_field_coordinates', 'class', 'sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_field_coordinates.inc', 'getlocations_fields', '0'),
('getlocations_fields_handler_field_country', 'class', 'sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_field_country.inc', 'getlocations_fields', '0'),
('getlocations_fields_handler_field_distance', 'class', 'sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_field_distance.inc', 'getlocations_fields', '0'),
('getlocations_fields_handler_field_latitude', 'class', 'sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_field_latitude.inc', 'getlocations_fields', '0'),
('getlocations_fields_handler_field_longitude', 'class', 'sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_field_longitude.inc', 'getlocations_fields', '0'),
('getlocations_fields_handler_filter_country', 'class', 'sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_filter_country.inc', 'getlocations_fields', '0'),
('getlocations_fields_handler_filter_distance', 'class', 'sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_filter_distance.inc', 'getlocations_fields', '0'),
('getlocations_fields_handler_sort_distance', 'class', 'sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_sort_distance.inc', 'getlocations_fields', '0'),
('getlocations_plugin_style_map', 'class', 'sites/all/modules/getlocations/views/getlocations_plugin_style_map.inc', 'getlocations', '0'),
('HookRequirementsTestCase', 'class', 'modules/system/system.test', 'system', '0'),
('ImageAdminStylesUnitTest', 'class', 'modules/image/image.test', 'image', '0'),
('ImageDimensionsScaleTestCase', 'class', 'modules/image/image.test', 'image', '0'),
('ImageDimensionsTestCase', 'class', 'modules/image/image.test', 'image', '0'),
('ImageEffectsUnitTest', 'class', 'modules/image/image.test', 'image', '0'),
('ImageFieldDefaultImagesTestCase', 'class', 'modules/image/image.test', 'image', '0'),
('ImageFieldDisplayTestCase', 'class', 'modules/image/image.test', 'image', '0'),
('ImageFieldTestCase', 'class', 'modules/image/image.test', 'image', '0'),
('ImageFieldValidateTestCase', 'class', 'modules/image/image.test', 'image', '0'),
('ImageStyleFlushTest', 'class', 'modules/image/image.test', 'image', '0'),
('ImageStylesPathAndUrlTestCase', 'class', 'modules/image/image.test', 'image', '0'),
('ImageThemeFunctionWebTestCase', 'class', 'modules/image/image.test', 'image', '0'),
('ImportOPMLTestCase', 'class', 'modules/aggregator/aggregator.test', 'aggregator', '0'),
('InfoFileParserTestCase', 'class', 'modules/system/system.test', 'system', '0'),
('InsertQuery', 'class', 'includes/database/query.inc', '', '0'),
('InsertQuery_mysql', 'class', 'includes/database/mysql/query.inc', '', '0'),
('InsertQuery_pgsql', 'class', 'includes/database/pgsql/query.inc', '', '0'),
('InsertQuery_sqlite', 'class', 'includes/database/sqlite/query.inc', '', '0'),
('InvalidMergeQueryException', 'class', 'includes/database/database.inc', '', '0'),
('IPAddressBlockingTestCase', 'class', 'modules/system/system.test', 'system', '0'),
('LibrariesTestCase', 'class', 'sites/all/modules/libraries/tests/libraries.test', 'libraries', '0'),
('LibrariesUnitTestCase', 'class', 'sites/all/modules/libraries/tests/libraries.test', 'libraries', '0'),
('ListDynamicValuesTestCase', 'class', 'modules/field/modules/list/tests/list.test', 'list', '0'),
('ListDynamicValuesValidationTestCase', 'class', 'modules/field/modules/list/tests/list.test', 'list', '0'),
('ListFieldTestCase', 'class', 'modules/field/modules/list/tests/list.test', 'list', '0'),
('ListFieldUITestCase', 'class', 'modules/field/modules/list/tests/list.test', 'list', '0'),
('LocaleBrowserDetectionTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('LocaleCommentLanguageFunctionalTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('LocaleConfigurationTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('LocaleContentFunctionalTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('LocaleCSSAlterTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('LocaleDateFormatsFunctionalTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('LocaleExportFunctionalTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('LocaleImportFunctionalTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('LocaleInstallTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('LocaleJavascriptTranslationTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('LocaleLanguageNegotiationInfoFunctionalTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('LocaleLanguageSwitchingFunctionalTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('LocaleLibraryInfoAlterTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('LocaleMultilingualFieldsFunctionalTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('LocalePathFunctionalTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('LocalePluralFormatTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('LocaleTranslationFunctionalTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('LocaleUILanguageNegotiationTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('LocaleUninstallFrenchFunctionalTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('LocaleUninstallFunctionalTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('LocaleUrlRewritingTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('LocaleUserCreationTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('LocaleUserLanguageFunctionalTest', 'class', 'modules/locale/locale.test', 'locale', '0'),
('MailSystemInterface', 'interface', 'includes/mail.inc', '', '0'),
('MemoryQueue', 'class', 'modules/system/system.queue.inc', 'system', '0'),
('MenuNodeTestCase', 'class', 'modules/menu/menu.test', 'menu', '0'),
('MenuTestCase', 'class', 'modules/menu/menu.test', 'menu', '0'),
('MergeQuery', 'class', 'includes/database/query.inc', '', '0'),
('ModuleDependencyTestCase', 'class', 'modules/system/system.test', 'system', '0'),
('ModuleRequiredTestCase', 'class', 'modules/system/system.test', 'system', '0'),
('ModuleTestCase', 'class', 'modules/system/system.test', 'system', '0'),
('ModuleUpdater', 'class', 'modules/system/system.updater.inc', 'system', '0'),
('ModuleVersionTestCase', 'class', 'modules/system/system.test', 'system', '0'),
('MultiStepNodeFormBasicOptionsTest', 'class', 'modules/node/node.test', 'node', '0'),
('NewDefaultThemeBlocks', 'class', 'modules/block/block.test', 'block', '-5'),
('NodeAccessBaseTableTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NodeAccessFieldTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NodeAccessPagerTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NodeAccessRebuildTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NodeAccessRecordsTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NodeAccessTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NodeAdminTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NodeBlockFunctionalTest', 'class', 'modules/node/node.test', 'node', '0'),
('NodeBlockTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NodeBuildContent', 'class', 'modules/node/node.test', 'node', '0'),
('NodeController', 'class', 'modules/node/node.module', 'node', '0'),
('NodeCreationTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NodeEntityFieldQueryAlter', 'class', 'modules/node/node.test', 'node', '0'),
('NodeEntityViewModeAlterTest', 'class', 'modules/node/node.test', 'node', '0'),
('NodeFeedTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NodeLoadHooksTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NodeLoadMultipleTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NodePostSettingsTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NodeQueryAlter', 'class', 'modules/node/node.test', 'node', '0'),
('NodeRevisionPermissionsTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NodeRevisionsTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NodeRSSContentTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NodeSaveTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NodeTitleTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NodeTitleXSSTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NodeTokenReplaceTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NodeTypePersistenceTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NodeTypeTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NodeWebTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('NoFieldsException', 'class', 'includes/database/database.inc', '', '0'),
('NonDefaultBlockAdmin', 'class', 'modules/block/block.test', 'block', '-5'),
('NumberFieldTestCase', 'class', 'modules/field/modules/number/number.test', 'number', '0'),
('OptionsSelectDynamicValuesTestCase', 'class', 'modules/field/modules/options/options.test', 'options', '0'),
('OptionsWidgetsTestCase', 'class', 'modules/field/modules/options/options.test', 'options', '0'),
('PageEditTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('PageNotFoundTestCase', 'class', 'modules/system/system.test', 'system', '0'),
('PagePreviewTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('PagerDefault', 'class', 'includes/pager.inc', '', '0'),
('PageTitleFiltering', 'class', 'modules/system/system.test', 'system', '0'),
('PageViewTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('PanelsLegacyState', 'class', 'sites/all/modules/panels/includes/legacy.inc', 'panels', '0'),
('panels_allowed_layouts', 'class', 'sites/all/modules/panels/includes/common.inc', 'panels', '0'),
('panels_cache_object', 'class', 'sites/all/modules/panels/includes/plugins.inc', 'panels', '0'),
('panels_display', 'class', 'sites/all/modules/panels/panels.module', 'panels', '0'),
('panels_layouts_ui', 'class', 'sites/all/modules/panels/plugins/export_ui/panels_layouts_ui.class.php', 'panels', '0'),
('panels_mini_ui', 'class', 'sites/all/modules/panels/panels_mini/plugins/export_ui/panels_mini_ui.class.php', 'panels_mini', '0'),
('panels_renderer_editor', 'class', 'sites/all/modules/panels/plugins/display_renderers/panels_renderer_editor.class.php', 'panels', '0'),
('panels_renderer_ipe', 'class', 'sites/all/modules/panels/panels_ipe/plugins/display_renderers/panels_renderer_ipe.class.php', 'panels_ipe', '0'),
('panels_renderer_simple', 'class', 'sites/all/modules/panels/plugins/display_renderers/panels_renderer_simple.class.php', 'panels', '0'),
('panels_renderer_standard', 'class', 'sites/all/modules/panels/plugins/display_renderers/panels_renderer_standard.class.php', 'panels', '0'),
('panels_views_plugin_row_fields', 'class', 'sites/all/modules/panels/plugins/views/panels_views_plugin_row_fields.inc', 'panels', '0'),
('PathLanguageTestCase', 'class', 'modules/path/path.test', 'path', '0'),
('PathLanguageUITestCase', 'class', 'modules/path/path.test', 'path', '0'),
('PathMonolingualTestCase', 'class', 'modules/path/path.test', 'path', '0'),
('PathTaxonomyTermTestCase', 'class', 'modules/path/path.test', 'path', '0'),
('PathTestCase', 'class', 'modules/path/path.test', 'path', '0'),
('PHPAccessTestCase', 'class', 'modules/php/php.test', 'php', '0'),
('PHPFilterTestCase', 'class', 'modules/php/php.test', 'php', '0'),
('PHPTestCase', 'class', 'modules/php/php.test', 'php', '0'),
('PollBlockTestCase', 'class', 'modules/poll/poll.test', 'poll', '0'),
('PollCreateTestCase', 'class', 'modules/poll/poll.test', 'poll', '0'),
('PollDeleteChoiceTestCase', 'class', 'modules/poll/poll.test', 'poll', '0'),
('PollExpirationTestCase', 'class', 'modules/poll/poll.test', 'poll', '0'),
('PollJSAddChoice', 'class', 'modules/poll/poll.test', 'poll', '0'),
('PollTestCase', 'class', 'modules/poll/poll.test', 'poll', '0'),
('PollTokenReplaceTestCase', 'class', 'modules/poll/poll.test', 'poll', '0'),
('PollTranslateTestCase', 'class', 'modules/poll/poll.test', 'poll', '0'),
('PollVoteCheckHostname', 'class', 'modules/poll/poll.test', 'poll', '0'),
('PollVoteTestCase', 'class', 'modules/poll/poll.test', 'poll', '0'),
('Query', 'class', 'includes/database/query.inc', '', '0'),
('QueryAlterableInterface', 'interface', 'includes/database/query.inc', '', '0'),
('QueryConditionInterface', 'interface', 'includes/database/query.inc', '', '0'),
('QueryExtendableInterface', 'interface', 'includes/database/select.inc', '', '0'),
('QueryPlaceholderInterface', 'interface', 'includes/database/query.inc', '', '0'),
('QueueTestCase', 'class', 'modules/system/system.test', 'system', '0'),
('RemoveFeedItemTestCase', 'class', 'modules/aggregator/aggregator.test', 'aggregator', '0'),
('RemoveFeedTestCase', 'class', 'modules/aggregator/aggregator.test', 'aggregator', '0'),
('RetrieveFileTestCase', 'class', 'modules/system/system.test', 'system', '0'),
('SchemaCache', 'class', 'includes/bootstrap.inc', '', '0'),
('SearchAdvancedSearchForm', 'class', 'modules/search/search.test', 'search', '0'),
('SearchBlockTestCase', 'class', 'modules/search/search.test', 'search', '0'),
('SearchCommentCountToggleTestCase', 'class', 'modules/search/search.test', 'search', '0'),
('SearchCommentTestCase', 'class', 'modules/search/search.test', 'search', '0'),
('SearchConfigSettingsForm', 'class', 'modules/search/search.test', 'search', '0'),
('SearchEmbedForm', 'class', 'modules/search/search.test', 'search', '0'),
('SearchExactTestCase', 'class', 'modules/search/search.test', 'search', '0'),
('SearchExcerptTestCase', 'class', 'modules/search/search.test', 'search', '0'),
('SearchExpressionInsertExtractTestCase', 'class', 'modules/search/search.test', 'search', '0'),
('SearchKeywordsConditions', 'class', 'modules/search/search.test', 'search', '0'),
('SearchLanguageTestCase', 'class', 'modules/search/search.test', 'search', '0'),
('SearchMatchTestCase', 'class', 'modules/search/search.test', 'search', '0'),
('SearchNodeAccessTest', 'class', 'modules/search/search.test', 'search', '0'),
('SearchNumberMatchingTestCase', 'class', 'modules/search/search.test', 'search', '0'),
('SearchNumbersTestCase', 'class', 'modules/search/search.test', 'search', '0'),
('SearchPageOverride', 'class', 'modules/search/search.test', 'search', '0'),
('SearchPageText', 'class', 'modules/search/search.test', 'search', '0'),
('SearchQuery', 'class', 'modules/search/search.extender.inc', 'search', '0'),
('SearchRankingTestCase', 'class', 'modules/search/search.test', 'search', '0'),
('SearchSimplifyTestCase', 'class', 'modules/search/search.test', 'search', '0'),
('SearchTokenizerTestCase', 'class', 'modules/search/search.test', 'search', '0'),
('SelectQuery', 'class', 'includes/database/select.inc', '', '0'),
('SelectQueryExtender', 'class', 'includes/database/select.inc', '', '0'),
('SelectQueryInterface', 'interface', 'includes/database/select.inc', '', '0'),
('SelectQuery_pgsql', 'class', 'includes/database/pgsql/select.inc', '', '0'),
('SelectQuery_sqlite', 'class', 'includes/database/sqlite/select.inc', '', '0'),
('semanticviews_plugin_row_fields', 'class', 'sites/all/modules/semanticviews/semanticviews_plugin_row_fields.inc', 'semanticviews', '0'),
('semanticviews_plugin_style_default', 'class', 'sites/all/modules/semanticviews/semanticviews_plugin_style_default.inc', 'semanticviews', '0'),
('ShortcutLinksTestCase', 'class', 'modules/shortcut/shortcut.test', 'shortcut', '0'),
('ShortcutSetsTestCase', 'class', 'modules/shortcut/shortcut.test', 'shortcut', '0'),
('ShortcutTestCase', 'class', 'modules/shortcut/shortcut.test', 'shortcut', '0'),
('ShutdownFunctionsTest', 'class', 'modules/system/system.test', 'system', '0'),
('SiteMaintenanceTestCase', 'class', 'modules/system/system.test', 'system', '0'),
('SkipDotsRecursiveDirectoryIterator', 'class', 'includes/filetransfer/filetransfer.inc', '', '0'),
('StreamWrapperInterface', 'interface', 'includes/stream_wrappers.inc', '', '0'),
('SummaryLengthTestCase', 'class', 'modules/node/node.test', 'node', '0'),
('SystemAdminTestCase', 'class', 'modules/system/system.test', 'system', '0'),
('SystemAuthorizeCase', 'class', 'modules/system/system.test', 'system', '0'),
('SystemBlockTestCase', 'class', 'modules/system/system.test', 'system', '0'),
('SystemIndexPhpTest', 'class', 'modules/system/system.test', 'system', '0'),
('SystemInfoAlterTestCase', 'class', 'modules/system/system.test', 'system', '0'),
('SystemMainContentFallback', 'class', 'modules/system/system.test', 'system', '0'),
('SystemQueue', 'class', 'modules/system/system.queue.inc', 'system', '0'),
('SystemThemeFunctionalTest', 'class', 'modules/system/system.test', 'system', '0'),
('TableSort', 'class', 'includes/tablesort.inc', '', '0'),
('TaxonomyEFQTestCase', 'class', 'modules/taxonomy/taxonomy.test', 'taxonomy', '0'),
('TaxonomyHooksTestCase', 'class', 'modules/taxonomy/taxonomy.test', 'taxonomy', '0'),
('TaxonomyLegacyTestCase', 'class', 'modules/taxonomy/taxonomy.test', 'taxonomy', '0'),
('TaxonomyLoadMultipleTestCase', 'class', 'modules/taxonomy/taxonomy.test', 'taxonomy', '0'),
('TaxonomyRSSTestCase', 'class', 'modules/taxonomy/taxonomy.test', 'taxonomy', '0'),
('TaxonomyTermController', 'class', 'modules/taxonomy/taxonomy.module', 'taxonomy', '0'),
('TaxonomyTermFieldMultipleVocabularyTestCase', 'class', 'modules/taxonomy/taxonomy.test', 'taxonomy', '0'),
('TaxonomyTermFieldTestCase', 'class', 'modules/taxonomy/taxonomy.test', 'taxonomy', '0'),
('TaxonomyTermFunctionTestCase', 'class', 'modules/taxonomy/taxonomy.test', 'taxonomy', '0'),
('TaxonomyTermIndexTestCase', 'class', 'modules/taxonomy/taxonomy.test', 'taxonomy', '0'),
('TaxonomyTermTestCase', 'class', 'modules/taxonomy/taxonomy.test', 'taxonomy', '0'),
('TaxonomyThemeTestCase', 'class', 'modules/taxonomy/taxonomy.test', 'taxonomy', '0'),
('TaxonomyTokenReplaceTestCase', 'class', 'modules/taxonomy/taxonomy.test', 'taxonomy', '0'),
('TaxonomyVocabularyController', 'class', 'modules/taxonomy/taxonomy.module', 'taxonomy', '0'),
('TaxonomyVocabularyFunctionalTest', 'class', 'modules/taxonomy/taxonomy.test', 'taxonomy', '0'),
('TaxonomyVocabularyTestCase', 'class', 'modules/taxonomy/taxonomy.test', 'taxonomy', '0'),
('TaxonomyWebTestCase', 'class', 'modules/taxonomy/taxonomy.test', 'taxonomy', '0'),
('TestHelper', 'class', 'sites/all/modules/addthis/addthis.test', 'addthis', '0'),
('TestingMailSystem', 'class', 'modules/system/system.mail.inc', 'system', '0'),
('TextFieldTestCase', 'class', 'modules/field/modules/text/text.test', 'text', '0'),
('TextSummaryTestCase', 'class', 'modules/field/modules/text/text.test', 'text', '0'),
('TextTranslationTestCase', 'class', 'modules/field/modules/text/text.test', 'text', '0'),
('ThemeRegistry', 'class', 'includes/theme.inc', '', '0'),
('ThemeUpdater', 'class', 'modules/system/system.updater.inc', 'system', '0'),
('TokenReplaceTestCase', 'class', 'modules/system/system.test', 'system', '0'),
('TokenScanTest', 'class', 'modules/system/system.test', 'system', '0'),
('TrackerTest', 'class', 'modules/tracker/tracker.test', 'tracker', '0'),
('TriggerActionTestCase', 'class', 'modules/trigger/trigger.test', 'trigger', '0'),
('TriggerContentTestCase', 'class', 'modules/trigger/trigger.test', 'trigger', '0'),
('TriggerCronTestCase', 'class', 'modules/trigger/trigger.test', 'trigger', '0'),
('TriggerOrphanedActionsTestCase', 'class', 'modules/trigger/trigger.test', 'trigger', '0'),
('TriggerOtherTestCase', 'class', 'modules/trigger/trigger.test', 'trigger', '0'),
('TriggerUnassignTestCase', 'class', 'modules/trigger/trigger.test', 'trigger', '0'),
('TriggerUserActionTestCase', 'class', 'modules/trigger/trigger.test', 'trigger', '0'),
('TriggerUserTokenTestCase', 'class', 'modules/trigger/trigger.test', 'trigger', '0'),
('TriggerWebTestCase', 'class', 'modules/trigger/trigger.test', 'trigger', '0'),
('TruncateQuery', 'class', 'includes/database/query.inc', '', '0'),
('TruncateQuery_mysql', 'class', 'includes/database/mysql/query.inc', '', '0'),
('TruncateQuery_sqlite', 'class', 'includes/database/sqlite/query.inc', '', '0'),
('UpdateCoreTestCase', 'class', 'modules/update/update.test', 'update', '0'),
('UpdateCoreUnitTestCase', 'class', 'modules/update/update.test', 'update', '0'),
('UpdateFeedItemTestCase', 'class', 'modules/aggregator/aggregator.test', 'aggregator', '0'),
('UpdateFeedTestCase', 'class', 'modules/aggregator/aggregator.test', 'aggregator', '0'),
('UpdateQuery', 'class', 'includes/database/query.inc', '', '0'),
('UpdateQuery_pgsql', 'class', 'includes/database/pgsql/query.inc', '', '0'),
('UpdateQuery_sqlite', 'class', 'includes/database/sqlite/query.inc', '', '0'),
('Updater', 'class', 'includes/updater.inc', '', '0'),
('UpdaterException', 'class', 'includes/updater.inc', '', '0'),
('UpdaterFileTransferException', 'class', 'includes/updater.inc', '', '0'),
('UpdateScriptFunctionalTest', 'class', 'modules/system/system.test', 'system', '0'),
('UpdateTestContribCase', 'class', 'modules/update/update.test', 'update', '0'),
('UpdateTestHelper', 'class', 'modules/update/update.test', 'update', '0'),
('UpdateTestUploadCase', 'class', 'modules/update/update.test', 'update', '0'),
('UserAccountLinksUnitTests', 'class', 'modules/user/user.test', 'user', '0'),
('UserAdminTestCase', 'class', 'modules/user/user.test', 'user', '0'),
('UserAuthmapAssignmentTestCase', 'class', 'modules/user/user.test', 'user', '0'),
('UserAutocompleteTestCase', 'class', 'modules/user/user.test', 'user', '0'),
('UserBlocksUnitTests', 'class', 'modules/user/user.test', 'user', '0'),
('UserCancelTestCase', 'class', 'modules/user/user.test', 'user', '0'),
('UserController', 'class', 'modules/user/user.module', 'user', '0'),
('UserCreateTestCase', 'class', 'modules/user/user.test', 'user', '0'),
('UserEditedOwnAccountTestCase', 'class', 'modules/user/user.test', 'user', '0'),
('UserEditTestCase', 'class', 'modules/user/user.test', 'user', '0'),
('UserLoginTestCase', 'class', 'modules/user/user.test', 'user', '0'),
('UserPasswordResetTestCase', 'class', 'modules/user/user.test', 'user', '0'),
('UserPermissionsTestCase', 'class', 'modules/user/user.test', 'user', '0'),
('UserPictureTestCase', 'class', 'modules/user/user.test', 'user', '0'),
('UserRegistrationTestCase', 'class', 'modules/user/user.test', 'user', '0'),
('UserRoleAdminTestCase', 'class', 'modules/user/user.test', 'user', '0'),
('UserRolesAssignmentTestCase', 'class', 'modules/user/user.test', 'user', '0'),
('UserSaveTestCase', 'class', 'modules/user/user.test', 'user', '0'),
('UserSignatureTestCase', 'class', 'modules/user/user.test', 'user', '0'),
('UserTimeZoneFunctionalTest', 'class', 'modules/user/user.test', 'user', '0'),
('UserTokenReplaceTestCase', 'class', 'modules/user/user.test', 'user', '0'),
('UserUserSearchTestCase', 'class', 'modules/user/user.test', 'user', '0'),
('UserValidateCurrentPassCustomForm', 'class', 'modules/user/user.test', 'user', '0'),
('UserValidationTestCase', 'class', 'modules/user/user.test', 'user', '0'),
('view', 'class', 'sites/all/modules/views/includes/view.inc', 'views', '10'),
('ViewsAccessTest', 'class', 'sites/all/modules/views/tests/views_access.test', 'views', '10'),
('ViewsAnalyzeTest', 'class', 'sites/all/modules/views/tests/views_analyze.test', 'views', '10'),
('ViewsArgumentDefaultTest', 'class', 'sites/all/modules/views/tests/views_argument_default.test', 'views', '10'),
('ViewsArgumentValidatorTest', 'class', 'sites/all/modules/views/tests/views_argument_validator.test', 'views', '10'),
('ViewsBasicTest', 'class', 'sites/all/modules/views/tests/views_basic.test', 'views', '10'),
('ViewsCacheTest', 'class', 'sites/all/modules/views/tests/views_cache.test', 'views', '10'),
('ViewsExposedFormTest', 'class', 'sites/all/modules/views/tests/views_exposed_form.test', 'views', '10'),
('viewsFieldApiDataTest', 'class', 'sites/all/modules/views/tests/field/views_fieldapi.test', 'views', '10'),
('ViewsFieldApiTestHelper', 'class', 'sites/all/modules/views/tests/field/views_fieldapi.test', 'views', '10'),
('ViewsGlossaryTestCase', 'class', 'sites/all/modules/views/tests/views_glossary.test', 'views', '10'),
('ViewsHandlerAreaTextTest', 'class', 'sites/all/modules/views/tests/handlers/views_handler_area_text.test', 'views', '10'),
('viewsHandlerArgumentCommentUserUidTest', 'class', 'sites/all/modules/views/tests/comment/views_handler_argument_comment_user_uid.test', 'views', '10'),
('ViewsHandlerArgumentNullTest', 'class', 'sites/all/modules/views/tests/handlers/views_handler_argument_null.test', 'views', '10'),
('ViewsHandlerArgumentStringTest', 'class', 'sites/all/modules/views/tests/handlers/views_handler_argument_string.test', 'views', '10'),
('ViewsHandlerFieldBooleanTest', 'class', 'sites/all/modules/views/tests/handlers/views_handler_field_boolean.test', 'views', '10'),
('ViewsHandlerFieldCustomTest', 'class', 'sites/all/modules/views/tests/handlers/views_handler_field_custom.test', 'views', '10'),
('ViewsHandlerFieldDateTest', 'class', 'sites/all/modules/views/tests/handlers/views_handler_field_date.test', 'views', '10'),
('viewsHandlerFieldFieldTest', 'class', 'sites/all/modules/views/tests/field/views_fieldapi.test', 'views', '10'),
('ViewsHandlerFieldMath', 'class', 'sites/all/modules/views/tests/handlers/views_handler_field_math.test', 'views', '10'),
('ViewsHandlerFieldTest', 'class', 'sites/all/modules/views/tests/handlers/views_handler_field.test', 'views', '10'),
('ViewsHandlerFieldUrlTest', 'class', 'sites/all/modules/views/tests/handlers/views_handler_field_url.test', 'views', '10'),
('viewsHandlerFieldUserNameTest', 'class', 'sites/all/modules/views/tests/user/views_handler_field_user_name.test', 'views', '10'),
('ViewsHandlerFilterCombineTest', 'class', 'sites/all/modules/views/tests/handlers/views_handler_filter_combine.test', 'views', '10'),
('viewsHandlerFilterCommentUserUidTest', 'class', 'sites/all/modules/views/tests/comment/views_handler_filter_comment_user_uid.test', 'views', '10'),
('ViewsHandlerFilterCounterTest', 'class', 'sites/all/modules/views/tests/handlers/views_handler_field_counter.test', 'views', '10'),
('ViewsHandlerFilterDateTest', 'class', 'sites/all/modules/views/tests/handlers/views_handler_filter_date.test', 'views', '10'),
('ViewsHandlerFilterEqualityTest', 'class', 'sites/all/modules/views/tests/handlers/views_handler_filter_equality.test', 'views', '10'),
('ViewsHandlerFilterInOperator', 'class', 'sites/all/modules/views/tests/handlers/views_handler_filter_in_operator.test', 'views', '10'),
('ViewsHandlerFilterNumericTest', 'class', 'sites/all/modules/views/tests/handlers/views_handler_filter_numeric.test', 'views', '10'),
('ViewsHandlerFilterStringTest', 'class', 'sites/all/modules/views/tests/handlers/views_handler_filter_string.test', 'views', '10'),
('ViewsHandlerRelationshipNodeTermDataTest', 'class', 'sites/all/modules/views/tests/taxonomy/views_handler_relationship_node_term_data.test', 'views', '10'),
('ViewsHandlerSortDateTest', 'class', 'sites/all/modules/views/tests/handlers/views_handler_sort_date.test', 'views', '10'),
('ViewsHandlerSortRandomTest', 'class', 'sites/all/modules/views/tests/handlers/views_handler_sort_random.test', 'views', '10'),
('ViewsHandlerSortTest', 'class', 'sites/all/modules/views/tests/handlers/views_handler_sort.test', 'views', '10'),
('ViewsHandlersTest', 'class', 'sites/all/modules/views/tests/views_handlers.test', 'views', '10'),
('ViewsHandlerTestFileSize', 'class', 'sites/all/modules/views/tests/handlers/views_handler_field_file_size.test', 'views', '10'),
('ViewsHandlerTestXss', 'class', 'sites/all/modules/views/tests/handlers/views_handler_field_xss.test', 'views', '10'),
('ViewsModuleTest', 'class', 'sites/all/modules/views/tests/views_module.test', 'views', '10'),
('ViewsNodeRevisionRelationsTestCase', 'class', 'sites/all/modules/views/tests/node/views_node_revision_relations.test', 'views', '10'),
('ViewsPagerTest', 'class', 'sites/all/modules/views/tests/views_pager.test', 'views', '10'),
('ViewsPluginDisplayTestCase', 'class', 'sites/all/modules/views/tests/plugins/views_plugin_display.test', 'views', '10'),
('viewsPluginStyleJumpMenuTest', 'class', 'sites/all/modules/views/tests/styles/views_plugin_style_jump_menu.test', 'views', '10'),
('ViewsPluginStyleMappingTest', 'class', 'sites/all/modules/views/tests/styles/views_plugin_style_mapping.test', 'views', '10'),
('ViewsPluginStyleTestBase', 'class', 'sites/all/modules/views/tests/styles/views_plugin_style_base.test', 'views', '10'),
('ViewsPluginStyleTestCase', 'class', 'sites/all/modules/views/tests/styles/views_plugin_style.test', 'views', '10'),
('ViewsPluginStyleUnformattedTestCase', 'class', 'sites/all/modules/views/tests/styles/views_plugin_style_unformatted.test', 'views', '10'),
('ViewsQueryGroupByTest', 'class', 'sites/all/modules/views/tests/views_groupby.test', 'views', '10'),
('viewsSearchQuery', 'class', 'sites/all/modules/views/modules/search/views_handler_filter_search.inc', 'views', '10'),
('ViewsSqlTest', 'class', 'sites/all/modules/views/tests/views_query.test', 'views', '10'),
('ViewsTestCase', 'class', 'sites/all/modules/views/tests/views_query.test', 'views', '10'),
('ViewsTranslatableTest', 'class', 'sites/all/modules/views/tests/views_translatable.test', 'views', '10'),
('ViewsUiBaseViewsWizard', 'class', 'sites/all/modules/views/plugins/views_wizard/views_ui_base_views_wizard.class.php', 'views_ui', '0'),
('ViewsUiCommentViewsWizard', 'class', 'sites/all/modules/views/plugins/views_wizard/views_ui_comment_views_wizard.class.php', 'views_ui', '0'),
('ViewsUiFileManagedViewsWizard', 'class', 'sites/all/modules/views/plugins/views_wizard/views_ui_file_managed_views_wizard.class.php', 'views_ui', '0'),
('viewsUiGroupbyTestCase', 'class', 'sites/all/modules/views/tests/views_groupby.test', 'views', '10'),
('ViewsUiNodeRevisionViewsWizard', 'class', 'sites/all/modules/views/plugins/views_wizard/views_ui_node_revision_views_wizard.class.php', 'views_ui', '0'),
('ViewsUiNodeViewsWizard', 'class', 'sites/all/modules/views/plugins/views_wizard/views_ui_node_views_wizard.class.php', 'views_ui', '0'),
('ViewsUiTaxonomyTermViewsWizard', 'class', 'sites/all/modules/views/plugins/views_wizard/views_ui_taxonomy_term_views_wizard.class.php', 'views_ui', '0'),
('ViewsUiUsersViewsWizard', 'class', 'sites/all/modules/views/plugins/views_wizard/views_ui_users_views_wizard.class.php', 'views_ui', '0'),
('ViewsUIWizardBasicTestCase', 'class', 'sites/all/modules/views/tests/views_ui.test', 'views', '10'),
('ViewsUIWizardDefaultViewsTestCase', 'class', 'sites/all/modules/views/tests/views_ui.test', 'views', '10'),
('ViewsUIWizardHelper', 'class', 'sites/all/modules/views/tests/views_ui.test', 'views', '10'),
('ViewsUIWizardItemsPerPageTestCase', 'class', 'sites/all/modules/views/tests/views_ui.test', 'views', '10'),
('ViewsUIWizardJumpMenuTestCase', 'class', 'sites/all/modules/views/tests/views_ui.test', 'views', '10'),
('ViewsUIWizardMenuTestCase', 'class', 'sites/all/modules/views/tests/views_ui.test', 'views', '10'),
('ViewsUIWizardOverrideDisplaysTestCase', 'class', 'sites/all/modules/views/tests/views_ui.test', 'views', '10'),
('ViewsUIWizardSortingTestCase', 'class', 'sites/all/modules/views/tests/views_ui.test', 'views', '10'),
('ViewsUIWizardTaggedWithTestCase', 'class', 'sites/all/modules/views/tests/views_ui.test', 'views', '10'),
('ViewsUpgradeTestCase', 'class', 'sites/all/modules/views/tests/views_upgrade.test', 'views', '10'),
('ViewsUserArgumentDefault', 'class', 'sites/all/modules/views/tests/user/views_user_argument_default.test', 'views', '10'),
('ViewsUserArgumentValidate', 'class', 'sites/all/modules/views/tests/user/views_user_argument_validate.test', 'views', '10'),
('ViewsUserTestCase', 'class', 'sites/all/modules/views/tests/user/views_user.test', 'views', '10'),
('ViewsViewTest', 'class', 'sites/all/modules/views/tests/views_view.test', 'views', '10'),
('ViewsWizardException', 'class', 'sites/all/modules/views/plugins/views_wizard/views_ui_base_views_wizard.class.php', 'views_ui', '0'),
('ViewsWizardInterface', 'interface', 'sites/all/modules/views/plugins/views_wizard/views_ui_base_views_wizard.class.php', 'views_ui', '0'),
('views_db_object', 'class', 'sites/all/modules/views/includes/view.inc', 'views', '10'),
('views_display', 'class', 'sites/all/modules/views/includes/view.inc', 'views', '10'),
('views_handler', 'class', 'sites/all/modules/views/includes/handlers.inc', 'views', '10'),
('views_handler_area', 'class', 'sites/all/modules/views/handlers/views_handler_area.inc', 'views', '10'),
('views_handler_area_broken', 'class', 'sites/all/modules/views/handlers/views_handler_area.inc', 'views', '10'),
('views_handler_area_result', 'class', 'sites/all/modules/views/handlers/views_handler_area_result.inc', 'views', '10'),
('views_handler_area_text', 'class', 'sites/all/modules/views/handlers/views_handler_area_text.inc', 'views', '10'),
('views_handler_area_text_custom', 'class', 'sites/all/modules/views/handlers/views_handler_area_text_custom.inc', 'views', '10'),
('views_handler_area_view', 'class', 'sites/all/modules/views/handlers/views_handler_area_view.inc', 'views', '10'),
('views_handler_argument', 'class', 'sites/all/modules/views/handlers/views_handler_argument.inc', 'views', '10'),
('views_handler_argument_aggregator_category_cid', 'class', 'sites/all/modules/views/modules/aggregator/views_handler_argument_aggregator_category_cid.inc', 'views', '10'),
('views_handler_argument_aggregator_fid', 'class', 'sites/all/modules/views/modules/aggregator/views_handler_argument_aggregator_fid.inc', 'views', '10'),
('views_handler_argument_aggregator_iid', 'class', 'sites/all/modules/views/modules/aggregator/views_handler_argument_aggregator_iid.inc', 'views', '10'),
('views_handler_argument_broken', 'class', 'sites/all/modules/views/handlers/views_handler_argument.inc', 'views', '10'),
('views_handler_argument_comment_user_uid', 'class', 'sites/all/modules/views/modules/comment/views_handler_argument_comment_user_uid.inc', 'views', '10');
INSERT INTO `registry` VALUES
('views_handler_argument_date', 'class', 'sites/all/modules/views/handlers/views_handler_argument_date.inc', 'views', '10'),
('views_handler_argument_field_list', 'class', 'sites/all/modules/views/modules/field/views_handler_argument_field_list.inc', 'views', '10'),
('views_handler_argument_field_list_string', 'class', 'sites/all/modules/views/modules/field/views_handler_argument_field_list_string.inc', 'views', '10'),
('views_handler_argument_file_fid', 'class', 'sites/all/modules/views/modules/system/views_handler_argument_file_fid.inc', 'views', '10'),
('views_handler_argument_formula', 'class', 'sites/all/modules/views/handlers/views_handler_argument_formula.inc', 'views', '10'),
('views_handler_argument_group_by_numeric', 'class', 'sites/all/modules/views/handlers/views_handler_argument_group_by_numeric.inc', 'views', '10'),
('views_handler_argument_locale_group', 'class', 'sites/all/modules/views/modules/locale/views_handler_argument_locale_group.inc', 'views', '10'),
('views_handler_argument_locale_language', 'class', 'sites/all/modules/views/modules/locale/views_handler_argument_locale_language.inc', 'views', '10'),
('views_handler_argument_many_to_one', 'class', 'sites/all/modules/views/handlers/views_handler_argument_many_to_one.inc', 'views', '10'),
('views_handler_argument_node_created_day', 'class', 'sites/all/modules/views/modules/node/views_handler_argument_dates_various.inc', 'views', '10'),
('views_handler_argument_node_created_fulldate', 'class', 'sites/all/modules/views/modules/node/views_handler_argument_dates_various.inc', 'views', '10'),
('views_handler_argument_node_created_month', 'class', 'sites/all/modules/views/modules/node/views_handler_argument_dates_various.inc', 'views', '10'),
('views_handler_argument_node_created_week', 'class', 'sites/all/modules/views/modules/node/views_handler_argument_dates_various.inc', 'views', '10'),
('views_handler_argument_node_created_year', 'class', 'sites/all/modules/views/modules/node/views_handler_argument_dates_various.inc', 'views', '10'),
('views_handler_argument_node_created_year_month', 'class', 'sites/all/modules/views/modules/node/views_handler_argument_dates_various.inc', 'views', '10'),
('views_handler_argument_node_language', 'class', 'sites/all/modules/views/modules/node/views_handler_argument_node_language.inc', 'views', '10'),
('views_handler_argument_node_nid', 'class', 'sites/all/modules/views/modules/node/views_handler_argument_node_nid.inc', 'views', '10'),
('views_handler_argument_node_tnid', 'class', 'sites/all/modules/views/modules/translation/views_handler_argument_node_tnid.inc', 'views', '10'),
('views_handler_argument_node_type', 'class', 'sites/all/modules/views/modules/node/views_handler_argument_node_type.inc', 'views', '10'),
('views_handler_argument_node_uid_revision', 'class', 'sites/all/modules/views/modules/node/views_handler_argument_node_uid_revision.inc', 'views', '10'),
('views_handler_argument_node_vid', 'class', 'sites/all/modules/views/modules/node/views_handler_argument_node_vid.inc', 'views', '10'),
('views_handler_argument_null', 'class', 'sites/all/modules/views/handlers/views_handler_argument_null.inc', 'views', '10'),
('views_handler_argument_numeric', 'class', 'sites/all/modules/views/handlers/views_handler_argument_numeric.inc', 'views', '10'),
('views_handler_argument_search', 'class', 'sites/all/modules/views/modules/search/views_handler_argument_search.inc', 'views', '10'),
('views_handler_argument_string', 'class', 'sites/all/modules/views/handlers/views_handler_argument_string.inc', 'views', '10'),
('views_handler_argument_taxonomy', 'class', 'sites/all/modules/views/modules/taxonomy/views_handler_argument_taxonomy.inc', 'views', '10'),
('views_handler_argument_term_node_tid', 'class', 'sites/all/modules/views/modules/taxonomy/views_handler_argument_term_node_tid.inc', 'views', '10'),
('views_handler_argument_term_node_tid_depth', 'class', 'sites/all/modules/views/modules/taxonomy/views_handler_argument_term_node_tid_depth.inc', 'views', '10'),
('views_handler_argument_term_node_tid_depth_modifier', 'class', 'sites/all/modules/views/modules/taxonomy/views_handler_argument_term_node_tid_depth_modifier.inc', 'views', '10'),
('views_handler_argument_tracker_comment_user_uid', 'class', 'sites/all/modules/views/modules/tracker/views_handler_argument_tracker_comment_user_uid.inc', 'views', '10'),
('views_handler_argument_users_roles_rid', 'class', 'sites/all/modules/views/modules/user/views_handler_argument_users_roles_rid.inc', 'views', '10'),
('views_handler_argument_user_uid', 'class', 'sites/all/modules/views/modules/user/views_handler_argument_user_uid.inc', 'views', '10'),
('views_handler_argument_vocabulary_machine_name', 'class', 'sites/all/modules/views/modules/taxonomy/views_handler_argument_vocabulary_machine_name.inc', 'views', '10'),
('views_handler_argument_vocabulary_vid', 'class', 'sites/all/modules/views/modules/taxonomy/views_handler_argument_vocabulary_vid.inc', 'views', '10'),
('views_handler_field', 'class', 'sites/all/modules/views/handlers/views_handler_field.inc', 'views', '10'),
('views_handler_field_accesslog_path', 'class', 'sites/all/modules/views/modules/statistics/views_handler_field_accesslog_path.inc', 'views', '10'),
('views_handler_field_aggregator_category', 'class', 'sites/all/modules/views/modules/aggregator/views_handler_field_aggregator_category.inc', 'views', '10'),
('views_handler_field_aggregator_title_link', 'class', 'sites/all/modules/views/modules/aggregator/views_handler_field_aggregator_title_link.inc', 'views', '10'),
('views_handler_field_aggregator_xss', 'class', 'sites/all/modules/views/modules/aggregator/views_handler_field_aggregator_xss.inc', 'views', '10'),
('views_handler_field_boolean', 'class', 'sites/all/modules/views/handlers/views_handler_field_boolean.inc', 'views', '10'),
('views_handler_field_broken', 'class', 'sites/all/modules/views/handlers/views_handler_field.inc', 'views', '10'),
('views_handler_field_comment', 'class', 'sites/all/modules/views/modules/comment/views_handler_field_comment.inc', 'views', '10'),
('views_handler_field_comment_depth', 'class', 'sites/all/modules/views/modules/comment/views_handler_field_comment_depth.inc', 'views', '10'),
('views_handler_field_comment_link', 'class', 'sites/all/modules/views/modules/comment/views_handler_field_comment_link.inc', 'views', '10'),
('views_handler_field_comment_link_approve', 'class', 'sites/all/modules/views/modules/comment/views_handler_field_comment_link_approve.inc', 'views', '10'),
('views_handler_field_comment_link_delete', 'class', 'sites/all/modules/views/modules/comment/views_handler_field_comment_link_delete.inc', 'views', '10'),
('views_handler_field_comment_link_edit', 'class', 'sites/all/modules/views/modules/comment/views_handler_field_comment_link_edit.inc', 'views', '10'),
('views_handler_field_comment_link_reply', 'class', 'sites/all/modules/views/modules/comment/views_handler_field_comment_link_reply.inc', 'views', '10'),
('views_handler_field_comment_node_link', 'class', 'sites/all/modules/views/modules/comment/views_handler_field_comment_node_link.inc', 'views', '10'),
('views_handler_field_comment_username', 'class', 'sites/all/modules/views/modules/comment/views_handler_field_comment_username.inc', 'views', '10'),
('views_handler_field_contact_link', 'class', 'sites/all/modules/views/modules/contact/views_handler_field_contact_link.inc', 'views', '10'),
('views_handler_field_contextual_links', 'class', 'sites/all/modules/views/handlers/views_handler_field_contextual_links.inc', 'views', '10'),
('views_handler_field_counter', 'class', 'sites/all/modules/views/handlers/views_handler_field_counter.inc', 'views', '10'),
('views_handler_field_custom', 'class', 'sites/all/modules/views/handlers/views_handler_field_custom.inc', 'views', '10'),
('views_handler_field_date', 'class', 'sites/all/modules/views/handlers/views_handler_field_date.inc', 'views', '10'),
('views_handler_field_entity', 'class', 'sites/all/modules/views/handlers/views_handler_field_entity.inc', 'views', '10'),
('views_handler_field_field', 'class', 'sites/all/modules/views/modules/field/views_handler_field_field.inc', 'views', '10'),
('views_handler_field_file', 'class', 'sites/all/modules/views/modules/system/views_handler_field_file.inc', 'views', '10'),
('views_handler_field_file_extension', 'class', 'sites/all/modules/views/modules/system/views_handler_field_file_extension.inc', 'views', '10'),
('views_handler_field_file_filemime', 'class', 'sites/all/modules/views/modules/system/views_handler_field_file_filemime.inc', 'views', '10'),
('views_handler_field_file_size', 'class', 'sites/all/modules/views/handlers/views_handler_field.inc', 'views', '10'),
('views_handler_field_file_status', 'class', 'sites/all/modules/views/modules/system/views_handler_field_file_status.inc', 'views', '10'),
('views_handler_field_file_uri', 'class', 'sites/all/modules/views/modules/system/views_handler_field_file_uri.inc', 'views', '10'),
('views_handler_field_filter_format_name', 'class', 'sites/all/modules/views/modules/filter/views_handler_field_filter_format_name.inc', 'views', '10'),
('views_handler_field_history_user_timestamp', 'class', 'sites/all/modules/views/modules/node/views_handler_field_history_user_timestamp.inc', 'views', '10'),
('views_handler_field_last_comment_timestamp', 'class', 'sites/all/modules/views/modules/comment/views_handler_field_last_comment_timestamp.inc', 'views', '10'),
('views_handler_field_locale_group', 'class', 'sites/all/modules/views/modules/locale/views_handler_field_locale_group.inc', 'views', '10'),
('views_handler_field_locale_language', 'class', 'sites/all/modules/views/modules/locale/views_handler_field_locale_language.inc', 'views', '10'),
('views_handler_field_locale_link_edit', 'class', 'sites/all/modules/views/modules/locale/views_handler_field_locale_link_edit.inc', 'views', '10'),
('views_handler_field_machine_name', 'class', 'sites/all/modules/views/handlers/views_handler_field_machine_name.inc', 'views', '10'),
('views_handler_field_markup', 'class', 'sites/all/modules/views/handlers/views_handler_field_markup.inc', 'views', '10'),
('views_handler_field_math', 'class', 'sites/all/modules/views/handlers/views_handler_field_math.inc', 'views', '10'),
('views_handler_field_ncs_last_comment_name', 'class', 'sites/all/modules/views/modules/comment/views_handler_field_ncs_last_comment_name.inc', 'views', '10'),
('views_handler_field_ncs_last_updated', 'class', 'sites/all/modules/views/modules/comment/views_handler_field_ncs_last_updated.inc', 'views', '10'),
('views_handler_field_node', 'class', 'sites/all/modules/views/modules/node/views_handler_field_node.inc', 'views', '10'),
('views_handler_field_node_comment', 'class', 'sites/all/modules/views/modules/comment/views_handler_field_node_comment.inc', 'views', '10'),
('views_handler_field_node_language', 'class', 'sites/all/modules/views/modules/locale/views_handler_field_node_language.inc', 'views', '10'),
('views_handler_field_node_link', 'class', 'sites/all/modules/views/modules/node/views_handler_field_node_link.inc', 'views', '10'),
('views_handler_field_node_link_delete', 'class', 'sites/all/modules/views/modules/node/views_handler_field_node_link_delete.inc', 'views', '10'),
('views_handler_field_node_link_edit', 'class', 'sites/all/modules/views/modules/node/views_handler_field_node_link_edit.inc', 'views', '10'),
('views_handler_field_node_link_translate', 'class', 'sites/all/modules/views/modules/translation/views_handler_field_node_link_translate.inc', 'views', '10'),
('views_handler_field_node_new_comments', 'class', 'sites/all/modules/views/modules/comment/views_handler_field_node_new_comments.inc', 'views', '10'),
('views_handler_field_node_path', 'class', 'sites/all/modules/views/modules/node/views_handler_field_node_path.inc', 'views', '10'),
('views_handler_field_node_revision', 'class', 'sites/all/modules/views/modules/node/views_handler_field_node_revision.inc', 'views', '10'),
('views_handler_field_node_revision_link', 'class', 'sites/all/modules/views/modules/node/views_handler_field_node_revision_link.inc', 'views', '10'),
('views_handler_field_node_revision_link_delete', 'class', 'sites/all/modules/views/modules/node/views_handler_field_node_revision_link_delete.inc', 'views', '10'),
('views_handler_field_node_revision_link_revert', 'class', 'sites/all/modules/views/modules/node/views_handler_field_node_revision_link_revert.inc', 'views', '10'),
('views_handler_field_node_translation_link', 'class', 'sites/all/modules/views/modules/translation/views_handler_field_node_translation_link.inc', 'views', '10'),
('views_handler_field_node_type', 'class', 'sites/all/modules/views/modules/node/views_handler_field_node_type.inc', 'views', '10'),
('views_handler_field_numeric', 'class', 'sites/all/modules/views/handlers/views_handler_field_numeric.inc', 'views', '10'),
('views_handler_field_prerender_list', 'class', 'sites/all/modules/views/handlers/views_handler_field_prerender_list.inc', 'views', '10'),
('views_handler_field_profile_date', 'class', 'sites/all/modules/views/modules/profile/views_handler_field_profile_date.inc', 'views', '10'),
('views_handler_field_profile_list', 'class', 'sites/all/modules/views/modules/profile/views_handler_field_profile_list.inc', 'views', '10'),
('views_handler_field_search_score', 'class', 'sites/all/modules/views/modules/search/views_handler_field_search_score.inc', 'views', '10'),
('views_handler_field_serialized', 'class', 'sites/all/modules/views/handlers/views_handler_field_serialized.inc', 'views', '10'),
('views_handler_field_taxonomy', 'class', 'sites/all/modules/views/modules/taxonomy/views_handler_field_taxonomy.inc', 'views', '10'),
('views_handler_field_term_link_edit', 'class', 'sites/all/modules/views/modules/taxonomy/views_handler_field_term_link_edit.inc', 'views', '10'),
('views_handler_field_term_node_tid', 'class', 'sites/all/modules/views/modules/taxonomy/views_handler_field_term_node_tid.inc', 'views', '10'),
('views_handler_field_time_interval', 'class', 'sites/all/modules/views/handlers/views_handler_field_time_interval.inc', 'views', '10'),
('views_handler_field_url', 'class', 'sites/all/modules/views/handlers/views_handler_field_url.inc', 'views', '10'),
('views_handler_field_user', 'class', 'sites/all/modules/views/modules/user/views_handler_field_user.inc', 'views', '10'),
('views_handler_field_user_language', 'class', 'sites/all/modules/views/modules/user/views_handler_field_user_language.inc', 'views', '10'),
('views_handler_field_user_link', 'class', 'sites/all/modules/views/modules/user/views_handler_field_user_link.inc', 'views', '10'),
('views_handler_field_user_link_cancel', 'class', 'sites/all/modules/views/modules/user/views_handler_field_user_link_cancel.inc', 'views', '10'),
('views_handler_field_user_link_edit', 'class', 'sites/all/modules/views/modules/user/views_handler_field_user_link_edit.inc', 'views', '10'),
('views_handler_field_user_mail', 'class', 'sites/all/modules/views/modules/user/views_handler_field_user_mail.inc', 'views', '10'),
('views_handler_field_user_name', 'class', 'sites/all/modules/views/modules/user/views_handler_field_user_name.inc', 'views', '10'),
('views_handler_field_user_permissions', 'class', 'sites/all/modules/views/modules/user/views_handler_field_user_permissions.inc', 'views', '10'),
('views_handler_field_user_picture', 'class', 'sites/all/modules/views/modules/user/views_handler_field_user_picture.inc', 'views', '10'),
('views_handler_field_user_roles', 'class', 'sites/all/modules/views/modules/user/views_handler_field_user_roles.inc', 'views', '10'),
('views_handler_field_xss', 'class', 'sites/all/modules/views/handlers/views_handler_field.inc', 'views', '10'),
('views_handler_filter', 'class', 'sites/all/modules/views/handlers/views_handler_filter.inc', 'views', '10'),
('views_handler_filter_aggregator_category_cid', 'class', 'sites/all/modules/views/modules/aggregator/views_handler_filter_aggregator_category_cid.inc', 'views', '10'),
('views_handler_filter_boolean_operator', 'class', 'sites/all/modules/views/handlers/views_handler_filter_boolean_operator.inc', 'views', '10'),
('views_handler_filter_boolean_operator_string', 'class', 'sites/all/modules/views/handlers/views_handler_filter_boolean_operator_string.inc', 'views', '10'),
('views_handler_filter_broken', 'class', 'sites/all/modules/views/handlers/views_handler_filter.inc', 'views', '10'),
('views_handler_filter_combine', 'class', 'sites/all/modules/views/handlers/views_handler_filter_combine.inc', 'views', '10'),
('views_handler_filter_comment_user_uid', 'class', 'sites/all/modules/views/modules/comment/views_handler_filter_comment_user_uid.inc', 'views', '10'),
('views_handler_filter_date', 'class', 'sites/all/modules/views/handlers/views_handler_filter_date.inc', 'views', '10'),
('views_handler_filter_entity_bundle', 'class', 'sites/all/modules/views/handlers/views_handler_filter_entity_bundle.inc', 'views', '10'),
('views_handler_filter_equality', 'class', 'sites/all/modules/views/handlers/views_handler_filter_equality.inc', 'views', '10'),
('views_handler_filter_field_list', 'class', 'sites/all/modules/views/modules/field/views_handler_filter_field_list.inc', 'views', '10'),
('views_handler_filter_file_status', 'class', 'sites/all/modules/views/modules/system/views_handler_filter_file_status.inc', 'views', '10'),
('views_handler_filter_group_by_numeric', 'class', 'sites/all/modules/views/handlers/views_handler_filter_group_by_numeric.inc', 'views', '10'),
('views_handler_filter_history_user_timestamp', 'class', 'sites/all/modules/views/modules/node/views_handler_filter_history_user_timestamp.inc', 'views', '10'),
('views_handler_filter_in_operator', 'class', 'sites/all/modules/views/handlers/views_handler_filter_in_operator.inc', 'views', '10'),
('views_handler_filter_locale_group', 'class', 'sites/all/modules/views/modules/locale/views_handler_filter_locale_group.inc', 'views', '10'),
('views_handler_filter_locale_language', 'class', 'sites/all/modules/views/modules/locale/views_handler_filter_locale_language.inc', 'views', '10'),
('views_handler_filter_locale_version', 'class', 'sites/all/modules/views/modules/locale/views_handler_filter_locale_version.inc', 'views', '10'),
('views_handler_filter_many_to_one', 'class', 'sites/all/modules/views/handlers/views_handler_filter_many_to_one.inc', 'views', '10'),
('views_handler_filter_ncs_last_updated', 'class', 'sites/all/modules/views/modules/comment/views_handler_filter_ncs_last_updated.inc', 'views', '10'),
('views_handler_filter_node_access', 'class', 'sites/all/modules/views/modules/node/views_handler_filter_node_access.inc', 'views', '10'),
('views_handler_filter_node_comment', 'class', 'sites/all/modules/views/modules/comment/views_handler_filter_node_comment.inc', 'views', '10'),
('views_handler_filter_node_language', 'class', 'sites/all/modules/views/modules/locale/views_handler_filter_node_language.inc', 'views', '10'),
('views_handler_filter_node_status', 'class', 'sites/all/modules/views/modules/node/views_handler_filter_node_status.inc', 'views', '10'),
('views_handler_filter_node_tnid', 'class', 'sites/all/modules/views/modules/translation/views_handler_filter_node_tnid.inc', 'views', '10'),
('views_handler_filter_node_tnid_child', 'class', 'sites/all/modules/views/modules/translation/views_handler_filter_node_tnid_child.inc', 'views', '10'),
('views_handler_filter_node_type', 'class', 'sites/all/modules/views/modules/node/views_handler_filter_node_type.inc', 'views', '10'),
('views_handler_filter_node_uid_revision', 'class', 'sites/all/modules/views/modules/node/views_handler_filter_node_uid_revision.inc', 'views', '10'),
('views_handler_filter_numeric', 'class', 'sites/all/modules/views/handlers/views_handler_filter_numeric.inc', 'views', '10'),
('views_handler_filter_profile_selection', 'class', 'sites/all/modules/views/modules/profile/views_handler_filter_profile_selection.inc', 'views', '10'),
('views_handler_filter_search', 'class', 'sites/all/modules/views/modules/search/views_handler_filter_search.inc', 'views', '10'),
('views_handler_filter_string', 'class', 'sites/all/modules/views/handlers/views_handler_filter_string.inc', 'views', '10'),
('views_handler_filter_system_type', 'class', 'sites/all/modules/views/modules/system/views_handler_filter_system_type.inc', 'views', '10'),
('views_handler_filter_term_node_tid', 'class', 'sites/all/modules/views/modules/taxonomy/views_handler_filter_term_node_tid.inc', 'views', '10'),
('views_handler_filter_term_node_tid_depth', 'class', 'sites/all/modules/views/modules/taxonomy/views_handler_filter_term_node_tid_depth.inc', 'views', '10'),
('views_handler_filter_tracker_boolean_operator', 'class', 'sites/all/modules/views/modules/tracker/views_handler_filter_tracker_boolean_operator.inc', 'views', '10'),
('views_handler_filter_tracker_comment_user_uid', 'class', 'sites/all/modules/views/modules/tracker/views_handler_filter_tracker_comment_user_uid.inc', 'views', '10'),
('views_handler_filter_user_current', 'class', 'sites/all/modules/views/modules/user/views_handler_filter_user_current.inc', 'views', '10'),
('views_handler_filter_user_name', 'class', 'sites/all/modules/views/modules/user/views_handler_filter_user_name.inc', 'views', '10'),
('views_handler_filter_user_permissions', 'class', 'sites/all/modules/views/modules/user/views_handler_filter_user_permissions.inc', 'views', '10'),
('views_handler_filter_user_roles', 'class', 'sites/all/modules/views/modules/user/views_handler_filter_user_roles.inc', 'views', '10'),
('views_handler_filter_vocabulary_machine_name', 'class', 'sites/all/modules/views/modules/taxonomy/views_handler_filter_vocabulary_machine_name.inc', 'views', '10'),
('views_handler_filter_vocabulary_vid', 'class', 'sites/all/modules/views/modules/taxonomy/views_handler_filter_vocabulary_vid.inc', 'views', '10'),
('views_handler_relationship', 'class', 'sites/all/modules/views/handlers/views_handler_relationship.inc', 'views', '10'),
('views_handler_relationship_broken', 'class', 'sites/all/modules/views/handlers/views_handler_relationship.inc', 'views', '10'),
('views_handler_relationship_entity_reverse', 'class', 'sites/all/modules/views/modules/field/views_handler_relationship_entity_reverse.inc', 'views', '10'),
('views_handler_relationship_groupwise_max', 'class', 'sites/all/modules/views/handlers/views_handler_relationship_groupwise_max.inc', 'views', '10'),
('views_handler_relationship_node_term_data', 'class', 'sites/all/modules/views/modules/taxonomy/views_handler_relationship_node_term_data.inc', 'views', '10'),
('views_handler_relationship_translation', 'class', 'sites/all/modules/views/modules/translation/views_handler_relationship_translation.inc', 'views', '10'),
('views_handler_sort', 'class', 'sites/all/modules/views/handlers/views_handler_sort.inc', 'views', '10'),
('views_handler_sort_broken', 'class', 'sites/all/modules/views/handlers/views_handler_sort.inc', 'views', '10'),
('views_handler_sort_comment_thread', 'class', 'sites/all/modules/views/modules/comment/views_handler_sort_comment_thread.inc', 'views', '10'),
('views_handler_sort_date', 'class', 'sites/all/modules/views/handlers/views_handler_sort_date.inc', 'views', '10'),
('views_handler_sort_group_by_numeric', 'class', 'sites/all/modules/views/handlers/views_handler_sort_group_by_numeric.inc', 'views', '10'),
('views_handler_sort_menu_hierarchy', 'class', 'sites/all/modules/views/handlers/views_handler_sort_menu_hierarchy.inc', 'views', '10'),
('views_handler_sort_ncs_last_comment_name', 'class', 'sites/all/modules/views/modules/comment/views_handler_sort_ncs_last_comment_name.inc', 'views', '10'),
('views_handler_sort_ncs_last_updated', 'class', 'sites/all/modules/views/modules/comment/views_handler_sort_ncs_last_updated.inc', 'views', '10'),
('views_handler_sort_random', 'class', 'sites/all/modules/views/handlers/views_handler_sort_random.inc', 'views', '10'),
('views_handler_sort_search_score', 'class', 'sites/all/modules/views/modules/search/views_handler_sort_search_score.inc', 'views', '10'),
('views_isotope_plugin_style_isotope', 'class', 'sites/all/modules/views_isotope/views_isotope_plugin_style_isotope.inc', 'views_isotope', '0'),
('views_join', 'class', 'sites/all/modules/views/includes/handlers.inc', 'views', '10'),
('views_join_subquery', 'class', 'sites/all/modules/views/includes/handlers.inc', 'views', '10'),
('views_many_to_one_helper', 'class', 'sites/all/modules/views/includes/handlers.inc', 'views', '10'),
('views_object', 'class', 'sites/all/modules/views/includes/base.inc', 'views', '10'),
('views_plugin', 'class', 'sites/all/modules/views/includes/plugins.inc', 'views', '10'),
('views_plugin_access', 'class', 'sites/all/modules/views/plugins/views_plugin_access.inc', 'views', '10'),
('views_plugin_access_none', 'class', 'sites/all/modules/views/plugins/views_plugin_access_none.inc', 'views', '10'),
('views_plugin_access_perm', 'class', 'sites/all/modules/views/plugins/views_plugin_access_perm.inc', 'views', '10'),
('views_plugin_access_role', 'class', 'sites/all/modules/views/plugins/views_plugin_access_role.inc', 'views', '10'),
('views_plugin_argument_default', 'class', 'sites/all/modules/views/plugins/views_plugin_argument_default.inc', 'views', '10'),
('views_plugin_argument_default_book_root', 'class', 'sites/all/modules/views/modules/book/views_plugin_argument_default_book_root.inc', 'views', '10'),
('views_plugin_argument_default_current_user', 'class', 'sites/all/modules/views/modules/user/views_plugin_argument_default_current_user.inc', 'views', '10'),
('views_plugin_argument_default_fixed', 'class', 'sites/all/modules/views/plugins/views_plugin_argument_default_fixed.inc', 'views', '10'),
('views_plugin_argument_default_node', 'class', 'sites/all/modules/views/modules/node/views_plugin_argument_default_node.inc', 'views', '10'),
('views_plugin_argument_default_php', 'class', 'sites/all/modules/views/plugins/views_plugin_argument_default_php.inc', 'views', '10'),
('views_plugin_argument_default_raw', 'class', 'sites/all/modules/views/plugins/views_plugin_argument_default_raw.inc', 'views', '10'),
('views_plugin_argument_default_taxonomy_tid', 'class', 'sites/all/modules/views/modules/taxonomy/views_plugin_argument_default_taxonomy_tid.inc', 'views', '10'),
('views_plugin_argument_default_user', 'class', 'sites/all/modules/views/modules/user/views_plugin_argument_default_user.inc', 'views', '10'),
('views_plugin_argument_validate', 'class', 'sites/all/modules/views/plugins/views_plugin_argument_validate.inc', 'views', '10'),
('views_plugin_argument_validate_node', 'class', 'sites/all/modules/views/modules/node/views_plugin_argument_validate_node.inc', 'views', '10'),
('views_plugin_argument_validate_numeric', 'class', 'sites/all/modules/views/plugins/views_plugin_argument_validate_numeric.inc', 'views', '10'),
('views_plugin_argument_validate_php', 'class', 'sites/all/modules/views/plugins/views_plugin_argument_validate_php.inc', 'views', '10'),
('views_plugin_argument_validate_taxonomy_term', 'class', 'sites/all/modules/views/modules/taxonomy/views_plugin_argument_validate_taxonomy_term.inc', 'views', '10'),
('views_plugin_argument_validate_user', 'class', 'sites/all/modules/views/modules/user/views_plugin_argument_validate_user.inc', 'views', '10'),
('views_plugin_cache', 'class', 'sites/all/modules/views/plugins/views_plugin_cache.inc', 'views', '10'),
('views_plugin_cache_none', 'class', 'sites/all/modules/views/plugins/views_plugin_cache_none.inc', 'views', '10'),
('views_plugin_cache_time', 'class', 'sites/all/modules/views/plugins/views_plugin_cache_time.inc', 'views', '10'),
('views_plugin_display', 'class', 'sites/all/modules/views/plugins/views_plugin_display.inc', 'views', '10'),
('views_plugin_display_attachment', 'class', 'sites/all/modules/views/plugins/views_plugin_display_attachment.inc', 'views', '10'),
('views_plugin_display_block', 'class', 'sites/all/modules/views/plugins/views_plugin_display_block.inc', 'views', '10'),
('views_plugin_display_default', 'class', 'sites/all/modules/views/plugins/views_plugin_display_default.inc', 'views', '10'),
('views_plugin_display_embed', 'class', 'sites/all/modules/views/plugins/views_plugin_display_embed.inc', 'views', '10'),
('views_plugin_display_extender', 'class', 'sites/all/modules/views/plugins/views_plugin_display_extender.inc', 'views', '10'),
('views_plugin_display_feed', 'class', 'sites/all/modules/views/plugins/views_plugin_display_feed.inc', 'views', '10'),
('views_plugin_display_page', 'class', 'sites/all/modules/views/plugins/views_plugin_display_page.inc', 'views', '10'),
('views_plugin_exposed_form', 'class', 'sites/all/modules/views/plugins/views_plugin_exposed_form.inc', 'views', '10'),
('views_plugin_exposed_form_basic', 'class', 'sites/all/modules/views/plugins/views_plugin_exposed_form_basic.inc', 'views', '10'),
('views_plugin_exposed_form_input_required', 'class', 'sites/all/modules/views/plugins/views_plugin_exposed_form_input_required.inc', 'views', '10'),
('views_plugin_localization', 'class', 'sites/all/modules/views/plugins/views_plugin_localization.inc', 'views', '10'),
('views_plugin_localization_core', 'class', 'sites/all/modules/views/plugins/views_plugin_localization_core.inc', 'views', '10'),
('views_plugin_localization_none', 'class', 'sites/all/modules/views/plugins/views_plugin_localization_none.inc', 'views', '0'),
('views_plugin_localization_test', 'class', 'sites/all/modules/views/tests/views_plugin_localization_test.inc', 'views', '10'),
('views_plugin_pager', 'class', 'sites/all/modules/views/plugins/views_plugin_pager.inc', 'views', '10'),
('views_plugin_pager_full', 'class', 'sites/all/modules/views/plugins/views_plugin_pager_full.inc', 'views', '10'),
('views_plugin_pager_mini', 'class', 'sites/all/modules/views/plugins/views_plugin_pager_mini.inc', 'views', '10'),
('views_plugin_pager_none', 'class', 'sites/all/modules/views/plugins/views_plugin_pager_none.inc', 'views', '10'),
('views_plugin_pager_some', 'class', 'sites/all/modules/views/plugins/views_plugin_pager_some.inc', 'views', '10'),
('views_plugin_query', 'class', 'sites/all/modules/views/plugins/views_plugin_query.inc', 'views', '10'),
('views_plugin_query_default', 'class', 'sites/all/modules/views/plugins/views_plugin_query_default.inc', 'views', '10'),
('views_plugin_row', 'class', 'sites/all/modules/views/plugins/views_plugin_row.inc', 'views', '10'),
('views_plugin_row_aggregator_rss', 'class', 'sites/all/modules/views/modules/aggregator/views_plugin_row_aggregator_rss.inc', 'views', '10'),
('views_plugin_row_comment_rss', 'class', 'sites/all/modules/views/modules/comment/views_plugin_row_comment_rss.inc', 'views', '10'),
('views_plugin_row_comment_view', 'class', 'sites/all/modules/views/modules/comment/views_plugin_row_comment_view.inc', 'views', '10'),
('views_plugin_row_fields', 'class', 'sites/all/modules/views/plugins/views_plugin_row_fields.inc', 'views', '10'),
('views_plugin_row_node_rss', 'class', 'sites/all/modules/views/modules/node/views_plugin_row_node_rss.inc', 'views', '10'),
('views_plugin_row_node_view', 'class', 'sites/all/modules/views/modules/node/views_plugin_row_node_view.inc', 'views', '10'),
('views_plugin_row_rss_fields', 'class', 'sites/all/modules/views/plugins/views_plugin_row_rss_fields.inc', 'views', '10'),
('views_plugin_row_search_view', 'class', 'sites/all/modules/views/modules/search/views_plugin_row_search_view.inc', 'views', '10'),
('views_plugin_row_user_view', 'class', 'sites/all/modules/views/modules/user/views_plugin_row_user_view.inc', 'views', '10'),
('views_plugin_style', 'class', 'sites/all/modules/views/plugins/views_plugin_style.inc', 'views', '10'),
('views_plugin_style_default', 'class', 'sites/all/modules/views/plugins/views_plugin_style_default.inc', 'views', '10'),
('views_plugin_style_grid', 'class', 'sites/all/modules/views/plugins/views_plugin_style_grid.inc', 'views', '10'),
('views_plugin_style_jump_menu', 'class', 'sites/all/modules/views/plugins/views_plugin_style_jump_menu.inc', 'views', '10'),
('views_plugin_style_list', 'class', 'sites/all/modules/views/plugins/views_plugin_style_list.inc', 'views', '10'),
('views_plugin_style_mapping', 'class', 'sites/all/modules/views/plugins/views_plugin_style_mapping.inc', 'views', '10'),
('views_plugin_style_rss', 'class', 'sites/all/modules/views/plugins/views_plugin_style_rss.inc', 'views', '10'),
('views_plugin_style_summary', 'class', 'sites/all/modules/views/plugins/views_plugin_style_summary.inc', 'views', '10'),
('views_plugin_style_summary_jump_menu', 'class', 'sites/all/modules/views/plugins/views_plugin_style_summary_jump_menu.inc', 'views', '10'),
('views_plugin_style_summary_unformatted', 'class', 'sites/all/modules/views/plugins/views_plugin_style_summary_unformatted.inc', 'views', '10'),
('views_plugin_style_table', 'class', 'sites/all/modules/views/plugins/views_plugin_style_table.inc', 'views', '10'),
('views_slideshow_plugin_style_slideshow', 'class', 'sites/all/modules/views_slideshow/views_slideshow_plugin_style_slideshow.inc', 'views_slideshow', '0'),
('views_test_plugin_access_test_dynamic', 'class', 'sites/all/modules/views/tests/test_plugins/views_test_plugin_access_test_dynamic.inc', 'views', '10'),
('views_test_plugin_access_test_static', 'class', 'sites/all/modules/views/tests/test_plugins/views_test_plugin_access_test_static.inc', 'views', '10'),
('views_test_plugin_style_test_mapping', 'class', 'sites/all/modules/views/tests/test_plugins/views_test_plugin_style_test_mapping.inc', 'views', '10'),
('views_ui', 'class', 'sites/all/modules/views/plugins/export_ui/views_ui.class.php', 'views_ui', '0'),
('WysiwygProfileController', 'class', 'sites/all/modules/wysiwyg/wysiwyg.module', 'wysiwyg', '0');
/*!40000 ALTER TABLE registry ENABLE KEYS */;

--
-- Table structure for table 'registry_file'
--

CREATE TABLE IF NOT EXISTS `registry_file` (
  `filename` varchar(255) NOT NULL COMMENT 'Path to the file.',
  `hash` varchar(64) NOT NULL COMMENT 'sha-256 hash of the file’s contents when last parsed.',
  PRIMARY KEY (`filename`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Files parsed to build the registry.';

--
-- Dumping data for table 'registry_file'
--

/*!40000 ALTER TABLE registry_file DISABLE KEYS */;
INSERT INTO `registry_file` VALUES
('includes/actions.inc', 'f36b066681463c7dfe189e0430cb1a89bf66f7e228cbb53cdfcd93987193f759'),
('includes/ajax.inc', '8328ec7441a0c101c1b39ba8d415c1d951b400887d8b29d2831210ae207f86eb'),
('includes/archiver.inc', 'bdbb21b712a62f6b913590b609fd17cd9f3c3b77c0d21f68e71a78427ed2e3e9'),
('includes/authorize.inc', '6d64d8c21aa01eb12fc29918732e4df6b871ed06e5d41373cb95c197ed661d13'),
('includes/batch.inc', '059da9e36e1f3717f27840aae73f10dea7d6c8daf16f6520401cc1ca3b4c0388'),
('includes/batch.queue.inc', '554b2e92e1dad0f7fd5a19cb8dff7e109f10fbe2441a5692d076338ec908de0f'),
('includes/bootstrap.inc', '025bd83ad086a9e2205de304ffcbdc9b19f74fa4cabfe32ad94c2dd0f49e6e9c'),
('includes/cache-install.inc', 'e7ed123c5805703c84ad2cce9c1ca46b3ce8caeeea0d8ef39a3024a4ab95fa0e'),
('includes/cache.inc', 'c1916375fcb92250a5c86aa53269d54854b983f34906d582fc912784f16ccaf4'),
('includes/common.inc', 'd4954efd95278dc8e1127e0703353d8a38d393c10b223c46adaef25ce8cb357c'),
('includes/database/database.inc', '1597142a1fbd6fcff24f2bb92805a1c98b7bc36520cc68007bc7383effcaf890'),
('includes/database/log.inc', '9feb5a17ae2fabcf26a96d2a634ba73da501f7bcfc3599a693d916a6971d00d1'),
('includes/database/mysql/database.inc', '8d3a784845064385ccdce8a66860f3177d52207df83d9735c0d72c9703dd258e'),
('includes/database/mysql/install.inc', '6ae316941f771732fbbabed7e1d6b4cbb41b1f429dd097d04b3345aa15e461a0'),
('includes/database/mysql/query.inc', '48cee5e5290282ccbe3e77814e70ab33b69efe8f0c09716ee465e3e5f888c2ce'),
('includes/database/mysql/schema.inc', 'd8d3904ea9c23a526c2f2a7acc8ba870b31c378aac2eb53e2e41a73c6209c5bd'),
('includes/database/pgsql/database.inc', '56726100fd44f461a04886c590c9c472cc2b2a1b92eb26c7674bf3821a76bb64'),
('includes/database/pgsql/install.inc', '585b80c5bbd6f134bff60d06397f15154657a577d4da8d1b181858905f09dea5'),
('includes/database/pgsql/query.inc', 'cb4c84f8f1ffc73098ed71137248dcd078a505a7530e60d979d74b3a3cdaa658'),
('includes/database/pgsql/schema.inc', '8fd647e4557522283caef63e528c6e403fc0751a46e94aac867a281af85eac27'),
('includes/database/pgsql/select.inc', 'fd4bba7887c1dc6abc8f080fc3a76c01d92ea085434e355dc1ecb50d8743c22d'),
('includes/database/prefetch.inc', 'b5b207a66a69ecb52ee4f4459af16a7b5eabedc87254245f37cc33bebb61c0fb'),
('includes/database/query.inc', 'cbc8fa88a15e58d39f3ae7a90bca55c48812202f8cdf74b9d4d7717ec54db469'),
('includes/database/schema.inc', '7eb7251f331109757173353263d1031493c1198ae17a165a6f5a03d3f14f93e7'),
('includes/database/select.inc', '1c74fa55c7721a704f5ef3389032604bf7a60fced15c40d844aee3e1cead7dc6'),
('includes/database/sqlite/database.inc', 'ed2b9981794239cdad2cd04cf4bcdc896ad4d6b66179a4fa487b0d1ec2150a10'),
('includes/database/sqlite/install.inc', '381f3db8c59837d961978ba3097bb6443534ed1659fd713aa563963fa0c42cc5'),
('includes/database/sqlite/query.inc', 'cd726af682495d8fe20283ddbc4d877536cad2df4a2df8afc2dc21be71a4eba8'),
('includes/database/sqlite/schema.inc', '238414785aa96dd27f10f48c961783f4d1091392beee8d0e7ca8ae774e917da2'),
('includes/database/sqlite/select.inc', '8d1c426dbd337733c206cce9f59a172546c6ed856d8ef3f1c7bef05a16f7bf68'),
('includes/date.inc', '18c047be64f201e16d189f1cc47ed9dcf0a145151b1ee187e90511b24e5d2b36'),
('includes/entity.inc', '43536d4fdfffdfcadf8606418a211113ba955b634d1d4a6df9c550df090bfa96'),
('includes/errors.inc', '58dc008b3b90ecc5e97fe2135ac25376b7719efec1fb74f43cde9068fedbf2ca'),
('includes/file.inc', 'eb9f794ed93a8550547a02fcdb137ba071497a4466f0e2878c76b0b941c5db8b'),
('includes/file.mimetypes.inc', 'f88c967550576694b7a1ce2afd0f2f1bbc1a91d21cc2c20f86c44d39ff353867'),
('includes/filetransfer/filetransfer.inc', 'fdea8ae48345ec91885ac48a9bc53daf87616271472bb7c29b7e3ce219b22034'),
('includes/filetransfer/ftp.inc', '589ebf4b8bd4a2973aa56a156ac1fa83b6c73e703391361fb573167670e0d832'),
('includes/filetransfer/local.inc', '7cbfdb46abbdf539640db27e66fb30e5265128f31002bd0dfc3af16ae01a9492'),
('includes/filetransfer/ssh.inc', '002e24a24cac133d12728bd3843868ce378681237d7fad420761af84e6efe5ad'),
('includes/form.inc', 'abb212b6be660bd10df31e248564411496ca972d3477a5b0ab529d413a5b3e5c'),
('includes/graph.inc', '8e0e313a8bb33488f371df11fc1b58d7cf80099b886cd1003871e2c896d1b536'),
('includes/image.inc', 'bcdc7e1599c02227502b9d0fe36eeb2b529b130a392bc709eb737647bd361826'),
('includes/install.core.inc', '2a036b695c555d7339115099e0b7b06bf7fbafbaad6d7cc143e49969ff96c394'),
('includes/install.inc', 'c5d672551327b22a4450f55e2d3a391c486882f99eec6148fedea0cd04a909b1'),
('includes/iso.inc', '27730e6175b79c3b5d494582a124f6210289faa03bef099e16347bb914464c66'),
('includes/json-encode.inc', '02a822a652d00151f79db9aa9e171c310b69b93a12f549bc2ce00533a8efa14e'),
('includes/language.inc', '77ef0c210a8f01d4ad24b13b147db3db0dcef801dbae8b644124cedd562a8a57'),
('includes/locale.inc', '8cc571c114587f2b30e4e24db17e97e51e81f9cc395fa01f348aba12cee8523e'),
('includes/lock.inc', 'daa62e95528f6b986b85680b600a896452bf2ce6f38921242857dcc5a3460a1b'),
('includes/mail.inc', '8b37b30d82941010eacf8f435abbf9cb5b6cfc2710c3446a5037192ae14d68bf'),
('includes/menu.inc', '3183e10659511cd5ad290c6a74bad9601a08827e7e6e025fcfd2cf9eea18cff0'),
('includes/module.inc', 'ca3f2e6129181bbbc67e5e6058a882047f2152174ec8e95c0ea99ce610ace4d7'),
('includes/pager.inc', '6f9494b85c07a2cc3be4e54aff2d2757485238c476a7da084d25bde1d88be6d8'),
('includes/password.inc', '7550ac434a929562a3380e82c546afbf9163598b22f2351f0e7d3f19567fb6c9'),
('includes/path.inc', 'd20d3efabcb752fcafafc887fc0f09704d87000742302f95cf58e62333d05279'),
('includes/registry.inc', '4ffb8c9c8c179c1417ff01790f339edf50b5f7cc0c8bb976eef6858cc71e9bc8'),
('includes/session.inc', '65764101f3746e25210e8a91a9c058218c83c7bf444051ba339c412a2d2bff63'),
('includes/stream_wrappers.inc', 'b04e31585a9a397b0edf7b3586050cbd4b1f631e283296e1c93f4356662faeb9'),
('includes/tablesort.inc', '4cb2a5a2d41b2a204a13f59085096e3f64237d32639ea5d30752905099bc7540'),
('includes/theme.inc', '7fc0ffea33bf25419adb89b91f0fc892c183cd0db41e4f00958694b6f03e7335'),
('includes/theme.maintenance.inc', '39f068b3eee4d10a90d6aa3c86db587b6d25844c2919d418d34d133cfe330f5a'),
('includes/token.inc', '5e7898cd78689e2c291ed3cd8f41c032075656896f1db57e49217aac19ae0428'),
('includes/unicode.entities.inc', '2b858138596d961fbaa4c6e3986e409921df7f76b6ee1b109c4af5970f1e0f54'),
('includes/unicode.inc', '518ad21bd4f43814277d67f76ff8eb2b99bd1be4caa5e02b6e5f06cf65d84eb0'),
('includes/update.inc', '177ce24362efc7f28b384c90a09c3e485396bbd18c3721d4b21e57dd1733bd92'),
('includes/updater.inc', 'd2da0e74ed86e93c209f16069f3d32e1a134ceb6c06a0044f78e841a1b54e380'),
('includes/utility.inc', '3458fd2b55ab004dd0cc529b8e58af12916e8bd36653b072bdd820b26b907ed5'),
('includes/xmlrpc.inc', 'c5b6ea78adeb135373d11aeaaea057d9fa8995faa4e8c0fec9b7c647f15cc4e0'),
('includes/xmlrpcs.inc', '79dc6e9882f4c506123d7dd8e228a61e22c46979c3aab21a5b1afa315ef6639c'),
('modules/aggregator/aggregator.test', 'a7bd9d48084f0c8653e5184dd6899b9388d2ca08134b0e27192ed9df8567e44f'),
('modules/block/block.test', '7aefd627d62b44f9c1e9ee3aa9da6c6e2a7cfce01c6613e8bd24c0b9c464dd73'),
('modules/blog/blog.test', '12dc3105782db5fb0df00ff4872561dd049f242eeeb65c979cf349aa75aa1a51'),
('modules/book/book.test', 'a75a4ec12f930d85adbf7c46d6a1a4ed1356657466874f21e9cc931b6cd41aa0'),
('modules/comment/comment.module', '966005005058b4df64d515ce2a6049843b2085fc8c2067a2e8ccd59d85d054e9'),
('modules/comment/comment.test', '5404277c15b1306a1ad5eca6703f7d2003567fea6085ffd2b1c3d65896acdf21'),
('modules/contact/contact.test', 'd49eedd71859fbb6ffa26b87226f640db56694c8f43c863c83d920cf3632f9ad'),
('modules/contextual/contextual.test', '023dafa199bd325ecc55a17b2a3db46ac0a31e23059f701f789f3bc42427ba0b'),
('modules/field/field.attach.inc', '25d05fb8ab30ba559051ca2034ea7e61bd1326cacb12dfeb865e90e2ffd147e6'),
('modules/field/field.info.class.inc', 'c2e4bc67ef51e4956c913be772914b1b2625aa5066ab67c74baf6404ed538174'),
('modules/field/field.module', 'd2d9b9b324c256ca11e117f84afd9722c5271887a57497e2dd1f339adae7c12d'),
('modules/field/modules/field_sql_storage/field_sql_storage.test', '35c9c300bc922d3a7c40516ad0ddeb7dc0ef02dd6b7f3f12b4820c41ce912593'),
('modules/field/modules/list/tests/list.test', '97e55bd49f6f4b0562d04aa3773b5ab9b35063aee05c8c7231780cdcf9c97714'),
('modules/field/modules/number/number.test', '9ccf835bbf80ff31b121286f6fbcf59cc42b622a51ab56b22362b2f55c656e18'),
('modules/field/modules/options/options.test', '360c5d3028036423106445eedde49827c75f3ba609186d349e1d0b1353183c18'),
('modules/field/modules/text/text.test', 'a1e5cb0fa8c0651c68d560d9bb7781463a84200f701b00b6e797a9ca792a7e42'),
('modules/field/tests/field.test', '73bc91bbb405f25021340c887f218ea3d1b38473599c234e4c90454e08db63e9'),
('modules/field_ui/field_ui.test', 'da42e28d6f32d447b4a6e5b463a2f7d87d6ce32f149de04a98fa8e3f286c9f68'),
('modules/file/tests/file.test', 'ca4f55f72e76eb1d8a5016f02b3ce3c67efbb3b49646d70ad0ff2248d6f77c38'),
('modules/filter/filter.test', '184fa79a4802b3903844d35a63fd065ba3d8d025ba39a70cf3ff0ac1ef108bb4'),
('modules/forum/forum.test', 'd282b29d6312d63183e003ba036d7645a946e828c94448592f930d80fceb42d6'),
('modules/image/image.test', '9c064ef1b09c6e67f4a038d0511cba1cc784df280ada8f89d81eda2ecf214b11'),
('modules/locale/locale.test', '0c55b74dc0e1b343bd4315b0744f490ebee212f5cc0305cb83db80d48aabf46e'),
('modules/menu/menu.test', '22a7d2b0e4819a670521c562fa868732b485dff2b58beca1896466ad62bffe44'),
('modules/node/node.module', '24bd6dbfa9fd1046baacc4590e9e18622b844278c10b4a1919902299325d09ee'),
('modules/node/node.test', '02eaf0f65000e2ed0d727ae8880d2e7d9ff8ba5e43ed605650770a75504ee04d'),
('modules/path/path.test', '2004183b2c7c86028bf78c519c6a7afc4397a8267874462b0c2b49b0f8c20322'),
('modules/php/php.test', 'd234f9c1ab18a05834a3cb6dc532fb4c259aa25612551f953ba6e3bb714657b8'),
('modules/poll/poll.test', 'ca9ed69731381d0314590e9acbe39f384d4e418c347a221b9b480c87453ac7d0'),
('modules/search/search.extender.inc', 'fea036745113dca3fea52ba956af605c4789f4acfa2ab1650a5843c6e173d7fe'),
('modules/search/search.test', '765220b310a8c20cdae1a0cb32405de5f3474b65ba5a2ceccd035f7fa1b828ba'),
('modules/shortcut/shortcut.test', '0d78280d4d0a05aa772218e45911552e39611ca9c258b9dd436307914ac3f254'),
('modules/system/system.archiver.inc', 'faa849f3e646a910ab82fd6c8bbf0a4e6b8c60725d7ba81ec0556bd716616cd1'),
('modules/system/system.mail.inc', '3c2c06b55bded609e72add89db41af3bb405d42b9553793acba5fe51be8861d8'),
('modules/system/system.queue.inc', 'ef00fd41ca86de386fa134d5bc1d816f9af550cf0e1334a5c0ade3119688ca3c'),
('modules/system/system.tar.inc', '8a31d91f7b3cd7eac25b3fa46e1ed9a8527c39718ba76c3f8c0bbbeaa3aa4086'),
('modules/system/system.test', '459ab9edeb638b76a35a5a751b517844d2f380724de8e469e43fc59599e53ddc'),
('modules/system/system.updater.inc', '338cf14cb691ba16ee551b3b9e0fa4f579a2f25c964130658236726d17563b6a'),
('modules/taxonomy/taxonomy.module', '037a417dd82a22b6e6ac6bf2bc1f724e7f744ade8c9a25ffd277535e9677525f'),
('modules/taxonomy/taxonomy.test', '966f863d207701e81f8166f726546ef8627b9dff7612c80cdca79b1a1a33620c'),
('modules/tracker/tracker.test', 'f6f8d43970743f7329d82c1b4568efcfecdcd39269b55ebaeb66fad733c8428f'),
('modules/trigger/trigger.test', '2d29ac4acb5353c90dbef8eec4a39ac39a3680708705731e0e500e5afc806928'),
('modules/update/update.test', '1ea3e22bd4d47afb8b2799057cdbdfbb57ce09013d9d5f2de7e61ef9c2ebc72d'),
('modules/user/user.module', 'bb7081d863fc9e05c1417344482a661ad68d9ea674c5cf4afc609c0de94c2add'),
('modules/user/user.test', 'e65ff6ba03c4b4afbc9a5e13a1b980749c1e711e7d9aa1052b5a6e534d68a47e'),
('sites/all/modules/addthis/addthis.install', '9a4315a6c4311c926d9ffa332962b4bfde4ffb99c4c122137901f80a7996d690'),
('sites/all/modules/addthis/addthis.module', '0c50f69ba2821418546894edc0a0d3868ed1c9cbee17eabfbf1bef29a1375bb7'),
('sites/all/modules/addthis/addthis.test', 'b839fb598e09f79433d9277b2bc5861dfe8749301616afd1a0200283c0c8a3f5'),
('sites/all/modules/addthis/addthis_displays/addthis_displays.field.inc', '65c9f16aec1594ef025ced5db32b653c879fc0186cd46af6ddcc86da5c8599cf'),
('sites/all/modules/addthis/classes/AddThis.php', '50be3748c734a650ded1e5a757a5fa131b96a618673c6daf4d5045474955d7c6'),
('sites/all/modules/addthis/classes/AddThisJson.php', 'a8f7b6185328fccfb02623410f176c3d458dda504cdc98d71000c45b43d9d66a'),
('sites/all/modules/addthis/includes/addthis.admin.inc', '2e231053055e79eaf78c3edbef536ce32887b9873c9fdb02fa7e338d6c5a00e1'),
('sites/all/modules/addthis/includes/addthis.block.inc', '942175df9781284e1f7b843c60d034c460a3b7567b22f7266352669f5975d7aa'),
('sites/all/modules/addthis/includes/addthis.field.inc', '74c09d39c333f15a1a735138068713c96bb9450dfeac9fab484ce126929b712f'),
('sites/all/modules/admin_menu/tests/admin_menu.test', '185f8244f7a086cda1bd9435ec529e8632598e9b09d1e0d7363b75cf87c04afb'),
('sites/all/modules/block_class/block_class.test', '4e03c264f086c6f569dcdfb14b669aeec5fef4b4d1f1af6fb813ca32bb605647'),
('sites/all/modules/colorbox/views/colorbox_handler_field_colorbox.inc', '5390d9181f55a63869ecee95b6c1db098d2aa985e5a5f207874d9ebb47456028'),
('sites/all/modules/ctools/includes/context.inc', 'b7b5b38b6d85ab438327fc6127e2f21654c45ffa6b55d7b01b3b65bf19918a7e'),
('sites/all/modules/ctools/includes/math-expr.inc', '3386323b01da62e02c9f3607cd7f0a0d46f1af90a107a07aed726b1fa8c28235'),
('sites/all/modules/ctools/includes/stylizer.inc', 'e18f5a1b8af526751d7175354162c06c2013c96f62d9baa399564d8c45a1c90e'),
('sites/all/modules/ctools/plugins/export_ui/ctools_export_ui.class.php', '3d6d5df2fd5657b59023c8cb7f2d8f96a3f282f28307e5803cc9159297d6a2ab'),
('sites/all/modules/demo/database_mysql_dump.inc', '9a22ad998838998eda232db42d500ce5715ad683659d2b069c88103d5762f0e1'),
('sites/all/modules/demo/demo.admin.inc', '3f05554a8656015b2dff5109f76091fcc0709043c9516494d9a53994865f0ffd'),
('sites/all/modules/demo/demo.module', 'e7480187e2777fda9abaa861389f76043d677970df5619219018860f3f6b2ce3'),
('sites/all/modules/dismiss/dismiss.module', '9509df3afbbac14e18b3256496397fae5ee58821d795e009a086f89dc72ffd93'),
('sites/all/modules/faq/faq.admin.inc', '1edba36dbe421533279a5fd19a1511bcb8975161f4bf2156b00ee274e4a7e958'),
('sites/all/modules/faq/faq.install', '03facc1905ab3c3132f6605cd6b6d703bebf0164a8ff565fa9ceed3b5394bb31'),
('sites/all/modules/faq/faq.module', 'e7357d6ac09644988cc3eaaca13fd772b92ebd3911bc39e2f576100a2c4462e8'),
('sites/all/modules/faq/faq.test', '37cf3c9adc279b8f39df266c7e9f30b26bda87a85ca74fe6d57644bafe039c5e'),
('sites/all/modules/faq/includes/faq-category-hide-answer.tpl.php', 'e9fd95fb84dd53acbe49e39a99ce02f4b4ef7529f585768d85a47ef66cd7e5fd'),
('sites/all/modules/faq/includes/faq-category-new-page.tpl.php', '969a2ccea705bf66568cbfb566cb9f6083e50250fa3bbdb444fb2a2cd1d3434c'),
('sites/all/modules/faq/includes/faq-category-questions-inline.tpl.php', 'baad460651ceaa7a093fde6418c53c7325eb8c639e70a9aa805efb0b8e46d26c'),
('sites/all/modules/faq/includes/faq-category-questions-top-answers.tpl.php', '88b029e35fa3e675492309e283d77d81ad4e2359e0fea52b89b4d3ebcc29985f'),
('sites/all/modules/faq/includes/faq-category-questions-top.tpl.php', '70370f2323d5528d8b9dbfdf0ee5c243acf034f756f0dc977f7765843e919059'),
('sites/all/modules/faq/includes/faq-hide-answer.tpl.php', '58608dc7eb1f113dd0cb375983670e2fbbb7bf4895e8a9e7624fb07a50373fb3'),
('sites/all/modules/faq/includes/faq-new-page.tpl.php', 'e98e7f99c36163a354c671d09c1a062959b61fc2f37abacb7e5890eac780ec5b'),
('sites/all/modules/faq/includes/faq-questions-inline.tpl.php', 'c3871d8c34446070683a85ca7c5b61195880ce8af45430cb095e45643899f070'),
('sites/all/modules/faq/includes/faq-questions-top.tpl.php', 'f9241ccfd06f4fdcf89664ee0034f4e7e57c52666b1ef01f60b916688b4a15a7'),
('sites/all/modules/faq/includes/faq.hide_answer.inc', '39d9dfb472a2fa9fe89c5ed76bc82e7c84239ea843b858ecf665becd35a925d9'),
('sites/all/modules/faq/includes/faq.new_page.inc', '9a0d7ff6266a1ce473787dc3a58b49923c786236295ae536abc97a3d9d680d37'),
('sites/all/modules/faq/includes/faq.questions_inline.inc', '201d3d2235ccb3320f0a7fb9735376c54f67d792e0a5266a4269b4e1d1cadd6b'),
('sites/all/modules/faq/includes/faq.questions_top.inc', '82e012729151f34f224ceab4c1b079679b366169a82dc5ebe165a72396cadfd0'),
('sites/all/modules/faq/views/faq.views.inc', 'd4638fc985bb99743c0029a84c7b49da9a26c07d7c1feec4e7b6097de68a973c'),
('sites/all/modules/flexslider/flexslider.test', '377205ce1adf7f8235881d5e3a9e465fc9157e1d1dd2cc83da924da82b93086a'),
('sites/all/modules/flexslider/flexslider_views/flexslider_views.module', 'bfb2794b3c8711c84db6f31c60e87314c26b5489903cedb92b9d632812f05496'),
('sites/all/modules/flexslider/flexslider_views/flexslider_views.views.inc', '6bba7b25386477b60098a754e67f26e93cf9256ef9b85d1f1801adb130b82c73'),
('sites/all/modules/flexslider/flexslider_views/flexslider_views_plugin_style_flexslider.inc', 'a4986b2603f1a0752766d4d327e7be9053cc8809bebd0221578778df4f9f5796'),
('sites/all/modules/flexslider/theme/flexslider.theme.inc', 'd8045c74c4d3e7daa9b0864e14a571d6aa36883f5ba80e065078b80cfb807a95'),
('sites/all/modules/flexslider_views_slideshow/flexslider_views_slideshow.module', '31077eaf46726edd3a776de0fc110a2c9a99978fb6bff0419e58b6f925e68179'),
('sites/all/modules/flexslider_views_slideshow/flexslider_views_slideshow.views_slideshow.inc', '9dd9bf7181f9a66b8df71a6c95cb206a29b41f0c8f12354e7b43cedd6e1612c4'),
('sites/all/modules/flexslider_views_slideshow/theme/flexslider_views_slideshow.theme.inc', '4f656c82757ca3a381273bfc9248925dbdaf9b26f6c1c1f1a0f603aed3c225a6'),
('sites/all/modules/follow/tests/follow.test', 'cc637fd95f81059485d774d2b4738bb2affb5f56ea597b2dd5db7a4f5974371c'),
('sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_argument_city.inc', '33a95632ecd2e17c5096ec67531664ee711716f8bab64d30abd884c412f6b696'),
('sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_argument_country.inc', '877407c64e29970efcbc8b1f9f7c574073c73e758082750c9bcb58eef13d7f9e'),
('sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_argument_distance.inc', '4d0b2318adfc35c83b233ae610be400d7bb447103d3191de8f6cd15c9d9abdbd'),
('sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_argument_glid.inc', 'cd907782c7d0ecbe6c8d08006d8050b1bb7ee071856ea3e3b7b0617371e362a0'),
('sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_argument_postcode.inc', 'c79c3a41d35277ad5da5c656e2295abe80be17e612d4794ef9a2cfe17327deb5'),
('sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_argument_province.inc', 'b0fc77553dc08960630de25a26bd672ed97043810a0763955280c9f85a651d06'),
('sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_field_coordinates.inc', '0c7f2e3dcd07c5601ed9ee04e83176717af68fd21f5735640ec0198cd6131776'),
('sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_field_country.inc', '128e45443247f4bef2cb0982a75283b390000a075c7d4677aed7e4840e50914d'),
('sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_field_distance.inc', 'df2fd554fa4ac01a424dbb8112d3d4769dfbac56f82931ce575e96bf7878b29a'),
('sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_field_latitude.inc', 'e5767579eb24cbb1a379e9d5128625192f7de3b28d9ac188b4476f248a79b035'),
('sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_field_longitude.inc', 'e3ee797954f3f46d920ca15f8c3facea147dbea4a6aba396e2fbf7917cd37b53'),
('sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_filter_country.inc', 'f9d0d0ab18d3c5312b8a7cea37adc146bcd6a91f2f2c28b02b055345b281e9b5'),
('sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_filter_distance.inc', '23141a662094afcf671a96f0fe820b991f093acea14013bfea7bf6d8ad76e06e'),
('sites/all/modules/getlocations/modules/getlocations_fields/handlers/getlocations_fields_handler_sort_distance.inc', '271b45ce7f4fe05587c792b84b26ba144f568868c710b2f34cda17cf1a6b5c3d'),
('sites/all/modules/getlocations/views/getlocations_plugin_style_map.inc', '2f54b3e8cb0c837c5ffc41e0f07330abe9070c768c23cbb569d60ae114a7a17c'),
('sites/all/modules/jquery_update/jquery_update.install', '17d0b3e4e05f9dc32bf6227459e7303068b92b000e20352b5af2c3d2f67f7183'),
('sites/all/modules/jquery_update/jquery_update.module', '28cbb57d05bd00f4042c04b477c8d309968b991aa077fdf08f092fcf82ae60e2'),
('sites/all/modules/libraries/tests/libraries.test', '6dccb7969e83afd82de3c83af5e0b06c1f27e35ab1069f5f669640eed6d5d4af'),
('sites/all/modules/module_filter/css/module_filter.css', '69609136efe52982305062cdf17756ad168aaf35920b7840ea1323e22b0ea0d0'),
('sites/all/modules/module_filter/css/module_filter_tab.css', '1789901bbb6bed007fff82895bf6d3ecfed7e237b408930c6c51a1c08e648487'),
('sites/all/modules/module_filter/js/module_filter.js', '60fbaebca184f9a3c91bedea28c947ccc19275b201c54d0a4536b65ec3bdb0de'),
('sites/all/modules/module_filter/js/module_filter_tab.js', '9bfc98157413ed632c6f13e4c153dbd47a18602d8ec61577f07ca0a5aa9e0339'),
('sites/all/modules/module_filter/module_filter.admin.inc', '7f5283cdc8ababa00aff07cbae28322e92f4254bf204146b2a2ade5f6ca760ec'),
('sites/all/modules/module_filter/module_filter.install', 'b05b0010641a06ed8f5d67403cae6c3a3a27aa687835b8f012136d3f68a3cbb3'),
('sites/all/modules/module_filter/module_filter.module', '2de046d2e7eb555b1cfc442627cc5f0be1cf5aa39cad9dda8026c59b78369853'),
('sites/all/modules/module_filter/module_filter.theme.inc', '4e2515f5e1587ff43a85c5e5d6ecb4059a89c880a22ea6cbba7d48bf5d91f674'),
('sites/all/modules/panels/includes/common.inc', 'fcc6c2923d7f567514109f1a333f518c9044df463d7bfef7b7d2f3f1515060c8'),
('sites/all/modules/panels/includes/legacy.inc', 'dc65c1a82f4a063f9cbebbd8a0ceb512a3b41a1ee2603ec8045034412a791aab'),
('sites/all/modules/panels/includes/plugins.inc', 'd08bc486c44016463a4af61c5c399e7f7b52a04a65a17a5e8e810e1a3c2d1158'),
('sites/all/modules/panels/panels.module', '0312b8d317e75f19196d8d8aaba3e9f895ca59c1da79f391d7181d1d5ef5ea34'),
('sites/all/modules/panels/panels_ipe/panels_ipe.module', '7e2b39b7936059831fde07d8e105d7871fe7084f4d4809db25cbb534f219976b'),
('sites/all/modules/panels/panels_ipe/plugins/display_renderers/panels_renderer_ipe.class.php', 'db86a41558641a0ec6af5f4b806feba41babc1c5ec3264abff68a5101bbf7e0c'),
('sites/all/modules/panels/panels_mini/plugins/export_ui/panels_mini_ui.class.php', 'c0d527cb81f4a01bf680223a818a4c48724bbc62732834d540c03084f720d6f3'),
('sites/all/modules/panels/panels_node/panels_node.module', '8018f05a4b9dfe8bbbcdb4efe1af233cda92e4e29cfb182e955e90783174d085'),
('sites/all/modules/panels/plugins/display_renderers/panels_renderer_editor.class.php', '962f6a761b008182f18cf90063e2b9eb289a9e9a7de69591a75735ccc449a64a'),
('sites/all/modules/panels/plugins/display_renderers/panels_renderer_simple.class.php', '420aeca22872635ebd5ab3ce719dd8e1d7fef339271db5f20a0834b812084a6e'),
('sites/all/modules/panels/plugins/display_renderers/panels_renderer_standard.class.php', '7497764e0b1afa55cab7126035b5957869550ab747db48299a9a336e97b48770'),
('sites/all/modules/panels/plugins/export_ui/panels_layouts_ui.class.php', 'c68da9f716ede2dab44e9b3d410374ab82d50f52657f6f363f1df6cb21c6fa9f'),
('sites/all/modules/panels/plugins/views/panels_views_plugin_row_fields.inc', 'a30d798fcbc5e0d44894166e31bc2ab9f9c12b1b34629bf5a7b745374e85408b'),
('sites/all/modules/semanticviews/semanticviews.module', '9a89e9092609ae748bd1852336347de8cd826ebdf882ddb5326f4ec33815a36a'),
('sites/all/modules/semanticviews/semanticviews.theme.inc', '7352e7a4d2e17ba1285bf32d801734ce491a6317d7fc47aa1adfbd2b984a3c1e'),
('sites/all/modules/semanticviews/semanticviews.views.inc', '58e0655a68012bd0cf5ef8466e766fd720e514c858aa0a3403e43c5b0b45ce9a'),
('sites/all/modules/semanticviews/semanticviews.views_default.inc', 'a8b837d5dd0d18b22371cdf35a306f4c27768fc1e9be3917cc44461973f51044'),
('sites/all/modules/semanticviews/semanticviews_plugin_row_fields.inc', '0d106ea376cf266b10e263f17a4379ea12e05cbae328b203389e6084f06a7632'),
('sites/all/modules/semanticviews/semanticviews_plugin_style_default.inc', 'ae5651a53c0358a4a5d1853d04306f8d544c2858f32e4bf196438b35cefd0e35'),
('sites/all/modules/views/handlers/views_handler_area.inc', '95d4374c805c057c9855304ded14ce316cdee8aca0744120a74400e2a8173fae'),
('sites/all/modules/views/handlers/views_handler_area_result.inc', '836747c024cc153ec4516737da0c42a864eb708e0b77d2f8ba606411c57356a2'),
('sites/all/modules/views/handlers/views_handler_area_text.inc', '531d0ac3b64206970593762df0abac60524f607253c3af876dd66ba747786dce'),
('sites/all/modules/views/handlers/views_handler_area_text_custom.inc', '35b702060c192b0adf6601ed437d0a02effd3accb71c07d6156013c8be9d5a15'),
('sites/all/modules/views/handlers/views_handler_area_view.inc', 'a6a4a618c96a5657eaa881aa0836663600629529ebfd943c91303a11171974d5'),
('sites/all/modules/views/handlers/views_handler_argument.inc', '5858d2d1ad3ea0321532da0f66c4d2ef2b2a208e941789b37341b76c783c2d42'),
('sites/all/modules/views/handlers/views_handler_argument_date.inc', '1b423d5a437bbd8ed97d0bfb69c635d36f15114699a7bc0056568cc87937477d'),
('sites/all/modules/views/handlers/views_handler_argument_formula.inc', '5a29748494a7e1c37606224de0c3cac45566efe057e4748b6676a898ac224a61'),
('sites/all/modules/views/handlers/views_handler_argument_group_by_numeric.inc', 'b8d29f27592448b63f15138510128203d726590daef56cf153a09407c90ec481'),
('sites/all/modules/views/handlers/views_handler_argument_many_to_one.inc', 'b2de259c2d00fe7ed04eb5d45eb5107ce60535dd0275823883cc29b04d1a3974'),
('sites/all/modules/views/handlers/views_handler_argument_null.inc', '26699660fd0915ec078d7eb35a93ef39fd53e3a2a4841c0ac5dbf0bb02207bee'),
('sites/all/modules/views/handlers/views_handler_argument_numeric.inc', 'ae23d847fa0f1e92baec32665a8894e26660999e338bebffb49ee42daac5a063'),
('sites/all/modules/views/handlers/views_handler_argument_string.inc', 'f8fe4daf0a636cc93d520a0d5ff212840d8bdaa704ddc3c59a24667f341ed3a1'),
('sites/all/modules/views/handlers/views_handler_field.inc', '3d059d737e738436a15651f9ac8374f460a71eb569619ba0a8a14a55a3efc87e'),
('sites/all/modules/views/handlers/views_handler_field_boolean.inc', 'dc00b916a223935e05f51d94a2dffbaf430b162517072f7c2122332af41e8fc2'),
('sites/all/modules/views/handlers/views_handler_field_contextual_links.inc', '9752231bd248bcbc5c7282361098350f080706e3886d20753c5b2059adb10c00'),
('sites/all/modules/views/handlers/views_handler_field_counter.inc', 'fcfd07c8a20b91819af375c5e1edc33ec7e5b6ee48f419f6183f3401abf9af42'),
('sites/all/modules/views/handlers/views_handler_field_custom.inc', 'a3d25fc20401ae0a1af4b7d6e83376a5b7dc18ab0aed17a3c6d81e2314cf19f8'),
('sites/all/modules/views/handlers/views_handler_field_date.inc', 'ea37efb7819df9a4c2b6f688ec101964474dc7df13e92824913f783314d80740'),
('sites/all/modules/views/handlers/views_handler_field_entity.inc', '909ab36aff896ad8fa4306d95a052172ec27e471ab385a035fcadef8d019e0f9'),
('sites/all/modules/views/handlers/views_handler_field_machine_name.inc', 'df2fe47cf9c6d2e7de8627c08da809fb60883c38697340966f303c223e22aee4'),
('sites/all/modules/views/handlers/views_handler_field_markup.inc', 'a0c652fdf47f7efe35bbf2371f00e230409fe90ea0038eb101bf0c93ae0718e9'),
('sites/all/modules/views/handlers/views_handler_field_math.inc', 'c0f1cd82305ecc2378a7346ed0e4e5503c031b155d53cbfee2c46f82e7996ce4'),
('sites/all/modules/views/handlers/views_handler_field_numeric.inc', '51311e98172a3f2b9f8d406e4c64f2bc9d1243ab8003e1d421bf6ffa5f0100df'),
('sites/all/modules/views/handlers/views_handler_field_prerender_list.inc', '0fe605bf457886fbca5f041a422fc51c6a1927654dcd06cbfc619496fe57de0e'),
('sites/all/modules/views/handlers/views_handler_field_serialized.inc', 'ad3d82a9f37ae4c71a875526c353839da2ff529351efc7861f8b7c9d4b5a47db'),
('sites/all/modules/views/handlers/views_handler_field_time_interval.inc', '280d569784312d19dabfb7aeb94639442ae37e16cba02659a8251de08a4f1de2'),
('sites/all/modules/views/handlers/views_handler_field_url.inc', '7ca57a8dcc42a3d1e7e7ec5defa64a689cb678073e15153ff6a7cafe54c90249'),
('sites/all/modules/views/handlers/views_handler_filter.inc', '70c93c35ffd8829e9e1bb0d8be80ff1641a868abecb41924c3cb2fc513f521ab'),
('sites/all/modules/views/handlers/views_handler_filter_boolean_operator.inc', 'f4ca59e4e1f91f219a1b33690a4ad412269946804fe7cacf24f2574b2c6d8599'),
('sites/all/modules/views/handlers/views_handler_filter_boolean_operator_string.inc', '306ce393a7a4f565fa3eaa4ede1bc7fb4b7f91c65c65f759cab864532bc9d182'),
('sites/all/modules/views/handlers/views_handler_filter_combine.inc', '804377cf5e931fa619c2a40425843b24b0bd6008ccb6e79064e0994d9fd696c2'),
('sites/all/modules/views/handlers/views_handler_filter_date.inc', 'e8f6b4181f3661155fd3b94355b2707441e87b2a151af669610a26eb0fba6674'),
('sites/all/modules/views/handlers/views_handler_filter_entity_bundle.inc', '02db977a67a09f70bdc8e2bbc46a05fff8a6d8bd6423308c95418476e84714a3'),
('sites/all/modules/views/handlers/views_handler_filter_equality.inc', '2100cdd7f5232348adae494c5122ba41ff051eee0a8cc14aeaf6a66202cb7ed1'),
('sites/all/modules/views/handlers/views_handler_filter_group_by_numeric.inc', '9401c4c0fe0d678898e5288ef8152784a12e0743df21dec15457353eb2cdb01d'),
('sites/all/modules/views/handlers/views_handler_filter_in_operator.inc', '8fd7f075468bddde5c4208b1c3a6105f8fea0ac0c214452a37c00fc2f3453a7d'),
('sites/all/modules/views/handlers/views_handler_filter_many_to_one.inc', 'b4a415c2824195d3d7d0e37ada9d69ebec0b9cd833ebcac2439efc20aac15595'),
('sites/all/modules/views/handlers/views_handler_filter_numeric.inc', '8a999227d17674a70381ab8b45fbdc91269a83a45e5f7514607ed8b4a5bf6a9f'),
('sites/all/modules/views/handlers/views_handler_filter_string.inc', '140006335ac5b19b6253b431afde624db70385b9d22390b8c275296ae469cc7b'),
('sites/all/modules/views/handlers/views_handler_relationship.inc', '4fefdb6c9c48b72dcfe86484123b97eb5f5b90b6a440d8026d71f74dccbd1cd6'),
('sites/all/modules/views/handlers/views_handler_relationship_groupwise_max.inc', '47dcfe351159b10153697c17b3a92607edb34a258ba3b44087c947b9cc88e86f'),
('sites/all/modules/views/handlers/views_handler_sort.inc', '06aab8d75f3dce81eb032128b8f755bfff752dcefc2e5d494b137bca161fdefa'),
('sites/all/modules/views/handlers/views_handler_sort_date.inc', 'd7e771abf74585bd09cc8e666747a093f40848b451de8ba67c8158317946f1b2'),
('sites/all/modules/views/handlers/views_handler_sort_group_by_numeric.inc', '4ba1c38c9af32789a951b8f9377e13631ae26bf1dac3371b31a37ead25b32eb8'),
('sites/all/modules/views/handlers/views_handler_sort_menu_hierarchy.inc', 'ccd65ea3b3270366b7175e2cd7cc9167a09c27e1486949e4a05495ff5c7be5c1'),
('sites/all/modules/views/handlers/views_handler_sort_random.inc', '05a00c3bf76c3278ae0ce39a206a6224089faf5ac4a00dd5b8a558f06fab8e46'),
('sites/all/modules/views/includes/base.inc', '8389f49a2bc00819c00eae88fc30630151a3487c54a17472956adc4b2c596d04'),
('sites/all/modules/views/includes/handlers.inc', '1ed338807e8fcdeab6432f374649b6adb03f9e3011ad019f408a6206605a01ea'),
('sites/all/modules/views/includes/plugins.inc', 'bb12703a4a4e8bbc42ecc8ce27bf98546d9ea024324f4d03ba77348ec18b328c'),
('sites/all/modules/views/includes/view.inc', '1c4773c34303378c10325d5bb8fd55a3c88b7f80c307d7daf7c3d2dfe80ead33'),
('sites/all/modules/views/modules/aggregator/views_handler_argument_aggregator_category_cid.inc', '97acf41d6694fd4451909c18b118f482db9f39aa4b8c5cfa75d044d410c46012'),
('sites/all/modules/views/modules/aggregator/views_handler_argument_aggregator_fid.inc', 'c37def91d635b01db36809141d147d263cc910895e11c05e73d703e86b39fd43'),
('sites/all/modules/views/modules/aggregator/views_handler_argument_aggregator_iid.inc', '344f2806344d9c6356f2e19d297522f53bab7a4cebdf23c76d04c85c9e0a0d8e'),
('sites/all/modules/views/modules/aggregator/views_handler_field_aggregator_category.inc', '252b30b832d8c0097d6878f5d56beecfc8cc1fc7cc8b5a4670d8d95a80b4f17d'),
('sites/all/modules/views/modules/aggregator/views_handler_field_aggregator_title_link.inc', '1bb18967b11f2f4de62075d27e483f175b5e3431622c2e5e8292afcd000beadf'),
('sites/all/modules/views/modules/aggregator/views_handler_field_aggregator_xss.inc', '2db2e1f0500e0a252c7367e6a92906870b3247f9d424f999c381368ee2c76597'),
('sites/all/modules/views/modules/aggregator/views_handler_filter_aggregator_category_cid.inc', '7c7c0690c836ac1b75bca3433aca587b79aec3e7d072ce97dc9b33a35780ad4f'),
('sites/all/modules/views/modules/aggregator/views_plugin_row_aggregator_rss.inc', '591e5bb7272e389fe5fc2b563f8887dbc3674811ffbb41333d36a7a9a1859e56'),
('sites/all/modules/views/modules/book/views_plugin_argument_default_book_root.inc', 'bd3bd9496bf519b1688cf39396f3afa495a29c8190a3e173c0740f4d20606a53'),
('sites/all/modules/views/modules/comment/views_handler_argument_comment_user_uid.inc', '5e29f7523010a074bda7c619b24c5d31e0c060cdbe47136b8b16b2f198ed4b4a'),
('sites/all/modules/views/modules/comment/views_handler_field_comment.inc', 'a126d690cc5bf8491cb4bee4cc8237b90e86768bebbbecb8a9409a3c1e00fa9e'),
('sites/all/modules/views/modules/comment/views_handler_field_comment_depth.inc', '1dc353a31d3c71c67d0b3e6854d9e767e421010fbbf6a8b04a14035e5f7c097f'),
('sites/all/modules/views/modules/comment/views_handler_field_comment_link.inc', '1f7382f7cb05c65a7cba44e4cd58022bbc6ce5597b96228d1891d7720510bf0e'),
('sites/all/modules/views/modules/comment/views_handler_field_comment_link_approve.inc', 'f6db8a0b4dd9fffba9d8ecb7b7363ba99d3b2dc7176436a0a6dd7a93195a5789'),
('sites/all/modules/views/modules/comment/views_handler_field_comment_link_delete.inc', '905a4cb1f91a4b40ee1ca1d1ded9958ae18e82286589fec100adb676769b1fe9'),
('sites/all/modules/views/modules/comment/views_handler_field_comment_link_edit.inc', '8139c932cde20f366a3019111c054b1ed00dbc0c40634b91239b400243b7723a'),
('sites/all/modules/views/modules/comment/views_handler_field_comment_link_reply.inc', '8807884efb840407696c909b9d5d07f60bde9d7f385a59eca214178ce5369558'),
('sites/all/modules/views/modules/comment/views_handler_field_comment_node_link.inc', '64746ff2b80a5f8e83b996a325c3d5c8393934c331510b93d5815ea11c1db162'),
('sites/all/modules/views/modules/comment/views_handler_field_comment_username.inc', '1ce3fa61b3933a3e15466760e4c5d4a85407ba4c8753422b766fc04395fa4d02'),
('sites/all/modules/views/modules/comment/views_handler_field_last_comment_timestamp.inc', '30c55ec6d55bf4928b757f2a236aab56d34a8e6955944a1471e9d7b7aed057c0'),
('sites/all/modules/views/modules/comment/views_handler_field_ncs_last_comment_name.inc', '82025f3ad22b63abc57172d358b3f975006109802f4a5ecac93ce3785c505cae'),
('sites/all/modules/views/modules/comment/views_handler_field_ncs_last_updated.inc', 'facfbc5defd843f4dfb60e645f09a784234d87876628c8de98d2dfa6bb98a895'),
('sites/all/modules/views/modules/comment/views_handler_field_node_comment.inc', '0cf9e8fb416dca35c3b9df3125eb3a8585f798c6a8f8d0e1034b1fccb5cec38b'),
('sites/all/modules/views/modules/comment/views_handler_field_node_new_comments.inc', 'e0830d1f70dea473e46ab2b86e380ef741b2907f033777889f812f46989f2ff7'),
('sites/all/modules/views/modules/comment/views_handler_filter_comment_user_uid.inc', 'f526c2c4153b28d7b144054828261ba7b26566169350477cd4fb3f5b5f280719'),
('sites/all/modules/views/modules/comment/views_handler_filter_ncs_last_updated.inc', '9369675dfee24891fe19bddf85a847c275b8127949c55112ae5cb4d422977d24'),
('sites/all/modules/views/modules/comment/views_handler_filter_node_comment.inc', '70706c47bad9180c2426005da6c178ed8d27b75b28cb797ca2a1925a96dcef09'),
('sites/all/modules/views/modules/comment/views_handler_sort_comment_thread.inc', 'a64bc780cba372bd408f08a5ea9289cdf3d40562bdf2f7320657be9a9f6c7882'),
('sites/all/modules/views/modules/comment/views_handler_sort_ncs_last_comment_name.inc', '9f039e8b8a046c058fda620804e3503be7b3e7e3e4119f0b015ccbae0922635b'),
('sites/all/modules/views/modules/comment/views_handler_sort_ncs_last_updated.inc', 'fa8b9c3614ad5838aa40194940d9dc6935175a16e141ac919f40e74a7428c4e3'),
('sites/all/modules/views/modules/comment/views_plugin_row_comment_rss.inc', 'ab97ac0ed4e6d7f2d44dc4ae9c5a84fe5658b739e1b609e5a877df528c3aa970'),
('sites/all/modules/views/modules/comment/views_plugin_row_comment_view.inc', '82d7296fa3109ca170f66f6f3b5e1209af98a9519bb5e4a2c42d9fc0e95d7078'),
('sites/all/modules/views/modules/contact/views_handler_field_contact_link.inc', 'ec783b215a06c89c0933107a580c144051118305dd0129ac28a7fea5f95a8fd5'),
('sites/all/modules/views/modules/field/views_handler_argument_field_list.inc', 'eff5152a2c120425a2a75fe7dbcb49ed86e5d48392b0f45b49c2e7abee9fa72b'),
('sites/all/modules/views/modules/field/views_handler_argument_field_list_string.inc', '534af91d92da7a622580ab8b262f9ef76241671a5185f30ba81898806c7b7f15'),
('sites/all/modules/views/modules/field/views_handler_field_field.inc', 'da78d77eff6f6292ebcacc61aef1d92dcae59ccedb6ab111a44fb28253d9d116'),
('sites/all/modules/views/modules/field/views_handler_filter_field_list.inc', '3b55cd0a14453c95ebd534507ab842a8505496d0b7e4c7fcd61c186034c7322d'),
('sites/all/modules/views/modules/field/views_handler_relationship_entity_reverse.inc', '060035c5430c81671e4541bcf7de833c8a1eb3fa3f3a9db94dd3cebfa4299ef1'),
('sites/all/modules/views/modules/filter/views_handler_field_filter_format_name.inc', 'fc3f074ffb39822182783a8d5cf2b89ffcc097ccbb2ed15818a72a99e3a18468'),
('sites/all/modules/views/modules/locale/views_handler_argument_locale_group.inc', 'c8545411096da40f48eef8ec59391f4729c884079482e3e5b3cdd5578a1f9ad7'),
('sites/all/modules/views/modules/locale/views_handler_argument_locale_language.inc', 'a1b6505bb26e4b3abce543b9097cd0a7b8cddf00bf1e49fbba86febebb0f4486'),
('sites/all/modules/views/modules/locale/views_handler_field_locale_group.inc', '5b62afe18f92ee4a5fb49eb0995e65b4744bbe3b9c24ffe8f6c21f3191c04afc'),
('sites/all/modules/views/modules/locale/views_handler_field_locale_language.inc', '0cc08bd2d42e07f26e7acc92642b36f0ac62bf23ee9ba3fd21e6cab9a80e9f72'),
('sites/all/modules/views/modules/locale/views_handler_field_locale_link_edit.inc', '836ceb1883047011ac1b3dca2254861b8caa1ea67405b3cdbe0fa6f3fbbd5a96'),
('sites/all/modules/views/modules/locale/views_handler_field_node_language.inc', 'a6ccdb6c1c4df3b4fd31b714f5aa4ac99771ffce63439d6c5de6c0ae2f09a2c1'),
('sites/all/modules/views/modules/locale/views_handler_filter_locale_group.inc', '40fbc041bab64f336f59d1e0593f184b879b2a0c9e2a6050709bdc54cceb2716'),
('sites/all/modules/views/modules/locale/views_handler_filter_locale_language.inc', '3433893d988aad36b918dd6214f5258b701506bc9c0c6a72fd854a036b635e20'),
('sites/all/modules/views/modules/locale/views_handler_filter_locale_version.inc', '9337ea5216784ffc67a0aa45c946e65ad11fc40849189cc70911a81366b78620'),
('sites/all/modules/views/modules/locale/views_handler_filter_node_language.inc', 'd7edea3f35891cc76aa3bb185b9c1404378623ea7fd214c2a1f0d824df12779a'),
('sites/all/modules/views/modules/node/views_handler_argument_dates_various.inc', 'd2c17e6ec3d221bdd0d1c060da4b0c85274c8ac5a0b624b1469b162694a8d0f5'),
('sites/all/modules/views/modules/node/views_handler_argument_node_language.inc', '7ee3ba02bddaa6aeef9961cdf6af7bb386fc2b12529f095b28520bb98af51775'),
('sites/all/modules/views/modules/node/views_handler_argument_node_nid.inc', '11c5b62413ffd1b2c66d4b60a2fe21cf6eb839ae40d4ef81c7a938c5be3e30de'),
('sites/all/modules/views/modules/node/views_handler_argument_node_type.inc', '9e21b4cc4ae861f58c804ea7e2c17fbc5dd2a7938b9abfeb54437b531fc95e6e'),
('sites/all/modules/views/modules/node/views_handler_argument_node_uid_revision.inc', '675c99f8da9748ac507e202f546914bee3ed4065f6ce83a23a2aaafdaefd084e'),
('sites/all/modules/views/modules/node/views_handler_argument_node_vid.inc', '7e5da5594a336c1d0f4cf080ab3fcd690e0de1ee6b5e1830b5fb76a46bced19c'),
('sites/all/modules/views/modules/node/views_handler_field_history_user_timestamp.inc', '7d6d9c8273d317ab908d4873a32086dbd5f78a2b2d07b7ed79975841a2cadea6'),
('sites/all/modules/views/modules/node/views_handler_field_node.inc', '99a0ef52b68e8913eb3563d5c47097c09e46c6493fcb006f383c6f6798edb7fc'),
('sites/all/modules/views/modules/node/views_handler_field_node_link.inc', '26d8309a3a9140682d7d90e4d16ff664a3d7ce662af6ccbf75dc4c493515d7d9'),
('sites/all/modules/views/modules/node/views_handler_field_node_link_delete.inc', '3eeed8c9ffc088ee28b8ffaa5e2b084db24284acc4d1b2e69f90c96cc889016d'),
('sites/all/modules/views/modules/node/views_handler_field_node_link_edit.inc', '28f8c3b7d3d60c31fec3cdf81c84cfbb20f492220457694a0e150c3ddee030c0'),
('sites/all/modules/views/modules/node/views_handler_field_node_path.inc', 'f392fde21e434fd40fc672546ef684780179d91827350ba9c348bb1cc5924727'),
('sites/all/modules/views/modules/node/views_handler_field_node_revision.inc', '3f510d58acaa8f844292b86c388cb1e78eac8c732bb5e7c9e92439c425710240'),
('sites/all/modules/views/modules/node/views_handler_field_node_revision_link.inc', 'ace72f296cf4a4da4b7dd7b303532aebf93b6b1c18a5d30b51b65738475e3889'),
('sites/all/modules/views/modules/node/views_handler_field_node_revision_link_delete.inc', '0a36602f080c4ef2bb5cb7dbddc5533deab7743c2fbf3bd88b9e478432cac7fb'),
('sites/all/modules/views/modules/node/views_handler_field_node_revision_link_revert.inc', '80ddc7f0c001fde9af491bb22d6044b85324fe90bea611fc3822408fd60008fa'),
('sites/all/modules/views/modules/node/views_handler_field_node_type.inc', 'f8f39c6f238f837270d1b2e42e67bf9ab400a37fe24246c8b86dfcfacc1c4fd9'),
('sites/all/modules/views/modules/node/views_handler_filter_history_user_timestamp.inc', '2970f270e071cad079880e9598d9f7b71d4dd2a2a42a31cd4489029a3cafe158'),
('sites/all/modules/views/modules/node/views_handler_filter_node_access.inc', 'ca625167c8928f1c5b354c27c120ed9b19c1df665dc3b02ed6d96b58194d6243'),
('sites/all/modules/views/modules/node/views_handler_filter_node_status.inc', 'f7099a59d3f237f2870ecb6b0b5e49dd9d785b1085e94baf55687251e7f3231b'),
('sites/all/modules/views/modules/node/views_handler_filter_node_type.inc', '6842082e7b6e131d6e002e627e6b4490b93ca6ffe7fc0b158d31843217c8c929'),
('sites/all/modules/views/modules/node/views_handler_filter_node_uid_revision.inc', 'b221785bc9a736ef67e4f03e6b26235333115b5b9ce571095de5c5286dd8d744'),
('sites/all/modules/views/modules/node/views_plugin_argument_default_node.inc', '7fb79c8f4adb9bcef7c7da4bf4046fe3490e16c244f6ab96fdca97a8567315ff'),
('sites/all/modules/views/modules/node/views_plugin_argument_validate_node.inc', 'f10d3f4081eed5ca32c41b67e9a0e6f35b2f8ba2cd7897230cb5a680b410a6de'),
('sites/all/modules/views/modules/node/views_plugin_row_node_rss.inc', 'd170c2aab84b73c862bfa79b7aa3f83f2a6d4668235970a1a797ce6d57501308'),
('sites/all/modules/views/modules/node/views_plugin_row_node_view.inc', '713e1c83702ac2d0d7fe76374110cdfd657598a8f3b086ec2352f2de38101504'),
('sites/all/modules/views/modules/profile/views_handler_field_profile_date.inc', '4f357b26c60afe2b812c995be69ebce6c6f4ea13075613baad7ec0aef1960d18'),
('sites/all/modules/views/modules/profile/views_handler_field_profile_list.inc', 'da5fa527ab4bb6a1ff44cc2f9cec91cf3b094670f9e6e3884e1fedce714afe6f'),
('sites/all/modules/views/modules/profile/views_handler_filter_profile_selection.inc', '758dea53760a1b655986c33d21345ac396ad41d10ddf39dd16bc7d8c68e72da7'),
('sites/all/modules/views/modules/search/views_handler_argument_search.inc', '3c20f1234af341ea2229419980d8405b7eca5005c1e0ee387c8d5cd7a58c5c60'),
('sites/all/modules/views/modules/search/views_handler_field_search_score.inc', '711af637c864b775672d9f6203fc2da0902ed17404181d1117b400012aac366f'),
('sites/all/modules/views/modules/search/views_handler_filter_search.inc', '15d63289e4821f329f44eb40dc121375e024e61fc2f1158f71b3d6c77fe6c4f1'),
('sites/all/modules/views/modules/search/views_handler_sort_search_score.inc', '9d23dd6c464d486266749106caec1d10cec2da1cc3ae5f907f39056c46badbdf'),
('sites/all/modules/views/modules/search/views_plugin_row_search_view.inc', 'bc25864154d4df0a58bc1ac1148581c76df36267a1d18f8caee2e3e1233c8286'),
('sites/all/modules/views/modules/statistics/views_handler_field_accesslog_path.inc', '7843e5f4b35f4322d673b5646e840c274f7d747f2c60c4d4e9c47e282e6db37d'),
('sites/all/modules/views/modules/system/views_handler_argument_file_fid.inc', 'e9bf1fdf12f210f0a77774381b670c77ee88e7789971ce732b254f6be5a0e451'),
('sites/all/modules/views/modules/system/views_handler_field_file.inc', '0fff4adb471c0c164a78f507b035a68d41f404ab10535f06f6c11206f39a7681'),
('sites/all/modules/views/modules/system/views_handler_field_file_extension.inc', 'f833f6ccd098994d91032d40c0eaf5817559917d860f8f2dd8b82768ca616c91'),
('sites/all/modules/views/modules/system/views_handler_field_file_filemime.inc', 'bdd7f1255f3000f7f2900341d4c4ca378244b96390ef52a30db2962d017b61a4'),
('sites/all/modules/views/modules/system/views_handler_field_file_status.inc', 'bfb0b9d796a4dbf95c4bb7a3deef7724bcda9e0d9067939b74ec787da934f2b0'),
('sites/all/modules/views/modules/system/views_handler_field_file_uri.inc', '350d7dde27ee97cb4279360374eb8633ce7fee115a109346bea85c2c4e3a68c2'),
('sites/all/modules/views/modules/system/views_handler_filter_file_status.inc', '9210a34795f9db36974525e718c91c03c28554da1199932791925d7c4a2f3b11'),
('sites/all/modules/views/modules/system/views_handler_filter_system_type.inc', 'd27513703a75c4d8af79b489266cf4102a36e350c3d90404dab24403ab637205'),
('sites/all/modules/views/modules/taxonomy/views_handler_argument_taxonomy.inc', '8962fa76f1e03316932468b0fd805817af94726beb82bf9f4786e0c709264662'),
('sites/all/modules/views/modules/taxonomy/views_handler_argument_term_node_tid.inc', '79a80284231b3bc5aab36833e8200853686784f880dc6b104552d61fc602f27c'),
('sites/all/modules/views/modules/taxonomy/views_handler_argument_term_node_tid_depth.inc', '5b2806fbad4a6cc104e733a3a0faf6eb1c19975930c67c4149fb3267976e0b7d'),
('sites/all/modules/views/modules/taxonomy/views_handler_argument_term_node_tid_depth_modifier.inc', 'd85ebe68290239b25fc240451655b825325854e9707cf742fbd75de81e0f1aa7'),
('sites/all/modules/views/modules/taxonomy/views_handler_argument_vocabulary_machine_name.inc', '888647527bec3444b2d0a571a77900396d7c5e884bca04a2a3667a61f6377b5e'),
('sites/all/modules/views/modules/taxonomy/views_handler_argument_vocabulary_vid.inc', 'bf4be783ef6899f004f4dbd06c1bf2cd6dbc322678c825eec36bee81d667e81f'),
('sites/all/modules/views/modules/taxonomy/views_handler_field_taxonomy.inc', 'b0dd5cfa87c44b95aefd819444e4985c1773350bcf9fe073a2ef5c82b680b833'),
('sites/all/modules/views/modules/taxonomy/views_handler_field_term_link_edit.inc', '3da63f6feb1fa3312853b54585d761d037dac8841b4c06e01e35463c9098064a'),
('sites/all/modules/views/modules/taxonomy/views_handler_field_term_node_tid.inc', '29c5132ac98a2959405e44f9a83096b0dcfa30ed7fb4688453ca7e1fc779684b'),
('sites/all/modules/views/modules/taxonomy/views_handler_filter_term_node_tid.inc', '0fd0384ec873d6db244da736e6f5f811ece9a8a5673aeca609a2a3f17f61fc45'),
('sites/all/modules/views/modules/taxonomy/views_handler_filter_term_node_tid_depth.inc', '0b05ec052dcc03081e20338808dda17beb0bdf869b0cfc1375ca96cfb758c22a'),
('sites/all/modules/views/modules/taxonomy/views_handler_filter_vocabulary_machine_name.inc', 'f1787b436b914cfe5ca6f2575d4c0595f4f496795711d6e8a116a39986728b0a'),
('sites/all/modules/views/modules/taxonomy/views_handler_filter_vocabulary_vid.inc', '2a4d7dfbb6b795d217e2617595238f552bbea04b80217c933f1ee9978ceb7a0e'),
('sites/all/modules/views/modules/taxonomy/views_handler_relationship_node_term_data.inc', '995345469938c7796ed77cb010984cb01c0d712386ae4a5f447e843620248570'),
('sites/all/modules/views/modules/taxonomy/views_plugin_argument_default_taxonomy_tid.inc', 'fc4c3ace525162fc922de581af0710c7d92dc355e9630040a29a5c3a6ab7f9af'),
('sites/all/modules/views/modules/taxonomy/views_plugin_argument_validate_taxonomy_term.inc', 'd1a7aa7ebd9c698afcdcf75b2f0affa981124064ff787ebc716bfac3ee0f60af'),
('sites/all/modules/views/modules/tracker/views_handler_argument_tracker_comment_user_uid.inc', '91f5b7e9537942eee7a1798906f772cb9806eebfdc201c54fcdecf027cd71d0f'),
('sites/all/modules/views/modules/tracker/views_handler_filter_tracker_boolean_operator.inc', '5efea908902052d68141017b6f29f17381e7bb8ebb6d88245471926f0a552207'),
('sites/all/modules/views/modules/tracker/views_handler_filter_tracker_comment_user_uid.inc', '05e07f74d1e3978afd4c80a9b4bd72444872b84a44949a512f1d3040ce28421c'),
('sites/all/modules/views/modules/translation/views_handler_argument_node_tnid.inc', 'b0e3c87d3790cfa2e265f3d9700f2b3c2857932aa4b6e003e5d0114fc1b4d499'),
('sites/all/modules/views/modules/translation/views_handler_field_node_link_translate.inc', '27a1ac81b50d4807d9a1eff4c5dc8929e4472f9d363f70f5391a794db73424a2'),
('sites/all/modules/views/modules/translation/views_handler_field_node_translation_link.inc', '641ff25cd317bb803de2ace4bd23e8c5f5af5ba4ac38aab7be2fdc58fbb9e86a'),
('sites/all/modules/views/modules/translation/views_handler_filter_node_tnid.inc', '0942fd793740e3aec032a1abb7132f53788a9cdeaeb3d931cac908ac30b73950'),
('sites/all/modules/views/modules/translation/views_handler_filter_node_tnid_child.inc', '2a7a96d6caa4a99996549be0457bf40fa619731543a636d4573e55c190c64c7a'),
('sites/all/modules/views/modules/translation/views_handler_relationship_translation.inc', '9137c85f5ca309d4ee0d3243c470563a5853f5926b8cbd3e843438d4308c9516'),
('sites/all/modules/views/modules/user/views_handler_argument_users_roles_rid.inc', '72da80e7f3c6980da024d86f37ba3721021cc1ead2cfcc1ab9b27897b7b5077a'),
('sites/all/modules/views/modules/user/views_handler_argument_user_uid.inc', 'a4af1bdc1ec5e40587c22c14e839980050baaa346c9d5934ef3f01794932cdc5'),
('sites/all/modules/views/modules/user/views_handler_field_user.inc', '1a2141524e43d86b52c7828fe6df61dd603ad433743c1139cfc5cc28ccb5ce74'),
('sites/all/modules/views/modules/user/views_handler_field_user_language.inc', '5a3da9e08ebeebbcb5abc6a9b16e0d380c5bb5c57b608afb540a3ca6dc1b2959'),
('sites/all/modules/views/modules/user/views_handler_field_user_link.inc', '5a0f35d5305a29816658385ecbd804bf43c92d4b3629fbe4bd9b8d0e9574b6ff'),
('sites/all/modules/views/modules/user/views_handler_field_user_link_cancel.inc', 'bcc690f03eca154ad02d1de3ebca7d99129455e8c8602c0642382ae66a6d2872'),
('sites/all/modules/views/modules/user/views_handler_field_user_link_edit.inc', '5d7c1155d9eccbd6b07c7446fe2b6a8848d6a500f508ac3779f16df56816f92b'),
('sites/all/modules/views/modules/user/views_handler_field_user_mail.inc', 'b7355b704f19322afb4876cea27744367e20098d4ed973e480bf2baf1ddd111c'),
('sites/all/modules/views/modules/user/views_handler_field_user_name.inc', '5fd9a4d7843fee83cf529384a52d7ae69e40a9c8846e7f285e94f4bbbf8c7e29'),
('sites/all/modules/views/modules/user/views_handler_field_user_permissions.inc', 'ec37373524bf23ae107adda6b825570c550e6654c0f0956409fc58df2c860903');
INSERT INTO `registry_file` VALUES
('sites/all/modules/views/modules/user/views_handler_field_user_picture.inc', '0103d136a91fb219fd981801301b7df00adf90617900ded08efbf6d7df04959b'),
('sites/all/modules/views/modules/user/views_handler_field_user_roles.inc', 'ab5068c4f01a05c6511f7d4b973a77650d5b5c481d4a73f63b7a9b1ef9c0d138'),
('sites/all/modules/views/modules/user/views_handler_filter_user_current.inc', '7f70b7e3b3c10e75d95f54afc9c2fe2f1af9b7a9eab2308d2961b2588dc05845'),
('sites/all/modules/views/modules/user/views_handler_filter_user_name.inc', '5225e5d89051313e0e49ea833709bb4dc44369afeee970b0cfaf1818ababa22c'),
('sites/all/modules/views/modules/user/views_handler_filter_user_permissions.inc', 'a72e8d02c1075cebfee33e5b046460eef9193b2a7c1d47ff130457e4485b6fe5'),
('sites/all/modules/views/modules/user/views_handler_filter_user_roles.inc', '3bb69fbc4e352ce8e4840ec78bdd0f1f29e8709097ce6b29cc2fedd2c74c023e'),
('sites/all/modules/views/modules/user/views_plugin_argument_default_current_user.inc', '11e729115350deffe46ebfe3a55281fa169a90e38a76c3a9d98f26c87900a22b'),
('sites/all/modules/views/modules/user/views_plugin_argument_default_user.inc', 'fe567f009a8e20f402f104b157fd44c04d6bd886a39b2f3355104f644f905419'),
('sites/all/modules/views/modules/user/views_plugin_argument_validate_user.inc', '40d623b0a678fa7c292da92582f06449d0396341ab161069f0fe8d1086ab95da'),
('sites/all/modules/views/modules/user/views_plugin_row_user_view.inc', '52548cca3f18d25b06cfce15ee00acea530b85bd22a10944d984b5a798c5969f'),
('sites/all/modules/views/plugins/export_ui/views_ui.class.php', '8548322a602b99e4343948255a8c89b034e005a29d71e499cea7c60a4d8a6d87'),
('sites/all/modules/views/plugins/views_plugin_access.inc', 'cc16bf7dc4c10eab382e948cfd91902ac1055514b627e3c50932376d3e3f1b91'),
('sites/all/modules/views/plugins/views_plugin_access_none.inc', '8e0a6b706c60abf63ab84d8624567ca12a5b80ad293e4334790065fbe6fa14d4'),
('sites/all/modules/views/plugins/views_plugin_access_perm.inc', '1807a9c91485a5abd3fb2f6590ed4bc185fdabe308db37b169be8abdfc30cab2'),
('sites/all/modules/views/plugins/views_plugin_access_role.inc', '8784836ea87ec6b0974125ed95ed6bbf6fdf91624f496f22c28e9229c695068d'),
('sites/all/modules/views/plugins/views_plugin_argument_default.inc', '43e593760f0e8f031f2e7b861385caa5e39f37de400fe4595925288c78f52f23'),
('sites/all/modules/views/plugins/views_plugin_argument_default_fixed.inc', 'daaa3b59b54cbb11e411e010303f67a51348bb97a4e06997b475f4c41e91c4e0'),
('sites/all/modules/views/plugins/views_plugin_argument_default_php.inc', '7a133b603294bfe498bfdeb50fade0b6e3cf8862270376067d86f69e7dc50eb8'),
('sites/all/modules/views/plugins/views_plugin_argument_default_raw.inc', '4318e0dfa56f167183453cf8cd913f3b7ee539b77a096507905e36db12ded97e'),
('sites/all/modules/views/plugins/views_plugin_argument_validate.inc', 'c71e2b54623cc62530ebb717dec1406c76200a59270d9c60b3be290694c9fdd8'),
('sites/all/modules/views/plugins/views_plugin_argument_validate_numeric.inc', 'c050d3b5723dbfdca9ad312c7fa198e509c626057b95eed326820ce733dd9730'),
('sites/all/modules/views/plugins/views_plugin_argument_validate_php.inc', '56a09922081a5e368d5796907727e35cbf43b0d634e53f947990c8a42d5b5f3e'),
('sites/all/modules/views/plugins/views_plugin_cache.inc', '5a8d4d584ab973b512ca674b45a1e2a4d43d18d420b333cf8179f1ce79d23d85'),
('sites/all/modules/views/plugins/views_plugin_cache_none.inc', 'a0d0ba252e1e2b65350c7ce648b97364726fa8ded5a366bfcce30c62daee4450'),
('sites/all/modules/views/plugins/views_plugin_cache_time.inc', '10db3dd52b06478b7be9b858f3a053ae2c2f6377abe488ad912f8ca786200a1d'),
('sites/all/modules/views/plugins/views_plugin_display.inc', 'e795572a7578eadf9af19ef503f31ef2cfb482d3b5c92f2ded7178fc5b55371b'),
('sites/all/modules/views/plugins/views_plugin_display_attachment.inc', '712f4b78334d8b9abe275ef309541f69ae920117c82930cba1ddbb163cb078f5'),
('sites/all/modules/views/plugins/views_plugin_display_block.inc', 'be9e3c4a9e28270147bb21de8056712d58e47eeddf6e002fdb9425996d5d5ead'),
('sites/all/modules/views/plugins/views_plugin_display_default.inc', '91c6554d8f41f848bf30093d44d076051c54e998f6b50bdc2a922bfeeef9c54d'),
('sites/all/modules/views/plugins/views_plugin_display_embed.inc', '5424f2ea9e031faade7a562b8013aea193db5b0bc1be92b97bd7967de0d7bfff'),
('sites/all/modules/views/plugins/views_plugin_display_extender.inc', '75fb9f80e7f153715b911690c7140f251df588e6a541fab5881fbfafc0bbf778'),
('sites/all/modules/views/plugins/views_plugin_display_feed.inc', 'fbff8bf3f2d9fcd6403ca31d6f351dea54c83a644a613f78d34267b504bc84fc'),
('sites/all/modules/views/plugins/views_plugin_display_page.inc', '7f38f2009e09400ddee42777fab356b0ed430653ca2f53b71061c3f2cb946cbc'),
('sites/all/modules/views/plugins/views_plugin_exposed_form.inc', '31c3e76560512e25200e64e17e7a9716482535cd6f1fac7c610e48343484e107'),
('sites/all/modules/views/plugins/views_plugin_exposed_form_basic.inc', 'c736e1862b393e15ecc80deb58663405a1d68c2db07eb620d8e640406876cd17'),
('sites/all/modules/views/plugins/views_plugin_exposed_form_input_required.inc', '46566e6bf33f1b3d4640526372af94c03334318fe4267e9f5e2e8cb74f4ddc81'),
('sites/all/modules/views/plugins/views_plugin_localization.inc', 'd7239cc693994dcd069c1f1e7847a7902c5bd29b8d64a93cdf37c602576661fb'),
('sites/all/modules/views/plugins/views_plugin_localization_core.inc', 'f0900c0640e7c779e9b876223ea395f613c8fe8449f6c8eb5d060e2d54a6afcc'),
('sites/all/modules/views/plugins/views_plugin_localization_none.inc', '4930c3a13ddc0df3065f4920a836ffdc933b037e1337764e6687d7311f49dd8a'),
('sites/all/modules/views/plugins/views_plugin_pager.inc', '1cbe6ca33f3a177726e4435b82d05e465deb38f9d32d45a20738f47e7c2b0877'),
('sites/all/modules/views/plugins/views_plugin_pager_full.inc', '1b6e5e1fd8837d6a5f458079a2dc87161a7814c6d8c181c1dee6958a37096c9a'),
('sites/all/modules/views/plugins/views_plugin_pager_mini.inc', '47ecac80489f13ebf16a7d2f3458c291bc06ba12e0aeb601d89cac8f6e32b6c0'),
('sites/all/modules/views/plugins/views_plugin_pager_none.inc', '822cab1ada25f4902a0505f13db86886061d2ced655438b33b197d031ccceddd'),
('sites/all/modules/views/plugins/views_plugin_pager_some.inc', 'bc6aa7cbf1bc09374eced33334195c8897e4078336b8306d02d71c7aaaa22c99'),
('sites/all/modules/views/plugins/views_plugin_query.inc', '0594d1fd0c34b86c6b81741e134da2d385d6be47b667af6660dd1d268fb7fa95'),
('sites/all/modules/views/plugins/views_plugin_query_default.inc', 'a35fff884bddaa3e45a2143ba96ac595af7dc380457d96b2cc9f4e35c2742617'),
('sites/all/modules/views/plugins/views_plugin_row.inc', '3ca81529526b930cfb0dda202757f203649236b90441e3c035bb79cd419ee2a6'),
('sites/all/modules/views/plugins/views_plugin_row_fields.inc', '875fb2868cdbcc5f7af03098cbe55b9bb91ef512e5e52ccde89f7a02a0c5fbe2'),
('sites/all/modules/views/plugins/views_plugin_row_rss_fields.inc', '62f4a0ceef14aec9958ee8b98d352303f10818ddc66031814cc8b9d21752ade9'),
('sites/all/modules/views/plugins/views_plugin_style.inc', '60243c95aa09e6b09de8418a6dc2b67eabf1e83289cfbf4658c519d6206227be'),
('sites/all/modules/views/plugins/views_plugin_style_default.inc', 'bf411e635d2fd9e09eb245b43581a0a7b670359180ccb042d42a5e579bbe9c30'),
('sites/all/modules/views/plugins/views_plugin_style_grid.inc', '35094b7f644b7e0692c9026b6b6b4c4c864c37fcdedef04b359dd2bdba496a47'),
('sites/all/modules/views/plugins/views_plugin_style_jump_menu.inc', '66170c5b4a8e779f20cf7cf064c65eeba9753b8f4cdf156b108f30d4a22007a2'),
('sites/all/modules/views/plugins/views_plugin_style_list.inc', '407b928d2c74a91903b681088bccce926d2268d0a9a6a34c185a4849dc0d7e31'),
('sites/all/modules/views/plugins/views_plugin_style_mapping.inc', 'af4b75dd08f1597280a8deb6086259be4f10af50acace43ce2013170655f752c'),
('sites/all/modules/views/plugins/views_plugin_style_rss.inc', '77fcd2a962022159e89a773c49823306ef69a0dd1b54e6b344d1e2e45590d3d1'),
('sites/all/modules/views/plugins/views_plugin_style_summary.inc', '872df59f8f389eaf9b019e82d859dd198d31166e26a9102132e3932c7f1f2916'),
('sites/all/modules/views/plugins/views_plugin_style_summary_jump_menu.inc', '2ec0d225824ee65b6bb61317979e1dabe2be524a66ab19da924c6949dd31af3b'),
('sites/all/modules/views/plugins/views_plugin_style_summary_unformatted.inc', 'c1e6f9dd1d75e29fee271171440d2182e633a1dbbc996cb186f637ff7ad93ed9'),
('sites/all/modules/views/plugins/views_plugin_style_table.inc', '0cbcc5d256a13953fbd3e5966a33d2426d5c3bd8c228ef370daebf2f428e693c'),
('sites/all/modules/views/plugins/views_wizard/views_ui_base_views_wizard.class.php', 'd8325414c8ddde5c955a5cfb053b77478bb4d73cb2f7d75b857b082bc5a1e12d'),
('sites/all/modules/views/plugins/views_wizard/views_ui_comment_views_wizard.class.php', '208d02d7185ccc89c6767d31be2f5417c7877a6846457194eb103bd648aa7577'),
('sites/all/modules/views/plugins/views_wizard/views_ui_file_managed_views_wizard.class.php', '5734fb564ba9e2485cfa5d4a49f0c76f65a9be357b78e769ee4af92c4ef9e22a'),
('sites/all/modules/views/plugins/views_wizard/views_ui_node_revision_views_wizard.class.php', '6faf9ef92501a4f1aeaf86bcff9edaeb47bd7526ba50d06b841c9366149e7725'),
('sites/all/modules/views/plugins/views_wizard/views_ui_node_views_wizard.class.php', '2862cfdcef52cdd42f3b0e0113148bd0da8a93b6cd200f94d51df34e5428fcd2'),
('sites/all/modules/views/plugins/views_wizard/views_ui_taxonomy_term_views_wizard.class.php', 'a8713b5a925ce8619f4f7b2ce74fbf9f7bb570f8ed084c8a7a5865fb40032eab'),
('sites/all/modules/views/plugins/views_wizard/views_ui_users_views_wizard.class.php', 'f9fe2fb1ee87a1871e6ad32bad61b2457313f24da1bd5423977ced12de542919'),
('sites/all/modules/views/tests/comment/views_handler_argument_comment_user_uid.test', 'b8b417ef0e05806a88bd7d5e2f7dcb41339fbf5b66f39311defc9fb65476d561'),
('sites/all/modules/views/tests/comment/views_handler_filter_comment_user_uid.test', '347c6ffd4383706dbde844235aaf31cff44a22e95d2e6d8ef4da34a41b70edd1'),
('sites/all/modules/views/tests/field/views_fieldapi.test', '53e6d57c2d1d6cd0cd92e15ca4077ba532214daf41e9c7c0f940c7c8dbd86a66'),
('sites/all/modules/views/tests/handlers/views_handler_area_text.test', 'af74a74a3357567b844606add76d7ca1271317778dd7bd245a216cf963c738b4'),
('sites/all/modules/views/tests/handlers/views_handler_argument_null.test', '1d174e1f467b905d67217bd755100d78ffeca4aa4ada5c4be40270cd6d30b721'),
('sites/all/modules/views/tests/handlers/views_handler_argument_string.test', '3d0213af0041146abb61dcdc750869ed773d0ac80cfa74ffbadfdd03b1f11c52'),
('sites/all/modules/views/tests/handlers/views_handler_field.test', 'af552bf825ab77486b3d0d156779b7c4806ce5a983c6116ad68b633daf9bb927'),
('sites/all/modules/views/tests/handlers/views_handler_field_boolean.test', 'd334b12a850f36b41fe89ab30a9d758fd3ce434286bd136404344b7b288460ae'),
('sites/all/modules/views/tests/handlers/views_handler_field_counter.test', '75b31942adf06b107f5ffd3c97545fde8cd1040b1d00f682e3c7c1320026e26c'),
('sites/all/modules/views/tests/handlers/views_handler_field_custom.test', '1446bc3d5a6b1180a79edfa46a5268dbf7f089836aa3bc45df00ddaff9dd0ce1'),
('sites/all/modules/views/tests/handlers/views_handler_field_date.test', '6f45326d7f74127956d9d8e4d7ad96a4beb0f66175fa40daf1d618d1a5fa996d'),
('sites/all/modules/views/tests/handlers/views_handler_field_file_size.test', '49184db68af398a54e81c8a76261acd861da8fd7846b9d51dcf476d61396bfb9'),
('sites/all/modules/views/tests/handlers/views_handler_field_math.test', '6e39e4f782e6b36151ceafb41a5509f7c661be79b393b24f6f5496d724535887'),
('sites/all/modules/views/tests/handlers/views_handler_field_url.test', 'b41f762a71594b438a2e60a79c8260ba54e6305635725b0747e29f0d3ffe08c9'),
('sites/all/modules/views/tests/handlers/views_handler_field_xss.test', 'f129ee16c03f84673e33990cbb2da5aa88c362f46e9ba1620b2a842ffd1c9cd2'),
('sites/all/modules/views/tests/handlers/views_handler_filter_combine.test', '05842d83a11822afe7d566835f5db9f0f94fdb27ddfc388d38138767bdf36f8b'),
('sites/all/modules/views/tests/handlers/views_handler_filter_date.test', '045cc449b68bbd5526071bf38c505b6d44f6c91868273c3120705c3bad250aee'),
('sites/all/modules/views/tests/handlers/views_handler_filter_equality.test', 'c88f21c9cbf1aae83393b26616908f8020c18fe378d76256c7ba192df2ec17af'),
('sites/all/modules/views/tests/handlers/views_handler_filter_in_operator.test', '89420a4071677232e0eb82b184b37b818a82bdb2ff90a8b21293f9ecb21808bf'),
('sites/all/modules/views/tests/handlers/views_handler_filter_numeric.test', '35ac7a34e696b979e86ef7209b6697098d9abe218e30a02cc4fe39fb11f2a852'),
('sites/all/modules/views/tests/handlers/views_handler_filter_string.test', 'b7d090780748faad478e619fd55673d746d4a0cf343d9e40ea96881324c34cbd'),
('sites/all/modules/views/tests/handlers/views_handler_sort.test', 'f4ff79e6bc54e83c4eb2777811f33702b7e9fe7416ef70ae00d100fa54d44fec'),
('sites/all/modules/views/tests/handlers/views_handler_sort_date.test', 'f548584d7c6a71cabd3ce07e04053a38df3f3e1685210ce8114238fd05344c10'),
('sites/all/modules/views/tests/handlers/views_handler_sort_random.test', '4fdba9bf05a26720ffa97e7a37da65ddc9044bd2832f8c89007b82feb062f182'),
('sites/all/modules/views/tests/node/views_node_revision_relations.test', '9467497a6d693615b48c8f57611a850002317bcb091b926d2efbbe56a4e61480'),
('sites/all/modules/views/tests/plugins/views_plugin_display.test', '4a6b136543a60999604c54125fa9d4f5aa61a5dcc71e2133d89325d81bc0fc2d'),
('sites/all/modules/views/tests/styles/views_plugin_style.test', 'fb6c3279645fbcc1126acb3e1c908189e5240c647f81dcfd9b0761570c99d269'),
('sites/all/modules/views/tests/styles/views_plugin_style_base.test', '54fb7816d18416d8b0db67e9f55aa2aa50ac204eb9311be14b6700b7d7a95ae7'),
('sites/all/modules/views/tests/styles/views_plugin_style_jump_menu.test', 'b88baa8aebe183943a6e4cf2df314fef13ac41b5844cd5fa4aa91557dd624895'),
('sites/all/modules/views/tests/styles/views_plugin_style_mapping.test', 'a4e68bc8cfbeff4a1d9b8085fd115bfe7a8c4b84c049573fa0409b0dc8c2f053'),
('sites/all/modules/views/tests/styles/views_plugin_style_unformatted.test', '033ca29d41af47cd7bd12d50fea6c956dde247202ebda9df7f637111481bb51d'),
('sites/all/modules/views/tests/taxonomy/views_handler_relationship_node_term_data.test', '6074f5c7ae63225ea0cd26626ace6c017740e226f4d3c234e39869c31308223d'),
('sites/all/modules/views/tests/test_plugins/views_test_plugin_access_test_dynamic.inc', '6a3ce8c256b84734b6b67a893ab24465a5f62d7bdf9ab5d22082a31849346b7d'),
('sites/all/modules/views/tests/test_plugins/views_test_plugin_access_test_static.inc', 'e345e42d443cfa73db0ed2be61291117ebd57b86196cdb77c6f440e93443def3'),
('sites/all/modules/views/tests/test_plugins/views_test_plugin_style_test_mapping.inc', '0b2c68626105bd5f6b9074022a37c3d09d3a6bd70b811bb26d5eacad6d74546f'),
('sites/all/modules/views/tests/user/views_handler_field_user_name.test', '69641b6da26d8daee9a2ceb2d0df56668bf09b86db1d4071c275b6e8d0885f9e'),
('sites/all/modules/views/tests/user/views_user.test', 'fbb63b42a0b7051bd4d33cf36841f39d7cc13a63b0554eca431b2a08c19facae'),
('sites/all/modules/views/tests/user/views_user_argument_default.test', '6423f2db7673763991b1fd0c452a7d84413c7dd888ca6c95545fadc531cfaaf4'),
('sites/all/modules/views/tests/user/views_user_argument_validate.test', 'c88c9e5d162958f8924849758486a0d83822ada06088f5cf71bfbe76932d8d84'),
('sites/all/modules/views/tests/views_access.test', 'f8b9d04b43c09a67ec722290a30408c1df8c163cf6e5863b41468bb4e381ee6f'),
('sites/all/modules/views/tests/views_analyze.test', '5548e36c99bb626209d63e5cddbc31f49ad83865c983d2662c6826b328d24ffb'),
('sites/all/modules/views/tests/views_argument_default.test', '5950937aae4608bba5b86f366ef3a56cc6518bbccfeaeacda79fa13246d220e4'),
('sites/all/modules/views/tests/views_argument_validator.test', '31f8f49946c8aa3b03d6d9a2281bdfb11c54071b28e83fb3e827ca6ff5e38c88'),
('sites/all/modules/views/tests/views_basic.test', '655bd33983f84bbea68a3f24bfab545d2c02f36a478566edf35a98a58ff0c6cf'),
('sites/all/modules/views/tests/views_cache.test', '76316e1f026c2ab81ef91450b9d6d5985cbfab087f839ea0edd112209bf84fd9'),
('sites/all/modules/views/tests/views_exposed_form.test', '2b2b16373af8ecade91d7c77bd8c2da8286a33bde554874f5d81399d201c3228'),
('sites/all/modules/views/tests/views_glossary.test', '118d50177a68a6f88e3727e10f8bcc6f95176282cc42fbd604458eeb932a36e8'),
('sites/all/modules/views/tests/views_groupby.test', 'ac6ca55f084f4884c06437815ccfa5c4d10bfef808c3f6f17a4f69537794a992'),
('sites/all/modules/views/tests/views_handlers.test', 'a696e3d6b1748da03a04ac532f403700d07c920b9c405c628a6c94ea6764f501'),
('sites/all/modules/views/tests/views_module.test', '3939798f2f679308903d4845f5625dd60df6110aec2615e33ab81e854d0b7e73'),
('sites/all/modules/views/tests/views_pager.test', '6f448c8c13c5177afb35103119d6281958a2d6dbdfb96ae5f4ee77cb3b44adc5'),
('sites/all/modules/views/tests/views_plugin_localization_test.inc', 'baedcf6c7381f9c5d3a5062f7d256f96808d06e04b6e73eff8e791e5f5293f45'),
('sites/all/modules/views/tests/views_query.test', '1ab587994dc43b1315e9a534d005798aecaa14182ba23a2b445e56516b9528cb'),
('sites/all/modules/views/tests/views_test.views_default.inc', '9664b95577fe2664410921bb751e1d99109e79b734f2c8c142d4083449282bd0'),
('sites/all/modules/views/tests/views_translatable.test', '6899c7b09ab72c262480cf78d200ecddfb683e8f2495438a55b35ae0e103a1b3'),
('sites/all/modules/views/tests/views_ui.test', 'f9687a363d7cc2828739583e3eedeb68c99acd505ff4e3036c806a42b93a2688'),
('sites/all/modules/views/tests/views_upgrade.test', 'c48bd74b85809dd78d963e525e38f3b6dd7e12aa249f73bd6a20247a40d6713a'),
('sites/all/modules/views/tests/views_view.test', 'a52e010d27cc2eb29804a3acd30f574adf11fad1f5860e431178b61cddbdbb69'),
('sites/all/modules/views/views_ui.module', '2451d4e3df513afe85c7e24acc90b89ed24f5a615e8b4002e9d3d6cd1ca8b32e'),
('sites/all/modules/views_isotope/views-isotope.tpl.php', 'b9ecd2a9f380b83ca0aede7bcd1096bc2525e744da5a15f4bf1e93ec7aedd670'),
('sites/all/modules/views_isotope/views_isotope.module', 'fc9739b7f9ba87b29c1bbd9f1a78c9f2461b1164284994a1e1a67b34e67feca9'),
('sites/all/modules/views_isotope/views_isotope.theme.inc', '8f90273bafcaee597f4f2528bdd771d8e4f58b3af7bbe880f95a2d981bb6dece'),
('sites/all/modules/views_isotope/views_isotope.views.inc', '2e03b37eab80aff2175fe0c940fe7011fe4b162e01fdb63b36071ccbfb1d5e9a'),
('sites/all/modules/views_isotope/views_isotope_plugin_style_isotope.inc', 'eec55678a9d03cfc3f4e6d15df7c9a112d5f8aff676537bf6e47dbf3c878ed72'),
('sites/all/modules/views_slideshow/theme/views_slideshow.theme.inc', 'a074f621f1343e51f1d2d7d38fc9ad76e78cb6542f82e00bc8dc5c1d0d9a4663'),
('sites/all/modules/views_slideshow/views_slideshow.module', '66bd739ceacafb250368469d70150955c91f745469b4520c8c5e8027285da337'),
('sites/all/modules/views_slideshow/views_slideshow.views.inc', '3b3834220b91a373a74347683de8cbe45dfc19f8263b71dae368abaca45ec617'),
('sites/all/modules/views_slideshow/views_slideshow_plugin_style_slideshow.inc', '51dbe2d3aa647df37e1854e4504f8426e4d7fc79ed3d2309707ee865134a0d3f'),
('sites/all/modules/wysiwyg/tests/wysiwyg.test', '351bd7ed3eb279052b92cd900ceaedb3baa97ab502eed61a390efed83d8cefd8'),
('sites/all/modules/wysiwyg/wysiwyg.module', '23bbe445f32ba4e8d58c555b11e3275bf954380fea6c4e2a02bbc46fcc41daf8');
/*!40000 ALTER TABLE registry_file ENABLE KEYS */;

--
-- Table structure for table 'role'
--

CREATE TABLE IF NOT EXISTS `role` (
  `rid` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique role ID.',
  `name` varchar(64) NOT NULL DEFAULT '' COMMENT 'Unique role name.',
  `weight` int(11) NOT NULL DEFAULT '0' COMMENT 'The weight of this role in listings and the user interface.',
  PRIMARY KEY (`rid`),
  UNIQUE KEY `name` (`name`),
  KEY `name_weight` (`name`,`weight`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores user roles.';

--
-- Dumping data for table 'role'
--

/*!40000 ALTER TABLE role DISABLE KEYS */;
INSERT INTO `role` VALUES
('3', 'administrator', '2'),
('1', 'anonymous user', '0'),
('2', 'authenticated user', '1');
/*!40000 ALTER TABLE role ENABLE KEYS */;

--
-- Table structure for table 'role_permission'
--

CREATE TABLE IF NOT EXISTS `role_permission` (
  `rid` int(10) unsigned NOT NULL COMMENT 'Foreign Key: role.rid.',
  `permission` varchar(128) NOT NULL DEFAULT '' COMMENT 'A single permission granted to the role identified by rid.',
  `module` varchar(255) NOT NULL DEFAULT '' COMMENT 'The module declaring the permission.',
  PRIMARY KEY (`rid`,`permission`),
  KEY `permission` (`permission`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores the permissions assigned to user roles.';

--
-- Dumping data for table 'role_permission'
--

/*!40000 ALTER TABLE role_permission DISABLE KEYS */;
INSERT INTO `role_permission` VALUES
('1', 'access comments', 'comment'),
('1', 'access content', 'node'),
('1', 'access site-wide contact form', 'contact'),
('1', 'access user contact forms', 'contact'),
('1', 'post comments', 'comment'),
('1', 'search content', 'search'),
('1', 'use advanced search', 'search'),
('1', 'use text format filtered_html', 'filter'),
('1', 'use text format gmap', 'filter'),
('1', 'view faq page', 'faq'),
('2', 'access comments', 'comment'),
('2', 'access content', 'node'),
('2', 'access site-wide contact form', 'contact'),
('2', 'access user contact forms', 'contact'),
('2', 'post comments', 'comment'),
('2', 'search content', 'search'),
('2', 'use advanced search', 'search'),
('2', 'use text format filtered_html', 'filter'),
('2', 'use text format gmap', 'filter'),
('2', 'view faq page', 'faq'),
('3', 'access administration menu', 'admin_menu'),
('3', 'access administration pages', 'system'),
('3', 'access all views', 'views'),
('3', 'access comments', 'comment'),
('3', 'access content', 'node'),
('3', 'access content overview', 'node'),
('3', 'access contextual links', 'contextual'),
('3', 'access dashboard', 'dashboard'),
('3', 'access devel information', 'devel'),
('3', 'access getlocations', 'getlocations'),
('3', 'access news feeds', 'aggregator'),
('3', 'access overlay', 'overlay'),
('3', 'access printer-friendly version', 'book'),
('3', 'access quotes', 'quotes'),
('3', 'access site in maintenance mode', 'system'),
('3', 'access site reports', 'system'),
('3', 'access site-wide contact form', 'contact'),
('3', 'access statistics', 'statistics'),
('3', 'access toolbar', 'toolbar'),
('3', 'access user contact forms', 'contact'),
('3', 'access user getlocations', 'getlocations'),
('3', 'access user profiles', 'user'),
('3', 'add content to books', 'book'),
('3', 'administer actions', 'system'),
('3', 'administer addthis', 'addthis'),
('3', 'administer addtoany', 'addtoany'),
('3', 'administer advanced addthis', 'addthis'),
('3', 'administer advanced pane settings', 'panels'),
('3', 'administer blocks', 'block'),
('3', 'administer book outlines', 'book'),
('3', 'administer comments', 'comment'),
('3', 'administer contact forms', 'contact'),
('3', 'administer content types', 'node'),
('3', 'administer cumulus', 'cumulus'),
('3', 'administer demo settings', 'demo'),
('3', 'administer faq', 'faq'),
('3', 'administer faq order', 'faq'),
('3', 'administer filters', 'filter'),
('3', 'administer flexslider', 'flexslider'),
('3', 'administer flickr', 'flickr'),
('3', 'administer follow', 'follow'),
('3', 'administer forums', 'forum'),
('3', 'administer image styles', 'image'),
('3', 'administer languages', 'locale'),
('3', 'administer menu', 'menu'),
('3', 'administer mini panels', 'panels_mini'),
('3', 'administer module filter', 'module_filter'),
('3', 'administer modules', 'system'),
('3', 'administer news feeds', 'aggregator'),
('3', 'administer nodes', 'node'),
('3', 'administer page manager', 'page_manager'),
('3', 'administer pane access', 'panels'),
('3', 'administer panel-nodes', 'panels_node'),
('3', 'administer panels layouts', 'panels'),
('3', 'administer permissions', 'user'),
('3', 'administer quicktabs', 'quicktabs'),
('3', 'administer quotes', 'quotes'),
('3', 'administer search', 'search'),
('3', 'administer shortcuts', 'shortcut'),
('3', 'administer site configuration', 'system'),
('3', 'administer software updates', 'system'),
('3', 'administer statistics', 'statistics'),
('3', 'administer taxonomy', 'taxonomy'),
('3', 'administer themes', 'system'),
('3', 'administer tipsy', 'tipsy'),
('3', 'administer unit tests', 'simpletest'),
('3', 'administer url aliases', 'path'),
('3', 'administer users', 'user'),
('3', 'administer views', 'views'),
('3', 'block IP addresses', 'system'),
('3', 'bypass node access', 'node'),
('3', 'cancel account', 'user'),
('3', 'cancel own vote', 'poll'),
('3', 'change follow link titles', 'follow'),
('3', 'change own username', 'user'),
('3', 'create article content', 'node'),
('3', 'create faq', 'faq'),
('3', 'create gmap macro', 'gmap_macro_builder'),
('3', 'create mini panels', 'panels_mini'),
('3', 'create new books', 'book'),
('3', 'create page content', 'node'),
('3', 'create panel-nodes', 'panels_node'),
('3', 'create quotes', 'quotes'),
('3', 'create url aliases', 'path'),
('3', 'customize shortcut links', 'shortcut'),
('3', 'delete any article content', 'node'),
('3', 'delete any page content', 'node'),
('3', 'delete any panel-nodes', 'panels_node'),
('3', 'delete own article content', 'node'),
('3', 'delete own page content', 'node'),
('3', 'delete own panel-nodes', 'panels_node'),
('3', 'delete revisions', 'node'),
('3', 'delete terms in 1', 'taxonomy'),
('3', 'display drupal links', 'admin_menu'),
('3', 'edit any article content', 'node'),
('3', 'edit any page content', 'node'),
('3', 'edit any panel-nodes', 'panels_node'),
('3', 'edit any user follow links', 'follow'),
('3', 'edit faq', 'faq'),
('3', 'edit own article content', 'node'),
('3', 'edit own comments', 'comment'),
('3', 'edit own faq', 'faq'),
('3', 'edit own follow links', 'follow'),
('3', 'edit own page content', 'node'),
('3', 'edit own panel-nodes', 'panels_node'),
('3', 'edit own quotes', 'quotes'),
('3', 'edit site follow links', 'follow'),
('3', 'edit terms in 1', 'taxonomy'),
('3', 'execute php code', 'devel'),
('3', 'flush caches', 'admin_menu'),
('3', 'import quotes', 'quotes'),
('3', 'inspect all votes', 'poll'),
('3', 'post comments', 'comment'),
('3', 'promote quotes to block', 'quotes'),
('3', 'revert revisions', 'node'),
('3', 'search content', 'search'),
('3', 'select account cancellation method', 'user'),
('3', 'skip comment approval', 'comment'),
('3', 'switch shortcut sets', 'shortcut'),
('3', 'switch users', 'devel'),
('3', 'translate content', 'translation'),
('3', 'translate interface', 'locale'),
('3', 'use advanced search', 'search'),
('3', 'use page manager', 'page_manager'),
('3', 'use panels caching features', 'panels'),
('3', 'use panels dashboard', 'panels'),
('3', 'use panels in place editing', 'panels'),
('3', 'use PHP for settings', 'php'),
('3', 'use text format filtered_html', 'filter'),
('3', 'use text format full_html', 'filter'),
('3', 'use text format gmap', 'filter'),
('3', 'use views exporter', 'views_export'),
('3', 'view addthis', 'addthis'),
('3', 'view all flickr photos', 'flickr'),
('3', 'view faq page', 'faq'),
('3', 'view own flickr photos', 'flickr'),
('3', 'view own unpublished content', 'node'),
('3', 'view pane admin links', 'panels'),
('3', 'view post access counter', 'statistics'),
('3', 'view revisions', 'node'),
('3', 'view the administration theme', 'system'),
('3', 'vote on polls', 'poll');
/*!40000 ALTER TABLE role_permission ENABLE KEYS */;

--
-- Table structure for table 'search_dataset'
--

CREATE TABLE IF NOT EXISTS `search_dataset` (
  `sid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'Search item ID, e.g. node ID for nodes.',
  `type` varchar(16) NOT NULL COMMENT 'Type of item, e.g. node.',
  `data` longtext NOT NULL COMMENT 'List of space-separated words from the item.',
  `reindex` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'Set to force node reindexing.',
  PRIMARY KEY (`sid`,`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores items that will be searched.';

--
-- Dumping data for table 'search_dataset'
--

/*!40000 ALTER TABLE search_dataset DISABLE KEYS */;
INSERT INTO `search_dataset` VALUES
('11', 'node', ' what do you think about us  super 39 847 votes good 31 678 votes normal 20 432 votes bad 11 235 votes total votes 2192  ', '0'),
('12', 'node', ' lorem ipsum dolor sit amet general discussion lorem ipsum dolor sit amet consectetur adipiscing elit phasellus feugiat viverra libero nec cursus fusce vestibulum felis non felis viverra dignissim molestie justo semper phasellus tortor nisl interdum a consequat mollis vehicula id neque vivamus interdum ornare erat eu egestas risus eleifend a donec a lacus id nulla volutpat gravida ac sed dui in hac habitasse platea dictumst nulla sagittis aliquam tellus sit amet facilisis metus imperdiet vitae integer convallis purus vitae lacinia bibendum dui ligula varius dolor vitae elementum dui risus sit amet velit phasellus enim nibh pharetra eget bibendum in condimentum a magna vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia curae mauris fermentum luctus eleifend donec quis velit lorem ut fermentum arcu in tellus dictum at porttitor odio porttitor vivamus sodales porttitor diam sit amet faucibus lorem imperdiet in nam volutpat eros ut convallis viverra odio velit iaculis dui quis tristique turpis justo non ipsum nulla aliquam varius ante sit amet dictum nulla aliquam libero at lorem pellentesque tincidunt phasellus dictum luctus odio sit amet adipiscing odio venenatis a praesent ut blandit felis donec auctor aliquet pellentesque fusce vitae auctor lorem integer vel urna diam integer vitae felis sit amet neque rutrum tincidunt id eget justo donec felis velit faucibus nec congue hendrerit cursus at nunc curabitur ac orci vel mauris eleifend pulvinar curabitur mollis risus nec interdum gravida velit nisl varius purus hendrerit vulputate arcu magna a felis in vitae consequat quam maecenas purus quam tincidunt sit amet venenatis vel venenatis dignissim nisi proin in ultricies risus quisque feugiat consequat vestibulum lorem ipsum dolor sit amet consectetur adipiscing elit nunc cursus purus ut lectus dictum volutpat imperdiet quam commodo pellentesque lobortis est quis nulla vestibulum lacinia class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos nullam eu ligula ut urna hendrerit malesuada at viverra justo fusce semper nisl a lorem vehicula consectetur fusce porttitor porta tortor permalink submitted by admin on wed 5112011 1535 fusce porttitor porta tortor pulvinar iaculis nulla facilisi etiam semper hendrerit lectus sit amet ultricies augue porta ut praesent vitae dolor vitae felis congue mollis nulla fermentum augue sit amet sem luctus dignissim class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos in dignissim tincidunt mollis sed sed massa lorem sed laoreet est pellentesque sit amet orci sed arcu euismod posuere id in nisl aenean in quam tortor curabitur consequat metus ut nulla viverra tincidunt in hac habitasse platea dictumst suspendisse hendrerit quam a dignissim pellentesque turpis risus bibendum massa quis lacinia sem sem eget est praesent magna nisi dignissim laoreet hendrerit lobortis gravida non velit nullam ut velit augue mauris mattis tellus elit et vehicula purus nulla eros libero pretium id elementum id euismod non risus donec enim nisi luctus quis vestibulum eu dapibus quis nisi cras porttitor sem sit amet metus fermentum pretium log in or register to post comments suspendisse potenti fusce permalink submitted by admin on wed 5112011 1535 suspendisse potenti fusce diam risus mattis sit amet pretium in feugiat sed purus vivamus in lectus tellus nam justo leo placerat sit amet imperdiet ut accumsan quis nulla donec tristique tristique massa at malesuada nulla eleifend ultricies tempus nulla dapibus tempus pulvinar nullam urna sem vestibulum ac porttitor sit amet semper ut dui etiam at turpis sed risus auctor molestie eget quis lectus donec lacus tortor condimentum nec pharetra et adipiscing a sapien nulla ac ante diam pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas phasellus bibendum euismod lobortis phasellus semper elementum quam a iaculis morbi tristique diam id ante sagittis rutrum log in or register to post comments lorem ipsum dolor sit amet  permalink submitted by admin on wed 5112011 1535 lorem ipsum dolor sit amet consectetur adipiscing elit ut egestas ante ac nunc dignissim vitae blandit lectus vulputate aliquam ultrices cursus scelerisque nullam interdum facilisis eros ut dignissim morbi luctus ultrices eros vel varius urna facilisis nec aliquam vulputate placerat velit id semper fusce nisi ante pulvinar rutrum semper non imperdiet quis urna duis blandit lacus eget pretium blandit justo orci molestie turpis sit amet tincidunt justo lacus eget augue etiam sodales egestas tincidunt quisque et est tellus eu commodo eros phasellus sed est nisl vel posuere massa fusce eu diam nec eros elementum congue a a augue donec tempus velit id leo vestibulum luctus quisque mattis orci eget feugiat volutpat dui orci lobortis metus quis elementum leo urna quis urna nullam et dolor urna praesent tincidunt velit at mauris pharetra sit amet rhoncus enim sollicitudin morbi non aliquet nisl log in or register to post comments  ', '0'),
('13', 'node', ' in pellentesque facilisis iaculis general discussion in pellentesque facilisis iaculis vestibulum euismod leo ac risus vulputate eget tempor mauris malesuada nulla feugiat leo vitae nisl ullamcorper in ornare urna aliquam donec eget dui feugiat turpis facilisis euismod quisque pretium erat eu feugiat porttitor lectus odio euismod elit eget varius purus massa non erat nam neque tellus imperdiet ac ullamcorper a elementum eget ipsum pellentesque ut sem nibh proin nec lectus augue sit amet ultrices neque in sit amet lacus justo a ultricies nibh nullam condimentum congue odio semper consequat nulla dignissim sed donec rhoncus lacus sed commodo laoreet arcu nulla ullamcorper arcu in facilisis risus mauris id nibh fusce lacinia vulputate odio ac luctus sapien elementum non sed scelerisque tristique enim ac feugiat velit ultricies at fusce eget dui urna sed tempus ipsum quisque aliquet convallis urna quis rhoncus aliquam vestibulum sodales interdum quisque quis nisi velit duis vestibulum nibh posuere sem commodo pharetra etiam eget mauris metus quisque congue ante augue quisque vehicula accumsan diam sit amet convallis donec eu nisl sed tellus condimentum lobortis fusce nulla sem lacinia vel lacinia et faucibus ac nibh etiam a congue massa praesent in nisi tellus praesent aliquam aliquam enim sit amet congue quisque pharetra aliquam odio in aliquam nunc et turpis mauris nulla tincidunt laoreet dictum lorem ipsum dolor sit amet consectetur adipiscing elit sed nunc nulla molestie at interdum sit amet consequat a justo nunc lobortis rhoncus malesuada nullam enim erat accumsan sed tincidunt vel pellentesque nec nibh morbi felis est consequat nec varius consequat ornare sit amet justo nam a tortor eget neque suscipit pharetra proin massa ante porttitor quis commodo ut fermentum id mi praesent ac sapien nunc nam id nisl eget dolor varius volutpat vel nec dolor vestibulum libero leo fermentum a euismod ut vehicula ac mauris integer at lectus dui tempor vulputate lacus quisque nec libero eu urna permalink submitted by admin on wed 5112011 1537 quisque nec libero eu urna volutpat cursus quisque elit velit consequat at fringilla quis tincidunt ac nisi donec consequat nisl nec leo vulputate nec fermentum sapien porttitor aliquam hendrerit faucibus diam at dictum quam euismod at sed luctus tempus libero vitae viverra est laoreet sit amet duis sit amet neque dui eu rutrum urna nunc purus urna hendrerit id suscipit nec pulvinar quis justo pellentesque id purus vel nibh iaculis iaculis suspendisse non ante eros duis condimentum tempor nulla at venenatis quisque tristique dui sit amet lorem vulputate eget eleifend ipsum sodales log in or register to post comments  ', '0'),
('14', 'node', ' mauris porta magna eget dolor vestibulum dapibus general discussion lorem ipsum dolor sit amet consectetur adipiscing elit nullam aliquet auctor tellus quis pharetra massa blandit ac pellentesque feugiat pulvinar tincidunt duis consequat mollis massa ut iaculis cras commodo magna a ante auctor tempor quisque vehicula tortor lobortis euismod ultricies odio risus malesuada ipsum sed euismod enim mauris in tellus fusce vehicula augue a dui faucibus fringilla etiam ut purus id metus convallis porttitor nam porta facilisis mauris aliquam dapibus lectus imperdiet vitae praesent lobortis egestas nisi quis fringilla nibh ultrices ut etiam vel est rhoncus orci viverra placerat porttitor quis nibh quisque rutrum euismod odio a porttitor suspendisse rhoncus odio a tempus commodo eros ipsum viverra enim in condimentum tortor magna sed nisi vivamus quam metus condimentum in consectetur sed aliquet id felis etiam non leo nunc a cursus velit vestibulum sed urna ut mauris facilisis ullamcorper ut et libero in bibendum tristique lectus nulla facilisi mauris porta magna eget dolor vestibulum dapibus integer lacus est vulputate eget porttitor in ultricies id nunc sed luctus augue quis hendrerit tincidunt orci turpis placerat dolor et luctus neque nisl sed nunc ut id interdum massa proin a eros ut nibh rhoncus rhoncus at et mauris phasellus ornare odio in est mollis tristique morbi hendrerit rutrum porttitor donec scelerisque ipsum nisl sed porttitor ante morbi posuere leo congue risus fringilla id rutrum sapien aliquam nam a dolor quam maecenas posuere rhoncus est a auctor sed odio nulla pulvinar a dapibus in sollicitudin a lectus maecenas pretium consectetur eleifend ut pharetra ipsum at magna venenatis vel ullamcorper mauris laoreet sed lacinia urna vulputate venenatis eleifend libero urna rhoncus lorem a convallis nisl magna a neque quisque lobortis justo in ultricies scelerisque ante velit commodo urna sit amet placerat dui nisi vitae est vestibulum quis euismod leo vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia curae morbi ultrices mi vitae ante elementum posuere nunc dapibus risus eget malesuada pellentesque lorem turpis pellentesque tortor et rutrum est nibh quis nisl integer suscipit lectus sit amet nibh malesuada aliquam ut iaculis tristique felis nec placerat maecenas et neque risus integer ultricies varius dui a auctor vestibulum erat erat tincidunt et pellentesque eget mattis ut est donec id tortor quis mauris consequat pharetra duis commodo consectetur odio non tempor dui mollis non donec tempor urna vel porta sagittis mi diam dictum lectus sit amet egestas justo nisi in quam quisque blandit interdum imperdiet cum sociis natoque penatibus et magnis dis parturient montes nascetur ridiculus mus in eget feugiat metus integer urna enim congue in pharetra id rutrum non lectus aliquam urna nisi tempus a facilisis et varius vel justo duis cursus mollis sapien eget porta ipsum ultricies vel ut eu nisl nisi sit amet dapibus urna donec sit amet tempus sem nunc ipsum libero laoreet a accumsan eget ullamcorper quis tellus duis hendrerit tortor lectus etiam ornare tellus quis permalink submitted by admin on wed 5112011 1538 etiam ornare tellus quis facilisis eleifend sem enim ultrices sem ut convallis eros massa sed mauris nulla facilisi quisque eu neque eu erat bibendum pharetra a sit amet tortor fusce a augue ante in hac habitasse platea dictumst aliquam eu purus eu lorem placerat aliquam proin in ante vitae diam cursus condimentum donec commodo nunc eu enim placerat ut tempor tortor feugiat in porttitor lacinia mi sed condimentum nam imperdiet sapien fringilla felis auctor faucibus morbi feugiat dui vel mi facilisis eu molestie nisl sagittis lorem ipsum dolor sit amet consectetur adipiscing elit pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas praesent nisl nisi bibendum pulvinar blandit non pretium vitae metus quisque turpis justo facilisis in semper at semper in urna vivamus pellentesque sollicitudin erat at iaculis quisque ullamcorper nunc at enim convallis vehicula fusce vel mi ante aenean quam libero elementum et varius in eleifend hendrerit eros log in or register to post comments fusce gravida consectetur mi permalink submitted by admin on wed 5112011 1538 fusce gravida consectetur mi non tincidunt sed dictum lacinia mauris sed tempus ligula blandit ac nam et posuere quam integer dui orci vulputate et pulvinar lobortis lacinia vel elit duis accumsan scelerisque arcu sit amet lacinia urna faucibus sit amet pellentesque sed est mollis purus ornare gravida pellentesque interdum justo vel urna pretium tempor maecenas sed sapien arcu sit amet tempus eros pellentesque cursus tempus facilisis cras auctor mauris a sem vestibulum fermentum log in or register to post comments lorem ipsum dolor sit amet  permalink submitted by admin on wed 5112011 1538 lorem ipsum dolor sit amet consectetur adipiscing elit aliquam euismod viverra volutpat praesent orci neque pellentesque tempus pharetra quis laoreet eget dolor ut adipiscing auctor dignissim nam eu odio sit amet lacus accumsan congue ut tempor est condimentum urna posuere porttitor mauris orci purus adipiscing non cursus at lacinia et quam integer ullamcorper leo sit amet nulla venenatis sit amet vehicula diam pulvinar in hac habitasse platea dictumst suspendisse ante sapien gravida semper pretium sit amet sollicitudin id eros donec eget tellus sit amet magna malesuada consectetur pellentesque luctus leo mi suspendisse vulputate auctor magna tempus scelerisque vivamus vehicula rhoncus erat ut luctus mauris sed dui id lorem ornare consectetur ac lacinia tortor maecenas nunc leo placerat eget rhoncus a pellentesque at erat log in or register to post comments etiam ornare tellus quis permalink submitted by admin on wed 5112011 1538 etiam ornare tellus quis facilisis eleifend sem enim ultrices sem ut convallis eros massa sed mauris nulla facilisi quisque eu neque eu erat bibendum pharetra a sit amet tortor fusce a augue ante in hac habitasse platea dictumst aliquam eu purus eu lorem placerat aliquam proin in ante vitae diam cursus condimentum donec commodo nunc eu enim placerat ut tempor tortor feugiat in porttitor lacinia mi sed condimentum nam imperdiet sapien fringilla felis auctor faucibus morbi feugiat dui vel mi facilisis eu molestie nisl sagittis lorem ipsum dolor sit amet consectetur adipiscing elit pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas praesent nisl nisi bibendum pulvinar blandit non pretium vitae metus quisque turpis justo facilisis in semper at semper in urna vivamus pellentesque sollicitudin erat at iaculis quisque ullamcorper nunc at enim convallis vehicula fusce vel mi ante aenean quam libero elementum et varius in eleifend hendrerit eros log in or register to post comments sed ornare ipsum id libero permalink submitted by admin on wed 5112011 1538 sed ornare ipsum id libero interdum vel eleifend neque egestas mauris sodales urna vitae felis placerat venenatis class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos sed justo magna sagittis nec consequat id placerat sit amet magna praesent lacus metus aliquet ut sodales et porta ut nunc nulla id massa in erat imperdiet pulvinar duis ut metus in mi volutpat convallis et id mi fusce in mi sit amet augue faucibus elementum praesent odio tortor tincidunt ac lacinia sit amet pellentesque id dolor ut pretium imperdiet sem non ornare sem pretium ut maecenas sit amet arcu nisi log in or register to post comments  ', '0'),
('15', 'node', ' suspendisse potenti general discussion suspendisse potenti fusce diam risus mattis sit amet pretium in feugiat sed purus vivamus in lectus tellus nam justo leo placerat sit amet imperdiet ut accumsan quis nulla donec tristique tristique massa at malesuada nulla eleifend ultricies tempus nulla dapibus tempus pulvinar nullam urna sem vestibulum ac porttitor sit amet semper ut dui etiam at turpis sed risus auctor molestie eget quis lectus donec lacus tortor condimentum nec pharetra et adipiscing a sapien nulla ac ante diam pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas phasellus bibendum euismod lobortis phasellus semper elementum quam a iaculis morbi tristique diam id ante sagittis rutrum maecenas porttitor varius velit eget lacinia mi semper et ut aliquam augue at volutpat venenatis quam tellus gravida enim cursus blandit libero purus sed quam aliquam sollicitudin mauris ac tincidunt convallis erat neque mollis lacus quis placerat odio justo placerat purus duis in ipsum eu sem vestibulum imperdiet sed ac neque vivamus in augue massa nec aliquam nulla pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas pellentesque consequat imperdiet odio ut accumsan donec vel dolor sit amet ante mollis molestie at nec felis quisque sit amet mauris eget massa dictum tempus et mattis eros nunc tincidunt mattis massa et malesuada fusce tempus pulvinar nisi vitae consectetur neque iaculis sit amet aliquam erat volutpat fusce porttitor porta tortor pulvinar iaculis nulla facilisi etiam semper hendrerit lectus sit amet ultricies augue porta ut praesent vitae dolor vitae felis congue mollis nulla fermentum augue sit amet sem luctus dignissim class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos in dignissim tincidunt mollis sed sed massa lorem sed laoreet est pellentesque sit amet orci sed arcu euismod posuere id in nisl aenean in quam tortor curabitur consequat metus ut nulla viverra tincidunt in hac habitasse platea dictumst suspendisse hendrerit quam a dignissim pellentesque turpis risus bibendum massa quis lacinia sem sem eget est praesent magna nisi dignissim laoreet hendrerit lobortis gravida non velit nullam ut velit augue mauris mattis tellus elit et vehicula purus nulla eros libero pretium id elementum id euismod non risus donec enim nisi luctus quis vestibulum eu dapibus quis nisi cras porttitor sem sit amet metus fermentum pretium  ', '0'),
('16', 'node', ' pellentesque habitant morbi tristique senectus general discussion pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas in mollis gravida auctor fusce facilisis blandit quam at imperdiet magna blandit id in dignissim rutrum dolor a lobortis cras eros ligula volutpat sed condimentum ut blandit at enim cras ipsum leo euismod vitae consectetur at suscipit et turpis integer aliquet dui ac cursus ultricies nibh ante varius lectus et blandit libero nulla consectetur massa sed lobortis lacinia dui at cursus vivamus posuere diam eget libero placerat dapibus aliquam sit amet justo nisl duis tristique felis a porttitor dictum ipsum justo ultrices ante vel facilisis lectus risus sit amet quam mauris vel enim a ante luctus dignissim nunc rhoncus convallis dolor mauris sem ante aliquam vel vulputate eget tristique et tellus curabitur cursus leo eu aliquet tempus est massa fringilla metus nec mollis nisl nisi eget ante etiam cursus ante consequat nisi feugiat consectetur suspendisse potenti fusce diam risus mattis sit amet pretium in feugiat sed purus vivamus in lectus tellus nam justo leo placerat sit amet imperdiet ut accumsan quis nulla donec tristique tristique massa at malesuada nulla eleifend ultricies tempus nulla dapibus tempus pulvinar nullam urna sem vestibulum ac porttitor sit amet semper ut dui etiam at turpis sed risus auctor molestie eget quis lectus donec lacus tortor condimentum nec pharetra et adipiscing a sapien nulla ac ante diam pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas phasellus bibendum euismod lobortis phasellus semper elementum quam a iaculis morbi tristique diam id ante sagittis rutrum maecenas porttitor varius velit eget lacinia mi semper et ut aliquam augue at volutpat venenatis quam tellus gravida enim cursus blandit libero purus sed quam aliquam sollicitudin mauris ac tincidunt convallis erat neque mollis lacus quis placerat odio justo placerat purus duis in ipsum eu sem vestibulum imperdiet sed ac neque vivamus in augue massa nec aliquam nulla pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas pellentesque consequat imperdiet odio ut accumsan donec vel dolor sit amet ante mollis molestie at nec felis quisque sit amet mauris eget massa dictum tempus et mattis eros nunc tincidunt mattis massa et malesuada fusce tempus pulvinar nisi vitae consectetur neque iaculis sit amet aliquam erat volutpat suspendisse convallis risus permalink submitted by admin on wed 5112011 1539 suspendisse convallis risus a tempor gravida purus nunc condimentum lorem eget lacinia lectus augue eget ante cras aliquet luctus sapien sed euismod mi porttitor ut nam vulputate nulla eu tincidunt convallis leo neque elementum leo sit amet vulputate libero lectus in mauris praesent arcu ipsum rhoncus nec tincidunt quis rutrum a augue fusce congue lacus nec pharetra venenatis risus sapien congue purus non dictum tellus sem id enim donec imperdiet pharetra tempus duis ac augue nec urna iaculis aliquet sed malesuada semper mauris id cursus velit convallis rutrum phasellus pulvinar nulla a condimentum varius enim tortor porttitor sem adipiscing fringilla felis massa vitae mi pellentesque vestibulum elit non turpis convallis scelerisque integer scelerisque scelerisque lorem nec aliquam turpis molestie nec reply cum sociis natoque penatibus permalink submitted by admin on wed 5112011 1540 cum sociis natoque penatibus et magnis dis parturient montes nascetur ridiculus mus mauris sed tempor arcu suspendisse potenti fusce a nibh sed libero faucibus faucibus in hac habitasse platea dictumst lorem ipsum dolor sit amet consectetur adipiscing elit nullam ac velit ligula aliquam aliquam est vitae dui faucibus consectetur non at sapien class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos suspendisse velit ligula faucibus ac elementum vel sagittis vitae sapien sed nec sem ut dui venenatis lobortis phasellus et lorem vitae mi aliquet tincidunt nunc et sodales nulla donec eu diam a ante condimentum lobortis reply ', '0'),
('17', 'node', ' ut vehicula quam aliquam fringilla vestibulum eleifend convallis lorem ipsum dolor sit amet consectetur adipiscing elit suspendisse eu lectus erat morbi malesuada porta lacus id consequat magna aliquet quis vestibulum facilisis vehicula felis auctor ornare dolor sagittis in curabitur ac nunc ante vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia curae nam vehicula venenatis scelerisque pellentesque accumsan eleifend lectus in ornare erat pharetra ut vivamus faucibus feugiat varius nam vitae nisi libero cras scelerisque egestas lacus id porttitor sed in ipsum a nulla tincidunt luctus integer tempus urna et dapibus pharetra sapien purus eleifend quam quis convallis nisi quam non justo mauris nec magna tortor vitae cursus diam ut vehicula quam aliquam fringilla condimentum diam metus hendrerit nisl eu tempus erat ante et odio nulla elementum fermentum pulvinar ut ut enim urna nec auctor velit sed ac risus ligula etiam tincidunt tempus est sit amet mattis nibh fringilla sed in augue sapien congue et ornare ornare auctor at tortor praesent hendrerit ipsum pulvinar erat pharetra dictum in vel ligula nunc convallis porttitor ipsum at vestibulum velit vehicula eu fusce nisi dui imperdiet sed auctor ut porta in quam pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas nam nec est a nulla pulvinar dignissim eget quis enim integer facilisis ipsum et leo molestie et cursus mi tristique nullam placerat facilisis vehicula in bibendum commodo urna mollis volutpat justo ultricies et proin quis justo velit vestibulum posuere nulla sit amet risus aliquet aliquet ornare enim luctus quisque vel massa scelerisque erat ultrices placerat non id augue nulla commodo scelerisque massa ac iaculis eros ultricies a praesent ac odio sit amet odio mollis ultricies ac eu erat integer eu diam nibh nam cursus magna congue augue facilisis tempus vivamus dapibus eleifend scelerisque curabitur posuere sapien in sodales suscipit dolor metus pulvinar ante varius tincidunt mi metus ac sapien curabitur lectus lacus ullamcorper at bibendum sit amet congue vitae nisl  ', '0'),
('18', 'node', ' nam nec est a nulla pulvinar dignissim vestibulum eleifend convallis nam nec est a nulla pulvinar dignissim eget quis enim integer facilisis ipsum et leo molestie et cursus mi tristique nullam placerat facilisis vehicula in bibendum commodo urna mollis volutpat justo ultricies et proin quis justo velit vestibulum posuere nulla sit amet risus aliquet aliquet ornare enim luctus quisque vel massa scelerisque erat ultrices placerat non id augue nulla commodo scelerisque massa ac iaculis eros ultricies a praesent ac odio sit amet odio mollis ultricies ac eu erat integer eu diam nibh nam cursus magna congue augue facilisis tempus vivamus dapibus eleifend scelerisque curabitur posuere sapien in sodales suscipit dolor metus pulvinar ante varius tincidunt mi metus ac sapien curabitur lectus lacus ullamcorper at bibendum sit amet congue vitae nisl duis lobortis arcu dignissim mauris accumsan laoreet donec nisl risus tincidunt at interdum nec elementum vitae metus integer non diam nec est imperdiet sollicitudin duis ac massa in nibh lacinia pellentesque aenean ac metus ac dolor dapibus hendrerit vivamus mauris tellus fringilla quis tempus vehicula convallis sit amet ligula proin eget velit nec urna placerat congue vivamus malesuada libero id sagittis vehicula elit diam vulputate erat in aliquet mauris mi sed lacus nullam sodales viverra leo nec sollicitudin phasellus rhoncus gravida ullamcorper mauris a enim orci vestibulum eleifend convallis mi id sodales ante varius ut vivamus at tristique nisi nunc sem leo venenatis eu fermentum et ultrices ut enim nullam nec augue neque vitae posuere nisl in convallis sapien at ultrices gravida enim libero bibendum nunc eget interdum mauris neque at felis mauris tincidunt varius tellus quis condimentum felis dictum a nam porta tellus massa  ', '0'),
('19', 'node', ' in ac lectus massa pellentesque eros ligula vestibulum eleifend convallis in ac lectus massa pellentesque eros ligula elementum ut tincidunt nec sodales et ipsum etiam sed neque magna nullam aliquet dolor et augue malesuada sagittis nullam vitae metus odio at aliquet velit in leo arcu auctor in suscipit sed auctor vitae purus sed vel mauris ante vivamus placerat venenatis mauris ut consectetur donec condimentum sagittis arcu eu lobortis erat facilisis sed morbi justo dolor vulputate sed iaculis lacinia molestie at nunc curabitur laoreet accumsan elit nec venenatis odio faucibus eu praesent rhoncus massa id pellentesque congue est neque sagittis lacus a pulvinar quam neque vitae tortor nam in mauris mattis neque pretium fringilla sed consectetur tellus aenean nisi ante tempus eget egestas sit amet molestie sit amet neque fusce interdum mi a ligula euismod posuere maecenas auctor orci vitae viverra bibendum ante erat molestie nulla consectetur accumsan nulla nunc vel lacus sed pretium neque risus sit amet laoreet purus suspendisse mattis ligula ut erat auctor placerat suscipit sapien pulvinar nam ullamcorper nisl et ligula pretium mollis etiam convallis enim id volutpat gravida enim diam aliquet lectus et euismod nulla turpis quis leo vestibulum consectetur augue eu elit consectetur auctor praesent dui nibh tincidunt eu rutrum ut vulputate sit amet arcu etiam varius mauris non justo tincidunt tristique fusce vitae mi a ligula malesuada interdum vivamus feugiat arcu sed neque vestibulum sed vulputate est fermentum mauris interdum dui sed luctus rutrum mauris nibh venenatis leo nec euismod erat nunc ac augue proin justo elit dictum ac malesuada sed vehicula fringilla ligula in tempus lectus quis odio blandit commodo mauris aliquam tellus at elit bibendum blandit donec non ipsum a lorem lacinia iaculis sed purus eros scelerisque et consectetur sed dictum eget erat donec non magna ligula suspendisse a volutpat enim  ', '0'),
('20', 'node', ' suspendisse vulputate hendrerit nulla vestibulum eleifend convallis aenean nisi ante tempus eget egestas sit amet molestie sit amet neque fusce interdum mi a ligula euismod posuere maecenas auctor orci vitae viverra bibendum ante erat molestie nulla consectetur accumsan nulla nunc vel lacus sed pretium neque risus sit amet laoreet purus suspendisse mattis ligula ut erat auctor placerat suscipit sapien pulvinar nam ullamcorper nisl et ligula pretium mollis etiam convallis enim id volutpat gravida enim diam aliquet lectus et euismod nulla turpis quis leo vestibulum consectetur augue eu elit consectetur auctor praesent dui nibh tincidunt eu rutrum ut vulputate sit amet arcu etiam varius mauris non justo tincidunt tristique fusce vitae mi a ligula malesuada interdum vivamus feugiat arcu sed neque vestibulum sed vulputate est fermentum mauris interdum dui sed luctus rutrum mauris nibh venenatis leo nec euismod erat nunc ac augue proin justo elit dictum ac malesuada sed vehicula fringilla ligula in tempus lectus quis odio blandit commodo mauris aliquam tellus at elit bibendum blandit donec non ipsum a lorem lacinia iaculis sed purus eros scelerisque et consectetur sed dictum eget erat donec non magna ligula suspendisse a volutpat enim suspendisse vulputate hendrerit nulla eget adipiscing nibh rutrum non praesent in accumsan risus praesent quis eros sem ac mattis eros curabitur erat ante porttitor et euismod et molestie a massa donec vitae urna quis nibh pretium eleifend fusce orci leo gravida nec venenatis sit amet interdum vitae dui duis vel condimentum neque in a justo nulla in hac habitasse platea dictumst curabitur vehicula eros sed lectus pellentesque facilisis morbi accumsan lorem sit amet purus posuere sed vulputate quam luctus fusce molestie urna at tempor pulvinar massa purus vehicula neque consectetur consequat nibh mi et leo proin id rhoncus arcu etiam vestibulum bibendum nisi nec eleifend donec velit turpis tincidunt sit amet varius eu rhoncus sed risus sed rhoncus dignissim arcu eu dignissim justo tempus ut fusce interdum lectus massa sit amet rhoncus sem mauris aliquam tempor lorem id mollis pellentesque vehicula nunc eu risus condimentum et placerat turpis dignissim donec scelerisque tellus sed massa ullamcorper molestie pellentesque sem metus vestibulum rhoncus hendrerit sed venenatis a ipsum duis sit amet dui velit id rhoncus neque etiam leo risus tincidunt at pharetra eget sodales sit amet lacus class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos duis eleifend sem ut iaculis pharetra sem mauris porttitor ligula et molestie orci augue et nibh ut vulputate aliquam tortor eu tristique nisl euismod et phasellus eget mauris ut metus mattis ullamcorper ut a orci nullam quam leo vulputate id condimentum id fermentum vitae urna donec eget lacus at tortor interdum elementum sed vulputate gravida nisi ac venenatis nisi blandit id curabitur ac nibh nibh ut ut neque urna nunc ullamcorper massa fermentum lacus elementum fringilla pellentesque quis metus a leo egestas vehicula  ', '0'),
('21', 'node', ' lorem ipsum dolor sit amet duis lobortis arcu dignissim mauris lorem ipsum dolor sit amet consectetur adipiscing elit donec vestibulum ultrices mollis sed id purus mattis leo pulvinar hendrerit quis non turpis donec eleifend malesuada lorem ac sagittis dui tempus id duis risus mi fringilla sit amet elementum in vulputate non orci mauris at pharetra elit curabitur libero orci elementum iaculis congue nec placerat a lorem nunc ornare leo id condimentum dictum metus ante mattis felis a venenatis urna magna a nisi donec hendrerit malesuada egestas mauris ligula tellus bibendum in pellentesque et cursus volutpat augue ut sollicitudin libero id purus dignissim pellentesque laoreet massa pharetra cras dignissim tortor quis erat hendrerit ut adipiscing elit laoreet sed hendrerit convallis pretium nunc quis turpis turpis at adipiscing neque sed mi nisi pulvinar non posuere non varius et lacus vestibulum risus metus vehicula nec ornare eget ultrices non tortor in vulputate turpis ipsum sed cursus mi sed elit sem tristique id tempor eu molestie et magna vestibulum porta nisl a urna tincidunt eget tristique leo blandit proin dictum libero eget aliquet dictum nisi mi venenatis sem sed rhoncus turpis nibh rhoncus elit cras porttitor nunc eu tincidunt vulputate enim dolor viverra ipsum vel eleifend risus justo vel neque proin hendrerit vestibulum diam at imperdiet enim rutrum eu curabitur eros augue iaculis in mollis sit amet tincidunt vitae turpis maecenas eu erat vel massa scelerisque mollis sed in ligula duis consectetur congue felis a porta pellentesque turpis nisl faucibus et blandit nec mattis vel purus nulla facilisi ut viverra fermentum felis nec dapibus massa suscipit ut vestibulum id ligula lacus et tristique libero cras euismod aliquet massa scelerisque euismod phasellus tincidunt eros sit amet cursus porta neque velit tincidunt lacus non mattis risus augue ut erat phasellus facilisis ornare massa ac porttitor erat hendrerit eget cras porttitor aliquet aliquam phasellus at mauris vitae metus pharetra semper aliquam mi ligula commodo ut pharetra quis bibendum ac odio nullam tincidunt nulla vel massa lacinia varius ut tortor urna faucibus vel posuere ut hendrerit eu ante pellentesque porttitor iaculis sem a adipiscing sapien commodo sit amet duis non massa quis leo fringilla aliquam phasellus fermentum congue velit sed blandit ante non ornare iaculis turpis mauris consectetur nunc id venenatis turpis odio et ante pellentesque bibendum tincidunt justo porta dictum vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia curae lorem ipsum dolor sit amet consectetur adipiscing elit mauris neque eros pretium nec cursus sit amet mattis vitae felis vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia curae aenean vel magna vitae felis euismod congue a at magna donec varius mattis diam vitae ultricies nisi vehicula eu  ', '0'),
('22', 'node', ' cras euismod aliquet massa scelerisque euismo duis lobortis arcu dignissim mauris cras euismod aliquet massa scelerisque euismod phasellus tincidunt eros sit amet cursus porta neque velit tincidunt lacus non mattis risus augue ut erat phasellus facilisis ornare massa ac porttitor erat hendrerit eget cras porttitor aliquet aliquam phasellus at mauris vitae metus pharetra semper aliquam mi ligula commodo ut pharetra quis bibendum ac odio nullam tincidunt nulla vel massa lacinia varius ut tortor urna faucibus vel posuere ut hendrerit eu ante pellentesque porttitor iaculis sem a adipiscing sapien commodo sit amet duis non massa quis leo fringilla aliquam phasellus fermentum congue velit sed blandit ante non ornare iaculis turpis mauris consectetur nunc id venenatis turpis odio et ante pellentesque bibendum tincidunt justo porta dictum vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia curae lorem ipsum dolor sit amet consectetur adipiscing elit mauris neque eros pretium nec cursus sit amet mattis vitae felis vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia curae aenean vel magna vitae felis euismod congue a at magna donec varius mattis diam vitae ultricies nisi vehicula eu cras congue porttitor ipsum nec pulvinar risus adipiscing ac nam vel augue nibh phasellus metus lectus placerat eu posuere ac molestie vel diam quisque blandit elit in neque vehicula eu fringilla tortor volutpat sed non turpis pretium lorem hendrerit pretium in ac dolor pellentesque semper volutpat urna vel dictum nunc tempor neque nec elementum luctus turpis dui lacinia est vitae placerat nibh mauris eu ipsum integer vel orci a quam posuere malesuada eget et turpis nunc porttitor quam non rutrum iaculis odio tellus condimentum tortor ut dapibus neque urna quis est phasellus ac lectus sed nisi pulvinar consectetur sed urna nulla aliquam et ullamcorper at porta quis libero duis sed est dolor morbi quam erat sagittis volutpat tristique at blandit non arcu suspendisse potenti praesent a metus odio proin eros ligula accumsan eu bibendum id rutrum sed urna phasellus quis suscipit mi vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia curae sed imperdiet velit nec semper mattis elit tellus ultricies nibh id bibendum justo lacus sit amet urna aliquam lacus risus condimentum ut accumsan non pretium vel leo praesent vel orci eget tortor molestie fringilla at et erat integer adipiscing gravida lobortis quisque varius metus in egestas sollicitudin risus lacus tempor erat quis ullamcorper arcu magna nec mauris aenean tempus sapien nibh ut ultrices enim vivamus in nulla massa vel aliquam dui suspendisse potenti class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos proin condimentum sapien sed ante sodales lobortis suspendisse et lectus id nibh lacinia ultricies cras commodo laoreet ullamcorper cum sociis natoque penatibus et magnis dis parturient montes nascetur ridiculus mus quisque diam tortor tincidunt nec lacinia vel suscipit id tellus pellentesque vitae semper ipsum  ', '0'),
('23', 'node', ' cras euismod aliquet massa scelerisque duis lobortis arcu dignissim mauris lorem ipsum dolor sit amet consectetur adipiscing elit donec vestibulum ultrices mollis sed id purus mattis leo pulvinar hendrerit quis non turpis donec eleifend malesuada lorem ac sagittis dui tempus id duis risus mi fringilla sit amet elementum in vulputate non orci mauris at pharetra elit curabitur libero orci elementum iaculis congue nec placerat a lorem nunc ornare leo id condimentum dictum metus ante mattis felis a venenatis urna magna a nisi donec hendrerit malesuada egestas mauris ligula tellus bibendum in pellentesque et cursus volutpat augue ut sollicitudin libero id purus dignissim pellentesque laoreet massa pharetra cras dignissim tortor quis erat hendrerit ut adipiscing elit laoreet sed hendrerit convallis pretium nunc quis turpis turpis at adipiscing neque sed mi nisi pulvinar non posuere non varius et lacus vestibulum risus metus vehicula nec ornare eget ultrices non tortor in vulputate turpis ipsum sed cursus mi sed elit sem tristique id tempor eu molestie et magna vestibulum porta nisl a urna tincidunt eget tristique leo blandit proin dictum libero eget aliquet dictum nisi mi venenatis sem sed rhoncus turpis nibh rhoncus elit cras porttitor nunc eu tincidunt vulputate enim dolor viverra ipsum vel eleifend risus justo vel neque proin hendrerit vestibulum diam at imperdiet enim rutrum eu curabitur eros augue iaculis in mollis sit amet tincidunt vitae turpis maecenas eu erat vel massa scelerisque mollis sed in ligula duis consectetur congue felis a porta pellentesque turpis nisl faucibus et blandit nec mattis vel purus nulla facilisi ut viverra fermentum felis nec dapibus massa suscipit ut vestibulum id ligula lacus et tristique libero cras euismod aliquet massa scelerisque euismod phasellus tincidunt eros sit amet cursus porta neque velit tincidunt lacus non mattis risus augue ut erat phasellus facilisis ornare massa ac porttitor erat hendrerit eget cras porttitor aliquet aliquam phasellus at mauris vitae metus pharetra semper aliquam mi ligula commodo ut pharetra quis bibendum ac odio nullam tincidunt nulla vel massa lacinia varius ut tortor urna faucibus vel posuere ut hendrerit eu ante pellentesque porttitor iaculis sem a adipiscing sapien commodo sit amet duis non massa quis leo fringilla aliquam phasellus fermentum congue velit sed blandit ante non ornare iaculis turpis mauris consectetur nunc id venenatis turpis odio et ante pellentesque bibendum tincidunt justo porta dictum vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia curae lorem ipsum dolor sit amet consectetur adipiscing elit mauris neque eros pretium nec cursus sit amet mattis vitae felis vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia curae aenean vel magna vitae felis euismod congue a at magna donec varius mattis diam vitae ultricies nisi vehicula eu  ', '0'),
('24', 'node', ' praesent non mauris eget nisi duis lobortis arcu dignissim mauris lorem ipsum dolor sit amet consectetur adipiscing elit integer in mollis turpis nam faucibus porta magna molestie faucibus enim posuere vel class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos nullam id libero facilisis augue euismod eleifend mauris quam eros scelerisque quis pharetra nec ornare ac justo etiam euismod felis vel odio rutrum fringilla ut non libero sit amet mauris eleifend auctor non non est morbi ullamcorper odio a orci scelerisque vehicula eget ac tortor cras condimentum orci ac arcu elementum non vehicula nisi rhoncus donec libero dolor dignissim in ultrices vel lacinia tempus elit nam sed ipsum ligula fusce interdum consequat neque a varius praesent scelerisque nisl a dictum pulvinar justo tellus lobortis diam eget ultricies nunc felis ut leo morbi pretium congue tellus at imperdiet ut nec mauris sit amet nibh ornare dapibus vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia curae praesent non mauris eget nisi porta dignissim in vitae sem duis condimentum iaculis nulla vel ullamcorper praesent et urna risus vel fermentum ante donec neque ipsum suscipit sed dictum a sodales ut tellus nullam et varius enim aliquam sed eros et leo adipiscing scelerisque maecenas varius pulvinar sodales maecenas a justo lectus mauris non sapien a arcu varius gravida vel at urna suspendisse at tortor augue proin eleifend blandit neque ut sodales risus porttitor in suspendisse pretium quam quis nunc fermentum vitae vulputate sapien dictum aliquam erat volutpat maecenas et justo odio praesent molestie lacus eu felis commodo ac rutrum sem commodo nullam blandit dolor ac felis euismod quis pellentesque purus consequat morbi ut molestie nisi nullam quam odio rhoncus vitae adipiscing at dictum ac libero fusce ac lacus metus et molestie mi nunc eleifend eleifend mauris at feugiat risus convallis sit amet suspendisse sem velit dignissim vitae vehicula sit amet mollis vel massa curabitur volutpat ligula eu lobortis elementum velit sapien sodales mi vitae dapibus mi lorem convallis sem maecenas ac purus luctus lacus tempus mattis sed vitae diam vivamus nec ullamcorper diam mauris nec est eu mi venenatis accumsan non id nisi integer pellentesque aliquam vulputate donec volutpat enim nec leo iaculis tempus duis ultrices ornare tortor eget lobortis  ', '0'),
('25', 'node', ' suspendisse tempor libero sed ip integer metus orci vestibulum fusce ac lacus metus et molestie mi nunc eleifend eleifend mauris at feugiat risus convallis sit amet suspendisse sem velit dignissim vitae vehicula sit amet mollis vel massa curabitur volutpat ligula eu lobortis elementum velit sapien sodales mi vitae dapibus mi lorem convallis sem maecenas ac purus luctus lacus tempus mattis sed vitae diam vivamus nec ullamcorper diam mauris nec est eu mi venenatis accumsan non id nisi integer pellentesque aliquam vulputate donec volutpat enim nec leo iaculis tempus duis ultrices ornare tortor eget lobortis suspendisse tempor libero sed ipsum imperdiet semper dapibus tortor laoreet suspendisse vitae sem dolor etiam sollicitudin tortor ut metus aliquet ullamcorper vivamus vel nulla id lorem tincidunt bibendum praesent malesuada tortor est aenean et dolor est tempus elementum libero proin massa nulla condimentum ut volutpat sit amet aliquet vitae orci morbi tincidunt ligula at diam venenatis hendrerit dignissim felis condimentum quisque iaculis erat non tristique mattis libero ligula ultricies massa vel scelerisque lorem eros eu lectus donec bibendum lacus sed scelerisque pretium tellus leo pretium sem id egestas elit ante sit amet est mauris pellentesque tortor at pellentesque vehicula massa ligula posuere lectus a dignissim urna magna eu eros donec in dui id tortor cursus lobortis phasellus placerat malesuada arcu at vehicula morbi sagittis ipsum vel diam aliquam in viverra lorem pellentesque donec laoreet tincidunt risus aenean ut diam in turpis consequat aliquet ut libero dui tempor vel sagittis eu fringilla a nisi aenean orci lectus cursus et viverra eu pharetra malesuada elit duis nec eros nibh sit amet suscipit ipsum lorem ipsum dolor sit amet consectetur adipiscing elit ut malesuada ultrices rhoncus donec dignissim tincidunt aliquam donec tempus dapibus augue at dictum sapien sodales et curabitur a orci nulla integer pulvinar nisi vel turpis pellentesque interdum praesent auctor scelerisque facilisis maecenas eget diam congue justo suscipit adipiscing aenean sit amet nunc massa in placerat leo suspendisse pharetra odio eu quam dapibus sagittis pellentesque feugiat mattis ultricies  ', '0'),
('26', 'node', ' fusce ac lacus metu integer metus orci vestibulum praesent non mauris eget nisi porta dignissim in vitae sem duis condimentum iaculis nulla vel ullamcorper praesent et urna risus vel fermentum ante donec neque ipsum suscipit sed dictum a sodales ut tellus nullam et varius enim aliquam sed eros et leo adipiscing scelerisque maecenas varius pulvinar sodales maecenas a justo lectus mauris non sapien a arcu varius gravida vel at urna suspendisse at tortor augue proin eleifend blandit neque ut sodales risus porttitor in suspendisse pretium quam quis nunc fermentum vitae vulputate sapien dictum aliquam erat volutpat maecenas et justo odio praesent molestie lacus eu felis commodo ac rutrum sem commodo nullam blandit dolor ac felis euismod quis pellentesque purus consequat morbi ut molestie nisi nullam quam odio rhoncus vitae adipiscing at dictum ac libero fusce ac lacus metus et molestie mi nunc eleifend eleifend mauris at feugiat risus convallis sit amet suspendisse sem velit dignissim vitae vehicula sit amet mollis vel massa curabitur volutpat ligula eu lobortis elementum velit sapien sodales mi vitae dapibus mi lorem convallis sem maecenas ac purus luctus lacus tempus mattis sed vitae diam vivamus nec ullamcorper diam mauris nec est eu mi venenatis accumsan non id nisi integer pellentesque aliquam vulputate donec volutpat enim nec leo iaculis tempus duis ultrices ornare tortor eget lobortis suspendisse tempor libero sed ipsum imperdiet semper dapibus tortor laoreet suspendisse vitae sem dolor etiam sollicitudin tortor ut metus aliquet ullamcorper vivamus vel nulla id lorem tincidunt bibendum praesent malesuada tortor est aenean et dolor est tempus elementum libero proin massa nulla condimentum ut volutpat sit amet aliquet vitae orci morbi tincidunt ligula at diam venenatis hendrerit dignissim felis condimentum quisque iaculis erat non tristique mattis libero ligula ultricies massa vel scelerisque lorem eros eu lectus donec bibendum lacus sed scelerisque pretium tellus leo pretium sem id egestas elit ante sit amet est mauris pellentesque tortor at pellentesque vehicula massa ligula posuere lectus a dignissim urna magna eu eros donec in dui id tortor cursus lobortis phasellus placerat malesuada arcu at vehicula morbi sagittis ipsum vel diam aliquam in viverra lorem pellentesque donec laoreet tincidunt risus aenean ut diam in turpis consequat aliquet ut libero dui tempor vel sagittis eu fringilla a nisi aenean orci lectus cursus et viverra eu pharetra malesuada elit duis nec eros nibh sit amet suscipit ipsum  ', '0'),
('27', 'node', ' curabitur feugiat ornare pul integer metus orci vestibulum curabitur feugiat ornare pulvinar phasellus mi urna tempor ut porttitor in facilisis id sapien pellentesque egestas erat laoreet felis aliquam tempus fusce turpis sem auctor et viverra non faucibus quis mauris sed feugiat libero ut egestas malesuada magna elit laoreet augue fermentum tristique metus dolor vitae leo nam vel quam in nisl feugiat elementum consectetur a turpis fusce dictum risus augue nam vel arcu nulla pellentesque pulvinar mauris duis eros libero tristique posuere adipiscing id dictum eget dui phasellus at neque metus nam aliquet venenatis ante sit amet pulvinar arcu ultricies eget suspendisse potenti in sagittis tempor nisi at egestas sem ultricies a nullam ac dolor id leo scelerisque accumsan sit amet id neque suspendisse ullamcorper feugiat magna quis condimentum ante luctus at morbi semper luctus quam non mattis aenean sed risus nisl praesent posuere vehicula neque aliquet luctus pellentesque tempus hendrerit gravida donec accumsan nisi ut dolor dapibus ac luctus diam hendrerit suspendisse sit amet mattis neque sed et rhoncus odio cras euismod pretium mauris eget facilisis eros aliquam quis suspendisse ut ante lacus nullam ut vulputate velit aliquam felis nulla eleifend in lobortis a semper non velit nam ac felis elit at euismod lacus integer fermentum arcu viverra nulla luctus scelerisque duis condimentum neque non orci pretium suscipit in vel ante eget lacus placerat hendrerit  ', '0');
INSERT INTO `search_dataset` VALUES
('28', 'node', ' suspendisse potenti nam nec est a nulla pulvinar suspendisse potenti in sagittis tempor nisi at egestas sem ultricies a nullam ac dolor id leo scelerisque accumsan sit amet id neque suspendisse ullamcorper feugiat magna quis condimentum ante luctus at morbi semper luctus quam non mattis aenean sed risus nisl praesent posuere vehicula neque aliquet luctus pellentesque tempus hendrerit gravida donec accumsan nisi ut dolor dapibus ac luctus diam hendrerit suspendisse sit amet mattis neque sed et rhoncus odio cras euismod pretium mauris eget facilisis eros aliquam quis suspendisse ut ante lacus nullam ut vulputate velit aliquam felis nulla eleifend in lobortis a semper non velit nam ac felis elit at euismod lacus integer fermentum arcu viverra nulla luctus scelerisque duis condimentum neque non orci pretium suscipit in vel ante eget lacus placerat hendrerit phasellus at nibh nisl curabitur nec eros ut neque ultrices luctus vivamus dapibus interdum nibh sit amet dictum vestibulum rutrum pharetra lacus quis congue risus consequat non duis eget luctus erat nullam faucibus neque non eros bibendum iaculis pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas morbi sed tempus massa pellentesque tortor nulla pharetra id pharetra quis ornare et lectus donec quis lacus nec lectus consequat eleifend id at lorem donec sodales lacinia nisl a venenatis lacus scelerisque eget sed sagittis turpis nec metus dictum dapibus quisque luctus elit vel sapien porta vel consectetur dolor blandit cras at erat eu erat egestas mollis sed nec augue et nibh sollicitudin facilisis vitae nec odio donec luctus fringilla viverra cras mattis commodo leo ut gravida erat rutrum in vivamus feugiat sodales egestas phasellus eros sem convallis at scelerisque eu adipiscing a urna fusce quis molestie sapien nunc vestibulum tincidunt dolor eget accumsan cras ornare laoreet augue lacinia rutrum dui semper eget cras aliquam odio ac turpis egestas consectetur in vulputate congue lacinia pellentesque ullamcorper nulla quis augue ullamcorper ut dictum massa lacinia phasellus ultrices urna ut scelerisque iaculis massa nunc dignissim augue ac placerat odio nibh sed urna nulla gravida sem suscipit risus fringilla sit amet aliquet turpis consectetur sed placerat convallis enim in bibendum risus cursus vitae suspendisse non justo leo nam consectetur consectetur libero quis facilisis duis ac arcu nec enim euismod rutrum etiam velit quam laoreet in blandit consectetur congue at leo aenean tempor arcu ac aliquet tincidunt massa odio dictum enim eget mollis justo nisi sit amet ligula nunc ipsum quam mollis sed commodo in aliquet sed lacus nunc vehicula justo vel consequat placerat dolor erat placerat leo ac vestibulum justo diam ac mauris vivamus id sem at elit mollis ultricies porta nec magna sed aliquet tincidunt pellentesque  ', '0'),
('29', 'node', ' curabitur feugiat ornare pulv nam nec est a nulla pulvinar lorem ipsum dolor sit amet consectetur adipiscing elit quisque sollicitudin elit nec purus ultricies rhoncus nulla non pellentesque ligula praesent porttitor nunc sit amet odio varius vitae venenatis nunc euismod phasellus erat felis eleifend porttitor lacinia in vehicula quis elit curabitur dui eros blandit vel mollis et molestie eu arcu aenean sagittis ligula vel purus elementum vel fringilla lorem mollis sed scelerisque risus ut metus vehicula a vehicula sem pharetra sed at ligula eget diam ullamcorper porta cras sagittis posuere ante a accumsan eros feugiat in vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia curae nulla pellentesque augue sed metus dapibus vitae convallis purus laoreet cras ultrices nulla vel erat sagittis tristique quis quis libero proin suscipit sapien quis risus interdum elementum duis tempor luctus velit fusce vel consequat est curabitur feugiat ornare pulvinar phasellus mi urna tempor ut porttitor in facilisis id sapien pellentesque egestas erat laoreet felis aliquam tempus fusce turpis sem auctor et viverra non faucibus quis mauris sed feugiat libero ut egestas malesuada magna elit laoreet augue fermentum tristique metus dolor vitae leo nam vel quam in nisl feugiat elementum consectetur a turpis fusce dictum risus augue nam vel arcu nulla pellentesque pulvinar mauris duis eros libero tristique posuere adipiscing id dictum eget dui phasellus at neque metus nam aliquet venenatis ante sit amet pulvinar arcu ultricies eget suspendisse potenti in sagittis tempor nisi at egestas sem ultricies a nullam ac dolor id leo scelerisque accumsan sit amet id neque suspendisse ullamcorper feugiat magna quis condimentum ante luctus at morbi semper luctus quam non mattis aenean sed risus nisl praesent posuere vehicula neque aliquet luctus pellentesque tempus hendrerit gravida donec accumsan nisi ut dolor dapibus ac luctus diam hendrerit suspendisse sit amet mattis neque sed et rhoncus odio cras euismod pretium mauris eget facilisis eros aliquam quis suspendisse ut ante lacus nullam ut vulputate velit aliquam felis nulla eleifend in lobortis a semper non velit nam ac felis elit at euismod lacus integer fermentum arcu viverra nulla luctus scelerisque duis condimentum neque non orci pretium suscipit in vel ante eget lacus placerat hendrerit  ', '0'),
('30', 'node', ' entesque tempus hend nam nec est a nulla pulvinar suspendisse potenti in sagittis tempor nisi at egestas sem ultricies a nullam ac dolor id leo scelerisque accumsan sit amet id neque suspendisse ullamcorper feugiat magna quis condimentum ante luctus at morbi semper luctus quam non mattis aenean sed risus nisl praesent posuere vehicula neque aliquet luctus pellentesque tempus hendrerit gravida donec accumsan nisi ut dolor dapibus ac luctus diam hendrerit suspendisse sit amet mattis neque sed et rhoncus odio cras euismod pretium mauris eget facilisis eros aliquam quis suspendisse ut ante lacus nullam ut vulputate velit aliquam felis nulla eleifend in lobortis a semper non velit nam ac felis elit at euismod lacus integer fermentum arcu viverra nulla luctus scelerisque duis condimentum neque non orci pretium suscipit in vel ante eget lacus placerat hendrerit phasellus at nibh nisl curabitur nec eros ut neque ultrices luctus vivamus dapibus interdum nibh sit amet dictum vestibulum rutrum pharetra lacus quis congue risus consequat non duis eget luctus erat nullam faucibus neque non eros bibendum iaculis pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas morbi sed tempus massa pellentesque tortor nulla pharetra id pharetra quis ornare et lectus donec quis lacus nec lectus consequat eleifend id at lorem donec sodales lacinia nisl a venenatis lacus scelerisque eget sed sagittis turpis nec metus dictum dapibus quisque luctus elit vel sapien porta vel consectetur dolor blandit cras at erat eu erat egestas mollis sed nec augue et nibh sollicitudin facilisis vitae nec odio donec luctus fringilla viverra cras mattis commodo leo ut gravida erat rutrum in vivamus feugiat sodales egestas phasellus eros sem convallis at scelerisque eu adipiscing a urna  ', '0'),
('31', 'node', ' rius metus consequat sollicit nam nec est a nulla pulvinar curabitur eu nibh non odio congue scelerisque consectetur eu justo duis ornare interdum sollicitudin suspendisse pretium pharetra rhoncus pellentesque luctus lacinia luctus donec tempor viverra nunc vel luctus massa consequat ac morbi auctor neque et consectetur aliquam est leo ultricies magna at volutpat ante ante ut sem sed cursus porta venenatis aliquam turpis massa bibendum sit amet hendrerit eleifend dictum in mauris vivamus ultrices urna nec ipsum pretium quis euismod ligula sollicitudin nam cursus molestie condimentum ut aliquet arcu id magna porttitor consequat proin at ultricies eros curabitur non metus ac neque tempus semper donec non nulla id purus congue elementum nunc sollicitudin metus sit amet mauris iaculis eget lacinia enim tempor phasellus eleifend sodales elit eu dignissim augue faucibus et in ac arcu eget risus facilisis laoreet nunc vel placerat libero duis egestas porta lectus et egestas ante vestibulum ac ut sit amet dui nibh pretium hendrerit lectus curabitur imperdiet euismod tortor id consectetur felis ultricies vel sed sagittis accumsan nibh sit amet fermentum sapien mattis non nulla congue quam sed eros iaculis at sagittis mi ornare donec rhoncus euismod elit sit amet tempus odio porta vel proin hendrerit libero eu tempor porttitor nisl eros ultricies urna eget sagittis metus ante tristique erat ut ac diam sit amet leo venenatis eleifend vivamus libero neque tristique id mollis id volutpat sit amet ipsum vivamus lobortis erat tempor fermentum facilisis sem arcu lacinia risus at euismod enim neque eu magna fusce elementum enim nec venenatis pretium sapien eros varius metus consequat sollicitudin sapien nibh et erat phasellus consequat felis non quam sodales in scelerisque nibh imperdiet nulla in leo massa quisque magna urna posuere eget molestie eu venenatis sit amet nulla maecenas lacus diam elementum sit amet vulputate sit amet pulvinar in metus in egestas arcu sit amet pharetra ornare urna libero vulputate est sed cursus dolor libero quis eros quisque venenatis porta arcu ut consectetur donec ac magna non tellus tempus aliquam sed at nisl nullam orci massa ultrices ac dictum non tincidunt ac odio phasellus pharetra elementum massa quis porta neque pretium quis  ', '0'),
('32', 'node', ' aliquam vitae nunc metus nam nec est a nulla pulvinar aenean quis mattis magna in pulvinar interdum mauris in ornare fusce molestie erat id sapien aliquam pharetra suspendisse ornare tincidunt magna sed sed turpis justo donec eleifend justo vel bibendum blandit est sem tempus lorem vel ultricies felis eros non est praesent ac dolor eu justo vestibulum dapibus maecenas id odio lectus in interdum libero in hac habitasse platea dictumst praesent sed urna turpis sit amet auctor sem pellentesque sit amet ante sit amet diam imperdiet ultrices proin congue iaculis semper vivamus mi enim dapibus quis laoreet at hendrerit sit amet eros nulla ut lacinia nisi nullam eu erat nibh aliquam ipsum sapien interdum a euismod vitae vehicula pellentesque dolor in sit amet eros pretium eros aliquet semper eget id massa donec malesuada rutrum est sed neque est ultricies ac dictum at tincidunt at arcu in hac habitasse platea dictumst cras posuere convallis mattis quisque blandit ullamcorper ligula dapibus tincidunt dolor lacinia non aliquam vitae nunc metus fusce nec sem sapien morbi pharetra pharetra purus eu condimentum phasellus pulvinar imperdiet mi vitae pellentesque nullam sed urna porta ligula tempus venenatis a at metus proin feugiat nulla nec mi hendrerit ut iaculis purus pulvinar suspendisse id magna lacus vel consequat arcu vestibulum non nulla felis in tempor magna aliquam lacinia iaculis leo eu consequat mauris molestie nec mauris facilisis facilisis eros quis pretium ipsum consectetur quis vestibulum sed massa vitae felis porta elementum nulla facilisi sed turpis mi ultrices sed blandit sit amet rutrum et tellus proin luctus egestas turpis eget luctus dolor mattis a nam sed rutrum diam sed quis nisl nisl eu fringilla diam  ', '0'),
('33', 'node', ' aliquam lacinia iaculis leo ut vehicula quam aliquam morbi pharetra pharetra purus eu condimentum phasellus pulvinar imperdiet mi vitae pellentesque nullam sed urna porta ligula tempus venenatis a at metus proin feugiat nulla nec mi hendrerit ut iaculis purus pulvinar suspendisse id magna lacus vel consequat arcu vestibulum non nulla felis in tempor magna aliquam lacinia iaculis leo eu consequat mauris molestie nec mauris facilisis facilisis eros quis pretium ipsum consectetur quis vestibulum sed massa vitae felis porta elementum nulla facilisi sed turpis mi ultrices sed blandit sit amet rutrum et tellus proin luctus egestas turpis eget luctus dolor mattis a nam sed rutrum diam sed quis nisl nisl eu fringilla diam aliquam vel euismod nulla aliquam erat volutpat fusce porta augue vitae felis dignissim pulvinar morbi non elit orci vestibulum erat libero ultricies non egestas ut aliquet in turpis aliquam erat volutpat in mollis neque a sodales convallis nulla felis luctus nisl non fringilla metus neque eu augue suspendisse lacinia enim a quam pretium tempus class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos mauris adipiscing ultrices nibh interdum iaculis diam ultricies ut maecenas suscipit enim a suscipit congue ipsum mi tempor elit pretium luctus lorem purus vestibulum diam etiam sodales turpis vel tortor sagittis sodales donec tellus turpis consequat eget facilisis nec interdum quis nulla proin bibendum mollis mattis proin at eros vitae nulla sagittis sollicitudin nec vel odio nam sed nibh vitae mauris viverra rhoncus aenean ut lectus eu massa gravida sodales id sed nulla donec semper justo facilisis mauris aliquam suscipit aenean ut dignissim est  ', '0'),
('34', 'node', ' lorem ipsum dolor sit am ut vehicula quam aliquam lorem ipsum dolor sit amet consectetur adipiscing elit etiam aliquet ipsum eget sodales blandit neque purus lacinia nulla quis sagittis elit lectus fringilla massa donec commodo quam eget nunc vestibulum nec venenatis nibh iaculis cum sociis natoque penatibus et magnis dis parturient montes nascetur ridiculus mus curabitur lobortis suscipit porttitor fusce massa elit consequat eu tincidunt et consectetur ut est in ligula tortor scelerisque a condimentum id venenatis vel est donec laoreet dictum nisi eget egestas sed malesuada erat vel magna dictum sit amet volutpat sem ornare fusce bibendum tellus sit amet elementum porta ligula enim luctus orci eget tristique magna eros sit amet sem phasellus placerat lacinia placerat sed porttitor nulla quis ullamcorper tempor risus erat sollicitudin enim tincidunt iaculis massa mi sit amet dolor vivamus molestie odio ut velit pellentesque sagittis in vitae turpis vel est semper eleifend aenean quis mattis magna in pulvinar interdum mauris in ornare fusce molestie erat id sapien aliquam pharetra suspendisse ornare tincidunt magna sed sed turpis justo donec eleifend justo vel bibendum blandit est sem tempus lorem vel ultricies felis eros non est praesent ac dolor eu justo vestibulum dapibus maecenas id odio lectus in interdum libero in hac habitasse platea dictumst praesent sed urna turpis sit amet auctor sem pellentesque sit amet ante sit amet diam imperdiet ultrices proin congue iaculis semper vivamus mi enim dapibus quis laoreet at hendrerit sit amet eros nulla ut lacinia nisi  ', '0'),
('35', 'node', ' nullam eu erat nibh maecenas semper feugiat aenean quis mattis magna in pulvinar interdum mauris in ornare fusce molestie erat id sapien aliquam pharetra suspendisse ornare tincidunt magna sed sed turpis justo donec eleifend justo vel bibendum blandit est sem tempus lorem vel ultricies felis eros non est praesent ac dolor eu justo vestibulum dapibus maecenas id odio lectus in interdum libero in hac habitasse platea dictumst praesent sed urna turpis sit amet auctor sem pellentesque sit amet ante sit amet diam imperdiet ultrices proin congue iaculis semper vivamus mi enim dapibus quis laoreet at hendrerit sit amet eros nulla ut lacinia nisi nullam eu erat nibh aliquam ipsum sapien interdum a euismod vitae vehicula pellentesque dolor in sit amet eros pretium eros aliquet semper eget id massa donec malesuada rutrum est sed neque est ultricies ac dictum at tincidunt at arcu in hac habitasse platea dictumst cras posuere convallis mattis quisque blandit ullamcorper ligula dapibus tincidunt dolor lacinia non aliquam vitae nunc metus fusce nec sem sapien morbi pharetra pharetra purus eu condimentum phasellus pulvinar imperdiet mi vitae pellentesque nullam sed urna porta ligula tempus venenatis a at metus proin feugiat nulla nec mi hendrerit ut iaculis purus pulvinar suspendisse id magna lacus vel consequat arcu vestibulum non nulla felis in tempor magna aliquam lacinia iaculis leo eu consequat mauris molestie nec mauris facilisis facilisis eros quis pretium ipsum consectetur quis vestibulum sed massa vitae felis porta elementum nulla facilisi sed turpis mi ultrices sed blandit sit amet rutrum et tellus proin luctus egestas turpis eget luctus dolor mattis a nam sed rutrum diam sed quis nisl nisl eu fringilla diam  ', '0'),
('36', 'node', ' lorem ipsum dolor sit amet consectetur adipisicing elit aenean placerat tortor ac dui luctus ut mattis est mollis donec blandit orci id velit cursus varius fusce quam enim  hendrerit nec ultrices a vestibulum nec enim quisque imperdiet ultricies dolor in convallis morbi sed fringilla elit duis sagittis lectus in orci volutpat elementum cras in purus sem curabitur augue velit mollis in suscipit eleifend faucibus ac elit morbi mattis tristique mi quis lobortis nulla sollicitudin quis cras adipiscing enim neque ut ultrices risus pellentesque auctor felis eu nibh volutpat ac malesuada elit blandit pellentesque porta felis vel sapien tincidunt rhoncus nunc sit amet dui eget odio blandit sagittis duis tempus egestas justo vitae rhoncus sed mollis risus in aliquet tincidunt nisl nunc imperdiet eros nec dictum ante est at ante nunc ullamcorper gravida porttitor sed sollicitudin dui vestibulum nisl condimentum at viverra urna dictum curabitur felis ligula mattis ornare rhoncus eget porta non urna nullam non porta est vestibulum pretium quam et purus tempus fringilla etiam vitae nulla turpis at interdum erat pellentesque aliquet lorem id nunc suscipit pretium maecenas vitae erat in erat bibendum tincidunt sit amet eget dolor maecenas ultricies nulla et felis rhoncus tincidunt vestibulum sed arcu nunc ut augue felis elementum ut dapibus posuere pulvinar at lorem class aptent taciti sociosqu ad litora torquent per conubia nostra  per inceptos himenaeos  class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos duis dignissim urna at tincidunt aliquam sem est scelerisque nibh nec convallis risus nisl in justo suspendisse imperdiet consequat gravida curabitur odio velit tempor ac cursus ut tempor eu sem donec consequat magna purus in ac leo nulla morbi scelerisque ligula quam consectetur sodales lacus sed viverra rutrum est quis tempor in non posuere mauris nullam odio tortor suscipit at semper ut tempus consectetur tellus morbi congue egestas est proin tortor mi tempor sit amet pretium eget sollicitudin quis elit nam massa nisi viverra in gravida et tincidunt in elit duis nec massa a tortor iaculis aliquam eu vel ante duis sagittis consequat imperdiet donec metus eros blandit et vestibulum eget vehicula at libero proin molestie odio vitae odio porta sagittis vivamus eu lorem in purus viverra viverra sit amet et orci nulla adipiscing neque ut leo ornare faucibus cras vel augue enim quisque vel volutpat nisl proin ullamcorper ultrices faucibus lorem ipsum dolor aliquam laoreet neque non permalink submitted by admin on tue 9202011 1813 aliquam laoreet neque non ipsum pharetra eget ultrices eros dictum nunc a enim justo donec venenatis libero nec feugiat congue mi sem scelerisque magna congue pellentesque tortor turpis et eros donec ligula quam aliquam eu vehicula ut aliquet eu erat vestibulum posuere justo eu venenatis consectetur eros nibh vulputate mauris dignissim blandit sapien dolor ut augue reply suspendisse semper velit a permalink submitted by admin on tue 9202011 1813 suspendisse semper velit a venenatis rhoncus leo nulla porttitor justo a volutpat nisi tortor vitae nisi nam volutpat interdum placerat sed posuere felis et sem commodo tempus reply aenean fermentum justo id permalink submitted by admin on tue 9202011 1813 aenean fermentum justo id nibh sagittis vestibulum donec vel interdum mi morbi vel diam vel arcu vestibulum vehicula nam vitae eros eu leo feugiat aliquam quisque sodales felis quis ullamcorper suscipit mi ipsum porta magna ut dapibus odio dolor a nisl mauris ac enim nisl id feugiat metus nunc purus enim euismod nec fringilla a bibendum in turpis praesent ac orci purus in vulputate risus reply ', '0'),
('37', 'node', ' donece pellente admin s blog lorem ipsum dolor sit amet consectetur adipiscing elit aenean tristique porta ligula ac elementum felis faucibus vel duis in nunc nibh aenean dictum lorem non diam ultricies non laoreet dolor auctor vestibulum blandit ante non turpis tristique tincidunt in adipiscing vulputate tortor at accumsan curabitur convallis eros sit amet dolor interdum varius donec a dolor velit aliquam rhoncus sagittis vestibulum praesent arcu turpis lobortis nec aliquet vitae feugiat quis ipsum quisque et tellus sit amet mauris luctus dignissim eu quis augue vestibulum velit nulla consectetur vel viverra eu ultricies sed felis pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas pellentesque id eros et tortor malesuada consequat sed commodo sem id diam varius luctus morbi justo augue hendrerit a blandit in hendrerit facilisis risus praesent sed massa tortor nam quis sollicitudin sapien in eu consectetur dolor nulla aliquet egestas lacus eget pulvinar donec at blandit lorem pellentesque ac ipsum purus pellentesque tincidunt congue fringilla fusce tincidunt mauris et lorem pellentesque faucibus curabitur adipiscing consectetur arcu ut vulputate magna tincidunt a nam semper commodo nibh sit amet suscipit lacus convallis vitae fusce sit amet sapien pharetra neque consectetur semper quis nec lacus morbi a metus non urna pellentesque vestibulum vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia curae pellentesque imperdiet elit sodales urna egestas molestie nulla eu nisi sed eros lacinia cursus ut in dolor nunc ut sapien metus fermentum tincidunt tellus duis nec diam mi etiam a ligula quis augue scelerisque tincidunt ullamcorper et arcu donec aliquet nulla quis dui sodales hendrerit a sed neque vivamus velit velit rutrum vitae ultrices eu facilisis a nisl proin velit ipsum porttitor et vestibulum quis luctus id augue curabitur metus mauris tincidunt non accumsan ac iaculis id est quisque venenatis magna quis quam adipiscing eget eleifend lorem lacinia praesent quis tellus non lorem tempus rhoncus vitae in velit praesent vestibulum tempus tempus lorem ipsum dolor sit amet consectetur adipiscing elit aenean consequat tellus in imperdiet faucibus nibh nisi vehicula metus eu posuere est sapien adipiscing lacus mauris dolor eros porttitor vitae rhoncus vel condimentum quis neque fusce sodales risus ac sem facilisis ultricies maecenas in leo arcu lorem ipsum dolor sit amet tincidunt tellus id euismod ', '0'),
('38', 'node', ' donece pellente admin s blog lorem ipsum dolor sit amet consectetur adipiscing elit curabitur eu elit sed nunc porta molestie vel vitae odio donec ut arcu in justo mollis consectetur vel a elit curabitur iaculis turpis pellentesque nibh ornare sit amet faucibus quam egestas vestibulum lacinia posuere vehicula ut eget nulla ut mi pellentesque vehicula suspendisse luctus semper ipsum vel dapibus sem sagittis quis nulla vehicula tincidunt libero vitae molestie duis et diam ante nec ultrices eros nullam volutpat auctor dolor in interdum ut augue sapien rutrum non tempor id feugiat in enim suspendisse fringilla magna et vulputate sollicitudin urna est sollicitudin arcu eu pretium diam lorem et massa vestibulum congue ante ac erat placerat sollicitudin donec eget ipsum sit amet libero suscipit aliquam in fringilla sapien ut consequat dictum mi enim tincidunt tortor id tristique dui diam congue erat vivamus massa lectus placerat non adipiscing id varius eu metus nunc arcu augue aliquet vitae suscipit id tincidunt sit amet mauris nulla eu nibh quis nisl convallis blandit sed rhoncus gravida magna ut aliquet phasellus consectetur turpis in convallis rhoncus mauris orci tincidunt leo in rutrum purus purus vitae justo duis aliquet dolor ut sapien ullamcorper id feugiat nunc interdum maecenas id augue sed tellus rutrum pellentesque cras vulputate placerat adipiscing nulla sed semper lacus in sollicitudin molestie felis id sollicitudin aliquam congue tellus eget ipsum consectetur non feugiat arcu aliquam sed pharetra lacus ac placerat consectetur magna elit posuere mauris a dapibus neque augue quis est mauris id justo sed dui tincidunt adipiscing nam porta nisl in sem dignissim cursus duis et eros odio pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas cras lorem nulla dictum eu consequat et adipiscing eu mi vivamus tincidunt sem consectetur urna mollis laoreet pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas praesent vel risus massa non suscipit sem sed malesuada magna et mauris vestibulum blandit donec ornare viverra nisi sed eleifend duis in tortor tortor dictum adipiscing est nunc sed nunc est vivamus porttitor interdum odio tempus semper libero elementum sit amet sed ac eros lacus sed urna mi fermentum sit amet tempus sit amet varius ac odio morbi vehicula magna eu nibh dignissim sit amet sagittis nulla porta ut ultricies mi mauris donec vel vulputate justo nulla et tellus lorem integer sed magna eget quam malesuada dapibus nulla in magna eu erat sagittis lobortis mauris a lorem non dolor vestibulum ultrices proin turpis dolor porta eget feugiat nec bibendum id velit aenean molestie nisl id arcu viverra accumsan aliquam egestas purus sit amet sem pharetra sed molestie justo malesuada lorem ipsum dolor sit amet consectetur adipiscing elit vivamus eu urna nec odio malesuada sollicitudin nec ut nunc duis vel nisifes netus et malesuada fames tincidunt tellus id euismod vestibulum ullamcorpermoles ', '0'),
('39', 'node', ' donece pellente admin s blog lorem ipsum dolor sit amet consectetur adipiscing elit nullam aliquet pellentesque cursus curabitur porta condimentum metus sed consequat nulla at mauris eget massa feugiat placerat nec id enim cras sollicitudin quam a est ullamcorper eleifend proin posuere rutrum urna sed porttitor pellentesque aliquam convallis molestie donec ut dolor enim nec pretium felis nunc id dui quam sed molestie libero quisque consequat vulputate neque ultrices tincidunt lacus scelerisque vitae proin imperdiet turpis eu gravida vestibulum ante nisl accumsan sapien in vestibulum risus dolor interdum purus aenean fringilla justo et aliquet eleifend urna eros faucibus urna et pellentesque neque nisl ut risus aliquam adipiscing tempor nisi id porttitor sapien molestie in curabitur felis massa volutpat quis gravida euismod commodo sit amet arcu cras mattis nisl sit amet egestas tempus urna quam ultrices augue nec sodales sapien leo at mauris in hac habitasse platea dictumst etiam facilisis ligula tempor cursus adipiscing nisi arcu ullamcorper risus eget gravida felis odio sit amet eratmorbi quis dictum libero nulla orci lectus venenatis at mattis non venenatis eget nunc pellentesque vel sapien mauris at aliquam dui etiam fringilla magna nec turpis placerat et posuere quam aliquet donec sit amet massa sit amet leo egestas sagittis at a nibh vestibulum vitae quam eget tellus scelerisque volutpat vel sit amet nisl aliquam vel metus lectus pellentesque vitae semper sem sed tempor malesuada arcu id tincidunt ut tincidunt ullamcorper justo ac euismod maecenas a lectus porta nulla semper porta ut quis eros elit cum sociis natoque penatibus et magnis dis parturient montes nascetur ridiculus mus morbi sagittis ante eu arcu molestie ac fringilla odio vulputate nulla sit amet arcu vel sem euismod dictum integer nisi urna consectetur et rhoncus sit amet semper eu tellus pellentesque blandit vestibulum leo ut laoreet phasellus sit amet justo ornare dolor consequat rutrum et non elit ut rutrum viverra neque non hendrerit phasellus nibh mi pharetra nec tempor sed faucibus ut felis ut quis nisl est sed condimentum urna at elementum placerat justo arcu iaculis dolor quis rutrum sapien turpis ac arcu duis vel nisifes netus et malesuada fames ', '0'),
('40', 'node', ' donece pellente admin s blog lorem ipsum dolor sit amet consectetur adipiscing elit nunc dolor metus pulvinar ac viverra id porttitor sed lorem morbi tincidunt accumsan nisi in mollis quisque placerat dictum facilisis nam lobortis pharetra libero vitae facilisis justo tempus gravida donec convallis euismod nisi vitae pellentesque lacus iaculis vulputate cum sociis natoque penatibus et magnis dis parturient montes nascetur ridiculus mus phasellus pretium lobortis est at varius donec viverra consequat leo et lobortis ipsum convallis in nam commodo ipsum quis risus ultricies at gravida leo varius pellentesque at velit ac sem scelerisque blandit et vel lectus aenean rhoncus odio eu leo fermentum tincidunt fusce sed urna eget nisi congue ornare vestibulum sed ligula suspendisse potenti sed dapibus odio vel facilisis rhoncus leo nunc interdum quam sed commodo nisl tortor a velit etiam orci nisi pretium a malesuada mattis adipiscing sed ante pellentesque at egestas nulla morbi justo nunc scelerisque at pretium ac tempus quis est nunc sodales ante et mollis cursus dolor libero rhoncus magna sed semper augue erat ac nulla nulla facilisi duis suscipit ipsum a sapien viverra scelerisque duis rhoncus est nec augue vulputate vestibulum nunc erat mauris laoreet eu blandit eget auctor nec dui suspendisse potenti duis congue porta neque id elementum etiam ultricies eleifend lorem in viverra sapien suscipit sed ut faucibus imperdiet lacus a egestas nulla ultrices iaculis sed purus lacus placerat et tempus at egestas eu libero in varius turpis vitae orci commodo eu lacinia erat sollicitudin nullam lacus ante gravida vel rutrum sed semper in dui pellentesque volutpat congue dui ut sodales phasellus laoreet velit ut convallis sollicitudin nunc elit dapibus lectus sit amet molestie ligula tellus a est vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia curae sed est nibh tempus eu ultrices quis consectetur nec est maecenas auctor quam et justo pretium et pulvinar nulla dignissim praesent facilisis nulla quis rutrum aliquet lorem sem tincidunt nulla ac bibendum est lectus viverra felis phasellus bibendum justo nec placerat aliquam massa erat aliquam sem bibendum mollis odio odio vitae augue vivamus non enim nisi mattis convallis nulla sed id orci eu mauris posuere fringilla pellentesque tincidunt molestie porta aenean eget viverra magna cras commodo nibh id justo dictum vulputate nam venenatis leo vel nisi fringilla at pellentesque orci pharetra fusce turpis tortor mollis sed iaculis et eleifend sit amet dolor aliquam consectetur tempor fringilla aenean nisl nulla faucibus quis dictum in viverra et arcu curabitur eget augue nec risus semper tristique condimentum tellus tellus duis vel nisifes lorem ipsum dolor sit amet lorem ipsum dolor sit amet netus et malesuada fames quisque viverra leo id tincidunt tincidunt tellus id euismod tristique senectus et vestibulum ullamcorpermoles ', '0'),
('41', 'node', ' donece pellente admin s blog lorem ipsum dolor sit amet consectetur adipiscing elit quisque cursus sem eget sagittis sagittis nisl magna sodales eros ut feugiat velit velit non turpis cras eu nibh dapibus justo fringilla bibendum donec eget aliquam massa etiam ac dui felis sed eleifend mi suspendisse consequat urna ac orci mattis consequat pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas in mattis mattis eleifend donec leo odio fringilla nec lacinia in dignissim molestie erat integer dui ipsum semper sed mattis quis convallis consequat magna quisque quis arcu justo nec laoreet lacus in vulputate malesuada auctor suspendisse pharetra diam eu auctor vestibulum orci sem mattis neque eget facilisis neque risus vitae libero duis tincidunt orci ut porttitor sollicitudin urna risus porttitor urna sit amet varius eros enim eu orci pellentesque non mauris eget ipsum tristique luctus quis eu orci vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia curae ut nunc enim pretium vel blandit ac euismod eget felis aenean sed purus nibh adipiscing pharetra dui aenean sed mauris dui etiam tincidunt ornare velit ut ornare maecenas ac arcu a orci aliquet accumsan sit amet sit amet augue curabitur turpis sem iaculis et dapibus ac placerat in quam proin congue neque sed sagittis facilisis enim purus hendrerit orci in blandit nulla elit eget velit sed congue justo vitae imperdiet condimentum nisi eros imperdiet tellus in iaculis tortor velit gravida neque etiam convallis nisi tincidunt nisi mollis non pretium elit interdum mauris adipiscing ante ut hendrerit sodales ante enim commodo enim sed posuere lacus arcu non est donec nibh augue accumsan at tristique ut luctus non sem nulla ac enim non sapien aliquam interdum fusce scelerisque semper massa sit amet tristique turpis semper sit amet aenean adipiscing mauris lorem et ultrices leo maecenas et felis eu turpis feugiat convallis phasellus sit amet ipsum quis dolor rhoncus aliquet ac id quam nunc ultricies ipsum a tortor tristique eleifend non eget nunc praesent vestibulum placerat felis et eleifend sed ut commodo diam donec et nunc massa sit amet rutrum diam fusce vulputate fermentum dapibus proin convallis condimentum tortor vivamus ut erat at neque consequat bibendum integer id libero eget mi semper hendrerit ac et odio vestibulum sodales quam quis ante auctor accumsan vivamus viverra porta nunc aliquam lobortis phasellus porttitor porta massa nec mollis vivamus sodales condimentum sem et volutpat aliquam erat volutpat curabitur accumsan interdum justo eget cursus dolor ultrices et nam dolor orci dapibus sed facilisis eu laoreet a nisi sed nec nunc sit amet urna viverra dapibus eget a libero cras lacinia blandit magna in accumsan suspendisse quis dui vel dolor scelerisque tristique donec pellentesque scelerisque semper condimentum tellus tellus duis vel nisifes lorem ipsum dolor sit amet pellentesque habitant morbi vestibulum ullamcorpermoles lorem ipsum dolor permalink submitted by admin on wed 7172013 1856 curabitur mauris tortor laoreet et consectetur non  rhoncus sed risus  donec nisi enim adipiscing quis convallis eu elementum a urna maecenas sit amet metus sem sed non est ligula sit amet vehicula nunc maecenas sed quam non urna tincidunt pellentesque ac ut enim vestibulum arcu tortor vulputate nec semper id commodo eget lacus integer mi dolor malesuada in ullamcorper ut tincidunt eu arcu mauris dictum libero id rutrum vehicula est l igula sagittis urna  ut convallis purus purus at dolor  praesent nec vehicula tortor nulla facilisi curabitur mauris sapien interdum id consequat et lobortis ut ipsum vestibulum tempus augue eu est malesuada viverra nunc mattis fermentum metus a consectetur magna egestas lobortis class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos morbi non mauris ligula  suspendisse facilisis sagittis mauris  ac dictum elit fringilla ut reply ', '0'),
('42', 'node', ' lorem ipsum dolor sit amet consectetur adipiscing elit  suspendisse sem justo commodo et tristique in aliquet in nibh ut bibendum blandit lacus integer sodales odio sed facilisis adipiscing felis magna sagittis mauris sit amet placerat sem nunc vitae velit ut sollicitudin augue non tortor semper ultrices curabitur libero neque ultrices feugiat laoreet a volutpat nec erat  ', '0'),
('43', 'node', ' phasellus non dui magna sit amet elementum lectus nullam ipsum ipsum bibendum id mollis a malesuada sit amet turpis  aliquam erat volutpat donec dapibus nisl sit amet purus vehicula condimentum pulvinar felis cursus sed tellus dui vulputate quis porttitor a consequat vel lectus cras rutrum lacus vel posuere sodales turpis elit pretium elit malesuada aliquam sapien nibh vitae tortor vivamus viverra blandit nibh faucibus hendrerit orci ultrices id  ', '0'),
('44', 'node', ' nunc commodo nisi ultricies nulla convallis et facilisis enim cursus ut purus ligula consequat a posuere at ultricies in quam  suspendisse ornare dapibus nisi vel placerat metus varius non cras tellus libero condimentum a pharetra ac aliquet at massa phasellus ullamcorper varius velit in hendrerit magna convallis et donec porta enim id tempor varius tortor diam porttitor odio at ultricies tellus dui vitae ante ut ut enim quam at consectetur leo  ', '0'),
('45', 'node', ' aliquam erat volutpat phasellus ac est velit proin sit amet urna dui sed volutpat orci nam molestie viverra eros eu lacinia nunc facilisis sed  donec id tortor sit amet enim ornare pretium vestibulum felis diam hendrerit non ornare quis eleifend quis erat quisque et dui sapien sit amet ultrices odio nullam faucibus bibendum felis nullam bibendum turpis et sollicitudin ullamcorper dui magna dictum turpis vitae pulvinar lorem orci sed neque duis sem leo rutrum quis tempus eu volutpat luctus felis nulla convallis congue molestie  ', '0'),
('46', 'node', ' sed vitae orci enim ut accumsan sem donec orci risus porta in tempor a blandit ut risus donec vitae velit neque nec adipiscing ipsum  phasellus ornare sapien at purus fringilla pellentesque ut laoreet gravida risus eu bibendum lacus mattis eu praesent ac pulvinar lectus proin eu venenatis eros vestibulum id lectus vitae erat eleifend semper et in tortor donec venenatis ante eu diam fringilla fermentum integer pharetra tellus at erat bibendum sed facilisis velit molestie  ', '0'),
('47', 'node', ' quality lorem ipsum dolor sit amet consectetur adipiscing elit etiam neque nisi interdum ac porta non condimentum eu tellus nunc rhoncus sem quis metus cursus sagittis nulla risus massa sagittis eu lobortis quis molestie ac urna etiam a nisi risus proin lacinia auctor dapibus mauris sit amet dignissim lectus praesent dignissim dui id dui accumsan molestie nulla luctus nulla vitae purus posuere in gravida ante vulputate quisque faucibus pellentesque risus a euismod sapien laoreet non praesent aliquet mattis neque quis euismod libero ultricies quis maecenas nec urna a lacus ultricies tristique sed a massa et dolor feugiat commodo praesent sed risus mollis eros sagittis hendrerit proin mattis enim ut arcu elementum ornare pharetra eget ligula donec et ante a diam scelerisque fringilla quisque nunc ipsum laoreet eget pellentesque eu sodales vitae massa phasellus non neque in lacus imperdiet varius aliquam suscipit libero non sodales lobortis erat enim rutrum lacus id malesuada enim neque commodo risus in sed erat nisi non porttitor ante maecenas at lorem lacus eget feugiat justo nam lacinia ligula eget ante malesuada luctus sed posuere dui quis lectus mollis volutpat vivamus suscipit blandit urna sit amet lobortis phasellus et elit magna in molestie nisi curabitur mattis nunc et nunc tristique porttitor a cursus lorem vestibulum non venenatis nibh aenean ultricies justo in tempus rhoncus mi eros luctus elit vel volutpat tellus felis eu ligula vivamus mattis orci a nunc commodo fringilla ut eget lacus proin vestibulum suscipit tincidunt duis dictum aliquet scelerisque praesent a tortor purus  ', '0'),
('50', 'node', ' style aliquam erat volutpat praesent quis nibh nisl cras at libero quam ut tincidunt diam fusce aliquet augue a ipsum ullamcorper semper suspendisse potenti proin id eros eu lectus blandit suscipit id eget tortor nulla augue purus molestie accumsan ullamcorper ut dictum sit amet erat proin eu leo eros eu tincidunt lorem donec sit amet mauris vitae felis viverra tristique mauris varius ante eu ante tincidunt aliquam etiam porttitor facilisis molestie etiam at tellus eu lacus volutpat suscipit nam blandit elit dignissim risus consequat egestas proin blandit turpis ut facilisis aliquet dui quam fringilla dolor id rutrum nisi urna ac nunc nulla congue justo quis magna laoreet vitae fringilla est venenatis cras blandit ante eget turpis eleifend rutrum sed non quam nec tortor molestie luctus nec sit amet massa nulla tincidunt orci sit amet nisl eleifend pretium donec sit amet libero nec nunc tristique vulputate vestibulum vel lectus massa curabitur consequat justo nec bibendum dignissim felis ipsum pharetra nunc non eleifend dui diam at ipsum cum sociis natoque penatibus et magnis dis parturient montes nascetur ridiculus mus etiam nec justo eu magna lacinia sollicitudin at quis odio nullam dui enim iaculis eu egestas a volutpat at tortor class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos cras vitae urna sit amet turpis lobortis tristique nullam eget orci id massa tempus auctor vivamus commodo porta magna non adipiscing cras id risus eu tellus mollis malesuada id in orci etiam mi magna gravida id ultrices vel sollicitudin nec sapien curabitur a euismod dui fusce vestibulum consequat imperdiet ut molestie eros ac lorem eleifend vitae pretium nunc porttitor  ', '0'),
('51', 'node', ' comfort curabitur nunc lacus fermentum eget rhoncus interdum pellentesque sed dui nulla lobortis bibendum ante non malesuada aliquam eget condimentum augue in et libero orci praesent ut augue et est interdum blandit tempor in felis vivamus laoreet sem sed velit malesuada posuere cras dolor augue commodo non auctor nec ornare in ipsum aenean et urna purus integer ac nisl risus sed interdum libero class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos nullam a ligula quis diam auctor laoreet vivamus molestie suscipit malesuada pellentesque tempus lacus in arcu venenatis eget ullamcorper ante euismod fusce condimentum ligula in congue tincidunt lectus eros hendrerit nibh id hendrerit dui quam sit amet velit pellentesque pretium magna ac aliquam feugiat ligula felis mollis enim nec lacinia ipsum nibh non neque aliquam vulputate massa quis lacus porttitor non malesuada dui auctor sed bibendum faucibus erat eu mollis nunc fermentum ut nullam vitae pharetra ante maecenas viverra fringilla metus a posuere ligula elementum sit amet aenean elit leo dapibus et vestibulum eu tristique sit amet ante in id mi et leo tristique ultrices in ac lacus nulla proin arcu massa imperdiet eget interdum vel ultrices eget sapien donec vestibulum aliquet leo eu tristique cras dolor quam bibendum non ullamcorper sit amet aliquam ac elit  ', '0'),
('52', 'node', ' lorem ipsum dolor sit amet vivamus vel eros eget magna volutpat sagittis  nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis curabitur et libero sit amet ante hendrerit molestie cras a erat in leo lobortis tincidunt praesent aliquet eros sit amet dapibus convallis ligula magna pellentesque urna quis laoreet erat velit ullamcorper odio curabitur eget molestie sem maecenas pretium ante non purus tincidunt egestas fusce tincidunt velit sit amet euismod interdum  quam ipsum interdum nulla et tincidunt lectus diam id purus pellentesque sodales magna id tellus ultrices pellentesque aliquam libero mi faucibus quis hendrerit nec porta ac mauris duis ullamcorper est quis est rhoncus vitae pulvinar mauris pretium sed elit dui vehicula ac gravida sit amet iaculis in sem aliquam id quam arcu sed tristique eros pellentesque vestibulum   elit ac tincidunt suscipit  metus mi laoreet tellus quis imperdiet sem dolor at massa nullam tincidunt justo at dictum viverra tortor metus bibendum mauris fermentum ullamcorper mi ante in odio sed id orci et est iaculis iaculis maecenas odio nunc malesuada ac posuere vel interdum id eros in dictum arcu vel lorem tempus nec faucibus metus sodales aenean ut sem nunc curabitur convallis euismod nulla a malesuada orci accumsan ut donec pellentesque ligula sed massa tristique ac auctor purus aliquet vestibulum malesuada commodo magna id hendrerit sed at ante ipsum integer nec justo aliquet mi porttitor scelerisque eget quis elit all vivamus ', '0'),
('53', 'node', ' fusce suscipit varius vivamus vel eros eget magna volutpat sagittis  nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis curabitur et libero sit amet ante hendrerit molestie cras a erat in leo lobortis tincidunt praesent aliquet eros sit amet dapibus convallis ligula magna pellentesque urna quis laoreet erat velit ullamcorper odio curabitur eget molestie sem maecenas pretium ante non purus tincidunt egestas fusce tincidunt velit sit amet euismod interdum  quam ipsum interdum nulla et tincidunt lectus diam id purus pellentesque sodales magna id tellus ultrices pellentesque aliquam libero mi faucibus quis hendrerit nec porta ac mauris duis ullamcorper est quis est rhoncus vitae pulvinar mauris pretium sed elit dui vehicula ac gravida sit amet iaculis in sem aliquam id quam arcu sed tristique eros pellentesque vestibulum   elit ac tincidunt suscipit  metus mi laoreet tellus quis imperdiet sem dolor at massa nullam tincidunt justo at dictum viverra tortor metus bibendum mauris fermentum ullamcorper mi ante in odio sed id orci et est iaculis iaculis maecenas odio nunc malesuada ac posuere vel interdum id eros in dictum arcu vel lorem tempus nec faucibus metus sodales aenean ut sem nunc curabitur convallis euismod nulla a malesuada orci accumsan ut donec pellentesque ligula sed massa tristique ac auctor purus aliquet vestibulum malesuada commodo magna id hendrerit sed at ante ipsum integer nec justo aliquet mi porttitor scelerisque eget quis elit all maecenas ', '0'),
('54', 'node', ' ut enim ad minima veniam vivamus vel eros eget magna volutpat sagittis  nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis curabitur et libero sit amet ante hendrerit molestie cras a erat in leo lobortis tincidunt praesent aliquet eros sit amet dapibus convallis ligula magna pellentesque urna quis laoreet erat velit ullamcorper odio curabitur eget molestie sem maecenas pretium ante non purus tincidunt egestas fusce tincidunt velit sit amet euismod interdum  quam ipsum interdum nulla et tincidunt lectus diam id purus pellentesque sodales magna id tellus ultrices pellentesque aliquam libero mi faucibus quis hendrerit nec porta ac mauris duis ullamcorper est quis est rhoncus vitae pulvinar mauris pretium sed elit dui vehicula ac gravida sit amet iaculis in sem aliquam id quam arcu sed tristique eros pellentesque vestibulum   elit ac tincidunt suscipit  metus mi laoreet tellus quis imperdiet sem dolor at massa nullam tincidunt justo at dictum viverra tortor metus bibendum mauris fermentum ullamcorper mi ante in odio sed id orci et est iaculis iaculis maecenas odio nunc malesuada ac posuere vel interdum id eros in dictum arcu vel lorem tempus nec faucibus metus sodales aenean ut sem nunc curabitur convallis euismod nulla a malesuada orci accumsan ut donec pellentesque ligula sed massa tristique ac auctor purus aliquet vestibulum malesuada commodo magna id hendrerit sed at ante ipsum integer nec justo aliquet mi porttitor scelerisque eget quis elit all ', '0'),
('55', 'node', ' sed utem perspiciatis vivamus vel eros eget magna volutpat sagittis  nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis curabitur et libero sit amet ante hendrerit molestie cras a erat in leo lobortis tincidunt praesent aliquet eros sit amet dapibus convallis ligula magna pellentesque urna quis laoreet erat velit ullamcorper odio curabitur eget molestie sem maecenas pretium ante non purus tincidunt egestas fusce tincidunt velit sit amet euismod interdum  quam ipsum interdum nulla et tincidunt lectus diam id purus pellentesque sodales magna id tellus ultrices pellentesque aliquam libero mi faucibus quis hendrerit nec porta ac mauris duis ullamcorper est quis est rhoncus vitae pulvinar mauris pretium sed elit dui vehicula ac gravida sit amet iaculis in sem aliquam id quam arcu sed tristique eros pellentesque vestibulum   elit ac tincidunt suscipit  metus mi laoreet tellus quis imperdiet sem dolor at massa nullam tincidunt justo at dictum viverra tortor metus bibendum mauris fermentum ullamcorper mi ante in odio sed id orci et est iaculis iaculis maecenas odio nunc malesuada ac posuere vel interdum id eros in dictum arcu vel lorem tempus nec faucibus metus sodales aenean ut sem nunc curabitur convallis euismod nulla a malesuada orci accumsan ut donec pellentesque ligula sed massa tristique ac auctor purus aliquet vestibulum malesuada commodo magna id hendrerit sed at ante ipsum integer nec justo aliquet mi porttitor scelerisque eget quis elit all aenean ', '0'),
('56', 'node', ' vestibulum libero nislum vivamus vel eros eget magna volutpat sagittis  nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis curabitur et libero sit amet ante hendrerit molestie cras a erat in leo lobortis tincidunt praesent aliquet eros sit amet dapibus convallis ligula magna pellentesque urna quis laoreet erat velit ullamcorper odio curabitur eget molestie sem maecenas pretium ante non purus tincidunt egestas fusce tincidunt velit sit amet euismod interdum  quam ipsum interdum nulla et tincidunt lectus diam id purus pellentesque sodales magna id tellus ultrices pellentesque aliquam libero mi faucibus quis hendrerit nec porta ac mauris duis ullamcorper est quis est rhoncus vitae pulvinar mauris pretium sed elit dui vehicula ac gravida sit amet iaculis in sem aliquam id quam arcu sed tristique eros pellentesque vestibulum   elit ac tincidunt suscipit  metus mi laoreet tellus quis imperdiet sem dolor at massa nullam tincidunt justo at dictum viverra tortor metus bibendum mauris fermentum ullamcorper mi ante in odio sed id orci et est iaculis iaculis maecenas odio nunc malesuada ac posuere vel interdum id eros in dictum arcu vel lorem tempus nec faucibus metus sodales aenean ut sem nunc curabitur convallis euismod nulla a malesuada orci accumsan ut donec pellentesque ligula sed massa tristique ac auctor purus aliquet vestibulum malesuada commodo magna id hendrerit sed at ante ipsum integer nec justo aliquet mi porttitor scelerisque eget quis elit all vivamus ', '0');
INSERT INTO `search_dataset` VALUES
('57', 'node', ' praesent vestibulum vivamus vel eros eget magna volutpat sagittis  nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis curabitur et libero sit amet ante hendrerit molestie cras a erat in leo lobortis tincidunt praesent aliquet eros sit amet dapibus convallis ligula magna pellentesque urna quis laoreet erat velit ullamcorper odio curabitur eget molestie sem maecenas pretium ante non purus tincidunt egestas fusce tincidunt velit sit amet euismod interdum  quam ipsum interdum nulla et tincidunt lectus diam id purus pellentesque sodales magna id tellus ultrices pellentesque aliquam libero mi faucibus quis hendrerit nec porta ac mauris duis ullamcorper est quis est rhoncus vitae pulvinar mauris pretium sed elit dui vehicula ac gravida sit amet iaculis in sem aliquam id quam arcu sed tristique eros pellentesque vestibulum   elit ac tincidunt suscipit  metus mi laoreet tellus quis imperdiet sem dolor at massa nullam tincidunt justo at dictum viverra tortor metus bibendum mauris fermentum ullamcorper mi ante in odio sed id orci et est iaculis iaculis maecenas odio nunc malesuada ac posuere vel interdum id eros in dictum arcu vel lorem tempus nec faucibus metus sodales aenean ut sem nunc curabitur convallis euismod nulla a malesuada orci accumsan ut donec pellentesque ligula sed massa tristique ac auctor purus aliquet vestibulum malesuada commodo magna id hendrerit sed at ante ipsum integer nec justo aliquet mi porttitor scelerisque eget quis elit all vivamus aenean ', '0'),
('58', 'node', ' praesent vestibulum vivamus vel eros eget magna volutpat sagittis  nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis curabitur et libero sit amet ante hendrerit molestie cras a erat in leo lobortis tincidunt praesent aliquet eros sit amet dapibus convallis ligula magna pellentesque urna quis laoreet erat velit ullamcorper odio curabitur eget molestie sem maecenas pretium ante non purus tincidunt egestas fusce tincidunt velit sit amet euismod interdum  quam ipsum interdum nulla et tincidunt lectus diam id purus pellentesque sodales magna id tellus ultrices pellentesque aliquam libero mi faucibus quis hendrerit nec porta ac mauris duis ullamcorper est quis est rhoncus vitae pulvinar mauris pretium sed elit dui vehicula ac gravida sit amet iaculis in sem aliquam id quam arcu sed tristique eros pellentesque vestibulum   elit ac tincidunt suscipit  metus mi laoreet tellus quis imperdiet sem dolor at massa nullam tincidunt justo at dictum viverra tortor metus bibendum mauris fermentum ullamcorper mi ante in odio sed id orci et est iaculis iaculis maecenas odio nunc malesuada ac posuere vel interdum id eros in dictum arcu vel lorem tempus nec faucibus metus sodales aenean ut sem nunc curabitur convallis euismod nulla a malesuada orci accumsan ut donec pellentesque ligula sed massa tristique ac auctor purus aliquet vestibulum malesuada commodo magna id hendrerit sed at ante ipsum integer nec justo aliquet mi porttitor scelerisque eget quis elit all aenean ', '0'),
('65', 'node', ' john franklin curabitur mauris tortor laoreet et consectetur non  rhoncus sed risus  donec nisi enim adipiscing quis convallis eu elementum a urna maecenas sit amet metus sem sed non est ligula sit amet vehicula nunc maecenas sed quam non urna tincidunt pellentesque ac ut enim vestibulum arcu tortor vulputate nec semper id commodo eget lacus integer mi dolor malesuada in ullamcorper ut tincidunt eu arcu mauris dictum libero id rutrum vehicula est l igula sagittis urna  ut convallis purus purus at dolor  praesent nec vehicula tortor nulla facilisi curabitur mauris sapien interdum id consequat et lobortis ut ipsum vestibulum tempus augue eu est malesuada viverra nunc mattis fermentum metus a consectetur magna egestas lobortis class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos morbi non mauris ligula  suspendisse facilisis sagittis mauris  ac dictum elit fringilla ut class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos sed vel erat justo in lorem augue varius ut hendrerit a gravida vel lectus donec fringilla metus in leo gravida facilisis suspendisse lacinia leo quis auctor suscipit massa sapien congue sem sit amet tincidunt enim nibh eget neque proin semper placerat odio sit amet vehicula mauris malesuada sed nulla facilisi quisque lectus dui aliquet eu placerat eu viverra at velit nunc sed magna ut tortor tempor mollis a eu justo fusce ultrices  velit eget aliquam auctor turpis dui tincidunt tellus id porta libero mauris ac ligula donec rutrum est id nisl euismod facilisis quisque vitae justo sed sem blandit tincidunt phasellus condimentum luctus odio nec aliquam donec sed augue sem sed ullamcorper varius fermentum ut commodo quam non sapien pellentesque porta  vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia curae mauris mattis elit et neque congue mollis duis lacinia felis at purus hendrerit venenatis mauris placerat nulla non faucibus cursus mauris urna malesuada augue vitae vestibulum erat nulla ac odio pellentesque enim felis dictum in sodales sit amet placerat non ante  etiam dapibus leo ut tellus fermentum a bibendum augue molestie  maecenas auctor neque id ante bibendum fermentum aliquam dui magna egestas vitae condimentum pharetra imperdiet sed enim donec nisl mauris facilisis hendrerit aliquam eu rutrum vitae nisl nulla dui eros vehicula facilisis ornare nec commodo vitae velit sed at justo justo nunc justo dolor condimentum vel dignissim id malesuada et odio programmer  ', '0'),
('67', 'node', ' samantha jacobs ut a augue arcu ut lacinia arcu maecenas blandit odio ac dui scelerisque vitae ullamcorper diam mattis  etiam pharetra interdum nunc eget elementum cras molestie magna nec auctor cursus est ante hendrerit libero eget dignissim urna neque ac risus aenean cursus iaculis lacinia mauris sit amet felis pretium nulla volutpat vehicula eu et turpis maecenas vehicula molestie felis vitae feugiat lacus mollis faucibus suspendisse sollicitudin faucibus metus non tristique justo fermentum vel in ligula lacus gravida a iaculis id molestie id nibh maecenas suscipit auctor ullamcorper vivamus ut odio vel ligula pretium porta a eget arcu ut tempus quam eget orci pharetra euismod donec id mi eu augue congue vulputate et in ipsum etiam cursus adipiscing auctor phasellus in arcu arcu  accumsan aliquam massa  phasellus lacinia nulla ut pellentesque viverra dui odio tristique dolor eu tincidunt purus sem a lectus duis ut sem neque duis dignissim leo nec egestas venenatis  nulla est porta quam eget commodo nulla turpis sit amet nibh ut in arcu eget massa scelerisque dapibus nec ut leo curabitur elementum mauris ac egestas imperdiet lorem lorem pellentesque leo  quis pulvinar nibh dui non massa  nam sed dapibus metus aliquam ultrices condimentum urna id sagittis dui convallis ac nulla mollis placerat quam blandit ultricies  maecenas scelerisque molestie quam id ornare urna ornare in maecenas libero quam elementum in fringilla eget tincidunt sit amet mi duis sagittis viverra tempus nam in elit orci  ac venenatis leo aenean auctor molestie nulla quis luctus urna vulputate at vestibulum mollis nisl accumsan dignissim tristique  ipsum eros scelerisque tortor  in suscipit augue mi vitae nunc ut vel justo ligula ut vehicula eros duis dictum commodo erat vestibulum consectetur nam porta sodales mauris tristique mattis ante tincidunt eget maecenas ut aliquam risus  sed porta porttitor rhoncus vestibulum dapibus vestibulum nulla quis viverra magna pharetra a suspendisse elit velit semper eget consequat at imperdiet nec leo sed ipsum quam gravida ac eleifend in  cursus eu tellus  suspendisse mattis lacus arcu vitae mollis purus aliquam ut lorem turpis in porttitor lectus non nibh dignissim quis fermentum nulla convallis manager  ', '0'),
('68', 'node', ' sarah conor aenean sodales dapibus massa ut feugiat nulla ultrices nec vestibulum at massa in mi scelerisque placerat ut id dolor class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos phasellus nibh velit malesuada ut viverra at ultrices quis libero phasellus lectus lacus scelerisque a condimentum nec  dignissim non felis  etiam aliquam leo dictum fringilla elementum nibh nulla volutpat felis non ultricies ipsum tortor nec eros vivamus placerat  mi non gravida consequat neque tellus congue augue at molestie purus ligula id leo phasellus at diam arcu quis accumsan enim donec gravida facilisis eros cras eu elit id lectus congue dapibus et sed mi duis scelerisque ligula at sem mollis sed posuere tellus egestas donec vel fermentum felis in hac habitasse platea dictumst pellentesque sit amet est at odio adipiscing rhoncus in laoreet enim nam sollicitudin  quam non pellentesque ornare  dolor enim ornare dolor sed aliquet neque tortor at risus cras et magna eget dui congue aliquam suspendisse quis ante non augue tincidunt ornare donec vitae lacus elit ac suscipit justo vestibulum vel est neque eu blandit nulla phasellus non ornare neque  in bibendum lorem vitae vulputate posuere quam purus ultricies lectus in vehicula eros arcu a quam aliquam lacus ante pharetra interdum egestas vitae  ultrices eget velit  aliquam erat volutpat praesent mauris est aliquam sit amet tincidunt sit amet tristique non turpis aliquam eget quam tellus  vivamus aliquam libero sit amet sapien ultricies aliquam lorem ipsum dolor sit amet consectetur adipiscing elit mauris vestibulum egestas augue non fringilla fusce vel nibh ligula nec molestie nisl  integer sed massa arcu non auctor mi aenean nisi quam sollicitudin at tincidunt sit amet aliquet imperdiet neque ut a augue arcu ut lacinia arcu maecenas blandit odio ac dui scelerisque vitae ullamcorper diam mattis  etiam pharetra interdum nunc eget elementum cras molestie magna nec auctor cursus est ante hendrerit libero eget dignissim urna neque ac risus aenean cursus iaculis lacinia mauris sit amet felis pretium nulla volutpat vehicula eu et turpis maecenas vehicula molestie felis vitae feugiat lacus mollis faucibus suspendisse sollicitudin faucibus metus non tristique justo fermentum vel in ligula lacus gravida a iaculis id molestie id nibh maecenas suscipit auctor ullamcorper vivamus ut odio vel ligula pretium porta a eget arcu ut tempus quam eget orci pharetra euismod donec id mi eu augue congue vulputate et in ipsum seller  ', '0'),
('69', 'node', ' jessica parker aenean sed fermentum metus integer imperdiet nisi vel lectus fermentum malesuada  aliquam tincidunt tempus tempus aliquam euismod mauris non eros facilisis nec sagittis ipsum rutrum curabitur venenatis molestie eros vitae sagittis quam viverra a duis vel augue vel metus tempus malesuada lorem ipsum dolor sit amet consectetur adipiscing elit ut vulputate metus at vulputate mattis nibh lorem molestie ligula sed tempor enim mi vel augue aenean sodales dapibus massa ut feugiat nulla ultrices nec vestibulum at massa in mi scelerisque placerat ut id dolor class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos phasellus nibh velit malesuada ut viverra at ultrices quis libero phasellus lectus lacus scelerisque a condimentum nec  dignissim non felis  etiam aliquam leo dictum fringilla elementum nibh nulla volutpat felis non ultricies ipsum tortor nec eros vivamus placerat  mi non gravida consequat neque tellus congue augue at molestie purus ligula id leo phasellus at diam arcu quis accumsan enim donec gravida facilisis eros cras eu elit id lectus congue dapibus et sed mi duis scelerisque ligula at sem mollis sed posuere tellus egestas donec vel fermentum felis in hac habitasse platea dictumst pellentesque sit amet est at odio adipiscing rhoncus in laoreet enim nam sollicitudin  quam non pellentesque ornare  dolor enim ornare dolor sed aliquet neque tortor at risus cras et magna eget dui congue aliquam suspendisse quis ante non augue tincidunt ornare donec vitae lacus elit ac suscipit justo vestibulum vel est neque eu blandit nulla phasellus non ornare neque  in bibendum lorem vitae vulputate posuere quam purus ultricies lectus in vehicula eros arcu a quam aliquam lacus ante pharetra interdum egestas vitae  ultrices eget velit  aliquam erat volutpat ceo  ', '0'),
('71', 'node', ' david johnson sed ullamcorper varius fermentum ut commodo quam non sapien pellentesque porta  vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia curae mauris mattis elit et neque congue mollis duis lacinia felis at purus hendrerit venenatis mauris placerat nulla non faucibus cursus mauris urna malesuada augue vitae vestibulum erat nulla ac odio pellentesque enim felis dictum in sodales sit amet placerat non ante  etiam dapibus leo ut tellus fermentum a bibendum augue molestie  maecenas auctor neque id ante bibendum fermentum aliquam dui magna egestas vitae condimentum pharetra imperdiet sed enim donec nisl mauris facilisis hendrerit aliquam eu rutrum vitae nisl nulla dui eros vehicula facilisis ornare nec commodo vitae velit sed at justo justo nunc justo dolor condimentum vel dignissim id malesuada et odio nulla ultricies enim aliquet augue eleifend iaculis nam sollicitudin ligula ac nisi iaculis eu scelerisque risus ultricies nullam eu elit risus vel interdum urna aenean leo nulla aliquet vitae ultricies sit amet porttitor id sapien in hac habitasse platea dictumst donec pharetra gravida augue at hendrerit cras ut sagittis justo maecenas velit elit eleifend sed sollicitudin sed interdum eu erat duis rhoncus libero vitae orci interdum vehicula sed sodales tellus at justo interdum aliquet proin dolor justo molestie ac suscipit vel faucibus nec eros phasellus congue ornare ipsum non pellentesque orci luctus in sed ligula lorem  commodo in suscipit eget bibendum nec sapien duis tincidunt magna ac ullamcorper euismod leo lectus ultricies nibh ut placerat lectus risus vitae orci duis tincidunt dolor vel fermentum eleifend  justo tortor pellentesque turpis at tincidunt metus metus et velit vivamus semper lacinia sodales sed ultrices metus tincidunt ante rutrum tincidunt nulla dignissim orci eu ante dapibus pulvinar integer nibh neque eleifend et egestas eget suscipit ut purus vestibulum pharetra ante sed mollis vestibulum arcu turpis dapibus nunc quis dictum erat nisl sed ante fusce est ipsum suscipit sed aliquet ut hendrerit eget nisi pellentesque auctor nisl eget mi accumsan auctor vivamus tempor magna eget tellus elementum a dignissim felis aliquam donec faucibus sem quis nibh iaculis scelerisque aliquet leo eleifend fusce accumsan mauris ut placerat mattis magna mauris ultricies magna fermentum hendrerit nunc turpis quis mi suspendisse cursus arcu eu nunc faucibus in dictum ligula viverra donec non semper leo sed quis enim arcu pellentesque vestibulum risus ut elit nulla commodo ac sagittis non dapibus ut elit nunc dignissim lacinia sapien nec blandit support  ', '0'),
('73', 'node', ' sam kronshtain vivamus vel eros eget magna volutpat sagittis  nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis curabitur et libero sit amet ante hendrerit molestie cras a erat in leo lobortis tincidunt praesent aliquet eros sit amet dapibus convallis ligula magna pellentesque urna quis laoreet erat velit ullamcorper odio curabitur eget molestie sem maecenas pretium ante non purus tincidunt egestas fusce tincidunt velit sit amet euismod interdum  quam ipsum interdum nulla et tincidunt lectus diam id purus pellentesque sodales magna id tellus ultrices pellentesque aliquam libero mi faucibus quis hendrerit nec porta ac mauris duis ullamcorper est quis est rhoncus vitae pulvinar mauris pretium sed elit dui vehicula ac gravida sit amet iaculis in sem aliquam id quam arcu sed tristique eros pellentesque vestibulum   elit ac tincidunt suscipit  metus mi laoreet tellus quis imperdiet sem dolor at massa nullam tincidunt justo at dictum viverra tortor metus bibendum mauris fermentum ullamcorper mi ante in odio sed id orci et est iaculis iaculis maecenas odio nunc malesuada ac posuere vel interdum id eros in dictum arcu vel lorem tempus nec faucibus metus sodales aenean ut sem nunc curabitur convallis euismod nulla a malesuada orci accumsan ut donec pellentesque ligula sed massa tristique ac auctor purus aliquet vestibulum malesuada commodo magna id hendrerit sed at ante ipsum integer nec justo aliquet mi porttitor scelerisque eget quis elit curabitur mauris tortor laoreet et consectetur non  rhoncus sed risus  donec nisi enim adipiscing quis convallis eu elementum a urna maecenas sit amet metus sem sed non est ligula sit amet vehicula nunc maecenas sed quam non urna tincidunt pellentesque ac ut enim vestibulum arcu tortor vulputate nec semper id commodo eget lacus integer mi dolor malesuada in ullamcorper ut tincidunt eu arcu mauris dictum libero id rutrum vehicula est l igula sagittis urna  ut convallis purus purus at dolor  praesent nec vehicula tortor nulla facilisi curabitur mauris sapien interdum id consequat et lobortis ut ipsum vestibulum tempus augue eu est malesuada viverra nunc mattis fermentum metus a consectetur magna egestas lobortis class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos morbi non mauris ligula  suspendisse facilisis sagittis mauris  ac dictum elit fringilla ut billing  ', '0'),
('76', 'node', ' interior design nulla at tortor quam eu ultricies nulla maecenas viverra leo vitae mattis iaculis nisi nunc semper ligula eget lobortis est orci et tortor maecenas vitae sapien magna nec malesuada nisi proin tempus felis et dolor accumsan id ultrices erat luctus duis porta lorem sed est scelerisque tincidunt cras nulla magna accumsan ac commodo in scelerisque sit amet leo nullam sed odio lorem eu commodo dui quisque non justo est at accumsan nulla vivamus ac purus sed nunc cursus hendrerit suspendisse nunc mauris tempus non pretium nec aliquam ac turpis curabitur neque dui viverra et varius et blandit eget lectus etiam augue dolor facilisis eu convallis ut rhoncus ut leo fusce vitae dictum diam aliquam erat volutpat duis vehicula ullamcorper elementum  aliquam iaculis est eu velit faucibus convallis aenean ac lacus nec odio cursus aliquet a id urna praesent quam elit malesuada quis accumsan eget tempus vel quam donec adipiscing leo quis sapien suscipit ac bibendum felis posuere quisque interdum metus ut eros laoreet ut viverra magna vestibulum ut quis diam ligula cras mauris sem malesuada vitae gravida et condimentum in ante pellentesque vel nisi enim ac varius mi duis sem leo interdum a mollis ut tempor quis lacus sed fringilla est nec ipsum mattis tempus nulla elementum tincidunt est in dignissim cras consequat neque in mi commodo eleifend nunc laoreet augue risus eget consequat leo cras enim sapien blandit vel eleifend sit amet mattis rutrum neque phasellus sed magna quis quam tincidunt porta aliquam eget dolor neque a convallis turpis praesent volutpat tristique arcu sed suscipit magna commodo hendrerit curabitur lorem velit  tempor at ultricies eu feugiat quis dui vestibulum gravida vulputate lacus sit amet hendrerit sed fringilla arcu a tempus molestie diam purus ultrices magna a convallis risus lorem vitae est sed nec neque elit donec nec adipiscing velit pellentesque ut mauris urna et volutpat libero nulla facilisi cum sociis natoque penatibus et magnis dis parturient montes nascetur ridiculus musvivamus a purus non nibh cursus faucibus sit amet ut velit morbi tempor sagittis commodo aenean a lorem magna vel lobortis nulla praesent ac erat sit amet erat laoreet volutpat pellentesque semper ullamcorper euismod donec lorem massa blandit sit amet rhoncus non lacinia a eros pellentesque sed odio varius lectus tempor blandit sed ullamcorper malesuada magna non feugiat in hac habitasse platea dictumst etiam sapien metus aliquet consequat ornare et commodo sit amet elit nunc at neque sed magna aliquet ornare in congue feugiat sapien sed congue dui sollicitudin iaculis  ', '0'),
('77', 'node', ' our team nullam eget felis id metus luctus semper quis vel nulla cras diam mauris molestie eu sodales non sodales vitae augue integer arcu nibh semper vel cursus eu adipiscing non lacus suspendisse ultrices lacus eu nibh euismod imperdiet nunc rutrum pharetra nisl sed eleifend risus pulvinar in nunc venenatis libero et erat interdum et condimentum quam semper nulla mattis sem eget odio consequat eget malesuada ante placerat sed rhoncus posuere vulputate nam dignissim tortor a felis lobortis posuere in et ante suspendisse eu risus non nisi euismod condimentum aliquam varius orci nec eros sodales fringilla donec ac odio urna a scelerisque dui nullam auctor lacus vitae neque porttitor malesuada maecenas vel nisi nec lorem auctor suscipit proin id tincidunt justo phasellus urna ipsum sagittis convallis consectetur sit amet vestibulum eu ligula quisque rutrum erat eget arcu malesuada semper praesent faucibus lorem mi quis interdum ipsum vivamus sit amet libero vitae augue ultrices tempor vitae in arcu maecenas rutrum turpis ut pulvinar fringilla diam massa interdum ligula sit amet euismod urna dolor non velit sed gravida mollis mi placerat tincidunt nulla hendrerit et integer tempor scelerisque tellus ut facilisis nisi eleifend eget aenean consequat mollis urna et convallis lectus fermentum sit amet nulla facilisi sed tempor nulla eu leo dapibus porttitor vestibulum nec leo et sapien eleifend sagittis aliquam at diam quam maecenas ut mollis metus fusce suscipit arcu sed elit lacinia faucibus ut dapibus enim mauris ultricies semper leo quis condimentum nisi ultricies id sed et vulputate dolor proin nec magna ac ligula ornare tristique ac a lacus sed eget nisl in lectus interdum posuere a varius quam cras eros lacus ultrices vitae consequat vitae fermentum et enim nullam iaculis iaculis nisl vel dictum sem ullamcorper eget integer mattis dapibus posuere fusce ut viverra velit duis vitae cursus nulla morbi felis mauris consequat sed ornare a sollicitudin at neque quisque non magna sed odio vehicula ornare at facilisis ante nam dui magna sollicitudin sed porta eget ultrices non risus praesent quis pulvinar leo in id nunc ligula quis laoreet nunc morbi fringilla bibendum neque nec facilisis odio ullamcorper sed proin hendrerit ornare fringilla curabitur iaculis sapien eget felis laoreet tempus nam convallis convallis purus quis varius eros tempus et nunc vel libero sit amet massa semper vestibulum quis in nunc nunc sapien eros imperdiet id elementum sit amet feugiat nec tellus donec condimentum vestibulum consequat sed luctus enim quis quam luctus auctor lorem ipsum dolor sit amet consectetur adipiscing elit pellentesque nec diam felis quis vulputate orci nunc semper orci eget dolor auctor fringilla in gravida euismod hendrerit pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas phasellus quis magna tortor vestibulum sed sapien eu nibh interdum imperdiet vitae ut dui  ', '0'),
('78', 'node', ' design ideas vestibulum quis felis ut enim aliquam iaculis nullam pharetra tortor at quam viverra volutpat phasellus vel faucibus dolor curabitur ac nisi non metus dignissim dapibus eu vel nibh phasellus semper dictum dapibus etiam tincidunt adipiscing ipsum praesent in urna ipsum mauris iaculis suscipit volutpat aliquam erat volutpat aliquam vestibulum lectus vitae sapien dictum id interdum nunc suscipit aenean pellentesque auctor porttitor phasellus auctor arcu sed mi pellentesque sodales aenean eros lectus varius a consectetur imperdiet hendrerit eu leo cras odio libero cursus ac pharetra vitae iaculis in orci proin id felis neque ac fermentum orci integer nisi nulla commodo ac sodales sit amet condimentum ac arcu donec a justo nisi maecenas fermentum orci ut turpis aliquet tristique etiam at lorem ut diam fermentum elementum maecenas aliquet dolor ac orci ultrices facilisis nam et arcu pharetra neque elementum hendrerit eu ac lorem ut dapibus lacus a nisl convallis at vehicula diam fermentum curabitur adipiscing lorem sed laoreet elementum erat velit dictum leo in aliquet dui ipsum vel erat sed nec fringilla massa sed ultrices molestie sem a sodales in hac habitasse platea dictumst nunc eros libero mollis sit amet sodales ut faucibus et mauris praesent egestas sollicitudin ultrices fusce ultrices sem nec lacus convallis a tempor velit consectetur lorem ipsum dolor sit amet consectetur adipiscing elit pellentesque sed tortor enim pellentesque eu mauris sed tortor ullamcorper lobortis quis non neque suspendisse scelerisque erat tellus eu congue ante cras pretium euismod quam eu pulvinar morbi dapibus sollicitudin sapien et sollicitudin vestibulum viverra dictum sem eget fermentum eros pretium in phasellus ut leo at ligula convallis pretium aliquam mollis luctus quam et mattis sed semper nunc porttitor erat elementum porttitor cras sit amet volutpat augue nam tortor diam aliquam vel volutpat eget convallis a diam proin metus metus commodo quis commodo nec fermentum eget arcu pellentesque eleifend leo sed lacus eleifend malesuada duis porttitor augue vel ante lacinia quis pharetra augue facilisis praesent dapibus dapibus dignissim quisque vitae orci nec mauris fringilla vehicula id nec ipsum  ', '0'),
('79', 'node', ' privacy policy lorem ipsum dolor sit amet consectetur adipiscing elit sed non arcu enim nam sed magna magna eget tempus neque donec lectus enim auctor ut dignissim sit amet auctor aliquam tortor pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas phasellus a lectus id nibh mattis ultrices lorem ipsum dolor sit amet consectetur adipiscing elit duis suscipit eleifend mauris non condimentum mauris iaculis nibh id interdum hendrerit turpis turpis placerat dui ac mattis augue quam eu tortor aenean condimentum feugiat rhoncus vestibulum id nulla auctor eros vehicula pellentesque proin nec nibh erat ut interdum tortor aliquam lectus risus hendrerit vitae mollis et molestie nec turpis nullam gravida diam sed velit dignissim bibendum cras tristique mi eu tortor aliquet a blandit urna tempor maecenas adipiscing euismod sagittis suspendisse vulputate convallis tellus sed mattis justo faucibus ac phasellus non diam ut nisl viverra sodales aenean at nunc quis tortor consequat scelerisque in dignissim ante vel imperdiet venenatis felis nisi imperdiet lectus et ultrices eros justo in lacus quisque et ante ac metus eleifend laoreet cras leo metus pharetra et molestie quis iaculis ut felis nullam sed viverra libero vestibulum imperdiet fermentum massa a fringilla tortor varius vel praesent ac metus massa ac dapibus lorem nunc cursus nisi eget dui suscipit aliquam viverra odio iaculis donec commodo erat non arcu volutpat viverra nulla facilisi nam sagittis metus sit amet quam porttitor sollicitudin mauris aliquam felis at enim gravida porta sed ultrices aliquam convallis sed non consequat ligula sed purus felis pellentesque quis pretium ut bibendum at est quisque lacinia iaculis fermentum sed sed ante mauris at pretium mauris mauris leo sem dictum eget tincidunt at gravida vel lacus nam fringilla tristique lectus etiam aliquam odio ac arcu posuere placerat nunc ipsum eros euismod vitae molestie at euismod ut nisl pellentesque a convallis dui nunc porttitor turpis vel faucibus sollicitudin dui nunc placerat risus non eleifend nulla risus at diam integer eget dui dui ut porta felis nam nisi nisl eleifend a pulvinar nec pulvinar vitae lorem in tristique egestas ligula mauris sed dui nec leo molestie tempor praesent pellentesque molestie magna a venenatis orci viverra in donec eget dui sit amet tortor ornare semper non et est suspendisse a orci ut velit consectetur placerat class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos maecenas lacinia tincidunt leo in tincidunt fusce lacus tortor venenatis id fringilla convallis interdum nec elit sed viverra felis in laoreet ultrices leo ligula molestie augue vel tincidunt turpis mi vel orci nunc dolor orci ultricies sed vestibulum sed cursus nec risus duis augue risus ullamcorper vel condimentum cursus aliquam nec risus nunc id mauris in massa lacinia bibendum mauris lacinia sagittis adipiscing maecenas gravida sapien at magna semper dignissim a vel erat phasellus nec risus vel augue bibendum bibendum nullam posuere libero dui id gravida erat morbi est tortor auctor a iaculis ullamcorper gravida eget magna nam aliquam enim non justo volutpat eget aliquet diam iaculis cras dui eros consectetur eu mattis eleifend laoreet in turpis curabitur eu porta lacus email  admin demolinkorg ', '0'),
('81', 'node', ' our location ', '0'),
('82', 'node', ' lorem ipsum dolor sit amet vivamus vel eros eget magna volutpat sagittis  nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis curabitur et libero sit amet ante hendrerit molestie cras a erat in leo lobortis tincidunt praesent aliquet eros sit amet dapibus convallis ligula magna pellentesque urna quis laoreet erat velit ullamcorper odio curabitur eget molestie sem maecenas pretium ante non purus tincidunt egestas fusce tincidunt velit sit amet euismod interdum  quam ipsum interdum nulla et tincidunt lectus diam id purus pellentesque sodales magna id tellus ultrices pellentesque aliquam libero mi faucibus quis hendrerit nec porta ac mauris duis ullamcorper est quis est rhoncus vitae pulvinar mauris pretium sed elit dui vehicula ac gravida sit amet iaculis in sem aliquam id quam arcu sed tristique eros pellentesque vestibulum   elit ac tincidunt suscipit  metus mi laoreet tellus quis imperdiet sem dolor at massa nullam tincidunt justo at dictum viverra tortor metus bibendum mauris fermentum ullamcorper mi ante in odio sed id orci et est iaculis iaculis maecenas odio nunc malesuada ac posuere vel interdum id eros in dictum arcu vel lorem tempus nec faucibus metus sodales aenean ut sem nunc curabitur convallis euismod nulla a malesuada orci accumsan ut donec pellentesque ligula sed massa tristique ac auctor purus aliquet vestibulum malesuada commodo magna id hendrerit sed at ante ipsum integer nec justo aliquet mi porttitor scelerisque eget quis elit all ', '1379064099'),
('83', 'node', ' praesent vestibulum vivamus vel eros eget magna volutpat sagittis  nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis curabitur et libero sit amet ante hendrerit molestie cras a erat in leo lobortis tincidunt praesent aliquet eros sit amet dapibus convallis ligula magna pellentesque urna quis laoreet erat velit ullamcorper odio curabitur eget molestie sem maecenas pretium ante non purus tincidunt egestas fusce tincidunt velit sit amet euismod interdum  quam ipsum interdum nulla et tincidunt lectus diam id purus pellentesque sodales magna id tellus ultrices pellentesque aliquam libero mi faucibus quis hendrerit nec porta ac mauris duis ullamcorper est quis est rhoncus vitae pulvinar mauris pretium sed elit dui vehicula ac gravida sit amet iaculis in sem aliquam id quam arcu sed tristique eros pellentesque vestibulum   elit ac tincidunt suscipit  metus mi laoreet tellus quis imperdiet sem dolor at massa nullam tincidunt justo at dictum viverra tortor metus bibendum mauris fermentum ullamcorper mi ante in odio sed id orci et est iaculis iaculis maecenas odio nunc malesuada ac posuere vel interdum id eros in dictum arcu vel lorem tempus nec faucibus metus sodales aenean ut sem nunc curabitur convallis euismod nulla a malesuada orci accumsan ut donec pellentesque ligula sed massa tristique ac auctor purus aliquet vestibulum malesuada commodo magna id hendrerit sed at ante ipsum integer nec justo aliquet mi porttitor scelerisque eget quis elit curabitur mauris tortor laoreet et consectetur non  rhoncus sed risus  donec nisi enim adipiscing quis convallis eu elementum a urna maecenas sit amet metus sem sed non est ligula sit amet vehicula nunc maecenas sed quam non urna tincidunt pellentesque ac ut enim vestibulum arcu tortor vulputate nec semper id commodo eget lacus integer mi dolor malesuada in ullamcorper ut tincidunt eu arcu mauris dictum libero id rutrum vehicula est l igula sagittis urna  ut convallis purus purus at dolor  praesent nec vehicula tortor nulla facilisi curabitur mauris sapien interdum id consequat et lobortis ut ipsum vestibulum tempus augue eu est malesuada viverra nunc mattis fermentum metus a consectetur magna egestas lobortis class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos morbi non mauris ligula  suspendisse facilisis sagittis mauris  ac dictum elit fringilla ut  ', '0'),
('84', 'node', ' lorem ipsum dolor sit amet vivamus vel eros eget magna volutpat sagittis  nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis curabitur et libero sit amet ante hendrerit molestie cras a erat in leo lobortis tincidunt praesent aliquet eros sit amet dapibus convallis ligula magna pellentesque urna quis laoreet erat velit ullamcorper odio curabitur eget molestie sem maecenas pretium ante non purus tincidunt egestas fusce tincidunt velit sit amet euismod interdum  quam ipsum interdum nulla et tincidunt lectus diam id purus pellentesque sodales magna id tellus ultrices pellentesque aliquam libero mi faucibus quis hendrerit nec porta ac mauris duis ullamcorper est quis est rhoncus vitae pulvinar mauris pretium sed elit dui vehicula ac gravida sit amet iaculis in sem aliquam id quam arcu sed tristique eros pellentesque vestibulum   elit ac tincidunt suscipit  metus mi laoreet tellus quis imperdiet sem dolor at massa nullam tincidunt justo at dictum viverra tortor metus bibendum mauris fermentum ullamcorper mi ante in odio sed id orci et est iaculis iaculis maecenas odio nunc malesuada ac posuere vel interdum id eros in dictum arcu vel lorem tempus nec faucibus metus sodales aenean ut sem nunc curabitur convallis euismod nulla a malesuada orci accumsan ut donec pellentesque ligula sed massa tristique ac auctor purus aliquet vestibulum malesuada commodo magna id hendrerit sed at ante ipsum integer nec justo aliquet mi porttitor scelerisque eget quis elit curabitur mauris tortor laoreet et consectetur non  rhoncus sed risus  donec nisi enim adipiscing quis convallis eu elementum a urna maecenas sit amet metus sem sed non est ligula sit amet vehicula nunc maecenas sed quam non urna tincidunt pellentesque ac ut enim vestibulum arcu tortor vulputate nec semper id commodo eget lacus integer mi dolor malesuada in ullamcorper ut tincidunt eu arcu mauris dictum libero id rutrum vehicula est l igula sagittis urna  ut convallis purus purus at dolor  praesent nec vehicula tortor nulla facilisi curabitur mauris sapien interdum id consequat et lobortis ut ipsum vestibulum tempus augue eu est malesuada viverra nunc mattis fermentum metus a consectetur magna egestas lobortis class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos morbi non mauris ligula  suspendisse facilisis sagittis mauris  ac dictum elit fringilla ut  ', '0'),
('85', 'node', ' ut enim ad minima veniam vivamus vel eros eget magna volutpat sagittis  nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis curabitur et libero sit amet ante hendrerit molestie cras a erat in leo lobortis tincidunt praesent aliquet eros sit amet dapibus convallis ligula magna pellentesque urna quis laoreet erat velit ullamcorper odio curabitur eget molestie sem maecenas pretium ante non purus tincidunt egestas fusce tincidunt velit sit amet euismod interdum  quam ipsum interdum nulla et tincidunt lectus diam id purus pellentesque sodales magna id tellus ultrices pellentesque aliquam libero mi faucibus quis hendrerit nec porta ac mauris duis ullamcorper est quis est rhoncus vitae pulvinar mauris pretium sed elit dui vehicula ac gravida sit amet iaculis in sem aliquam id quam arcu sed tristique eros pellentesque vestibulum   elit ac tincidunt suscipit  metus mi laoreet tellus quis imperdiet sem dolor at massa nullam tincidunt justo at dictum viverra tortor metus bibendum mauris fermentum ullamcorper mi ante in odio sed id orci et est iaculis iaculis maecenas odio nunc malesuada ac posuere vel interdum id eros in dictum arcu vel lorem tempus nec faucibus metus sodales aenean ut sem nunc curabitur convallis euismod nulla a malesuada orci accumsan ut donec pellentesque ligula sed massa tristique ac auctor purus aliquet vestibulum malesuada commodo magna id hendrerit sed at ante ipsum integer nec justo aliquet mi porttitor scelerisque eget quis elit curabitur mauris tortor laoreet et consectetur non  rhoncus sed risus  donec nisi enim adipiscing quis convallis eu elementum a urna maecenas sit amet metus sem sed non est ligula sit amet vehicula nunc maecenas sed quam non urna tincidunt pellentesque ac ut enim vestibulum arcu tortor vulputate nec semper id commodo eget lacus integer mi dolor malesuada in ullamcorper ut tincidunt eu arcu mauris dictum libero id rutrum vehicula est l igula sagittis urna  ut convallis purus purus at dolor  praesent nec vehicula tortor nulla facilisi curabitur mauris sapien interdum id consequat et lobortis ut ipsum vestibulum tempus augue eu est malesuada viverra nunc mattis fermentum metus a consectetur magna egestas lobortis class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos morbi non mauris ligula  suspendisse facilisis sagittis mauris  ac dictum elit fringilla ut  ', '0'),
('86', 'node', ' sed ut perspiciatis unde vivamus vel eros eget magna volutpat sagittis  nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis curabitur et libero sit amet ante hendrerit molestie cras a erat in leo lobortis tincidunt praesent aliquet eros sit amet dapibus convallis ligula magna pellentesque urna quis laoreet erat velit ullamcorper odio curabitur eget molestie sem maecenas pretium ante non purus tincidunt egestas fusce tincidunt velit sit amet euismod interdum  quam ipsum interdum nulla et tincidunt lectus diam id purus pellentesque sodales magna id tellus ultrices pellentesque aliquam libero mi faucibus quis hendrerit nec porta ac mauris duis ullamcorper est quis est rhoncus vitae pulvinar mauris pretium sed elit dui vehicula ac gravida sit amet iaculis in sem aliquam id quam arcu sed tristique eros pellentesque vestibulum   elit ac tincidunt suscipit  metus mi laoreet tellus quis imperdiet sem dolor at massa nullam tincidunt justo at dictum viverra tortor metus bibendum mauris fermentum ullamcorper mi ante in odio sed id orci et est iaculis iaculis maecenas odio nunc malesuada ac posuere vel interdum id eros in dictum arcu vel lorem tempus nec faucibus metus sodales aenean ut sem nunc curabitur convallis euismod nulla a malesuada orci accumsan ut donec pellentesque ligula sed massa tristique ac auctor purus aliquet vestibulum malesuada commodo magna id hendrerit sed at ante ipsum integer nec justo aliquet mi porttitor scelerisque eget quis elit curabitur mauris tortor laoreet et consectetur non  rhoncus sed risus  donec nisi enim adipiscing quis convallis eu elementum a urna maecenas sit amet metus sem sed non est ligula sit amet vehicula nunc maecenas sed quam non urna tincidunt pellentesque ac ut enim vestibulum arcu tortor vulputate nec semper id commodo eget lacus integer mi dolor malesuada in ullamcorper ut tincidunt eu arcu mauris dictum libero id rutrum vehicula est l igula sagittis urna  ut convallis purus purus at dolor  praesent nec vehicula tortor nulla facilisi curabitur mauris sapien interdum id consequat et lobortis ut ipsum vestibulum tempus augue eu est malesuada viverra nunc mattis fermentum metus a consectetur magna egestas lobortis class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos morbi non mauris ligula  suspendisse facilisis sagittis mauris  ac dictum elit fringilla ut  ', '0'),
('87', 'node', ' vestibulum iaculis lacinia vivamus vel eros eget magna volutpat sagittis  nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis curabitur et libero sit amet ante hendrerit molestie cras a erat in leo lobortis tincidunt praesent aliquet eros sit amet dapibus convallis ligula magna pellentesque urna quis laoreet erat velit ullamcorper odio curabitur eget molestie sem maecenas pretium ante non purus tincidunt egestas fusce tincidunt velit sit amet euismod interdum  quam ipsum interdum nulla et tincidunt lectus diam id purus pellentesque sodales magna id tellus ultrices pellentesque aliquam libero mi faucibus quis hendrerit nec porta ac mauris duis ullamcorper est quis est rhoncus vitae pulvinar mauris pretium sed elit dui vehicula ac gravida sit amet iaculis in sem aliquam id quam arcu sed tristique eros pellentesque vestibulum   elit ac tincidunt suscipit  metus mi laoreet tellus quis imperdiet sem dolor at massa nullam tincidunt justo at dictum viverra tortor metus bibendum mauris fermentum ullamcorper mi ante in odio sed id orci et est iaculis iaculis maecenas odio nunc malesuada ac posuere vel interdum id eros in dictum arcu vel lorem tempus nec faucibus metus sodales aenean ut sem nunc curabitur convallis euismod nulla a malesuada orci accumsan ut donec pellentesque ligula sed massa tristique ac auctor purus aliquet vestibulum malesuada commodo magna id hendrerit sed at ante ipsum integer nec justo aliquet mi porttitor scelerisque eget quis elit curabitur mauris tortor laoreet et consectetur non  rhoncus sed risus  donec nisi enim adipiscing quis convallis eu elementum a urna maecenas sit amet metus sem sed non est ligula sit amet vehicula nunc maecenas sed quam non urna tincidunt pellentesque ac ut enim vestibulum arcu tortor vulputate nec semper id commodo eget lacus integer mi dolor malesuada in ullamcorper ut tincidunt eu arcu mauris dictum libero id rutrum vehicula est l igula sagittis urna  ut convallis purus purus at dolor  praesent nec vehicula tortor nulla facilisi curabitur mauris sapien interdum id consequat et lobortis ut ipsum vestibulum tempus augue eu est malesuada viverra nunc mattis fermentum metus a consectetur magna egestas lobortis class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos morbi non mauris ligula  suspendisse facilisis sagittis mauris  ac dictum elit fringilla ut  ', '0'),
('88', 'node', ' jack smith vivamus vel eros eget magna volutpat sagittis  nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis curabitur et libero sit amet ante hendrerit molestie cras a erat in leo lobortis tincidunt praesent aliquet eros sit amet dapibus convallis ligula magna pellentesque urna quis laoreet erat velit ullamcorper odio curabitur eget molestie sem maecenas pretium ante non purus tincidunt egestas fusce tincidunt velit sit amet euismod interdum  quam ipsum interdum nulla et tincidunt lectus diam id purus pellentesque sodales magna id tellus ultrices pellentesque aliquam libero mi faucibus quis hendrerit nec porta ac mauris duis ullamcorper est quis est rhoncus vitae pulvinar mauris pretium sed elit dui vehicula ac gravida sit amet iaculis in sem aliquam id quam arcu sed tristique eros pellentesque vestibulum   elit ac tincidunt suscipit  metus mi laoreet tellus quis imperdiet sem dolor at massa nullam tincidunt justo at dictum viverra tortor metus bibendum mauris fermentum ullamcorper mi ante in odio sed id orci et est iaculis iaculis maecenas odio nunc malesuada ac posuere vel interdum id eros in dictum arcu vel lorem tempus nec faucibus metus sodales aenean ut sem nunc curabitur convallis euismod nulla a malesuada orci accumsan ut donec pellentesque ligula sed massa tristique ac auctor purus aliquet vestibulum malesuada commodo magna id hendrerit sed at ante ipsum integer nec justo aliquet mi porttitor scelerisque eget quis elit curabitur mauris tortor laoreet et consectetur non  rhoncus sed risus  donec nisi enim adipiscing quis convallis eu elementum a urna maecenas sit amet metus sem sed non est ligula sit amet vehicula nunc maecenas sed quam non urna tincidunt pellentesque ac ut enim vestibulum arcu tortor vulputate nec semper id commodo eget lacus integer mi dolor malesuada in ullamcorper ut tincidunt eu arcu mauris dictum libero id rutrum vehicula est l igula sagittis urna  ut convallis purus purus at dolor  praesent nec vehicula tortor nulla facilisi curabitur mauris sapien interdum id consequat et lobortis ut ipsum vestibulum tempus augue eu est malesuada viverra nunc mattis fermentum metus a consectetur magna egestas lobortis class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos morbi non mauris ligula  suspendisse facilisis sagittis mauris  ac dictum elit fringilla ut metho org  ', '0'),
('89', 'node', ' lisa cole vivamus vel eros eget magna volutpat sagittis  nulla faucibus nibh a magna tincidunt accumsan hendrerit nunc facilisis curabitur et libero sit amet ante hendrerit molestie cras a erat in leo lobortis tincidunt praesent aliquet eros sit amet dapibus convallis ligula magna pellentesque urna quis laoreet erat velit ullamcorper odio curabitur eget molestie sem maecenas pretium ante non purus tincidunt egestas fusce tincidunt velit sit amet euismod interdum  quam ipsum interdum nulla et tincidunt lectus diam id purus pellentesque sodales magna id tellus ultrices pellentesque aliquam libero mi faucibus quis hendrerit nec porta ac mauris duis ullamcorper est quis est rhoncus vitae pulvinar mauris pretium sed elit dui vehicula ac gravida sit amet iaculis in sem aliquam id quam arcu sed tristique eros pellentesque vestibulum   elit ac tincidunt suscipit  metus mi laoreet tellus quis imperdiet sem dolor at massa nullam tincidunt justo at dictum viverra tortor metus bibendum mauris fermentum ullamcorper mi ante in odio sed id orci et est iaculis iaculis maecenas odio nunc malesuada ac posuere vel interdum id eros in dictum arcu vel lorem tempus nec faucibus metus sodales aenean ut sem nunc curabitur convallis euismod nulla a malesuada orci accumsan ut donec pellentesque ligula sed massa tristique ac auctor purus aliquet vestibulum malesuada commodo magna id hendrerit sed at ante ipsum integer nec justo aliquet mi porttitor scelerisque eget quis elit curabitur mauris tortor laoreet et consectetur non  rhoncus sed risus  donec nisi enim adipiscing quis convallis eu elementum a urna maecenas sit amet metus sem sed non est ligula sit amet vehicula nunc maecenas sed quam non urna tincidunt pellentesque ac ut enim vestibulum arcu tortor vulputate nec semper id commodo eget lacus integer mi dolor malesuada in ullamcorper ut tincidunt eu arcu mauris dictum libero id rutrum vehicula est l igula sagittis urna  ut convallis purus purus at dolor  praesent nec vehicula tortor nulla facilisi curabitur mauris sapien interdum id consequat et lobortis ut ipsum vestibulum tempus augue eu est malesuada viverra nunc mattis fermentum metus a consectetur magna egestas lobortis class aptent taciti sociosqu ad litora torquent per conubia nostra per inceptos himenaeos morbi non mauris ligula  suspendisse facilisis sagittis mauris  ac dictum elit fringilla ut metho org  ', '0');
/*!40000 ALTER TABLE search_dataset ENABLE KEYS */;

--
-- Table structure for table 'search_index'
--

CREATE TABLE IF NOT EXISTS `search_index` (
  `word` varchar(50) NOT NULL DEFAULT '' COMMENT 'The search_total.word that is associated with the search item.',
  `sid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The search_dataset.sid of the searchable item to which the word belongs.',
  `type` varchar(16) NOT NULL COMMENT 'The search_dataset.type of the searchable item to which the word belongs.',
  `score` float DEFAULT NULL COMMENT 'The numeric score of the word, higher being more important.',
  PRIMARY KEY (`word`,`sid`,`type`),
  KEY `sid_type` (`sid`,`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores the search index, associating words, items and...';

--
-- Dumping data for table 'search_index'
--

/*!40000 ALTER TABLE search_index DISABLE KEYS */;
INSERT INTO `search_index` VALUES
('11', '11', 'node', '1'),
('1535', '12', 'node', '2.47054'),
('1537', '13', 'node', '0.953396'),
('1538', '14', 'node', '3.94806'),
('1539', '16', 'node', '0.902857'),
('1540', '16', 'node', '0.857458'),
('1813', '36', 'node', '2.53037'),
('1856', '41', 'node', '0.854391'),
('20', '11', 'node', '1'),
('2192', '11', 'node', '1'),
('235', '11', 'node', '1'),
('31', '11', 'node', '1'),
('39', '11', 'node', '1'),
('432', '11', 'node', '1'),
('5112011', '12', 'node', '2.47372'),
('5112011', '13', 'node', '0.957226'),
('5112011', '14', 'node', '3.95098'),
('5112011', '16', 'node', '1.76374'),
('678', '11', 'node', '1'),
('7172013', '41', 'node', '0.857458'),
('847', '11', 'node', '1'),
('9202011', '36', 'node', '2.53346'),
('about', '11', 'node', '26'),
('accumsan', '12', 'node', '0.808176'),
('accumsan', '13', 'node', '2'),
('accumsan', '14', 'node', '2.40987'),
('accumsan', '15', 'node', '2'),
('accumsan', '16', 'node', '1.92384'),
('accumsan', '17', 'node', '1'),
('accumsan', '18', 'node', '1'),
('accumsan', '19', 'node', '2'),
('accumsan', '20', 'node', '2.96498'),
('accumsan', '22', 'node', '1.87314'),
('accumsan', '24', 'node', '0.886095'),
('accumsan', '25', 'node', '1'),
('accumsan', '26', 'node', '1'),
('accumsan', '27', 'node', '2'),
('accumsan', '28', 'node', '2.91674'),
('accumsan', '29', 'node', '2.91099'),
('accumsan', '30', 'node', '2'),
('accumsan', '31', 'node', '1'),
('accumsan', '37', 'node', '1.9347'),
('accumsan', '38', 'node', '0.892724'),
('accumsan', '39', 'node', '1'),
('accumsan', '40', 'node', '1'),
('accumsan', '41', 'node', '4.5627'),
('accumsan', '46', 'node', '26'),
('accumsan', '47', 'node', '1'),
('accumsan', '50', 'node', '1'),
('accumsan', '52', 'node', '2'),
('accumsan', '53', 'node', '2'),
('accumsan', '54', 'node', '2'),
('accumsan', '55', 'node', '2'),
('accumsan', '56', 'node', '2'),
('accumsan', '57', 'node', '2'),
('accumsan', '58', 'node', '2'),
('accumsan', '67', 'node', '4.97685'),
('accumsan', '68', 'node', '1'),
('accumsan', '69', 'node', '1'),
('accumsan', '71', 'node', '1.84066'),
('accumsan', '73', 'node', '2'),
('accumsan', '76', 'node', '4'),
('accumsan', '82', 'node', '2'),
('accumsan', '83', 'node', '2'),
('accumsan', '84', 'node', '2'),
('accumsan', '85', 'node', '2'),
('accumsan', '86', 'node', '2'),
('accumsan', '87', 'node', '2'),
('accumsan', '88', 'node', '2'),
('accumsan', '89', 'node', '2'),
('adipiscing', '12', 'node', '4.53926'),
('adipiscing', '13', 'node', '1'),
('adipiscing', '14', 'node', '4.92077'),
('adipiscing', '15', 'node', '1'),
('adipiscing', '16', 'node', '2.68374'),
('adipiscing', '17', 'node', '1'),
('adipiscing', '20', 'node', '1'),
('adipiscing', '21', 'node', '4.87326'),
('adipiscing', '22', 'node', '3.93105'),
('adipiscing', '23', 'node', '4.87326'),
('adipiscing', '24', 'node', '2.8896'),
('adipiscing', '25', 'node', '1.89996'),
('adipiscing', '26', 'node', '2'),
('adipiscing', '27', 'node', '1'),
('adipiscing', '28', 'node', '0.938382'),
('adipiscing', '29', 'node', '1.99315'),
('adipiscing', '30', 'node', '0.931053'),
('adipiscing', '33', 'node', '1'),
('adipiscing', '34', 'node', '1'),
('adipiscing', '36', 'node', '1.87634'),
('adipiscing', '37', 'node', '5.74324'),
('adipiscing', '38', 'node', '6.76287'),
('adipiscing', '39', 'node', '3'),
('adipiscing', '40', 'node', '2'),
('adipiscing', '41', 'node', '4.69562'),
('adipiscing', '42', 'node', '27'),
('adipiscing', '46', 'node', '1'),
('adipiscing', '47', 'node', '1'),
('adipiscing', '50', 'node', '0.938382'),
('adipiscing', '65', 'node', '1'),
('adipiscing', '67', 'node', '1'),
('adipiscing', '68', 'node', '1.94583'),
('adipiscing', '69', 'node', '4.99315'),
('adipiscing', '73', 'node', '1'),
('adipiscing', '76', 'node', '1.9496'),
('adipiscing', '77', 'node', '1.89272'),
('adipiscing', '78', 'node', '3'),
('adipiscing', '79', 'node', '6.84234'),
('adipiscing', '83', 'node', '1'),
('adipiscing', '84', 'node', '1'),
('adipiscing', '85', 'node', '1'),
('adipiscing', '86', 'node', '1'),
('adipiscing', '87', 'node', '1'),
('adipiscing', '88', 'node', '1'),
('adipiscing', '89', 'node', '1'),
('adipisicing', '36', 'node', '26'),
('admin', '12', 'node', '2.48015'),
('admin', '13', 'node', '0.96498'),
('admin', '14', 'node', '3.95687'),
('admin', '16', 'node', '1.77068'),
('admin', '36', 'node', '2.53971'),
('admin', '37', 'node', '11'),
('admin', '38', 'node', '11'),
('admin', '39', 'node', '11'),
('admin', '40', 'node', '11'),
('admin', '41', 'node', '11.8605'),
('admin', '79', 'node', '9.16882'),
('aenean', '12', 'node', '0.845322'),
('aenean', '14', 'node', '1.57694'),
('aenean', '15', 'node', '0.896076'),
('aenean', '18', 'node', '1'),
('aenean', '19', 'node', '1'),
('aenean', '20', 'node', '1'),
('aenean', '21', 'node', '0.927431'),
('aenean', '22', 'node', '1.92027'),
('aenean', '23', 'node', '0.927431'),
('aenean', '25', 'node', '3.91329'),
('aenean', '26', 'node', '2.77758'),
('aenean', '27', 'node', '1'),
('aenean', '28', 'node', '1.8894'),
('aenean', '29', 'node', '1.9534'),
('aenean', '30', 'node', '1'),
('aenean', '32', 'node', '1'),
('aenean', '33', 'node', '1.93408'),
('aenean', '34', 'node', '1'),
('aenean', '35', 'node', '1'),
('aenean', '36', 'node', '23.5811'),
('aenean', '37', 'node', '2.91323'),
('aenean', '38', 'node', '0.896076'),
('aenean', '39', 'node', '1'),
('aenean', '40', 'node', '2.69971'),
('aenean', '41', 'node', '2.91323'),
('aenean', '47', 'node', '1'),
('aenean', '51', 'node', '2'),
('aenean', '52', 'node', '1'),
('aenean', '53', 'node', '1'),
('aenean', '54', 'node', '1'),
('aenean', '55', 'node', '12'),
('aenean', '56', 'node', '1'),
('aenean', '57', 'node', '12'),
('aenean', '58', 'node', '12'),
('aenean', '67', 'node', '11.8792'),
('aenean', '68', 'node', '2.82713'),
('aenean', '69', 'node', '2'),
('aenean', '71', 'node', '1'),
('aenean', '73', 'node', '1'),
('aenean', '76', 'node', '1.89272'),
('aenean', '77', 'node', '1'),
('aenean', '78', 'node', '2'),
('aenean', '79', 'node', '2'),
('aenean', '82', 'node', '1'),
('aenean', '83', 'node', '1'),
('aenean', '84', 'node', '1'),
('aenean', '85', 'node', '1'),
('aenean', '86', 'node', '1'),
('aenean', '87', 'node', '1'),
('aenean', '88', 'node', '1'),
('aenean', '89', 'node', '1'),
('aliquam', '12', 'node', '4.57125'),
('aliquam', '13', 'node', '6.94209'),
('aliquam', '14', 'node', '7.69482'),
('aliquam', '15', 'node', '3.99315'),
('aliquam', '16', 'node', '8.24743'),
('aliquam', '17', 'node', '27'),
('aliquam', '19', 'node', '0.96498'),
('aliquam', '20', 'node', '2.83481'),
('aliquam', '21', 'node', '2.87208'),
('aliquam', '22', 'node', '5.81765'),
('aliquam', '23', 'node', '2.87208'),
('aliquam', '24', 'node', '2.79805'),
('aliquam', '25', 'node', '2.96109'),
('aliquam', '26', 'node', '3.91323'),
('aliquam', '27', 'node', '3'),
('aliquam', '28', 'node', '2.90974'),
('aliquam', '29', 'node', '2.86943'),
('aliquam', '30', 'node', '2'),
('aliquam', '31', 'node', '2.94583'),
('aliquam', '32', 'node', '30'),
('aliquam', '33', 'node', '41.9572'),
('aliquam', '34', 'node', '12'),
('aliquam', '35', 'node', '4'),
('aliquam', '36', 'node', '27.1689'),
('aliquam', '37', 'node', '1'),
('aliquam', '38', 'node', '3.88401'),
('aliquam', '39', 'node', '3.98493'),
('aliquam', '40', 'node', '2.58825'),
('aliquam', '41', 'node', '3.67943'),
('aliquam', '43', 'node', '2'),
('aliquam', '45', 'node', '26'),
('aliquam', '47', 'node', '1'),
('aliquam', '50', 'node', '2'),
('aliquam', '51', 'node', '3.97685'),
('aliquam', '52', 'node', '2'),
('aliquam', '53', 'node', '2'),
('aliquam', '54', 'node', '2'),
('aliquam', '55', 'node', '2'),
('aliquam', '56', 'node', '2'),
('aliquam', '57', 'node', '2'),
('aliquam', '58', 'node', '2'),
('aliquam', '65', 'node', '3.67841'),
('aliquam', '67', 'node', '9.74102'),
('aliquam', '68', 'node', '10.6314'),
('aliquam', '69', 'node', '5.8011'),
('aliquam', '71', 'node', '2.91674'),
('aliquam', '73', 'node', '2'),
('aliquam', '76', 'node', '3.9689'),
('aliquam', '77', 'node', '1.98087'),
('aliquam', '78', 'node', '4.88798'),
('aliquam', '79', 'node', '7.43347'),
('aliquam', '82', 'node', '2'),
('aliquam', '83', 'node', '2'),
('aliquam', '84', 'node', '2'),
('aliquam', '85', 'node', '2'),
('aliquam', '86', 'node', '2'),
('aliquam', '87', 'node', '2'),
('aliquam', '88', 'node', '2'),
('aliquam', '89', 'node', '2'),
('aliquet', '12', 'node', '1.7767'),
('aliquet', '13', 'node', '1'),
('aliquet', '14', 'node', '2.74529'),
('aliquet', '16', 'node', '4.5618'),
('aliquet', '17', 'node', '2.89919'),
('aliquet', '18', 'node', '3'),
('aliquet', '19', 'node', '3'),
('aliquet', '20', 'node', '1'),
('aliquet', '21', 'node', '2.94978'),
('aliquet', '22', 'node', '28'),
('aliquet', '23', 'node', '28.9498'),
('aliquet', '25', 'node', '2.98902'),
('aliquet', '26', 'node', '2.84825'),
('aliquet', '27', 'node', '2'),
('aliquet', '28', 'node', '4.56132'),
('aliquet', '29', 'node', '1.94242'),
('aliquet', '30', 'node', '1'),
('aliquet', '31', 'node', '1'),
('aliquet', '32', 'node', '1'),
('aliquet', '33', 'node', '1'),
('aliquet', '34', 'node', '1'),
('aliquet', '35', 'node', '1'),
('aliquet', '36', 'node', '2.84532'),
('aliquet', '37', 'node', '2.95723'),
('aliquet', '38', 'node', '3'),
('aliquet', '39', 'node', '2.99731'),
('aliquet', '40', 'node', '0.882818'),
('aliquet', '41', 'node', '1.90629'),
('aliquet', '42', 'node', '1'),
('aliquet', '44', 'node', '1'),
('aliquet', '47', 'node', '1.98493'),
('aliquet', '50', 'node', '2'),
('aliquet', '51', 'node', '0.980874'),
('aliquet', '52', 'node', '3'),
('aliquet', '53', 'node', '3'),
('aliquet', '54', 'node', '3'),
('aliquet', '55', 'node', '3'),
('aliquet', '56', 'node', '3'),
('aliquet', '57', 'node', '3'),
('aliquet', '58', 'node', '3'),
('aliquet', '65', 'node', '1'),
('aliquet', '68', 'node', '1.92743'),
('aliquet', '69', 'node', '0.972861'),
('aliquet', '71', 'node', '4.84066'),
('aliquet', '73', 'node', '3'),
('aliquet', '76', 'node', '2.73674'),
('aliquet', '78', 'node', '13'),
('aliquet', '79', 'node', '1.83938'),
('aliquet', '82', 'node', '3'),
('aliquet', '83', 'node', '3'),
('aliquet', '84', 'node', '3'),
('aliquet', '85', 'node', '3'),
('aliquet', '86', 'node', '3'),
('aliquet', '87', 'node', '3'),
('aliquet', '88', 'node', '3'),
('aliquet', '89', 'node', '3'),
('all', '52', 'node', '11'),
('all', '53', 'node', '11'),
('all', '54', 'node', '11'),
('all', '55', 'node', '11'),
('all', '56', 'node', '11'),
('all', '57', 'node', '11'),
('all', '58', 'node', '11'),
('all', '82', 'node', '11'),
('amet', '12', 'node', '63.5435'),
('amet', '13', 'node', '9.77264'),
('amet', '14', 'node', '38.8746'),
('amet', '15', 'node', '9.70706'),
('amet', '16', 'node', '9.47636'),
('amet', '17', 'node', '4.80814'),
('amet', '18', 'node', '4'),
('amet', '19', 'node', '4'),
('amet', '20', 'node', '9.72233'),
('amet', '21', 'node', '32.7738'),
('amet', '22', 'node', '4.93105'),
('amet', '23', 'node', '6.7738'),
('amet', '24', 'node', '4.80914'),
('amet', '25', 'node', '6.88076'),
('amet', '26', 'node', '4.79555'),
('amet', '27', 'node', '3'),
('amet', '28', 'node', '4.79568'),
('amet', '29', 'node', '4.89593'),
('amet', '30', 'node', '3'),
('amet', '31', 'node', '10.8029'),
('amet', '32', 'node', '5.99315'),
('amet', '33', 'node', '1'),
('amet', '34', 'node', '8.77266'),
('amet', '35', 'node', '5.99731'),
('amet', '36', 'node', '29.7826'),
('amet', '37', 'node', '15.8072'),
('amet', '38', 'node', '9.44927'),
('amet', '39', 'node', '9.7264'),
('amet', '40', 'node', '21.0425'),
('amet', '41', 'node', '19.7635'),
('amet', '42', 'node', '27'),
('amet', '43', 'node', '28'),
('amet', '45', 'node', '28'),
('amet', '47', 'node', '3'),
('amet', '50', 'node', '5.96109'),
('amet', '51', 'node', '3.97685'),
('amet', '52', 'node', '30'),
('amet', '53', 'node', '4'),
('amet', '54', 'node', '4'),
('amet', '55', 'node', '4'),
('amet', '56', 'node', '4'),
('amet', '57', 'node', '4'),
('amet', '58', 'node', '4'),
('amet', '65', 'node', '7.5843'),
('amet', '67', 'node', '2.99315'),
('amet', '68', 'node', '6.64532'),
('amet', '69', 'node', '5'),
('amet', '71', 'node', '5'),
('amet', '73', 'node', '5.99461'),
('amet', '76', 'node', '6.47531'),
('amet', '77', 'node', '6.68556'),
('amet', '78', 'node', '3.94209'),
('amet', '79', 'node', '7.84232'),
('amet', '82', 'node', '30'),
('amet', '83', 'node', '6'),
('amet', '84', 'node', '32'),
('amet', '85', 'node', '5.99461'),
('amet', '86', 'node', '5.99461'),
('amet', '87', 'node', '6'),
('amet', '88', 'node', '5.99461'),
('amet', '89', 'node', '5.99461'),
('ante', '12', 'node', '5.15823'),
('ante', '13', 'node', '2.90929'),
('ante', '14', 'node', '10.3046'),
('ante', '15', 'node', '3'),
('ante', '16', 'node', '10.5414'),
('ante', '17', 'node', '3.92743'),
('ante', '18', 'node', '2'),
('ante', '19', 'node', '3'),
('ante', '20', 'node', '3'),
('ante', '21', 'node', '5.69953'),
('ante', '22', 'node', '6.80783'),
('ante', '23', 'node', '5.69953'),
('ante', '24', 'node', '1.98493'),
('ante', '25', 'node', '1'),
('ante', '26', 'node', '1.93838'),
('ante', '27', 'node', '4'),
('ante', '28', 'node', '3'),
('ante', '29', 'node', '5.81213'),
('ante', '30', 'node', '3'),
('ante', '31', 'node', '4'),
('ante', '32', 'node', '1'),
('ante', '34', 'node', '0.949597'),
('ante', '35', 'node', '1'),
('ante', '36', 'node', '2.89272'),
('ante', '37', 'node', '2'),
('ante', '38', 'node', '2'),
('ante', '39', 'node', '1.92384'),
('ante', '40', 'node', '3.84066'),
('ante', '41', 'node', '3.7515'),
('ante', '44', 'node', '1'),
('ante', '46', 'node', '1'),
('ante', '47', 'node', '4'),
('ante', '50', 'node', '3'),
('ante', '51', 'node', '4'),
('ante', '52', 'node', '4'),
('ante', '53', 'node', '4'),
('ante', '54', 'node', '4'),
('ante', '55', 'node', '4'),
('ante', '56', 'node', '4'),
('ante', '57', 'node', '4'),
('ante', '58', 'node', '4'),
('ante', '65', 'node', '14.7893'),
('ante', '67', 'node', '1.9534'),
('ante', '68', 'node', '2.88373'),
('ante', '69', 'node', '1.87703'),
('ante', '71', 'node', '32.1208'),
('ante', '73', 'node', '4'),
('ante', '76', 'node', '1'),
('ante', '77', 'node', '2.92027'),
('ante', '78', 'node', '1.90428'),
('ante', '79', 'node', '2.92027'),
('ante', '82', 'node', '4'),
('ante', '83', 'node', '4'),
('ante', '84', 'node', '4'),
('ante', '85', 'node', '4'),
('ante', '86', 'node', '4'),
('ante', '87', 'node', '4'),
('ante', '88', 'node', '4'),
('ante', '89', 'node', '4'),
('aptent', '12', 'node', '1.78544'),
('aptent', '14', 'node', '0.769219'),
('aptent', '15', 'node', '0.957226'),
('aptent', '16', 'node', '0.816452'),
('aptent', '20', 'node', '0.927431'),
('aptent', '22', 'node', '0.906287'),
('aptent', '24', 'node', '1'),
('aptent', '33', 'node', '1'),
('aptent', '36', 'node', '1.96498'),
('aptent', '41', 'node', '0.822065'),
('aptent', '50', 'node', '1'),
('aptent', '51', 'node', '1'),
('aptent', '65', 'node', '2'),
('aptent', '68', 'node', '1'),
('aptent', '69', 'node', '1'),
('aptent', '73', 'node', '0.953396'),
('aptent', '79', 'node', '0.882818'),
('aptent', '83', 'node', '0.961087'),
('aptent', '84', 'node', '0.961087'),
('aptent', '85', 'node', '0.953396'),
('aptent', '86', 'node', '0.953396'),
('aptent', '87', 'node', '0.957226'),
('aptent', '88', 'node', '0.953396'),
('aptent', '89', 'node', '0.953396'),
('arcu', '12', 'node', '2.82118'),
('arcu', '13', 'node', '2'),
('arcu', '14', 'node', '2.31141'),
('arcu', '15', 'node', '0.906287'),
('arcu', '16', 'node', '1.72293'),
('arcu', '18', 'node', '1'),
('arcu', '19', 'node', '3.99315'),
('arcu', '20', 'node', '3.89169'),
('arcu', '21', 'node', '11'),
('arcu', '22', 'node', '12.8775'),
('arcu', '23', 'node', '11'),
('arcu', '24', 'node', '12.9611'),
('arcu', '25', 'node', '1'),
('arcu', '26', 'node', '1.91674'),
('arcu', '27', 'node', '3'),
('arcu', '28', 'node', '2.78212'),
('arcu', '29', 'node', '3.90191'),
('arcu', '30', 'node', '1'),
('arcu', '31', 'node', '4.88387'),
('arcu', '32', 'node', '2'),
('arcu', '33', 'node', '1'),
('arcu', '35', 'node', '2'),
('arcu', '36', 'node', '1.83063'),
('arcu', '37', 'node', '3.85668'),
('arcu', '38', 'node', '4.89003'),
('arcu', '39', 'node', '6.59603'),
('arcu', '40', 'node', '0.845322'),
('arcu', '41', 'node', '4.60326'),
('arcu', '47', 'node', '1'),
('arcu', '51', 'node', '1.99731'),
('arcu', '52', 'node', '2'),
('arcu', '53', 'node', '2'),
('arcu', '54', 'node', '2'),
('arcu', '55', 'node', '2'),
('arcu', '56', 'node', '2'),
('arcu', '57', 'node', '2'),
('arcu', '58', 'node', '2'),
('arcu', '65', 'node', '2'),
('arcu', '67', 'node', '6.92743'),
('arcu', '68', 'node', '14.9863'),
('arcu', '69', 'node', '1.92743'),
('arcu', '71', 'node', '2.75812'),
('arcu', '73', 'node', '3.98224'),
('arcu', '76', 'node', '1.91838'),
('arcu', '77', 'node', '3.97685'),
('arcu', '78', 'node', '3.93838'),
('arcu', '79', 'node', '2.86351'),
('arcu', '82', 'node', '2'),
('arcu', '83', 'node', '3.99315'),
('arcu', '84', 'node', '3.99315'),
('arcu', '85', 'node', '3.98224'),
('arcu', '86', 'node', '3.98224'),
('arcu', '87', 'node', '3.98902'),
('arcu', '88', 'node', '3.98224'),
('arcu', '89', 'node', '3.98224'),
('auctor', '12', 'node', '2.80275'),
('auctor', '14', 'node', '7.78962'),
('auctor', '15', 'node', '1'),
('auctor', '16', 'node', '2'),
('auctor', '17', 'node', '4'),
('auctor', '19', 'node', '5'),
('auctor', '20', 'node', '3'),
('auctor', '24', 'node', '1'),
('auctor', '25', 'node', '0.945829'),
('auctor', '27', 'node', '1'),
('auctor', '29', 'node', '1'),
('auctor', '31', 'node', '1'),
('auctor', '32', 'node', '1'),
('auctor', '34', 'node', '0.953396'),
('auctor', '35', 'node', '1'),
('auctor', '36', 'node', '1'),
('auctor', '37', 'node', '1'),
('auctor', '38', 'node', '1'),
('auctor', '40', 'node', '1.87027'),
('auctor', '41', 'node', '2.8894'),
('auctor', '47', 'node', '1'),
('auctor', '50', 'node', '0.953396'),
('auctor', '51', 'node', '3'),
('auctor', '52', 'node', '1'),
('auctor', '53', 'node', '1'),
('auctor', '54', 'node', '1'),
('auctor', '55', 'node', '1'),
('auctor', '56', 'node', '1'),
('auctor', '57', 'node', '1'),
('auctor', '58', 'node', '1'),
('auctor', '65', 'node', '2.85967'),
('auctor', '67', 'node', '13.8792'),
('auctor', '68', 'node', '12.0708'),
('auctor', '71', 'node', '2.85127'),
('auctor', '73', 'node', '1'),
('auctor', '77', 'node', '3.78212'),
('auctor', '78', 'node', '2'),
('auctor', '79', 'node', '3.83938'),
('auctor', '82', 'node', '1'),
('auctor', '83', 'node', '1'),
('auctor', '84', 'node', '1'),
('auctor', '85', 'node', '1'),
('auctor', '86', 'node', '1'),
('auctor', '87', 'node', '1'),
('auctor', '88', 'node', '1'),
('auctor', '89', 'node', '1'),
('augue', '12', 'node', '4.12094'),
('augue', '13', 'node', '2'),
('augue', '14', 'node', '4.35012'),
('augue', '15', 'node', '4.81344'),
('augue', '16', 'node', '4.53182'),
('augue', '17', 'node', '2.87679'),
('augue', '18', 'node', '2.98902'),
('augue', '19', 'node', '2.98493'),
('augue', '20', 'node', '2.89272'),
('augue', '21', 'node', '2.97286'),
('augue', '22', 'node', '2'),
('augue', '23', 'node', '2.97286'),
('augue', '24', 'node', '1.9534'),
('augue', '25', 'node', '0.961087'),
('augue', '26', 'node', '1'),
('augue', '27', 'node', '2'),
('augue', '28', 'node', '3.69034'),
('augue', '29', 'node', '2.99315'),
('augue', '30', 'node', '0.953396'),
('augue', '31', 'node', '1'),
('augue', '33', 'node', '2'),
('augue', '36', 'node', '3.71868'),
('augue', '37', 'node', '3.89968'),
('augue', '38', 'node', '3.98902'),
('augue', '39', 'node', '1'),
('augue', '40', 'node', '3.6952'),
('augue', '41', 'node', '2.74605'),
('augue', '42', 'node', '1'),
('augue', '50', 'node', '2'),
('augue', '51', 'node', '3'),
('augue', '65', 'node', '7.38222'),
('augue', '67', 'node', '2.9689'),
('augue', '68', 'node', '4.73962'),
('augue', '69', 'node', '13.9458'),
('augue', '71', 'node', '7'),
('augue', '73', 'node', '0.96498'),
('augue', '76', 'node', '1.98087'),
('augue', '77', 'node', '2'),
('augue', '78', 'node', '2.79336'),
('augue', '79', 'node', '3.53303'),
('augue', '83', 'node', '0.972861'),
('augue', '84', 'node', '0.972861'),
('augue', '85', 'node', '0.96498'),
('augue', '86', 'node', '0.96498'),
('augue', '87', 'node', '0.968904'),
('augue', '88', 'node', '0.96498'),
('augue', '89', 'node', '0.96498'),
('bad', '11', 'node', '1'),
('bibendum', '12', 'node', '3.6263'),
('bibendum', '14', 'node', '4.18447'),
('bibendum', '15', 'node', '1.86995'),
('bibendum', '16', 'node', '0.972861'),
('bibendum', '17', 'node', '1.8967'),
('bibendum', '18', 'node', '2.98493'),
('bibendum', '19', 'node', '1.96109'),
('bibendum', '20', 'node', '2.9496'),
('bibendum', '21', 'node', '2.89932'),
('bibendum', '22', 'node', '3.86943'),
('bibendum', '23', 'node', '2.89932'),
('bibendum', '25', 'node', '2'),
('bibendum', '26', 'node', '1.91869'),
('bibendum', '28', 'node', '1.90286'),
('bibendum', '30', 'node', '1'),
('bibendum', '31', 'node', '1'),
('bibendum', '32', 'node', '1'),
('bibendum', '33', 'node', '0.997306'),
('bibendum', '34', 'node', '2'),
('bibendum', '35', 'node', '1'),
('bibendum', '36', 'node', '1.82776'),
('bibendum', '38', 'node', '0.902857'),
('bibendum', '40', 'node', '2.61949'),
('bibendum', '41', 'node', '1.8894'),
('bibendum', '42', 'node', '1'),
('bibendum', '43', 'node', '26'),
('bibendum', '45', 'node', '2'),
('bibendum', '46', 'node', '2'),
('bibendum', '50', 'node', '1'),
('bibendum', '51', 'node', '2.97685'),
('bibendum', '52', 'node', '1'),
('bibendum', '53', 'node', '1'),
('bibendum', '54', 'node', '1'),
('bibendum', '55', 'node', '1'),
('bibendum', '56', 'node', '1'),
('bibendum', '57', 'node', '1'),
('bibendum', '58', 'node', '1'),
('bibendum', '65', 'node', '4.44041'),
('bibendum', '68', 'node', '0.997306'),
('bibendum', '69', 'node', '0.934703'),
('bibendum', '71', 'node', '5.98493'),
('bibendum', '73', 'node', '1'),
('bibendum', '76', 'node', '1'),
('bibendum', '77', 'node', '0.913226'),
('bibendum', '79', 'node', '4.44854'),
('bibendum', '82', 'node', '1'),
('bibendum', '83', 'node', '1'),
('bibendum', '84', 'node', '1'),
('bibendum', '85', 'node', '1'),
('bibendum', '86', 'node', '1'),
('bibendum', '87', 'node', '1'),
('bibendum', '88', 'node', '1'),
('bibendum', '89', 'node', '1'),
('billing', '73', 'node', '0.906287'),
('blandit', '12', 'node', '3.35046'),
('blandit', '14', 'node', '4.25338'),
('blandit', '15', 'node', '1'),
('blandit', '16', 'node', '4.94209'),
('blandit', '19', 'node', '1.93395'),
('blandit', '20', 'node', '2.87957'),
('blandit', '21', 'node', '2.94209'),
('blandit', '22', 'node', '2.95723'),
('blandit', '23', 'node', '2.94209'),
('blandit', '24', 'node', '1.87344'),
('blandit', '26', 'node', '2'),
('blandit', '28', 'node', '1.8583'),
('blandit', '29', 'node', '1'),
('blandit', '30', 'node', '0.961087'),
('blandit', '32', 'node', '2.99315'),
('blandit', '33', 'node', '1'),
('blandit', '34', 'node', '2'),
('blandit', '35', 'node', '2.99731'),
('blandit', '36', 'node', '4.73174'),
('blandit', '37', 'node', '3'),
('blandit', '38', 'node', '1.94209'),
('blandit', '39', 'node', '0.916736'),
('blandit', '40', 'node', '1.98087'),
('blandit', '41', 'node', '2.83811'),
('blandit', '42', 'node', '1'),
('blandit', '43', 'node', '1'),
('blandit', '46', 'node', '26'),
('blandit', '47', 'node', '1'),
('blandit', '50', 'node', '4'),
('blandit', '51', 'node', '1'),
('blandit', '65', 'node', '0.953396'),
('blandit', '67', 'node', '12'),
('blandit', '68', 'node', '1.91674'),
('blandit', '69', 'node', '0.938382'),
('blandit', '71', 'node', '0.906287'),
('blandit', '76', 'node', '3.74576'),
('blandit', '79', 'node', '1'),
('blog', '37', 'node', '11'),
('blog', '38', 'node', '11'),
('blog', '39', 'node', '11'),
('blog', '40', 'node', '11'),
('blog', '41', 'node', '11'),
('ceo', '69', 'node', '0.916736'),
('class', '12', 'node', '1.78909'),
('class', '14', 'node', '0.771698'),
('class', '15', 'node', '0.961087'),
('class', '16', 'node', '0.819249'),
('class', '20', 'node', '0.931053'),
('class', '22', 'node', '0.909743'),
('class', '24', 'node', '1'),
('class', '33', 'node', '1'),
('class', '36', 'node', '1.96498'),
('class', '41', 'node', '0.824901'),
('class', '50', 'node', '1'),
('class', '51', 'node', '1'),
('class', '65', 'node', '2'),
('class', '68', 'node', '1'),
('class', '69', 'node', '1'),
('class', '73', 'node', '0.957226'),
('class', '79', 'node', '0.886095'),
('class', '83', 'node', '0.96498'),
('class', '84', 'node', '0.96498'),
('class', '85', 'node', '0.957226'),
('class', '86', 'node', '0.957226'),
('class', '87', 'node', '0.961087'),
('class', '88', 'node', '0.957226'),
('class', '89', 'node', '0.957226'),
('cole', '89', 'node', '26'),
('comfort', '51', 'node', '26'),
('comments', '12', 'node', '2.38287'),
('comments', '13', 'node', '0.899454'),
('comments', '14', 'node', '3.86503'),
('commodo', '12', 'node', '1.7276'),
('commodo', '13', 'node', '2.98902'),
('commodo', '14', 'node', '5.42395'),
('commodo', '17', 'node', '1.91099'),
('commodo', '18', 'node', '2'),
('commodo', '19', 'node', '0.968904'),
('commodo', '20', 'node', '1'),
('commodo', '21', 'node', '1.90318'),
('commodo', '22', 'node', '2.86995'),
('commodo', '23', 'node', '1.90318'),
('commodo', '24', 'node', '1.85127'),
('commodo', '26', 'node', '2'),
('commodo', '28', 'node', '1.82865'),
('commodo', '30', 'node', '0.938382'),
('commodo', '34', 'node', '1'),
('commodo', '36', 'node', '0.839384'),
('commodo', '37', 'node', '2'),
('commodo', '39', 'node', '1'),
('commodo', '40', 'node', '3.78973'),
('commodo', '41', 'node', '2.66989'),
('commodo', '42', 'node', '1'),
('commodo', '44', 'node', '26'),
('commodo', '47', 'node', '2.99731'),
('commodo', '50', 'node', '0.945829'),
('commodo', '51', 'node', '1'),
('commodo', '52', 'node', '4'),
('commodo', '53', 'node', '4'),
('commodo', '54', 'node', '4'),
('commodo', '55', 'node', '4'),
('commodo', '56', 'node', '4'),
('commodo', '57', 'node', '4'),
('commodo', '58', 'node', '4'),
('commodo', '65', 'node', '2.80833'),
('commodo', '67', 'node', '1.96498'),
('commodo', '71', 'node', '6.86237'),
('commodo', '73', 'node', '4.98902'),
('commodo', '76', 'node', '5.70553'),
('commodo', '78', 'node', '2.87676'),
('commodo', '79', 'node', '0.961087'),
('commodo', '82', 'node', '4'),
('commodo', '83', 'node', '4.99731'),
('commodo', '84', 'node', '4.99731'),
('commodo', '85', 'node', '4.98902'),
('commodo', '86', 'node', '4.98902'),
('commodo', '87', 'node', '4.99315'),
('commodo', '88', 'node', '4.98902'),
('commodo', '89', 'node', '4.98902'),
('condimentum', '12', 'node', '1.80275'),
('condimentum', '13', 'node', '2.91674'),
('condimentum', '14', 'node', '5.96107'),
('condimentum', '15', 'node', '1'),
('condimentum', '16', 'node', '4.55158'),
('condimentum', '17', 'node', '1'),
('condimentum', '18', 'node', '0.980874'),
('condimentum', '19', 'node', '1'),
('condimentum', '20', 'node', '2.82221'),
('condimentum', '21', 'node', '1'),
('condimentum', '22', 'node', '2.78911'),
('condimentum', '23', 'node', '1'),
('condimentum', '24', 'node', '2'),
('condimentum', '25', 'node', '2'),
('condimentum', '26', 'node', '2.91831'),
('condimentum', '27', 'node', '2'),
('condimentum', '28', 'node', '2'),
('condimentum', '29', 'node', '1.89274'),
('condimentum', '30', 'node', '2'),
('condimentum', '31', 'node', '1'),
('condimentum', '32', 'node', '1'),
('condimentum', '33', 'node', '1'),
('condimentum', '34', 'node', '1'),
('condimentum', '35', 'node', '1'),
('condimentum', '36', 'node', '1'),
('condimentum', '37', 'node', '0.909743'),
('condimentum', '39', 'node', '1.89272'),
('condimentum', '40', 'node', '9.20091'),
('condimentum', '41', 'node', '12.334'),
('condimentum', '43', 'node', '1'),
('condimentum', '44', 'node', '1'),
('condimentum', '47', 'node', '1'),
('condimentum', '51', 'node', '2'),
('condimentum', '65', 'node', '2.6986'),
('condimentum', '67', 'node', '1'),
('condimentum', '68', 'node', '1'),
('condimentum', '69', 'node', '1'),
('condimentum', '71', 'node', '2'),
('condimentum', '76', 'node', '1'),
('condimentum', '77', 'node', '3.85381'),
('condimentum', '78', 'node', '1'),
('condimentum', '79', 'node', '2.84234'),
('congue', '12', 'node', '2.63654'),
('congue', '13', 'node', '4'),
('congue', '14', 'node', '2.59749'),
('congue', '15', 'node', '0.976851'),
('congue', '16', 'node', '1.76891'),
('congue', '17', 'node', '2.85854'),
('congue', '18', 'node', '3'),
('congue', '19', 'node', '1'),
('congue', '21', 'node', '3.86593'),
('congue', '22', 'node', '3'),
('congue', '23', 'node', '3.86593'),
('congue', '24', 'node', '1'),
('congue', '25', 'node', '0.938382'),
('congue', '28', 'node', '2.79914'),
('congue', '30', 'node', '1'),
('congue', '31', 'node', '3'),
('congue', '32', 'node', '1'),
('congue', '33', 'node', '1'),
('congue', '34', 'node', '0.931053'),
('congue', '35', 'node', '1'),
('congue', '36', 'node', '2.60387'),
('congue', '37', 'node', '1'),
('congue', '38', 'node', '2.99731'),
('congue', '40', 'node', '2.89313'),
('congue', '41', 'node', '1.93395'),
('congue', '45', 'node', '1'),
('congue', '50', 'node', '1'),
('congue', '51', 'node', '1'),
('congue', '65', 'node', '1.91323'),
('congue', '67', 'node', '1'),
('congue', '68', 'node', '3.86995'),
('congue', '69', 'node', '2.9534'),
('congue', '71', 'node', '4.97258'),
('congue', '76', 'node', '1.73045'),
('congue', '78', 'node', '0.980874'),
('conor', '68', 'node', '26'),
('consectetur', '12', 'node', '3.62591'),
('consectetur', '13', 'node', '1'),
('consectetur', '14', 'node', '29.014'),
('consectetur', '15', 'node', '0.997306'),
('consectetur', '16', 'node', '5.55877'),
('consectetur', '17', 'node', '1'),
('consectetur', '19', 'node', '5.9534'),
('consectetur', '20', 'node', '4.95723'),
('consectetur', '21', 'node', '3.86952'),
('consectetur', '22', 'node', '2.97685'),
('consectetur', '23', 'node', '3.86952'),
('consectetur', '24', 'node', '1'),
('consectetur', '25', 'node', '0.972861'),
('consectetur', '27', 'node', '1'),
('consectetur', '28', 'node', '5.47044'),
('consectetur', '29', 'node', '1.99731'),
('consectetur', '30', 'node', '0.96498'),
('consectetur', '31', 'node', '3.9496'),
('consectetur', '32', 'node', '1'),
('consectetur', '33', 'node', '1'),
('consectetur', '34', 'node', '2'),
('consectetur', '35', 'node', '1'),
('consectetur', '36', 'node', '28.6968'),
('consectetur', '37', 'node', '5.91323'),
('consectetur', '38', 'node', '6.83325'),
('consectetur', '39', 'node', '1.92027'),
('consectetur', '40', 'node', '2.74105'),
('consectetur', '41', 'node', '2.67625'),
('consectetur', '42', 'node', '26'),
('consectetur', '44', 'node', '1'),
('consectetur', '47', 'node', '1'),
('consectetur', '65', 'node', '2'),
('consectetur', '67', 'node', '0.961087'),
('consectetur', '68', 'node', '0.949597'),
('consectetur', '69', 'node', '4'),
('consectetur', '73', 'node', '1.95723'),
('consectetur', '77', 'node', '1.89272'),
('consectetur', '78', 'node', '3'),
('consectetur', '79', 'node', '6.72548'),
('consectetur', '83', 'node', '1.96498'),
('consectetur', '84', 'node', '1.96498'),
('consectetur', '85', 'node', '1.95723'),
('consectetur', '86', 'node', '1.95723'),
('consectetur', '87', 'node', '1.96109'),
('consectetur', '88', 'node', '1.95723'),
('consectetur', '89', 'node', '1.95723'),
('consequat', '12', 'node', '3.7648'),
('consequat', '13', 'node', '5.88253'),
('consequat', '14', 'node', '2.64475'),
('consequat', '15', 'node', '1.8894'),
('consequat', '16', 'node', '1.92384'),
('consequat', '17', 'node', '1'),
('consequat', '20', 'node', '0.957226'),
('consequat', '24', 'node', '1.91674'),
('consequat', '25', 'node', '0.993146'),
('consequat', '26', 'node', '1.90629'),
('consequat', '28', 'node', '2.88282'),
('consequat', '29', 'node', '1'),
('consequat', '30', 'node', '1.99731'),
('consequat', '31', 'node', '29.9457'),
('consequat', '32', 'node', '2'),
('consequat', '33', 'node', '2.99731'),
('consequat', '34', 'node', '1'),
('consequat', '35', 'node', '2'),
('consequat', '36', 'node', '2.78441'),
('consequat', '37', 'node', '1.91323'),
('consequat', '38', 'node', '1.9534'),
('consequat', '39', 'node', '2.90286'),
('consequat', '40', 'node', '1'),
('consequat', '41', 'node', '4.71715'),
('consequat', '43', 'node', '1'),
('consequat', '44', 'node', '26'),
('consequat', '50', 'node', '2.91323'),
('consequat', '65', 'node', '1'),
('consequat', '67', 'node', '0.938382'),
('consequat', '68', 'node', '4'),
('consequat', '69', 'node', '4'),
('consequat', '73', 'node', '0.968904'),
('consequat', '76', 'node', '2.83582'),
('consequat', '77', 'node', '4.76975'),
('consequat', '79', 'node', '1.93838'),
('consequat', '83', 'node', '0.976851'),
('consequat', '84', 'node', '0.976851'),
('consequat', '85', 'node', '0.968904'),
('consequat', '86', 'node', '0.968904'),
('consequat', '87', 'node', '0.972861'),
('consequat', '88', 'node', '0.968904'),
('consequat', '89', 'node', '0.968904'),
('conubia', '12', 'node', '1.76413'),
('conubia', '14', 'node', '0.754681'),
('conubia', '15', 'node', '0.934703'),
('conubia', '16', 'node', '0.800068'),
('conubia', '20', 'node', '0.906287'),
('conubia', '22', 'node', '0.886095'),
('conubia', '24', 'node', '1'),
('conubia', '33', 'node', '1'),
('conubia', '36', 'node', '1.94585'),
('conubia', '41', 'node', '0.805455'),
('conubia', '50', 'node', '0.976851'),
('conubia', '51', 'node', '1'),
('conubia', '65', 'node', '2'),
('conubia', '68', 'node', '1'),
('conubia', '69', 'node', '1'),
('conubia', '73', 'node', '0.931053'),
('conubia', '79', 'node', '0.863659'),
('conubia', '83', 'node', '0.938382'),
('conubia', '84', 'node', '0.938382'),
('conubia', '85', 'node', '0.931053'),
('conubia', '86', 'node', '0.931053'),
('conubia', '87', 'node', '0.934703'),
('conubia', '88', 'node', '0.931053'),
('conubia', '89', 'node', '0.931053'),
('convallis', '12', 'node', '2'),
('convallis', '13', 'node', '2'),
('convallis', '14', 'node', '5.86177'),
('convallis', '15', 'node', '1'),
('convallis', '16', 'node', '29.4099'),
('convallis', '17', 'node', '13'),
('convallis', '18', 'node', '13.9849'),
('convallis', '19', 'node', '12'),
('convallis', '20', 'node', '12'),
('convallis', '21', 'node', '1'),
('convallis', '23', 'node', '1'),
('convallis', '24', 'node', '1.80582'),
('convallis', '25', 'node', '2'),
('convallis', '26', 'node', '2'),
('convallis', '28', 'node', '1.84838'),
('convallis', '29', 'node', '1'),
('convallis', '30', 'node', '0.934703'),
('convallis', '32', 'node', '1'),
('convallis', '33', 'node', '1'),
('convallis', '35', 'node', '1'),
('convallis', '36', 'node', '1.9534'),
('convallis', '37', 'node', '2'),
('convallis', '38', 'node', '2'),
('convallis', '39', 'node', '1'),
('convallis', '40', 'node', '3.77773'),
('convallis', '41', 'node', '7.98035'),
('convallis', '44', 'node', '27'),
('convallis', '45', 'node', '1'),
('convallis', '52', 'node', '2'),
('convallis', '53', 'node', '2'),
('convallis', '54', 'node', '2'),
('convallis', '55', 'node', '2'),
('convallis', '56', 'node', '2'),
('convallis', '57', 'node', '2'),
('convallis', '58', 'node', '2'),
('convallis', '65', 'node', '5'),
('convallis', '67', 'node', '1.92743'),
('convallis', '73', 'node', '6.97685'),
('convallis', '76', 'node', '3.9185'),
('convallis', '77', 'node', '3.80571'),
('convallis', '78', 'node', '3.88798'),
('convallis', '79', 'node', '6.23453'),
('convallis', '82', 'node', '2'),
('convallis', '83', 'node', '6.98493'),
('convallis', '84', 'node', '6.98493'),
('convallis', '85', 'node', '6.97685'),
('convallis', '86', 'node', '6.97685'),
('convallis', '87', 'node', '6.98087'),
('convallis', '88', 'node', '6.97685'),
('convallis', '89', 'node', '6.97685'),
('cras', '12', 'node', '0.830633'),
('cras', '14', 'node', '1.78178'),
('cras', '15', 'node', '0.857458'),
('cras', '16', 'node', '2.89272'),
('cras', '17', 'node', '1'),
('cras', '21', 'node', '3.95383'),
('cras', '22', 'node', '29.87'),
('cras', '23', 'node', '29.9498'),
('cras', '24', 'node', '1'),
('cras', '27', 'node', '1'),
('cras', '28', 'node', '4.73729'),
('cras', '29', 'node', '2.94209'),
('cras', '30', 'node', '2.89561'),
('cras', '32', 'node', '1'),
('cras', '35', 'node', '1'),
('cras', '36', 'node', '2.87634'),
('cras', '38', 'node', '1.9534'),
('cras', '39', 'node', '2'),
('cras', '40', 'node', '0.854391'),
('cras', '41', 'node', '1.87313'),
('cras', '43', 'node', '1'),
('cras', '44', 'node', '1'),
('cras', '50', 'node', '3.89579'),
('cras', '51', 'node', '1.97685'),
('cras', '52', 'node', '1'),
('cras', '53', 'node', '1'),
('cras', '54', 'node', '1'),
('cras', '55', 'node', '1'),
('cras', '56', 'node', '1'),
('cras', '57', 'node', '1'),
('cras', '58', 'node', '1'),
('cras', '67', 'node', '1'),
('cras', '68', 'node', '2.90629'),
('cras', '69', 'node', '1.96498'),
('cras', '71', 'node', '1'),
('cras', '73', 'node', '1'),
('cras', '76', 'node', '3.96587'),
('cras', '77', 'node', '1.9496'),
('cras', '78', 'node', '2.91495'),
('cras', '79', 'node', '2.83938'),
('cras', '82', 'node', '1'),
('cras', '83', 'node', '1'),
('cras', '84', 'node', '1'),
('cras', '85', 'node', '1'),
('cras', '86', 'node', '1'),
('cras', '87', 'node', '1'),
('cras', '88', 'node', '1'),
('cras', '89', 'node', '1'),
('cubilia', '12', 'node', '1'),
('cubilia', '14', 'node', '0.927431'),
('cubilia', '17', 'node', '1'),
('cubilia', '21', 'node', '1.86213'),
('cubilia', '22', 'node', '2.9347'),
('cubilia', '23', 'node', '1.86213'),
('cubilia', '24', 'node', '1'),
('cubilia', '29', 'node', '1'),
('cubilia', '37', 'node', '1'),
('cubilia', '40', 'node', '0.902857'),
('cubilia', '41', 'node', '1'),
('cubilia', '65', 'node', '0.920273'),
('cubilia', '71', 'node', '1'),
('cum', '14', 'node', '0.889397'),
('cum', '16', 'node', '23.4731'),
('cum', '22', 'node', '0.866793'),
('cum', '34', 'node', '1'),
('cum', '39', 'node', '0.968904'),
('cum', '40', 'node', '1'),
('cum', '50', 'node', '1'),
('cum', '76', 'node', '0.942091'),
('curabitur', '12', 'node', '2.80412'),
('curabitur', '15', 'node', '0.892724'),
('curabitur', '16', 'node', '1'),
('curabitur', '17', 'node', '2.86213'),
('curabitur', '18', 'node', '2'),
('curabitur', '19', 'node', '1'),
('curabitur', '20', 'node', '2.85642'),
('curabitur', '21', 'node', '2'),
('curabitur', '23', 'node', '2'),
('curabitur', '24', 'node', '0.899454'),
('curabitur', '25', 'node', '1.9534'),
('curabitur', '26', 'node', '1'),
('curabitur', '27', 'node', '27'),
('curabitur', '28', 'node', '1'),
('curabitur', '29', 'node', '28'),
('curabitur', '30', 'node', '1'),
('curabitur', '31', 'node', '3'),
('curabitur', '34', 'node', '1'),
('curabitur', '36', 'node', '2.94583'),
('curabitur', '37', 'node', '2.9347'),
('curabitur', '38', 'node', '2'),
('curabitur', '39', 'node', '2'),
('curabitur', '40', 'node', '0.842342'),
('curabitur', '41', 'node', '3.54859'),
('curabitur', '42', 'node', '1'),
('curabitur', '47', 'node', '1'),
('curabitur', '50', 'node', '1.91674'),
('curabitur', '51', 'node', '1'),
('curabitur', '52', 'node', '3'),
('curabitur', '53', 'node', '3'),
('curabitur', '54', 'node', '3'),
('curabitur', '55', 'node', '3'),
('curabitur', '56', 'node', '3'),
('curabitur', '57', 'node', '3'),
('curabitur', '58', 'node', '3'),
('curabitur', '65', 'node', '2'),
('curabitur', '67', 'node', '1'),
('curabitur', '69', 'node', '1'),
('curabitur', '73', 'node', '4.97286'),
('curabitur', '76', 'node', '11.572'),
('curabitur', '77', 'node', '0.909743'),
('curabitur', '78', 'node', '2'),
('curabitur', '79', 'node', '0.839384'),
('curabitur', '82', 'node', '3'),
('curabitur', '83', 'node', '4.98087'),
('curabitur', '84', 'node', '4.98087'),
('curabitur', '85', 'node', '4.97286'),
('curabitur', '86', 'node', '4.97286'),
('curabitur', '87', 'node', '4.97685'),
('curabitur', '88', 'node', '4.97286'),
('curabitur', '89', 'node', '4.97286'),
('curae', '12', 'node', '1'),
('curae', '14', 'node', '0.923838'),
('curae', '17', 'node', '1'),
('curae', '21', 'node', '1.85848'),
('curae', '22', 'node', '2.9347'),
('curae', '23', 'node', '1.85848'),
('curae', '24', 'node', '1'),
('curae', '29', 'node', '1'),
('curae', '37', 'node', '1'),
('curae', '40', 'node', '0.899454'),
('curae', '41', 'node', '1'),
('curae', '65', 'node', '0.916736'),
('curae', '71', 'node', '1'),
('cursus', '12', 'node', '3.72553'),
('cursus', '13', 'node', '0.949597'),
('cursus', '14', 'node', '5.0038'),
('cursus', '15', 'node', '1'),
('cursus', '16', 'node', '5.82166'),
('cursus', '17', 'node', '2.91558'),
('cursus', '18', 'node', '2'),
('cursus', '21', 'node', '3.90428'),
('cursus', '22', 'node', '2'),
('cursus', '23', 'node', '3.90428'),
('cursus', '25', 'node', '1.98493'),
('cursus', '26', 'node', '1.83029'),
('cursus', '28', 'node', '0.902857'),
('cursus', '31', 'node', '2.9534'),
('cursus', '36', 'node', '1.94209'),
('cursus', '37', 'node', '0.976851'),
('cursus', '38', 'node', '0.980874'),
('cursus', '39', 'node', '2'),
('cursus', '40', 'node', '1'),
('cursus', '41', 'node', '1.87634'),
('cursus', '43', 'node', '1'),
('cursus', '44', 'node', '26'),
('cursus', '47', 'node', '2'),
('cursus', '65', 'node', '0.902857'),
('cursus', '67', 'node', '13.2416'),
('cursus', '68', 'node', '1.80236'),
('cursus', '71', 'node', '1.90974'),
('cursus', '76', 'node', '2.89945'),
('cursus', '77', 'node', '1.93105'),
('cursus', '78', 'node', '1'),
('cursus', '79', 'node', '2.65657'),
('dapibus', '12', 'node', '1.63628'),
('dapibus', '14', 'node', '30.7284'),
('dapibus', '15', 'node', '1.85746'),
('dapibus', '16', 'node', '2'),
('dapibus', '17', 'node', '1.9347'),
('dapibus', '18', 'node', '2'),
('dapibus', '21', 'node', '0.993146'),
('dapibus', '22', 'node', '0.980874'),
('dapibus', '23', 'node', '0.989021'),
('dapibus', '24', 'node', '1.89608'),
('dapibus', '25', 'node', '3.88493'),
('dapibus', '26', 'node', '1.99315'),
('dapibus', '27', 'node', '1'),
('dapibus', '28', 'node', '2.98493'),
('dapibus', '29', 'node', '1.94209'),
('dapibus', '30', 'node', '2.97685'),
('dapibus', '32', 'node', '3'),
('dapibus', '34', 'node', '1.91236'),
('dapibus', '35', 'node', '3'),
('dapibus', '36', 'node', '1.83063'),
('dapibus', '38', 'node', '2.90289'),
('dapibus', '40', 'node', '1.92027'),
('dapibus', '41', 'node', '4.62392'),
('dapibus', '43', 'node', '1'),
('dapibus', '44', 'node', '1'),
('dapibus', '47', 'node', '1'),
('dapibus', '51', 'node', '1'),
('dapibus', '52', 'node', '1'),
('dapibus', '53', 'node', '1'),
('dapibus', '54', 'node', '1'),
('dapibus', '55', 'node', '1'),
('dapibus', '56', 'node', '1'),
('dapibus', '57', 'node', '1'),
('dapibus', '58', 'node', '1'),
('dapibus', '65', 'node', '9.81996'),
('dapibus', '67', 'node', '2.94583'),
('dapibus', '68', 'node', '2'),
('dapibus', '69', 'node', '2'),
('dapibus', '71', 'node', '13.7943'),
('dapibus', '73', 'node', '1'),
('dapibus', '77', 'node', '2.89631'),
('dapibus', '78', 'node', '5.8049'),
('dapibus', '79', 'node', '0.972861'),
('dapibus', '82', 'node', '1'),
('dapibus', '83', 'node', '1'),
('dapibus', '84', 'node', '1'),
('dapibus', '85', 'node', '1'),
('dapibus', '86', 'node', '1'),
('dapibus', '87', 'node', '1'),
('dapibus', '88', 'node', '1'),
('dapibus', '89', 'node', '1'),
('david', '71', 'node', '26'),
('demolinkorg', '79', 'node', '9.13696'),
('design', '76', 'node', '26'),
('design', '78', 'node', '26'),
('diam', '12', 'node', '5.18243'),
('diam', '13', 'node', '1.93838'),
('diam', '14', 'node', '3.26371'),
('diam', '15', 'node', '3'),
('diam', '16', 'node', '4.72485'),
('diam', '17', 'node', '2.9347'),
('diam', '18', 'node', '3'),
('diam', '19', 'node', '1'),
('diam', '20', 'node', '1'),
('diam', '21', 'node', '1.92384'),
('diam', '22', 'node', '2.83353'),
('diam', '23', 'node', '1.92384'),
('diam', '24', 'node', '2.78212'),
('diam', '25', 'node', '5.93569'),
('diam', '26', 'node', '4.78406'),
('diam', '27', 'node', '1'),
('diam', '28', 'node', '1.88282'),
('diam', '29', 'node', '1.94209'),
('diam', '30', 'node', '1'),
('diam', '31', 'node', '1.95037'),
('diam', '32', 'node', '2.95373'),
('diam', '33', 'node', '4'),
('diam', '34', 'node', '0.945829'),
('diam', '35', 'node', '2.95373'),
('diam', '36', 'node', '0.833529'),
('diam', '37', 'node', '2.9689'),
('diam', '38', 'node', '3'),
('diam', '41', 'node', '2.79553'),
('diam', '44', 'node', '1'),
('diam', '45', 'node', '1'),
('diam', '46', 'node', '1'),
('diam', '47', 'node', '1'),
('diam', '50', 'node', '2'),
('diam', '51', 'node', '1'),
('diam', '52', 'node', '1'),
('diam', '53', 'node', '1'),
('diam', '54', 'node', '1'),
('diam', '55', 'node', '1'),
('diam', '56', 'node', '1'),
('diam', '57', 'node', '1'),
('diam', '58', 'node', '1'),
('diam', '67', 'node', '11'),
('diam', '68', 'node', '11.0455'),
('diam', '69', 'node', '1'),
('diam', '73', 'node', '1'),
('diam', '76', 'node', '2.9496'),
('diam', '77', 'node', '3.87027'),
('diam', '78', 'node', '3.87676'),
('diam', '79', 'node', '3.74224'),
('diam', '82', 'node', '1'),
('diam', '83', 'node', '1'),
('diam', '84', 'node', '1'),
('diam', '85', 'node', '1'),
('diam', '86', 'node', '1'),
('diam', '87', 'node', '1'),
('diam', '88', 'node', '1'),
('diam', '89', 'node', '1'),
('dictum', '12', 'node', '3.94583'),
('dictum', '13', 'node', '1.93838'),
('dictum', '14', 'node', '1.67964'),
('dictum', '15', 'node', '1'),
('dictum', '16', 'node', '2.79984'),
('dictum', '17', 'node', '1'),
('dictum', '18', 'node', '0.976851'),
('dictum', '19', 'node', '1.93427'),
('dictum', '20', 'node', '2'),
('dictum', '21', 'node', '3.94209'),
('dictum', '22', 'node', '2'),
('dictum', '23', 'node', '3.94209'),
('dictum', '24', 'node', '3.83599'),
('dictum', '25', 'node', '0.957226'),
('dictum', '26', 'node', '3'),
('dictum', '27', 'node', '2'),
('dictum', '28', 'node', '3.78407'),
('dictum', '29', 'node', '1.99045'),
('dictum', '30', 'node', '1.97685'),
('dictum', '31', 'node', '1.93838'),
('dictum', '32', 'node', '1'),
('dictum', '34', 'node', '2'),
('dictum', '35', 'node', '1'),
('dictum', '36', 'node', '2.85135'),
('dictum', '37', 'node', '1'),
('dictum', '38', 'node', '2.88445'),
('dictum', '39', 'node', '1.92384'),
('dictum', '40', 'node', '2.69667'),
('dictum', '41', 'node', '1.6312'),
('dictum', '45', 'node', '1'),
('dictum', '47', 'node', '0.989021'),
('dictum', '50', 'node', '1'),
('dictum', '52', 'node', '2'),
('dictum', '53', 'node', '2'),
('dictum', '54', 'node', '2'),
('dictum', '55', 'node', '2'),
('dictum', '56', 'node', '2'),
('dictum', '57', 'node', '2'),
('dictum', '58', 'node', '2'),
('dictum', '65', 'node', '2.89945'),
('dictum', '67', 'node', '0.968904'),
('dictum', '68', 'node', '1'),
('dictum', '69', 'node', '1'),
('dictum', '71', 'node', '2.84445'),
('dictum', '73', 'node', '3.89467'),
('dictum', '76', 'node', '1'),
('dictum', '77', 'node', '0.945829'),
('dictum', '78', 'node', '3.95723'),
('dictum', '79', 'node', '0.916736'),
('dictum', '82', 'node', '2'),
('dictum', '83', 'node', '3.90988'),
('dictum', '84', 'node', '3.90988'),
('dictum', '85', 'node', '3.89467'),
('dictum', '86', 'node', '3.89467'),
('dictum', '87', 'node', '3.90225'),
('dictum', '88', 'node', '3.89467'),
('dictum', '89', 'node', '3.89467'),
('dictumst', '12', 'node', '1.84234'),
('dictumst', '14', 'node', '2.37045'),
('dictumst', '15', 'node', '0.873132'),
('dictumst', '16', 'node', '0.822065'),
('dictumst', '20', 'node', '0.980874'),
('dictumst', '32', 'node', '2'),
('dictumst', '34', 'node', '0.961087'),
('dictumst', '35', 'node', '2'),
('dictumst', '39', 'node', '1'),
('dictumst', '68', 'node', '1'),
('dictumst', '69', 'node', '1'),
('dictumst', '71', 'node', '1'),
('dictumst', '76', 'node', '0.873132'),
('dictumst', '78', 'node', '1'),
('dignissim', '12', 'node', '6.92378'),
('dignissim', '13', 'node', '1'),
('dignissim', '14', 'node', '0.776703'),
('dignissim', '15', 'node', '3.622'),
('dignissim', '16', 'node', '2'),
('dignissim', '17', 'node', '0.997306'),
('dignissim', '18', 'node', '28'),
('dignissim', '20', 'node', '2.83001'),
('dignissim', '21', 'node', '13'),
('dignissim', '22', 'node', '11'),
('dignissim', '23', 'node', '13'),
('dignissim', '24', 'node', '13.9029'),
('dignissim', '25', 'node', '3.96109'),
('dignissim', '26', 'node', '3.89193'),
('dignissim', '28', 'node', '0.909743'),
('dignissim', '31', 'node', '1'),
('dignissim', '33', 'node', '1.95723'),
('dignissim', '36', 'node', '1.80732'),
('dignissim', '37', 'node', '1'),
('dignissim', '38', 'node', '1.90167'),
('dignissim', '40', 'node', '0.889397'),
('dignissim', '41', 'node', '1'),
('dignissim', '47', 'node', '2'),
('dignissim', '50', 'node', '2'),
('dignissim', '65', 'node', '0.869951'),
('dignissim', '67', 'node', '6.90428'),
('dignissim', '68', 'node', '4.89945'),
('dignissim', '69', 'node', '4'),
('dignissim', '71', 'node', '9.34027'),
('dignissim', '76', 'node', '0.993146'),
('dignissim', '77', 'node', '1'),
('dignissim', '78', 'node', '1.92384'),
('dignissim', '79', 'node', '3.83938'),
('dis', '14', 'node', '0.873132'),
('dis', '16', 'node', '0.851346'),
('dis', '22', 'node', '0.851346'),
('dis', '34', 'node', '1'),
('dis', '39', 'node', '0.949597'),
('dis', '40', 'node', '1'),
('dis', '50', 'node', '1'),
('dis', '76', 'node', '0.923838'),
('discussion', '12', 'node', '11'),
('discussion', '13', 'node', '11'),
('discussion', '14', 'node', '11'),
('discussion', '15', 'node', '11'),
('discussion', '16', 'node', '11'),
('dolor', '12', 'node', '51.8355'),
('dolor', '13', 'node', '2.9658'),
('dolor', '14', 'node', '54.113'),
('dolor', '15', 'node', '1.97685'),
('dolor', '16', 'node', '3.74309'),
('dolor', '17', 'node', '2.92743'),
('dolor', '18', 'node', '2'),
('dolor', '19', 'node', '2'),
('dolor', '21', 'node', '28.9274'),
('dolor', '22', 'node', '2.9689'),
('dolor', '23', 'node', '2.92743'),
('dolor', '24', 'node', '2.92384'),
('dolor', '25', 'node', '2.97286'),
('dolor', '26', 'node', '2.95011'),
('dolor', '27', 'node', '3'),
('dolor', '28', 'node', '4.76846'),
('dolor', '29', 'node', '3.91099'),
('dolor', '30', 'node', '2.96109'),
('dolor', '31', 'node', '0.953396'),
('dolor', '32', 'node', '3.98087'),
('dolor', '33', 'node', '1'),
('dolor', '34', 'node', '28.9849'),
('dolor', '35', 'node', '3.98493'),
('dolor', '36', 'node', '39.3127'),
('dolor', '37', 'node', '17.6898'),
('dolor', '38', 'node', '5.69854'),
('dolor', '39', 'node', '4.78895'),
('dolor', '40', 'node', '22.1223'),
('dolor', '41', 'node', '40.8003'),
('dolor', '42', 'node', '26'),
('dolor', '47', 'node', '2'),
('dolor', '50', 'node', '1'),
('dolor', '51', 'node', '1.97685'),
('dolor', '52', 'node', '27'),
('dolor', '53', 'node', '1'),
('dolor', '54', 'node', '1'),
('dolor', '55', 'node', '1'),
('dolor', '56', 'node', '1'),
('dolor', '57', 'node', '1'),
('dolor', '58', 'node', '1'),
('dolor', '65', 'node', '5.86995'),
('dolor', '67', 'node', '1'),
('dolor', '68', 'node', '3.9496'),
('dolor', '69', 'node', '6.94572'),
('dolor', '71', 'node', '2.9689'),
('dolor', '73', 'node', '5.89233'),
('dolor', '76', 'node', '2.9689'),
('dolor', '77', 'node', '3.74321'),
('dolor', '78', 'node', '13'),
('dolor', '79', 'node', '5.84832'),
('dolor', '82', 'node', '27'),
('dolor', '83', 'node', '5.93287'),
('dolor', '84', 'node', '31.9329'),
('dolor', '85', 'node', '5.89233'),
('dolor', '86', 'node', '5.89233'),
('dolor', '87', 'node', '5.91252'),
('dolor', '88', 'node', '5.89233'),
('dolor', '89', 'node', '5.89233'),
('donec', '12', 'node', '7.22082'),
('donec', '13', 'node', '3.94209'),
('donec', '14', 'node', '6.0018'),
('donec', '15', 'node', '3.85746'),
('donec', '16', 'node', '4.58762'),
('donec', '18', 'node', '1'),
('donec', '19', 'node', '2.91448'),
('donec', '20', 'node', '5.77451'),
('donec', '21', 'node', '3.92384'),
('donec', '22', 'node', '1'),
('donec', '23', 'node', '3.92384'),
('donec', '24', 'node', '2.86775'),
('donec', '25', 'node', '5.91948'),
('donec', '26', 'node', '4.78662'),
('donec', '27', 'node', '1'),
('donec', '28', 'node', '3.9496'),
('donec', '29', 'node', '0.945829'),
('donec', '30', 'node', '3.93254'),
('donec', '31', 'node', '3.9496'),
('donec', '32', 'node', '2'),
('donec', '33', 'node', '1.96498'),
('donec', '34', 'node', '3'),
('donec', '35', 'node', '2'),
('donec', '36', 'node', '5.36501'),
('donec', '37', 'node', '2.95723'),
('donec', '38', 'node', '3.85532'),
('donec', '39', 'node', '1.99731'),
('donec', '40', 'node', '2'),
('donec', '41', 'node', '5.54777'),
('donec', '43', 'node', '1'),
('donec', '44', 'node', '1'),
('donec', '45', 'node', '1'),
('donec', '46', 'node', '28'),
('donec', '47', 'node', '1'),
('donec', '50', 'node', '2'),
('donec', '51', 'node', '0.98493'),
('donec', '52', 'node', '1'),
('donec', '53', 'node', '1'),
('donec', '54', 'node', '1'),
('donec', '55', 'node', '1'),
('donec', '56', 'node', '1'),
('donec', '57', 'node', '1'),
('donec', '58', 'node', '1'),
('donec', '65', 'node', '4.7797'),
('donec', '67', 'node', '1'),
('donec', '68', 'node', '3.86995'),
('donec', '69', 'node', '2.94583'),
('donec', '71', 'node', '12.9904'),
('donec', '73', 'node', '2'),
('donec', '76', 'node', '2.83899'),
('donec', '77', 'node', '1.89272'),
('donec', '78', 'node', '1'),
('donec', '79', 'node', '2.85381'),
('donec', '82', 'node', '1'),
('donec', '83', 'node', '2'),
('donec', '84', 'node', '2'),
('donec', '85', 'node', '2'),
('donec', '86', 'node', '2'),
('donec', '87', 'node', '2'),
('donec', '88', 'node', '2'),
('donec', '89', 'node', '2'),
('donece', '37', 'node', '26'),
('donece', '38', 'node', '26'),
('donece', '39', 'node', '26'),
('donece', '40', 'node', '26');
INSERT INTO `search_index` VALUES
('donece', '41', 'node', '26'),
('dui', '12', 'node', '5.58453'),
('dui', '13', 'node', '4.81714'),
('dui', '14', 'node', '6.88876'),
('dui', '15', 'node', '1'),
('dui', '16', 'node', '4.60876'),
('dui', '17', 'node', '1'),
('dui', '19', 'node', '1.98902'),
('dui', '20', 'node', '3.93838'),
('dui', '21', 'node', '1'),
('dui', '22', 'node', '1.90974'),
('dui', '23', 'node', '1'),
('dui', '25', 'node', '1.98902'),
('dui', '26', 'node', '1.83734'),
('dui', '27', 'node', '1'),
('dui', '28', 'node', '0.913226'),
('dui', '29', 'node', '1.99315'),
('dui', '31', 'node', '1'),
('dui', '36', 'node', '3'),
('dui', '37', 'node', '0.957226'),
('dui', '38', 'node', '1.98902'),
('dui', '39', 'node', '2'),
('dui', '40', 'node', '2.82096'),
('dui', '41', 'node', '4.87313'),
('dui', '43', 'node', '27'),
('dui', '44', 'node', '1'),
('dui', '45', 'node', '28'),
('dui', '47', 'node', '3'),
('dui', '50', 'node', '3.91323'),
('dui', '51', 'node', '3'),
('dui', '52', 'node', '1'),
('dui', '53', 'node', '1'),
('dui', '54', 'node', '1'),
('dui', '55', 'node', '1'),
('dui', '56', 'node', '1'),
('dui', '57', 'node', '1'),
('dui', '58', 'node', '1'),
('dui', '65', 'node', '3.73202'),
('dui', '67', 'node', '14'),
('dui', '68', 'node', '1.91674'),
('dui', '69', 'node', '0.957226'),
('dui', '71', 'node', '2'),
('dui', '73', 'node', '1'),
('dui', '76', 'node', '3.82088'),
('dui', '77', 'node', '2.79341'),
('dui', '78', 'node', '1'),
('dui', '79', 'node', '9.03717'),
('dui', '82', 'node', '1'),
('dui', '83', 'node', '1'),
('dui', '84', 'node', '1'),
('dui', '85', 'node', '1'),
('dui', '86', 'node', '1'),
('dui', '87', 'node', '1'),
('dui', '88', 'node', '1'),
('dui', '89', 'node', '1'),
('duis', '12', 'node', '0.784336'),
('duis', '13', 'node', '2.84779'),
('duis', '14', 'node', '5.1318'),
('duis', '15', 'node', '1'),
('duis', '16', 'node', '2.8034'),
('duis', '18', 'node', '2'),
('duis', '20', 'node', '2.83111'),
('duis', '21', 'node', '13.9421'),
('duis', '22', 'node', '12.9689'),
('duis', '23', 'node', '13.9421'),
('duis', '24', 'node', '12.8828'),
('duis', '25', 'node', '1.98087'),
('duis', '26', 'node', '2.89945'),
('duis', '27', 'node', '2'),
('duis', '28', 'node', '2.89272'),
('duis', '29', 'node', '2.91698'),
('duis', '30', 'node', '2'),
('duis', '31', 'node', '2'),
('duis', '36', 'node', '4.75378'),
('duis', '37', 'node', '1.9689'),
('duis', '38', 'node', '13.6913'),
('duis', '39', 'node', '9.74705'),
('duis', '40', 'node', '12.1348'),
('duis', '41', 'node', '10.6045'),
('duis', '45', 'node', '1'),
('duis', '47', 'node', '0.993146'),
('duis', '52', 'node', '1'),
('duis', '53', 'node', '1'),
('duis', '54', 'node', '1'),
('duis', '55', 'node', '1'),
('duis', '56', 'node', '1'),
('duis', '57', 'node', '1'),
('duis', '58', 'node', '1'),
('duis', '65', 'node', '0.913226'),
('duis', '67', 'node', '3.96205'),
('duis', '68', 'node', '1'),
('duis', '69', 'node', '12'),
('duis', '71', 'node', '3.95383'),
('duis', '73', 'node', '1'),
('duis', '76', 'node', '13'),
('duis', '77', 'node', '0.934703'),
('duis', '78', 'node', '0.931053'),
('duis', '79', 'node', '1.84532'),
('duis', '82', 'node', '1'),
('duis', '83', 'node', '1'),
('duis', '84', 'node', '1'),
('duis', '85', 'node', '1'),
('duis', '86', 'node', '1'),
('duis', '87', 'node', '1'),
('duis', '88', 'node', '1'),
('duis', '89', 'node', '1'),
('egestas', '12', 'node', '3.3556'),
('egestas', '14', 'node', '4.24324'),
('egestas', '15', 'node', '2'),
('egestas', '16', 'node', '2.90069'),
('egestas', '17', 'node', '1.99731'),
('egestas', '19', 'node', '1'),
('egestas', '20', 'node', '1.87957'),
('egestas', '21', 'node', '1'),
('egestas', '22', 'node', '0.927431'),
('egestas', '23', 'node', '1'),
('egestas', '25', 'node', '1'),
('egestas', '26', 'node', '0.945829'),
('egestas', '27', 'node', '3'),
('egestas', '28', 'node', '4.81681'),
('egestas', '29', 'node', '2.97286'),
('egestas', '30', 'node', '3.89193'),
('egestas', '31', 'node', '2.9534'),
('egestas', '32', 'node', '0.98493'),
('egestas', '33', 'node', '2'),
('egestas', '34', 'node', '1'),
('egestas', '35', 'node', '0.989021'),
('egestas', '36', 'node', '1.90974'),
('egestas', '37', 'node', '2.98902'),
('egestas', '38', 'node', '3.79239'),
('egestas', '39', 'node', '1.99731'),
('egestas', '40', 'node', '2.89169'),
('egestas', '41', 'node', '1.8249'),
('egestas', '50', 'node', '2'),
('egestas', '52', 'node', '1'),
('egestas', '53', 'node', '1'),
('egestas', '54', 'node', '1'),
('egestas', '55', 'node', '1'),
('egestas', '56', 'node', '1'),
('egestas', '57', 'node', '1'),
('egestas', '58', 'node', '1'),
('egestas', '65', 'node', '1.88282'),
('egestas', '67', 'node', '5'),
('egestas', '68', 'node', '2.91869'),
('egestas', '69', 'node', '1.92027'),
('egestas', '71', 'node', '1.94209'),
('egestas', '73', 'node', '1.95723'),
('egestas', '77', 'node', '0.876337'),
('egestas', '78', 'node', '1'),
('egestas', '79', 'node', '1.89608'),
('egestas', '82', 'node', '1'),
('egestas', '83', 'node', '1.96498'),
('egestas', '84', 'node', '1.96498'),
('egestas', '85', 'node', '1.95723'),
('egestas', '86', 'node', '1.95723'),
('egestas', '87', 'node', '1.96109'),
('egestas', '88', 'node', '1.95723'),
('egestas', '89', 'node', '1.95723'),
('eget', '12', 'node', '5.98477'),
('eget', '13', 'node', '8.8913'),
('eget', '14', 'node', '34.7018'),
('eget', '15', 'node', '3.86995'),
('eget', '16', 'node', '7.65262'),
('eget', '17', 'node', '0.993146'),
('eget', '18', 'node', '2.98493'),
('eget', '19', 'node', '1.9534'),
('eget', '20', 'node', '5.70362'),
('eget', '21', 'node', '3.9689'),
('eget', '22', 'node', '2.9242'),
('eget', '23', 'node', '3.9689'),
('eget', '24', 'node', '29.8828'),
('eget', '25', 'node', '1.93838'),
('eget', '26', 'node', '2'),
('eget', '27', 'node', '4'),
('eget', '28', 'node', '6.7049'),
('eget', '29', 'node', '4.8403'),
('eget', '30', 'node', '3.98087'),
('eget', '31', 'node', '3.96498'),
('eget', '32', 'node', '1.98087'),
('eget', '33', 'node', '1.99731'),
('eget', '34', 'node', '4'),
('eget', '35', 'node', '1.98493'),
('eget', '36', 'node', '5.64703'),
('eget', '37', 'node', '1.92027'),
('eget', '38', 'node', '4.80991'),
('eget', '39', 'node', '3.98902'),
('eget', '40', 'node', '3.67465'),
('eget', '41', 'node', '10.3422'),
('eget', '47', 'node', '4.99731'),
('eget', '50', 'node', '2.95723'),
('eget', '51', 'node', '4.98217'),
('eget', '52', 'node', '3'),
('eget', '53', 'node', '3'),
('eget', '54', 'node', '3'),
('eget', '55', 'node', '3'),
('eget', '56', 'node', '3'),
('eget', '57', 'node', '3'),
('eget', '58', 'node', '3'),
('eget', '65', 'node', '2.98087'),
('eget', '67', 'node', '8.88492'),
('eget', '68', 'node', '12.2667'),
('eget', '69', 'node', '4.64218'),
('eget', '71', 'node', '7.46707'),
('eget', '73', 'node', '3.98902'),
('eget', '76', 'node', '4.94576'),
('eget', '77', 'node', '9.6004'),
('eget', '78', 'node', '2.83399'),
('eget', '79', 'node', '6.34915'),
('eget', '82', 'node', '3'),
('eget', '83', 'node', '3.99731'),
('eget', '84', 'node', '3.99731'),
('eget', '85', 'node', '3.98902'),
('eget', '86', 'node', '3.98902'),
('eget', '87', 'node', '3.99315'),
('eget', '88', 'node', '3.98902'),
('eget', '89', 'node', '3.98902'),
('eleifend', '12', 'node', '3.78633'),
('eleifend', '13', 'node', '0.913226'),
('eleifend', '14', 'node', '5.83758'),
('eleifend', '15', 'node', '1'),
('eleifend', '16', 'node', '1'),
('eleifend', '17', 'node', '13.9347'),
('eleifend', '18', 'node', '13'),
('eleifend', '19', 'node', '11'),
('eleifend', '20', 'node', '13.8423'),
('eleifend', '21', 'node', '2'),
('eleifend', '23', 'node', '2'),
('eleifend', '24', 'node', '4.77605'),
('eleifend', '25', 'node', '2'),
('eleifend', '26', 'node', '3'),
('eleifend', '27', 'node', '1'),
('eleifend', '28', 'node', '2'),
('eleifend', '29', 'node', '1.93105'),
('eleifend', '30', 'node', '1.99731'),
('eleifend', '31', 'node', '2.98902'),
('eleifend', '32', 'node', '1'),
('eleifend', '34', 'node', '2'),
('eleifend', '35', 'node', '1'),
('eleifend', '36', 'node', '1'),
('eleifend', '37', 'node', '0.920273'),
('eleifend', '38', 'node', '0.934703'),
('eleifend', '39', 'node', '2'),
('eleifend', '40', 'node', '1.80941'),
('eleifend', '41', 'node', '3.80231'),
('eleifend', '45', 'node', '1'),
('eleifend', '46', 'node', '1'),
('eleifend', '50', 'node', '3.90974'),
('eleifend', '67', 'node', '0.934703'),
('eleifend', '71', 'node', '14.5133'),
('eleifend', '76', 'node', '1.96178'),
('eleifend', '77', 'node', '2.98087'),
('eleifend', '78', 'node', '1.87308'),
('eleifend', '79', 'node', '4.64169'),
('elementum', '12', 'node', '4.18399'),
('elementum', '13', 'node', '2'),
('elementum', '14', 'node', '3.23983'),
('elementum', '15', 'node', '1.85746'),
('elementum', '16', 'node', '2.65114'),
('elementum', '17', 'node', '1'),
('elementum', '18', 'node', '1'),
('elementum', '19', 'node', '1'),
('elementum', '20', 'node', '1.76238'),
('elementum', '21', 'node', '2'),
('elementum', '22', 'node', '1'),
('elementum', '23', 'node', '2'),
('elementum', '24', 'node', '1.89608'),
('elementum', '25', 'node', '2'),
('elementum', '26', 'node', '1.96109'),
('elementum', '27', 'node', '1'),
('elementum', '29', 'node', '2.99731'),
('elementum', '31', 'node', '3.86878'),
('elementum', '32', 'node', '1'),
('elementum', '33', 'node', '1'),
('elementum', '34', 'node', '1'),
('elementum', '35', 'node', '1'),
('elementum', '36', 'node', '2'),
('elementum', '37', 'node', '1'),
('elementum', '38', 'node', '0.923838'),
('elementum', '39', 'node', '0.892724'),
('elementum', '40', 'node', '0.96498'),
('elementum', '41', 'node', '0.851346'),
('elementum', '43', 'node', '26'),
('elementum', '47', 'node', '1'),
('elementum', '51', 'node', '1'),
('elementum', '65', 'node', '1'),
('elementum', '67', 'node', '2.99731'),
('elementum', '68', 'node', '1.90629'),
('elementum', '69', 'node', '1'),
('elementum', '71', 'node', '0.920273'),
('elementum', '73', 'node', '1'),
('elementum', '76', 'node', '11.9931'),
('elementum', '77', 'node', '0.899454'),
('elementum', '78', 'node', '3.94209'),
('elementum', '83', 'node', '1'),
('elementum', '84', 'node', '1'),
('elementum', '85', 'node', '1'),
('elementum', '86', 'node', '1'),
('elementum', '87', 'node', '1'),
('elementum', '88', 'node', '1'),
('elementum', '89', 'node', '1'),
('elit', '12', 'node', '3.57296'),
('elit', '13', 'node', '2.94583'),
('elit', '14', 'node', '4.15421'),
('elit', '15', 'node', '0.863659'),
('elit', '16', 'node', '1.69881'),
('elit', '17', 'node', '1'),
('elit', '18', 'node', '1'),
('elit', '19', 'node', '3.94196'),
('elit', '20', 'node', '3'),
('elit', '21', 'node', '5.92743'),
('elit', '22', 'node', '2.93105'),
('elit', '23', 'node', '5.92743'),
('elit', '24', 'node', '2'),
('elit', '25', 'node', '2.94585'),
('elit', '26', 'node', '1.84154'),
('elit', '27', 'node', '2'),
('elit', '28', 'node', '2.86369'),
('elit', '29', 'node', '4.92743'),
('elit', '30', 'node', '1.97286'),
('elit', '31', 'node', '2'),
('elit', '33', 'node', '2'),
('elit', '34', 'node', '3'),
('elit', '36', 'node', '30.8024'),
('elit', '37', 'node', '2.90637'),
('elit', '38', 'node', '4.88254'),
('elit', '39', 'node', '2.87176'),
('elit', '40', 'node', '1.92027'),
('elit', '41', 'node', '3.69054'),
('elit', '42', 'node', '26'),
('elit', '43', 'node', '2'),
('elit', '47', 'node', '3'),
('elit', '50', 'node', '1'),
('elit', '51', 'node', '1.97685'),
('elit', '52', 'node', '13'),
('elit', '53', 'node', '13'),
('elit', '54', 'node', '13'),
('elit', '55', 'node', '13'),
('elit', '56', 'node', '13'),
('elit', '57', 'node', '13'),
('elit', '58', 'node', '13'),
('elit', '65', 'node', '1.91323'),
('elit', '67', 'node', '4.91841'),
('elit', '68', 'node', '2.94583'),
('elit', '69', 'node', '5.94583'),
('elit', '71', 'node', '4.81257'),
('elit', '73', 'node', '13.9097'),
('elit', '76', 'node', '2.81639'),
('elit', '77', 'node', '1.86957'),
('elit', '78', 'node', '1'),
('elit', '79', 'node', '8.39329'),
('elit', '82', 'node', '13'),
('elit', '83', 'node', '13.9167'),
('elit', '84', 'node', '13.9167'),
('elit', '85', 'node', '13.9097'),
('elit', '86', 'node', '13.9097'),
('elit', '87', 'node', '13.9132'),
('elit', '88', 'node', '13.9097'),
('elit', '89', 'node', '13.9097'),
('email', '79', 'node', '0.836446'),
('enim', '12', 'node', '2.61276'),
('enim', '13', 'node', '3'),
('enim', '14', 'node', '7.6296'),
('enim', '15', 'node', '1.85746'),
('enim', '16', 'node', '4.70122'),
('enim', '17', 'node', '2.93862'),
('enim', '18', 'node', '4.97395'),
('enim', '19', 'node', '2.9534'),
('enim', '20', 'node', '3'),
('enim', '21', 'node', '2'),
('enim', '22', 'node', '0.916736'),
('enim', '23', 'node', '2'),
('enim', '24', 'node', '2.85967'),
('enim', '25', 'node', '1'),
('enim', '26', 'node', '2'),
('enim', '28', 'node', '2.68841'),
('enim', '31', 'node', '2.95772'),
('enim', '32', 'node', '1'),
('enim', '33', 'node', '2'),
('enim', '34', 'node', '2.92743'),
('enim', '35', 'node', '1'),
('enim', '36', 'node', '6.38895'),
('enim', '38', 'node', '2'),
('enim', '39', 'node', '2'),
('enim', '40', 'node', '0.860547'),
('enim', '41', 'node', '7.44196'),
('enim', '44', 'node', '28'),
('enim', '45', 'node', '1'),
('enim', '46', 'node', '26'),
('enim', '47', 'node', '3'),
('enim', '50', 'node', '1'),
('enim', '51', 'node', '1'),
('enim', '54', 'node', '26'),
('enim', '65', 'node', '4.77579'),
('enim', '68', 'node', '3'),
('enim', '69', 'node', '3.95779'),
('enim', '71', 'node', '3.90629'),
('enim', '73', 'node', '1.99731'),
('enim', '76', 'node', '1.97685'),
('enim', '77', 'node', '2.81123'),
('enim', '78', 'node', '2'),
('enim', '79', 'node', '3.78147'),
('enim', '83', 'node', '2'),
('enim', '84', 'node', '2'),
('enim', '85', 'node', '27.9973'),
('enim', '86', 'node', '1.99731'),
('enim', '87', 'node', '2'),
('enim', '88', 'node', '1.99731'),
('enim', '89', 'node', '1.99731'),
('entesque', '30', 'node', '26'),
('erat', '12', 'node', '1'),
('erat', '13', 'node', '3'),
('erat', '14', 'node', '7.28459'),
('erat', '15', 'node', '1.99315'),
('erat', '16', 'node', '1.85498'),
('erat', '17', 'node', '5.87679'),
('erat', '18', 'node', '3'),
('erat', '19', 'node', '4.93833'),
('erat', '20', 'node', '5'),
('erat', '21', 'node', '3.94177'),
('erat', '22', 'node', '4.81631'),
('erat', '23', 'node', '3.94177'),
('erat', '24', 'node', '0.938382'),
('erat', '25', 'node', '1'),
('erat', '26', 'node', '1.9534'),
('erat', '27', 'node', '1'),
('erat', '28', 'node', '4.75487'),
('erat', '29', 'node', '3'),
('erat', '30', 'node', '3.84915'),
('erat', '31', 'node', '2.95104'),
('erat', '32', 'node', '2'),
('erat', '33', 'node', '3'),
('erat', '34', 'node', '3'),
('erat', '35', 'node', '28'),
('erat', '36', 'node', '3.84532'),
('erat', '38', 'node', '2.90974'),
('erat', '40', 'node', '3.79052'),
('erat', '41', 'node', '2.76573'),
('erat', '42', 'node', '1'),
('erat', '43', 'node', '1'),
('erat', '45', 'node', '27'),
('erat', '46', 'node', '2'),
('erat', '47', 'node', '2'),
('erat', '50', 'node', '2'),
('erat', '51', 'node', '1'),
('erat', '52', 'node', '2'),
('erat', '53', 'node', '2'),
('erat', '54', 'node', '2'),
('erat', '55', 'node', '2'),
('erat', '56', 'node', '2'),
('erat', '57', 'node', '2'),
('erat', '58', 'node', '2'),
('erat', '65', 'node', '1.89945'),
('erat', '67', 'node', '0.96498'),
('erat', '68', 'node', '0.972861'),
('erat', '69', 'node', '0.920273'),
('erat', '71', 'node', '2.9347'),
('erat', '73', 'node', '2'),
('erat', '76', 'node', '3.78545'),
('erat', '77', 'node', '2'),
('erat', '78', 'node', '4.92702'),
('erat', '79', 'node', '6.63599'),
('erat', '82', 'node', '2'),
('erat', '83', 'node', '2'),
('erat', '84', 'node', '2'),
('erat', '85', 'node', '2'),
('erat', '86', 'node', '2'),
('erat', '87', 'node', '2'),
('erat', '88', 'node', '2'),
('erat', '89', 'node', '2'),
('eratmorbi', '39', 'node', '1'),
('eros', '12', 'node', '4.96867'),
('eros', '13', 'node', '0.920273'),
('eros', '14', 'node', '6.7282'),
('eros', '15', 'node', '1.85746'),
('eros', '16', 'node', '1.92027'),
('eros', '17', 'node', '0.938382'),
('eros', '18', 'node', '1'),
('eros', '19', 'node', '27.9572'),
('eros', '20', 'node', '3.97685'),
('eros', '21', 'node', '2.90428'),
('eros', '22', 'node', '2.94209'),
('eros', '23', 'node', '2.90428'),
('eros', '24', 'node', '1.97286'),
('eros', '25', 'node', '2.98087'),
('eros', '26', 'node', '3.77634'),
('eros', '27', 'node', '2'),
('eros', '28', 'node', '3.94209'),
('eros', '29', 'node', '3.93153'),
('eros', '30', 'node', '3.9347'),
('eros', '31', 'node', '4.92645'),
('eros', '32', 'node', '5'),
('eros', '33', 'node', '1.99315'),
('eros', '34', 'node', '2.91698'),
('eros', '35', 'node', '5'),
('eros', '36', 'node', '5.26202'),
('eros', '37', 'node', '3.89062'),
('eros', '38', 'node', '2.89712'),
('eros', '39', 'node', '1.9689'),
('eros', '41', 'node', '2.9496'),
('eros', '45', 'node', '1'),
('eros', '46', 'node', '1'),
('eros', '47', 'node', '2'),
('eros', '50', 'node', '2.90974'),
('eros', '51', 'node', '1'),
('eros', '52', 'node', '4'),
('eros', '53', 'node', '4'),
('eros', '54', 'node', '4'),
('eros', '55', 'node', '4'),
('eros', '56', 'node', '4'),
('eros', '57', 'node', '4'),
('eros', '58', 'node', '4'),
('eros', '65', 'node', '0.876337'),
('eros', '67', 'node', '4.87631'),
('eros', '68', 'node', '2.98087'),
('eros', '69', 'node', '4.92743'),
('eros', '71', 'node', '1.99731'),
('eros', '73', 'node', '4'),
('eros', '76', 'node', '1.88282'),
('eros', '77', 'node', '3.7485'),
('eros', '78', 'node', '2.9534'),
('eros', '79', 'node', '3.74224'),
('eros', '82', 'node', '4'),
('eros', '83', 'node', '4'),
('eros', '84', 'node', '4'),
('eros', '85', 'node', '4'),
('eros', '86', 'node', '4'),
('eros', '87', 'node', '4'),
('eros', '88', 'node', '4'),
('eros', '89', 'node', '4'),
('est', '12', 'node', '4.18964'),
('est', '13', 'node', '1.93105'),
('est', '14', 'node', '8.24537'),
('est', '15', 'node', '1.78318'),
('est', '16', 'node', '1.81925'),
('est', '17', 'node', '1.99731'),
('est', '18', 'node', '28'),
('est', '19', 'node', '1.99315'),
('est', '20', 'node', '1'),
('est', '22', 'node', '2.94576'),
('est', '24', 'node', '1.8894'),
('est', '25', 'node', '4'),
('est', '26', 'node', '3.86445'),
('est', '28', 'node', '11'),
('est', '29', 'node', '12'),
('est', '30', 'node', '11'),
('est', '31', 'node', '12.9534'),
('est', '32', 'node', '15'),
('est', '33', 'node', '0.957226'),
('est', '34', 'node', '4.98902'),
('est', '35', 'node', '4'),
('est', '36', 'node', '5.79081'),
('est', '37', 'node', '1.8408'),
('est', '38', 'node', '3.85113'),
('est', '39', 'node', '1.89272'),
('est', '40', 'node', '6.57151'),
('est', '41', 'node', '3.43118'),
('est', '45', 'node', '26'),
('est', '50', 'node', '1'),
('est', '51', 'node', '1'),
('est', '52', 'node', '3'),
('est', '53', 'node', '3'),
('est', '54', 'node', '3'),
('est', '55', 'node', '3'),
('est', '56', 'node', '3'),
('est', '57', 'node', '3'),
('est', '58', 'node', '3'),
('est', '65', 'node', '3.96498'),
('est', '67', 'node', '2'),
('est', '68', 'node', '6.86394'),
('est', '69', 'node', '4.75353'),
('est', '71', 'node', '0.931053'),
('est', '73', 'node', '5.93927'),
('est', '76', 'node', '6.94005'),
('est', '79', 'node', '2.65291'),
('est', '82', 'node', '3'),
('est', '83', 'node', '5.95793'),
('est', '84', 'node', '5.95793'),
('est', '85', 'node', '5.93927'),
('est', '86', 'node', '5.93927'),
('est', '87', 'node', '5.94991'),
('est', '88', 'node', '5.93927'),
('est', '89', 'node', '5.93927'),
('etiam', '12', 'node', '2.44819'),
('etiam', '13', 'node', '2'),
('etiam', '14', 'node', '46.7902'),
('etiam', '15', 'node', '1.98493'),
('etiam', '16', 'node', '2'),
('etiam', '17', 'node', '1'),
('etiam', '19', 'node', '3'),
('etiam', '20', 'node', '3.88798'),
('etiam', '24', 'node', '1'),
('etiam', '25', 'node', '1'),
('etiam', '26', 'node', '0.989021'),
('etiam', '28', 'node', '0.892724'),
('etiam', '33', 'node', '1'),
('etiam', '34', 'node', '1'),
('etiam', '36', 'node', '1'),
('etiam', '37', 'node', '0.968904'),
('etiam', '39', 'node', '2'),
('etiam', '40', 'node', '1.96109'),
('etiam', '41', 'node', '2.93838'),
('etiam', '47', 'node', '2'),
('etiam', '50', 'node', '3.92743'),
('etiam', '65', 'node', '0.896076'),
('etiam', '67', 'node', '2'),
('etiam', '68', 'node', '1.90974'),
('etiam', '69', 'node', '1'),
('etiam', '71', 'node', '1'),
('etiam', '76', 'node', '1.86995'),
('etiam', '78', 'node', '2'),
('etiam', '79', 'node', '0.909743'),
('euismo', '22', 'node', '26'),
('euismod', '12', 'node', '2.46877'),
('euismod', '13', 'node', '4.91155'),
('euismod', '14', 'node', '4.71028'),
('euismod', '15', 'node', '2.76031'),
('euismod', '16', 'node', '2.86163'),
('euismod', '19', 'node', '2.98493'),
('euismod', '20', 'node', '4.8894'),
('euismod', '21', 'node', '2.88964'),
('euismod', '22', 'node', '29'),
('euismod', '23', 'node', '28.8856'),
('euismod', '24', 'node', '2.92384'),
('euismod', '26', 'node', '1'),
('euismod', '27', 'node', '2'),
('euismod', '28', 'node', '2.89272'),
('euismod', '29', 'node', '2.86952'),
('euismod', '30', 'node', '2'),
('euismod', '31', 'node', '3.98087'),
('euismod', '32', 'node', '1'),
('euismod', '33', 'node', '1'),
('euismod', '35', 'node', '1'),
('euismod', '36', 'node', '0.830633'),
('euismod', '37', 'node', '9.89399'),
('euismod', '38', 'node', '9.74705'),
('euismod', '39', 'node', '2.8967'),
('euismod', '40', 'node', '10.0739'),
('euismod', '41', 'node', '1'),
('euismod', '47', 'node', '2'),
('euismod', '50', 'node', '0.916736'),
('euismod', '51', 'node', '1'),
('euismod', '52', 'node', '5'),
('euismod', '53', 'node', '5'),
('euismod', '54', 'node', '5'),
('euismod', '55', 'node', '5'),
('euismod', '56', 'node', '5'),
('euismod', '57', 'node', '5'),
('euismod', '58', 'node', '5'),
('euismod', '65', 'node', '0.961087'),
('euismod', '67', 'node', '1'),
('euismod', '68', 'node', '0.873132'),
('euismod', '69', 'node', '1'),
('euismod', '71', 'node', '0.980874'),
('euismod', '73', 'node', '5'),
('euismod', '76', 'node', '0.892724'),
('euismod', '77', 'node', '3.8894'),
('euismod', '78', 'node', '0.968904'),
('euismod', '79', 'node', '2.80571'),
('euismod', '82', 'node', '5'),
('euismod', '83', 'node', '5'),
('euismod', '84', 'node', '5'),
('euismod', '85', 'node', '5'),
('euismod', '86', 'node', '5'),
('euismod', '87', 'node', '5'),
('euismod', '88', 'node', '5'),
('euismod', '89', 'node', '5'),
('facilisi', '12', 'node', '0.866793'),
('facilisi', '14', 'node', '2.60483'),
('facilisi', '15', 'node', '0.989021'),
('facilisi', '21', 'node', '1'),
('facilisi', '23', 'node', '0.997306'),
('facilisi', '32', 'node', '0.997306'),
('facilisi', '33', 'node', '1'),
('facilisi', '35', 'node', '1'),
('facilisi', '40', 'node', '1'),
('facilisi', '41', 'node', '0.830633'),
('facilisi', '65', 'node', '2'),
('facilisi', '73', 'node', '0.976851'),
('facilisi', '76', 'node', '0.945829'),
('facilisi', '77', 'node', '0.997306'),
('facilisi', '79', 'node', '0.953396'),
('facilisi', '83', 'node', '0.98493'),
('facilisi', '84', 'node', '0.98493'),
('facilisi', '85', 'node', '0.976851'),
('facilisi', '86', 'node', '0.976851'),
('facilisi', '87', 'node', '0.980874'),
('facilisi', '88', 'node', '0.976851'),
('facilisi', '89', 'node', '0.976851'),
('facilisis', '12', 'node', '2.56867'),
('facilisis', '13', 'node', '29'),
('facilisis', '14', 'node', '8.41408'),
('facilisis', '16', 'node', '2'),
('facilisis', '17', 'node', '3.89658'),
('facilisis', '18', 'node', '3'),
('facilisis', '19', 'node', '1'),
('facilisis', '20', 'node', '0.972861'),
('facilisis', '21', 'node', '0.972861'),
('facilisis', '22', 'node', '1'),
('facilisis', '23', 'node', '0.972861'),
('facilisis', '24', 'node', '1'),
('facilisis', '25', 'node', '0.942091'),
('facilisis', '27', 'node', '2'),
('facilisis', '28', 'node', '2.84612'),
('facilisis', '29', 'node', '1.93838'),
('facilisis', '30', 'node', '1.94583'),
('facilisis', '31', 'node', '1.98087'),
('facilisis', '32', 'node', '2'),
('facilisis', '33', 'node', '3.95453'),
('facilisis', '35', 'node', '2'),
('facilisis', '37', 'node', '2.85212'),
('facilisis', '39', 'node', '1'),
('facilisis', '40', 'node', '3.88282'),
('facilisis', '41', 'node', '3.63679'),
('facilisis', '42', 'node', '1'),
('facilisis', '44', 'node', '26'),
('facilisis', '45', 'node', '1'),
('facilisis', '46', 'node', '1'),
('facilisis', '50', 'node', '2'),
('facilisis', '52', 'node', '1'),
('facilisis', '53', 'node', '1'),
('facilisis', '54', 'node', '1'),
('facilisis', '55', 'node', '1'),
('facilisis', '56', 'node', '1'),
('facilisis', '57', 'node', '1'),
('facilisis', '58', 'node', '1'),
('facilisis', '65', 'node', '4.70669'),
('facilisis', '68', 'node', '1'),
('facilisis', '69', 'node', '2'),
('facilisis', '71', 'node', '2'),
('facilisis', '73', 'node', '1.90974'),
('facilisis', '76', 'node', '1'),
('facilisis', '77', 'node', '2.83002'),
('facilisis', '78', 'node', '1.92384'),
('facilisis', '82', 'node', '1'),
('facilisis', '83', 'node', '1.91674'),
('facilisis', '84', 'node', '1.91674'),
('facilisis', '85', 'node', '1.90974'),
('facilisis', '86', 'node', '1.90974'),
('facilisis', '87', 'node', '1.91323'),
('facilisis', '88', 'node', '1.90974'),
('facilisis', '89', 'node', '1.90974'),
('fames', '12', 'node', '0.78951'),
('fames', '14', 'node', '1.58237'),
('fames', '15', 'node', '2'),
('fames', '16', 'node', '2.90069'),
('fames', '17', 'node', '1'),
('fames', '28', 'node', '1'),
('fames', '30', 'node', '1'),
('fames', '37', 'node', '1'),
('fames', '38', 'node', '11.6539'),
('fames', '39', 'node', '9.6397'),
('fames', '40', 'node', '9.10533'),
('fames', '41', 'node', '1'),
('fames', '77', 'node', '0.879565'),
('fames', '79', 'node', '1'),
('faucibus', '12', 'node', '2.99731'),
('faucibus', '13', 'node', '1.93838'),
('faucibus', '14', 'node', '5.04794'),
('faucibus', '16', 'node', '3.27292'),
('faucibus', '17', 'node', '2'),
('faucibus', '19', 'node', '1'),
('faucibus', '21', 'node', '3.81164'),
('faucibus', '22', 'node', '3.9347'),
('faucibus', '23', 'node', '3.81164'),
('faucibus', '24', 'node', '3'),
('faucibus', '27', 'node', '1'),
('faucibus', '28', 'node', '1'),
('faucibus', '29', 'node', '2'),
('faucibus', '30', 'node', '1'),
('faucibus', '31', 'node', '1'),
('faucibus', '36', 'node', '2.75267'),
('faucibus', '37', 'node', '3.91323'),
('faucibus', '38', 'node', '1'),
('faucibus', '39', 'node', '1.89272'),
('faucibus', '40', 'node', '2.71229'),
('faucibus', '41', 'node', '1'),
('faucibus', '43', 'node', '1'),
('faucibus', '45', 'node', '1'),
('faucibus', '47', 'node', '1'),
('faucibus', '51', 'node', '1'),
('faucibus', '52', 'node', '6'),
('faucibus', '53', 'node', '6'),
('faucibus', '54', 'node', '6'),
('faucibus', '55', 'node', '6'),
('faucibus', '56', 'node', '6'),
('faucibus', '57', 'node', '6'),
('faucibus', '58', 'node', '6'),
('faucibus', '65', 'node', '1.83391'),
('faucibus', '67', 'node', '2'),
('faucibus', '68', 'node', '1.77549'),
('faucibus', '71', 'node', '13.9911'),
('faucibus', '73', 'node', '6'),
('faucibus', '76', 'node', '1.89945'),
('faucibus', '77', 'node', '1.9689'),
('faucibus', '78', 'node', '2'),
('faucibus', '79', 'node', '1.90286'),
('faucibus', '82', 'node', '6'),
('faucibus', '83', 'node', '6'),
('faucibus', '84', 'node', '6'),
('faucibus', '85', 'node', '6'),
('faucibus', '86', 'node', '6'),
('faucibus', '87', 'node', '6'),
('faucibus', '88', 'node', '6'),
('faucibus', '89', 'node', '6'),
('felis', '12', 'node', '6.82762'),
('felis', '13', 'node', '1'),
('felis', '14', 'node', '4.27836'),
('felis', '15', 'node', '1.97685'),
('felis', '16', 'node', '2.8034'),
('felis', '17', 'node', '1'),
('felis', '18', 'node', '1.96178'),
('felis', '21', 'node', '4.84442'),
('felis', '22', 'node', '2'),
('felis', '23', 'node', '4.84029'),
('felis', '24', 'node', '3.85127'),
('felis', '25', 'node', '1'),
('felis', '26', 'node', '2.95723'),
('felis', '27', 'node', '3'),
('felis', '28', 'node', '2'),
('felis', '29', 'node', '3.85848'),
('felis', '30', 'node', '2'),
('felis', '31', 'node', '1.97286'),
('felis', '32', 'node', '3'),
('felis', '33', 'node', '4'),
('felis', '34', 'node', '0.997306'),
('felis', '35', 'node', '3'),
('felis', '36', 'node', '6.67002'),
('felis', '37', 'node', '2'),
('felis', '38', 'node', '1'),
('felis', '39', 'node', '3.89272'),
('felis', '40', 'node', '0.876337'),
('felis', '41', 'node', '3.81268'),
('felis', '42', 'node', '1'),
('felis', '43', 'node', '1'),
('felis', '45', 'node', '3'),
('felis', '47', 'node', '1'),
('felis', '50', 'node', '2'),
('felis', '51', 'node', '2'),
('felis', '65', 'node', '1.8092'),
('felis', '67', 'node', '2'),
('felis', '68', 'node', '7.78212'),
('felis', '69', 'node', '6'),
('felis', '71', 'node', '2.91674'),
('felis', '76', 'node', '2'),
('felis', '77', 'node', '4.72311'),
('felis', '78', 'node', '2'),
('felis', '79', 'node', '5.61823'),
('fermentum', '12', 'node', '3.68521'),
('fermentum', '13', 'node', '2.90796'),
('fermentum', '14', 'node', '0.781775'),
('fermentum', '15', 'node', '1.82725'),
('fermentum', '17', 'node', '1'),
('fermentum', '18', 'node', '0.993146'),
('fermentum', '19', 'node', '0.993146'),
('fermentum', '20', 'node', '2.76238'),
('fermentum', '21', 'node', '1.9394'),
('fermentum', '22', 'node', '1'),
('fermentum', '23', 'node', '1.93524'),
('fermentum', '24', 'node', '1.93111'),
('fermentum', '26', 'node', '2'),
('fermentum', '27', 'node', '2'),
('fermentum', '28', 'node', '1'),
('fermentum', '29', 'node', '1.92384'),
('fermentum', '30', 'node', '1'),
('fermentum', '31', 'node', '1.98087'),
('fermentum', '36', 'node', '22.5811'),
('fermentum', '37', 'node', '0.972861'),
('fermentum', '38', 'node', '0.920273'),
('fermentum', '40', 'node', '1'),
('fermentum', '41', 'node', '1.72098'),
('fermentum', '46', 'node', '1'),
('fermentum', '51', 'node', '2'),
('fermentum', '52', 'node', '1'),
('fermentum', '53', 'node', '1'),
('fermentum', '54', 'node', '1'),
('fermentum', '55', 'node', '1'),
('fermentum', '56', 'node', '1'),
('fermentum', '57', 'node', '1'),
('fermentum', '58', 'node', '1'),
('fermentum', '65', 'node', '12.6046'),
('fermentum', '67', 'node', '1.92743'),
('fermentum', '68', 'node', '1.88282'),
('fermentum', '69', 'node', '6'),
('fermentum', '71', 'node', '24.5712'),
('fermentum', '73', 'node', '1.95723'),
('fermentum', '77', 'node', '1.9496'),
('fermentum', '78', 'node', '5.89178'),
('fermentum', '79', 'node', '4.67424'),
('fermentum', '82', 'node', '1'),
('fermentum', '83', 'node', '1.96498'),
('fermentum', '84', 'node', '1.96498'),
('fermentum', '85', 'node', '1.95723'),
('fermentum', '86', 'node', '1.95723'),
('fermentum', '87', 'node', '1.96109'),
('fermentum', '88', 'node', '1.95723'),
('fermentum', '89', 'node', '1.95723'),
('feugiat', '12', 'node', '3.54505'),
('feugiat', '13', 'node', '4'),
('feugiat', '14', 'node', '5.04127'),
('feugiat', '15', 'node', '1'),
('feugiat', '16', 'node', '2'),
('feugiat', '17', 'node', '1'),
('feugiat', '19', 'node', '0.997306'),
('feugiat', '20', 'node', '1'),
('feugiat', '24', 'node', '0.913226'),
('feugiat', '25', 'node', '1.92384'),
('feugiat', '26', 'node', '1'),
('feugiat', '27', 'node', '30'),
('feugiat', '28', 'node', '1.94209'),
('feugiat', '29', 'node', '30.9662'),
('feugiat', '30', 'node', '1.9347'),
('feugiat', '32', 'node', '1'),
('feugiat', '33', 'node', '1'),
('feugiat', '35', 'node', '12'),
('feugiat', '36', 'node', '2.50959'),
('feugiat', '37', 'node', '1'),
('feugiat', '38', 'node', '3.90016'),
('feugiat', '39', 'node', '1'),
('feugiat', '41', 'node', '1.91323'),
('feugiat', '42', 'node', '1'),
('feugiat', '47', 'node', '2'),
('feugiat', '51', 'node', '1'),
('feugiat', '67', 'node', '1'),
('feugiat', '68', 'node', '11.8894'),
('feugiat', '69', 'node', '11'),
('feugiat', '76', 'node', '2.70756'),
('feugiat', '77', 'node', '0.896076'),
('feugiat', '79', 'node', '1'),
('franklin', '65', 'node', '26'),
('fringilla', '13', 'node', '0.945829'),
('fringilla', '14', 'node', '4.55842'),
('fringilla', '16', 'node', '1.87957'),
('fringilla', '17', 'node', '28'),
('fringilla', '18', 'node', '1'),
('fringilla', '19', 'node', '1.97286'),
('fringilla', '20', 'node', '1.87957'),
('fringilla', '21', 'node', '1.94209'),
('fringilla', '22', 'node', '2.93105'),
('fringilla', '23', 'node', '1.94209'),
('fringilla', '24', 'node', '1'),
('fringilla', '25', 'node', '0.989021'),
('fringilla', '26', 'node', '0.906287'),
('fringilla', '28', 'node', '1.85588'),
('fringilla', '29', 'node', '1'),
('fringilla', '30', 'node', '0.942091'),
('fringilla', '32', 'node', '0.976851'),
('fringilla', '33', 'node', '2'),
('fringilla', '34', 'node', '1'),
('fringilla', '35', 'node', '0.976851'),
('fringilla', '36', 'node', '2.82776'),
('fringilla', '37', 'node', '1'),
('fringilla', '38', 'node', '2'),
('fringilla', '39', 'node', '2.92384'),
('fringilla', '40', 'node', '2.5511'),
('fringilla', '41', 'node', '2.79475'),
('fringilla', '46', 'node', '2'),
('fringilla', '47', 'node', '1.99731'),
('fringilla', '50', 'node', '2'),
('fringilla', '51', 'node', '1'),
('fringilla', '65', 'node', '2'),
('fringilla', '67', 'node', '0.997306'),
('fringilla', '68', 'node', '1.94583'),
('fringilla', '69', 'node', '1'),
('fringilla', '73', 'node', '0.909743'),
('fringilla', '76', 'node', '1.9534'),
('fringilla', '77', 'node', '4.71237'),
('fringilla', '78', 'node', '1.92027'),
('fringilla', '79', 'node', '5.28797'),
('fringilla', '83', 'node', '0.916736'),
('fringilla', '84', 'node', '0.916736'),
('fringilla', '85', 'node', '0.909743'),
('fringilla', '86', 'node', '0.909743'),
('fringilla', '87', 'node', '0.913226'),
('fringilla', '88', 'node', '0.909743'),
('fringilla', '89', 'node', '0.909743'),
('fusce', '12', 'node', '50.4158'),
('fusce', '13', 'node', '3'),
('fusce', '14', 'node', '26.2412'),
('fusce', '15', 'node', '2.99315'),
('fusce', '16', 'node', '4.6399'),
('fusce', '17', 'node', '1'),
('fusce', '19', 'node', '1.99731'),
('fusce', '20', 'node', '4.90318'),
('fusce', '24', 'node', '1.91674'),
('fusce', '25', 'node', '1'),
('fusce', '26', 'node', '27'),
('fusce', '27', 'node', '2'),
('fusce', '28', 'node', '0.931053'),
('fusce', '29', 'node', '2.99731'),
('fusce', '31', 'node', '0.980874'),
('fusce', '32', 'node', '2'),
('fusce', '33', 'node', '1'),
('fusce', '34', 'node', '3'),
('fusce', '35', 'node', '2'),
('fusce', '36', 'node', '1'),
('fusce', '37', 'node', '2.90629'),
('fusce', '40', 'node', '1.84832'),
('fusce', '41', 'node', '1.81635'),
('fusce', '50', 'node', '1.91323'),
('fusce', '51', 'node', '1'),
('fusce', '52', 'node', '1'),
('fusce', '53', 'node', '27'),
('fusce', '54', 'node', '1'),
('fusce', '55', 'node', '1'),
('fusce', '56', 'node', '1'),
('fusce', '57', 'node', '1'),
('fusce', '58', 'node', '1'),
('fusce', '65', 'node', '10.8792'),
('fusce', '68', 'node', '0.945829'),
('fusce', '71', 'node', '1.84793'),
('fusce', '73', 'node', '1'),
('fusce', '76', 'node', '1'),
('fusce', '77', 'node', '1.91926'),
('fusce', '78', 'node', '1'),
('fusce', '79', 'node', '3.40538'),
('fusce', '82', 'node', '1'),
('fusce', '83', 'node', '1'),
('fusce', '84', 'node', '1'),
('fusce', '85', 'node', '1'),
('fusce', '86', 'node', '1'),
('fusce', '87', 'node', '1'),
('fusce', '88', 'node', '1'),
('fusce', '89', 'node', '1'),
('general', '12', 'node', '11'),
('general', '13', 'node', '11'),
('general', '14', 'node', '11'),
('general', '15', 'node', '11'),
('general', '16', 'node', '11'),
('good', '11', 'node', '1'),
('gravida', '12', 'node', '2.81623'),
('gravida', '14', 'node', '22.8701'),
('gravida', '15', 'node', '1.86679'),
('gravida', '16', 'node', '2.83817'),
('gravida', '18', 'node', '1.98493'),
('gravida', '19', 'node', '1'),
('gravida', '20', 'node', '2.87957'),
('gravida', '22', 'node', '0.931053'),
('gravida', '24', 'node', '0.961087'),
('gravida', '26', 'node', '1'),
('gravida', '27', 'node', '1'),
('gravida', '28', 'node', '2.84838'),
('gravida', '29', 'node', '0.949597'),
('gravida', '30', 'node', '1.9347'),
('gravida', '33', 'node', '0.968904'),
('gravida', '36', 'node', '2.8419'),
('gravida', '38', 'node', '1'),
('gravida', '39', 'node', '3'),
('gravida', '40', 'node', '2.92743'),
('gravida', '41', 'node', '0.942091'),
('gravida', '46', 'node', '1'),
('gravida', '47', 'node', '1'),
('gravida', '50', 'node', '0.927431'),
('gravida', '52', 'node', '1'),
('gravida', '53', 'node', '1'),
('gravida', '54', 'node', '1'),
('gravida', '55', 'node', '1'),
('gravida', '56', 'node', '1'),
('gravida', '57', 'node', '1'),
('gravida', '58', 'node', '1'),
('gravida', '65', 'node', '2'),
('gravida', '67', 'node', '4.9347'),
('gravida', '68', 'node', '8.53127'),
('gravida', '69', 'node', '5'),
('gravida', '71', 'node', '1'),
('gravida', '73', 'node', '1'),
('gravida', '76', 'node', '1.95723'),
('gravida', '77', 'node', '1.8894'),
('gravida', '79', 'node', '5.37294'),
('gravida', '82', 'node', '1'),
('gravida', '83', 'node', '1'),
('gravida', '84', 'node', '1'),
('gravida', '85', 'node', '1'),
('gravida', '86', 'node', '1'),
('gravida', '87', 'node', '1'),
('gravida', '88', 'node', '1'),
('gravida', '89', 'node', '1'),
('habitant', '12', 'node', '0.800068'),
('habitant', '14', 'node', '1.59064'),
('habitant', '15', 'node', '2'),
('habitant', '16', 'node', '28.9007'),
('habitant', '17', 'node', '1'),
('habitant', '28', 'node', '1'),
('habitant', '30', 'node', '1'),
('habitant', '37', 'node', '1'),
('habitant', '38', 'node', '1.92645'),
('habitant', '41', 'node', '10.5695'),
('habitant', '77', 'node', '0.889397'),
('habitant', '79', 'node', '1'),
('habitasse', '12', 'node', '1.84234'),
('habitasse', '14', 'node', '2.37614'),
('habitasse', '15', 'node', '0.879565'),
('habitasse', '16', 'node', '0.827757'),
('habitasse', '20', 'node', '0.989021'),
('habitasse', '32', 'node', '2'),
('habitasse', '34', 'node', '0.968904'),
('habitasse', '35', 'node', '2'),
('habitasse', '39', 'node', '1'),
('habitasse', '68', 'node', '1'),
('habitasse', '69', 'node', '1'),
('habitasse', '71', 'node', '1'),
('habitasse', '76', 'node', '0.879565'),
('habitasse', '78', 'node', '1'),
('hac', '12', 'node', '1.84234'),
('hac', '14', 'node', '2.37902'),
('hac', '15', 'node', '0.882818'),
('hac', '16', 'node', '0.830633'),
('hac', '20', 'node', '0.993146'),
('hac', '32', 'node', '2'),
('hac', '34', 'node', '0.972861'),
('hac', '35', 'node', '2'),
('hac', '39', 'node', '1'),
('hac', '68', 'node', '1'),
('hac', '69', 'node', '1'),
('hac', '71', 'node', '1'),
('hac', '76', 'node', '0.882818'),
('hac', '78', 'node', '1'),
('hend', '30', 'node', '26'),
('hendrerit', '12', 'node', '5.40204'),
('hendrerit', '13', 'node', '1.86952'),
('hendrerit', '14', 'node', '4.40346'),
('hendrerit', '15', 'node', '2.72167'),
('hendrerit', '17', 'node', '2'),
('hendrerit', '18', 'node', '1'),
('hendrerit', '20', 'node', '27.9384'),
('hendrerit', '21', 'node', '6.91473'),
('hendrerit', '22', 'node', '3'),
('hendrerit', '23', 'node', '6.91473'),
('hendrerit', '25', 'node', '1'),
('hendrerit', '26', 'node', '0.961087'),
('hendrerit', '27', 'node', '3'),
('hendrerit', '28', 'node', '3'),
('hendrerit', '29', 'node', '2.81576'),
('hendrerit', '30', 'node', '3'),
('hendrerit', '31', 'node', '3'),
('hendrerit', '32', 'node', '2'),
('hendrerit', '33', 'node', '1'),
('hendrerit', '34', 'node', '0.927431'),
('hendrerit', '35', 'node', '2'),
('hendrerit', '36', 'node', '11'),
('hendrerit', '37', 'node', '2.9534'),
('hendrerit', '39', 'node', '0.899454'),
('hendrerit', '41', 'node', '2.78935'),
('hendrerit', '43', 'node', '1'),
('hendrerit', '44', 'node', '1'),
('hendrerit', '45', 'node', '1'),
('hendrerit', '47', 'node', '1'),
('hendrerit', '51', 'node', '2'),
('hendrerit', '52', 'node', '4'),
('hendrerit', '53', 'node', '4'),
('hendrerit', '54', 'node', '4'),
('hendrerit', '55', 'node', '4'),
('hendrerit', '56', 'node', '4'),
('hendrerit', '57', 'node', '4'),
('hendrerit', '58', 'node', '4'),
('hendrerit', '65', 'node', '2.78262'),
('hendrerit', '67', 'node', '1'),
('hendrerit', '68', 'node', '0.902857'),
('hendrerit', '71', 'node', '7.58033'),
('hendrerit', '73', 'node', '4'),
('hendrerit', '76', 'node', '2.91448'),
('hendrerit', '77', 'node', '2.79914'),
('hendrerit', '78', 'node', '2'),
('hendrerit', '79', 'node', '2'),
('hendrerit', '82', 'node', '4'),
('hendrerit', '83', 'node', '4'),
('hendrerit', '84', 'node', '4'),
('hendrerit', '85', 'node', '4'),
('hendrerit', '86', 'node', '4'),
('hendrerit', '87', 'node', '4'),
('hendrerit', '88', 'node', '4'),
('hendrerit', '89', 'node', '4'),
('himenaeos', '12', 'node', '1.75384'),
('himenaeos', '14', 'node', '0.747619'),
('himenaeos', '15', 'node', '0.923838'),
('himenaeos', '16', 'node', '0.792123'),
('himenaeos', '20', 'node', '0.896076'),
('himenaeos', '22', 'node', '0.876337'),
('himenaeos', '24', 'node', '1'),
('himenaeos', '33', 'node', '1'),
('himenaeos', '36', 'node', '11.6229'),
('himenaeos', '41', 'node', '0.797402'),
('himenaeos', '50', 'node', '0.96498'),
('himenaeos', '51', 'node', '1'),
('himenaeos', '65', 'node', '2'),
('himenaeos', '68', 'node', '1'),
('himenaeos', '69', 'node', '1'),
('himenaeos', '73', 'node', '0.920273'),
('himenaeos', '79', 'node', '0.854391'),
('himenaeos', '83', 'node', '0.927431'),
('himenaeos', '84', 'node', '0.927431'),
('himenaeos', '85', 'node', '0.920273'),
('himenaeos', '86', 'node', '0.920273'),
('himenaeos', '87', 'node', '0.923838'),
('himenaeos', '88', 'node', '0.920273'),
('himenaeos', '89', 'node', '0.920273'),
('iaculis', '12', 'node', '2.65371'),
('iaculis', '13', 'node', '28.8477'),
('iaculis', '14', 'node', '3.49017'),
('iaculis', '15', 'node', '2.98217'),
('iaculis', '16', 'node', '2.76482'),
('iaculis', '17', 'node', '0.942091'),
('iaculis', '18', 'node', '1'),
('iaculis', '19', 'node', '1.95723'),
('iaculis', '20', 'node', '1.89272'),
('iaculis', '21', 'node', '3.88792'),
('iaculis', '22', 'node', '2.98902'),
('iaculis', '23', 'node', '3.88792'),
('iaculis', '24', 'node', '1.88282'),
('iaculis', '25', 'node', '2'),
('iaculis', '26', 'node', '2.9534'),
('iaculis', '28', 'node', '1.90974'),
('iaculis', '30', 'node', '1'),
('iaculis', '31', 'node', '2'),
('iaculis', '32', 'node', '3'),
('iaculis', '33', 'node', '29'),
('iaculis', '34', 'node', '2.92743'),
('iaculis', '35', 'node', '3'),
('iaculis', '36', 'node', '0.896076'),
('iaculis', '37', 'node', '0.934703'),
('iaculis', '38', 'node', '1'),
('iaculis', '39', 'node', '0.889397'),
('iaculis', '40', 'node', '2.79415'),
('iaculis', '41', 'node', '1.93485'),
('iaculis', '50', 'node', '1'),
('iaculis', '52', 'node', '3'),
('iaculis', '53', 'node', '3'),
('iaculis', '54', 'node', '3'),
('iaculis', '55', 'node', '3'),
('iaculis', '56', 'node', '3'),
('iaculis', '57', 'node', '3'),
('iaculis', '58', 'node', '3'),
('iaculis', '67', 'node', '2'),
('iaculis', '68', 'node', '1.77889'),
('iaculis', '71', 'node', '2.91323'),
('iaculis', '73', 'node', '3'),
('iaculis', '76', 'node', '2.86055'),
('iaculis', '77', 'node', '2.80171'),
('iaculis', '78', 'node', '3'),
('iaculis', '79', 'node', '8.31825'),
('iaculis', '82', 'node', '3'),
('iaculis', '83', 'node', '3'),
('iaculis', '84', 'node', '3'),
('iaculis', '85', 'node', '3'),
('iaculis', '86', 'node', '3'),
('iaculis', '87', 'node', '29'),
('iaculis', '88', 'node', '3'),
('iaculis', '89', 'node', '3'),
('ideas', '78', 'node', '26'),
('igula', '41', 'node', '3.33412'),
('igula', '65', 'node', '4'),
('igula', '73', 'node', '3.9235'),
('igula', '83', 'node', '3.95608'),
('igula', '84', 'node', '3.95608'),
('igula', '85', 'node', '3.9235'),
('igula', '86', 'node', '3.9235'),
('igula', '87', 'node', '3.93972'),
('igula', '88', 'node', '3.9235'),
('igula', '89', 'node', '3.9235'),
('imperdiet', '12', 'node', '4.53834'),
('imperdiet', '13', 'node', '1'),
('imperdiet', '14', 'node', '4.97343'),
('imperdiet', '15', 'node', '3'),
('imperdiet', '16', 'node', '4.72724'),
('imperdiet', '17', 'node', '1'),
('imperdiet', '18', 'node', '1'),
('imperdiet', '21', 'node', '1'),
('imperdiet', '22', 'node', '0.934703'),
('imperdiet', '23', 'node', '1'),
('imperdiet', '24', 'node', '1'),
('imperdiet', '25', 'node', '1'),
('imperdiet', '26', 'node', '1'),
('imperdiet', '31', 'node', '1.97286'),
('imperdiet', '32', 'node', '2'),
('imperdiet', '33', 'node', '1'),
('imperdiet', '34', 'node', '0.942091'),
('imperdiet', '35', 'node', '2'),
('imperdiet', '36', 'node', '3.84232'),
('imperdiet', '37', 'node', '1.91053'),
('imperdiet', '39', 'node', '1'),
('imperdiet', '40', 'node', '0.953396'),
('imperdiet', '41', 'node', '1.91068'),
('imperdiet', '47', 'node', '1'),
('imperdiet', '50', 'node', '0.913226'),
('imperdiet', '51', 'node', '0.997306'),
('imperdiet', '52', 'node', '1'),
('imperdiet', '53', 'node', '1'),
('imperdiet', '54', 'node', '1'),
('imperdiet', '55', 'node', '1'),
('imperdiet', '56', 'node', '1'),
('imperdiet', '57', 'node', '1'),
('imperdiet', '58', 'node', '1'),
('imperdiet', '65', 'node', '0.879565'),
('imperdiet', '67', 'node', '1.9347'),
('imperdiet', '68', 'node', '0.927431'),
('imperdiet', '69', 'node', '1'),
('imperdiet', '71', 'node', '1'),
('imperdiet', '73', 'node', '1'),
('imperdiet', '77', 'node', '2.77259'),
('imperdiet', '78', 'node', '1'),
('imperdiet', '79', 'node', '2.99315'),
('imperdiet', '82', 'node', '1'),
('imperdiet', '83', 'node', '1'),
('imperdiet', '84', 'node', '1'),
('imperdiet', '85', 'node', '1'),
('imperdiet', '86', 'node', '1'),
('imperdiet', '87', 'node', '1'),
('imperdiet', '88', 'node', '1'),
('imperdiet', '89', 'node', '1'),
('inceptos', '12', 'node', '1.75725'),
('inceptos', '14', 'node', '0.749958'),
('inceptos', '15', 'node', '0.927431'),
('inceptos', '16', 'node', '0.794753'),
('inceptos', '20', 'node', '0.899454'),
('inceptos', '22', 'node', '0.879565'),
('inceptos', '24', 'node', '1'),
('inceptos', '33', 'node', '1'),
('inceptos', '36', 'node', '11.6665'),
('inceptos', '41', 'node', '0.800068'),
('inceptos', '50', 'node', '0.968904'),
('inceptos', '51', 'node', '1'),
('inceptos', '65', 'node', '2'),
('inceptos', '68', 'node', '1'),
('inceptos', '69', 'node', '1'),
('inceptos', '73', 'node', '0.923838'),
('inceptos', '79', 'node', '0.857458'),
('inceptos', '83', 'node', '0.931053'),
('inceptos', '84', 'node', '0.931053'),
('inceptos', '85', 'node', '0.923838'),
('inceptos', '86', 'node', '0.923838'),
('inceptos', '87', 'node', '0.927431'),
('inceptos', '88', 'node', '0.923838'),
('inceptos', '89', 'node', '0.923838'),
('integer', '12', 'node', '3'),
('integer', '13', 'node', '0.976851'),
('integer', '14', 'node', '5.2394'),
('integer', '16', 'node', '1.87313'),
('integer', '17', 'node', '2.92372'),
('integer', '18', 'node', '3'),
('integer', '22', 'node', '1.93105'),
('integer', '24', 'node', '1.88282'),
('integer', '25', 'node', '12.9534'),
('integer', '26', 'node', '12'),
('integer', '27', 'node', '12'),
('integer', '28', 'node', '1'),
('integer', '29', 'node', '0.927431'),
('integer', '30', 'node', '1'),
('integer', '38', 'node', '0.913226'),
('integer', '39', 'node', '0.923838'),
('integer', '41', 'node', '2.72878'),
('integer', '42', 'node', '1'),
('integer', '46', 'node', '1'),
('integer', '51', 'node', '1'),
('integer', '52', 'node', '1'),
('integer', '53', 'node', '1'),
('integer', '54', 'node', '1'),
('integer', '55', 'node', '1'),
('integer', '56', 'node', '1'),
('integer', '57', 'node', '1'),
('integer', '58', 'node', '1'),
('integer', '65', 'node', '1'),
('integer', '68', 'node', '0.938382'),
('integer', '69', 'node', '1'),
('integer', '71', 'node', '0.945829'),
('integer', '73', 'node', '1.98493'),
('integer', '77', 'node', '2.93838'),
('integer', '78', 'node', '1'),
('integer', '79', 'node', '0.902857'),
('integer', '82', 'node', '1'),
('integer', '83', 'node', '1.99315'),
('integer', '84', 'node', '1.99315'),
('integer', '85', 'node', '1.98493'),
('integer', '86', 'node', '1.98493'),
('integer', '87', 'node', '1.98902'),
('integer', '88', 'node', '1.98493'),
('integer', '89', 'node', '1.98493'),
('interdum', '12', 'node', '3.76119'),
('interdum', '13', 'node', '2'),
('interdum', '14', 'node', '3.44536'),
('interdum', '18', 'node', '1.98493'),
('interdum', '19', 'node', '2.98633'),
('interdum', '20', 'node', '5.82491'),
('interdum', '24', 'node', '1'),
('interdum', '25', 'node', '0.949597'),
('interdum', '28', 'node', '1'),
('interdum', '29', 'node', '1'),
('interdum', '30', 'node', '1'),
('interdum', '31', 'node', '1'),
('interdum', '32', 'node', '3'),
('interdum', '33', 'node', '1.99731'),
('interdum', '34', 'node', '1.97685'),
('interdum', '35', 'node', '3'),
('interdum', '36', 'node', '2.67291'),
('interdum', '37', 'node', '1'),
('interdum', '38', 'node', '2.92743'),
('interdum', '39', 'node', '1'),
('interdum', '40', 'node', '1'),
('interdum', '41', 'node', '3.55907'),
('interdum', '47', 'node', '1'),
('interdum', '51', 'node', '3.99315'),
('interdum', '52', 'node', '6'),
('interdum', '53', 'node', '6'),
('interdum', '54', 'node', '6'),
('interdum', '55', 'node', '6'),
('interdum', '56', 'node', '6'),
('interdum', '57', 'node', '6'),
('interdum', '58', 'node', '6'),
('interdum', '65', 'node', '1'),
('interdum', '67', 'node', '1'),
('interdum', '68', 'node', '1.88659'),
('interdum', '69', 'node', '0.923838'),
('interdum', '71', 'node', '7'),
('interdum', '73', 'node', '6.9689'),
('interdum', '76', 'node', '2'),
('interdum', '77', 'node', '4.82273'),
('interdum', '78', 'node', '1'),
('interdum', '79', 'node', '8.39329'),
('interdum', '82', 'node', '6'),
('interdum', '83', 'node', '6.97685'),
('interdum', '84', 'node', '6.97685'),
('interdum', '85', 'node', '6.9689'),
('interdum', '86', 'node', '6.9689'),
('interdum', '87', 'node', '6.97286'),
('interdum', '88', 'node', '6.9689'),
('interdum', '89', 'node', '6.9689'),
('interior', '76', 'node', '26'),
('ipsum', '12', 'node', '51.1963'),
('ipsum', '13', 'node', '3.90974'),
('ipsum', '14', 'node', '51.0885'),
('ipsum', '15', 'node', '1'),
('ipsum', '16', 'node', '4.62918'),
('ipsum', '17', 'node', '5.98902'),
('ipsum', '18', 'node', '1'),
('ipsum', '19', 'node', '1.96109'),
('ipsum', '20', 'node', '1.93838'),
('ipsum', '21', 'node', '31.797'),
('ipsum', '22', 'node', '6.76823'),
('ipsum', '23', 'node', '5.79695'),
('ipsum', '24', 'node', '3.98493'),
('ipsum', '25', 'node', '3.94572'),
('ipsum', '26', 'node', '3.8093'),
('ipsum', '28', 'node', '0.886095'),
('ipsum', '29', 'node', '2'),
('ipsum', '31', 'node', '1.98493'),
('ipsum', '32', 'node', '2'),
('ipsum', '33', 'node', '2'),
('ipsum', '34', 'node', '28'),
('ipsum', '35', 'node', '2'),
('ipsum', '36', 'node', '37.3247'),
('ipsum', '37', 'node', '15.7456'),
('ipsum', '38', 'node', '4.8867'),
('ipsum', '39', 'node', '1'),
('ipsum', '40', 'node', '23.1845'),
('ipsum', '41', 'node', '38.7464'),
('ipsum', '42', 'node', '26'),
('ipsum', '43', 'node', '52'),
('ipsum', '46', 'node', '1'),
('ipsum', '47', 'node', '2'),
('ipsum', '50', 'node', '3'),
('ipsum', '51', 'node', '2'),
('ipsum', '52', 'node', '28'),
('ipsum', '53', 'node', '2'),
('ipsum', '54', 'node', '2'),
('ipsum', '55', 'node', '2'),
('ipsum', '56', 'node', '2'),
('ipsum', '57', 'node', '2'),
('ipsum', '58', 'node', '2'),
('ipsum', '65', 'node', '1.9347'),
('ipsum', '67', 'node', '5.84211'),
('ipsum', '68', 'node', '2.81955'),
('ipsum', '69', 'node', '6'),
('ipsum', '71', 'node', '2.92058'),
('ipsum', '73', 'node', '2.96498'),
('ipsum', '76', 'node', '0.997306'),
('ipsum', '77', 'node', '2.89272'),
('ipsum', '78', 'node', '4.92027'),
('ipsum', '79', 'node', '5.90286'),
('ipsum', '82', 'node', '28'),
('ipsum', '83', 'node', '2.97286'),
('ipsum', '84', 'node', '28.9729'),
('ipsum', '85', 'node', '2.96498'),
('ipsum', '86', 'node', '2.96498'),
('ipsum', '87', 'node', '2.9689'),
('ipsum', '88', 'node', '2.96498'),
('ipsum', '89', 'node', '2.96498'),
('jack', '88', 'node', '26'),
('jacobs', '67', 'node', '26'),
('jessica', '69', 'node', '26'),
('john', '65', 'node', '26'),
('johnson', '71', 'node', '26'),
('justo', '12', 'node', '6.26393'),
('justo', '13', 'node', '3.92114'),
('justo', '14', 'node', '5.78521'),
('justo', '15', 'node', '2'),
('justo', '16', 'node', '3.92384'),
('justo', '17', 'node', '2.90682'),
('justo', '18', 'node', '2'),
('justo', '19', 'node', '2.98087'),
('justo', '20', 'node', '3.93524'),
('justo', '21', 'node', '1.94209'),
('justo', '22', 'node', '1.93105'),
('justo', '23', 'node', '1.94209'),
('justo', '24', 'node', '3.89996'),
('justo', '25', 'node', '0.934703'),
('justo', '26', 'node', '2'),
('justo', '28', 'node', '3.55449'),
('justo', '31', 'node', '1'),
('justo', '32', 'node', '3'),
('justo', '33', 'node', '0.961087'),
('justo', '34', 'node', '2.98493'),
('justo', '35', 'node', '3'),
('justo', '36', 'node', '26.9947'),
('justo', '37', 'node', '1'),
('justo', '38', 'node', '4.79164'),
('justo', '39', 'node', '3.76854'),
('justo', '40', 'node', '4.61387'),
('justo', '41', 'node', '3.83742'),
('justo', '42', 'node', '1'),
('justo', '47', 'node', '2'),
('justo', '50', 'node', '3'),
('justo', '52', 'node', '2'),
('justo', '53', 'node', '2'),
('justo', '54', 'node', '2'),
('justo', '55', 'node', '2'),
('justo', '56', 'node', '2'),
('justo', '57', 'node', '2'),
('justo', '58', 'node', '2'),
('justo', '65', 'node', '5.55227'),
('justo', '67', 'node', '1.9689'),
('justo', '68', 'node', '1.88282'),
('justo', '69', 'node', '0.942091'),
('justo', '71', 'node', '9.9689'),
('justo', '73', 'node', '2'),
('justo', '76', 'node', '1'),
('justo', '77', 'node', '1'),
('justo', '78', 'node', '1'),
('justo', '79', 'node', '2.83938'),
('justo', '82', 'node', '2');
INSERT INTO `search_index` VALUES
('justo', '83', 'node', '2'),
('justo', '84', 'node', '2'),
('justo', '85', 'node', '2'),
('justo', '86', 'node', '2'),
('justo', '87', 'node', '2'),
('justo', '88', 'node', '2'),
('justo', '89', 'node', '2'),
('kronshtain', '73', 'node', '26'),
('lacinia', '12', 'node', '2.77409'),
('lacinia', '13', 'node', '3'),
('lacinia', '14', 'node', '7.17853'),
('lacinia', '15', 'node', '1.86995'),
('lacinia', '16', 'node', '2.84232'),
('lacinia', '18', 'node', '1'),
('lacinia', '19', 'node', '1.95723'),
('lacinia', '20', 'node', '1'),
('lacinia', '21', 'node', '0.949597'),
('lacinia', '22', 'node', '3.70348'),
('lacinia', '23', 'node', '0.949597'),
('lacinia', '24', 'node', '1'),
('lacinia', '28', 'node', '3.73002'),
('lacinia', '29', 'node', '1'),
('lacinia', '30', 'node', '0.989021'),
('lacinia', '31', 'node', '2.98087'),
('lacinia', '32', 'node', '3'),
('lacinia', '33', 'node', '28'),
('lacinia', '34', 'node', '2.92384'),
('lacinia', '35', 'node', '3'),
('lacinia', '37', 'node', '1.89761'),
('lacinia', '38', 'node', '1'),
('lacinia', '40', 'node', '0.938382'),
('lacinia', '41', 'node', '1.87313'),
('lacinia', '45', 'node', '1'),
('lacinia', '47', 'node', '2'),
('lacinia', '50', 'node', '1'),
('lacinia', '51', 'node', '1'),
('lacinia', '65', 'node', '1.90974'),
('lacinia', '67', 'node', '3'),
('lacinia', '68', 'node', '1.81656'),
('lacinia', '71', 'node', '5.57474'),
('lacinia', '76', 'node', '0.886095'),
('lacinia', '77', 'node', '0.972861'),
('lacinia', '78', 'node', '0.927431'),
('lacinia', '79', 'node', '6.23138'),
('lacinia', '87', 'node', '26'),
('lacus', '12', 'node', '3.3663'),
('lacus', '13', 'node', '2.97286'),
('lacus', '14', 'node', '2.51949'),
('lacus', '15', 'node', '2'),
('lacus', '16', 'node', '2.80756'),
('lacus', '17', 'node', '2.92743'),
('lacus', '18', 'node', '2'),
('lacus', '19', 'node', '2'),
('lacus', '20', 'node', '3.69344'),
('lacus', '21', 'node', '2.95779'),
('lacus', '22', 'node', '3.78238'),
('lacus', '23', 'node', '2.95373'),
('lacus', '24', 'node', '2.74386'),
('lacus', '25', 'node', '3'),
('lacus', '26', 'node', '29.9458'),
('lacus', '27', 'node', '3'),
('lacus', '28', 'node', '6.87184'),
('lacus', '29', 'node', '2.78965'),
('lacus', '30', 'node', '5.97818'),
('lacus', '31', 'node', '0.961087'),
('lacus', '32', 'node', '1'),
('lacus', '33', 'node', '1'),
('lacus', '35', 'node', '1'),
('lacus', '36', 'node', '0.931053'),
('lacus', '37', 'node', '3.90974'),
('lacus', '38', 'node', '2.91342'),
('lacus', '39', 'node', '1'),
('lacus', '40', 'node', '3.81912'),
('lacus', '41', 'node', '2.76682'),
('lacus', '42', 'node', '1'),
('lacus', '43', 'node', '1'),
('lacus', '46', 'node', '1'),
('lacus', '47', 'node', '4.99731'),
('lacus', '50', 'node', '1'),
('lacus', '51', 'node', '4'),
('lacus', '65', 'node', '1'),
('lacus', '67', 'node', '5.92743'),
('lacus', '68', 'node', '7.40154'),
('lacus', '69', 'node', '2.87326'),
('lacus', '73', 'node', '0.989021'),
('lacus', '76', 'node', '2.9534'),
('lacus', '77', 'node', '4.89919'),
('lacus', '78', 'node', '2.9347'),
('lacus', '79', 'node', '6.13948'),
('lacus', '83', 'node', '0.997306'),
('lacus', '84', 'node', '0.997306'),
('lacus', '85', 'node', '0.989021'),
('lacus', '86', 'node', '0.989021'),
('lacus', '87', 'node', '0.993146'),
('lacus', '88', 'node', '0.989021'),
('lacus', '89', 'node', '0.989021'),
('laoreet', '12', 'node', '1.69073'),
('laoreet', '13', 'node', '2.93105'),
('laoreet', '14', 'node', '2.57014'),
('laoreet', '15', 'node', '1.78353'),
('laoreet', '18', 'node', '1'),
('laoreet', '19', 'node', '2'),
('laoreet', '20', 'node', '1'),
('laoreet', '21', 'node', '2'),
('laoreet', '22', 'node', '0.869951'),
('laoreet', '23', 'node', '2'),
('laoreet', '25', 'node', '1.99731'),
('laoreet', '26', 'node', '1.90289'),
('laoreet', '27', 'node', '2'),
('laoreet', '28', 'node', '1.80613'),
('laoreet', '29', 'node', '3'),
('laoreet', '31', 'node', '1'),
('laoreet', '32', 'node', '1'),
('laoreet', '34', 'node', '1.92743'),
('laoreet', '35', 'node', '1'),
('laoreet', '36', 'node', '23.6391'),
('laoreet', '37', 'node', '1'),
('laoreet', '38', 'node', '0.953396'),
('laoreet', '39', 'node', '0.913226'),
('laoreet', '40', 'node', '1.9052'),
('laoreet', '41', 'node', '2.72448'),
('laoreet', '42', 'node', '1'),
('laoreet', '46', 'node', '1'),
('laoreet', '47', 'node', '2'),
('laoreet', '50', 'node', '1'),
('laoreet', '51', 'node', '2'),
('laoreet', '52', 'node', '2'),
('laoreet', '53', 'node', '2'),
('laoreet', '54', 'node', '2'),
('laoreet', '55', 'node', '2'),
('laoreet', '56', 'node', '2'),
('laoreet', '57', 'node', '2'),
('laoreet', '58', 'node', '2'),
('laoreet', '65', 'node', '1'),
('laoreet', '68', 'node', '1'),
('laoreet', '69', 'node', '0.989021'),
('laoreet', '73', 'node', '3'),
('laoreet', '76', 'node', '2.8736'),
('laoreet', '77', 'node', '1.82302'),
('laoreet', '78', 'node', '1'),
('laoreet', '79', 'node', '2.68771'),
('laoreet', '82', 'node', '2'),
('laoreet', '83', 'node', '3'),
('laoreet', '84', 'node', '3'),
('laoreet', '85', 'node', '3'),
('laoreet', '86', 'node', '3'),
('laoreet', '87', 'node', '3'),
('laoreet', '88', 'node', '3'),
('laoreet', '89', 'node', '3'),
('lectus', '12', 'node', '4.21348'),
('lectus', '13', 'node', '2.97286'),
('lectus', '14', 'node', '6.45873'),
('lectus', '15', 'node', '2.98087'),
('lectus', '16', 'node', '5.78275'),
('lectus', '17', 'node', '2.92743'),
('lectus', '18', 'node', '1'),
('lectus', '19', 'node', '28.9729'),
('lectus', '20', 'node', '3.91894'),
('lectus', '22', 'node', '2.8468'),
('lectus', '24', 'node', '0.968904'),
('lectus', '25', 'node', '2.98493'),
('lectus', '26', 'node', '3.78339'),
('lectus', '28', 'node', '2'),
('lectus', '30', 'node', '1.99731'),
('lectus', '31', 'node', '2'),
('lectus', '32', 'node', '1'),
('lectus', '33', 'node', '0.972861'),
('lectus', '34', 'node', '1.97685'),
('lectus', '35', 'node', '1'),
('lectus', '36', 'node', '1'),
('lectus', '38', 'node', '1'),
('lectus', '39', 'node', '2.95383'),
('lectus', '40', 'node', '2.79661'),
('lectus', '43', 'node', '27'),
('lectus', '46', 'node', '2'),
('lectus', '47', 'node', '2'),
('lectus', '50', 'node', '2'),
('lectus', '51', 'node', '1'),
('lectus', '52', 'node', '1'),
('lectus', '53', 'node', '1'),
('lectus', '54', 'node', '1'),
('lectus', '55', 'node', '1'),
('lectus', '56', 'node', '1'),
('lectus', '57', 'node', '1'),
('lectus', '58', 'node', '1'),
('lectus', '65', 'node', '2'),
('lectus', '67', 'node', '1.92743'),
('lectus', '68', 'node', '2.98493'),
('lectus', '69', 'node', '3.93105'),
('lectus', '71', 'node', '1.94575'),
('lectus', '73', 'node', '1'),
('lectus', '76', 'node', '1.88282'),
('lectus', '77', 'node', '1.9496'),
('lectus', '78', 'node', '2'),
('lectus', '79', 'node', '4.90974'),
('lectus', '82', 'node', '1'),
('lectus', '83', 'node', '1'),
('lectus', '84', 'node', '1'),
('lectus', '85', 'node', '1'),
('lectus', '86', 'node', '1'),
('lectus', '87', 'node', '1'),
('lectus', '88', 'node', '1'),
('lectus', '89', 'node', '1'),
('leo', '12', 'node', '2.37722'),
('leo', '13', 'node', '3.91894'),
('leo', '14', 'node', '5.22253'),
('leo', '15', 'node', '1'),
('leo', '16', 'node', '4.78545'),
('leo', '17', 'node', '0.989021'),
('leo', '18', 'node', '2.99731'),
('leo', '19', 'node', '2.98493'),
('leo', '20', 'node', '6.65416'),
('leo', '21', 'node', '3.94209'),
('leo', '22', 'node', '1.93105'),
('leo', '23', 'node', '3.94209'),
('leo', '24', 'node', '2.85568'),
('leo', '25', 'node', '2.93105'),
('leo', '26', 'node', '2.94583'),
('leo', '27', 'node', '2'),
('leo', '28', 'node', '4.61038'),
('leo', '29', 'node', '1.9689'),
('leo', '30', 'node', '1.9347'),
('leo', '31', 'node', '2.96188'),
('leo', '32', 'node', '1'),
('leo', '33', 'node', '27'),
('leo', '35', 'node', '1'),
('leo', '36', 'node', '3.48474'),
('leo', '37', 'node', '0.902857'),
('leo', '38', 'node', '1'),
('leo', '39', 'node', '2.91053'),
('leo', '40', 'node', '13.9222'),
('leo', '41', 'node', '1.91323'),
('leo', '44', 'node', '1'),
('leo', '45', 'node', '1'),
('leo', '50', 'node', '1'),
('leo', '51', 'node', '2.97685'),
('leo', '52', 'node', '1'),
('leo', '53', 'node', '1'),
('leo', '54', 'node', '1'),
('leo', '55', 'node', '1'),
('leo', '56', 'node', '1'),
('leo', '57', 'node', '1'),
('leo', '58', 'node', '1'),
('leo', '65', 'node', '11.7834'),
('leo', '67', 'node', '10.9237'),
('leo', '68', 'node', '2'),
('leo', '69', 'node', '2'),
('leo', '71', 'node', '14.7964'),
('leo', '73', 'node', '1'),
('leo', '76', 'node', '5.97685'),
('leo', '77', 'node', '3.8559'),
('leo', '78', 'node', '3.8881'),
('leo', '79', 'node', '4.51602'),
('leo', '82', 'node', '1'),
('leo', '83', 'node', '1'),
('leo', '84', 'node', '1'),
('leo', '85', 'node', '1'),
('leo', '86', 'node', '1'),
('leo', '87', 'node', '1'),
('leo', '88', 'node', '1'),
('leo', '89', 'node', '1'),
('libero', '12', 'node', '2.83645'),
('libero', '13', 'node', '28.1596'),
('libero', '14', 'node', '25.2635'),
('libero', '15', 'node', '1.85746'),
('libero', '16', 'node', '4.66834'),
('libero', '17', 'node', '1'),
('libero', '18', 'node', '1.98493'),
('libero', '21', 'node', '3.98493'),
('libero', '22', 'node', '0.972861'),
('libero', '23', 'node', '3.98087'),
('libero', '24', 'node', '3.91674'),
('libero', '25', 'node', '29.989'),
('libero', '26', 'node', '4.81697'),
('libero', '27', 'node', '2'),
('libero', '28', 'node', '0.896076'),
('libero', '29', 'node', '2.99315'),
('libero', '31', 'node', '4.89201'),
('libero', '32', 'node', '1'),
('libero', '33', 'node', '1'),
('libero', '34', 'node', '0.976851'),
('libero', '35', 'node', '1'),
('libero', '36', 'node', '1.73442'),
('libero', '38', 'node', '2.92384'),
('libero', '39', 'node', '2'),
('libero', '40', 'node', '2.94209'),
('libero', '41', 'node', '3.59606'),
('libero', '42', 'node', '1'),
('libero', '44', 'node', '1'),
('libero', '47', 'node', '2'),
('libero', '50', 'node', '2'),
('libero', '51', 'node', '2'),
('libero', '52', 'node', '2'),
('libero', '53', 'node', '2'),
('libero', '54', 'node', '2'),
('libero', '55', 'node', '2'),
('libero', '56', 'node', '28'),
('libero', '57', 'node', '2'),
('libero', '58', 'node', '2'),
('libero', '65', 'node', '1.96498'),
('libero', '67', 'node', '1.99731'),
('libero', '68', 'node', '2.85285'),
('libero', '69', 'node', '1'),
('libero', '71', 'node', '11'),
('libero', '73', 'node', '2.98493'),
('libero', '76', 'node', '0.949597'),
('libero', '77', 'node', '2.89945'),
('libero', '78', 'node', '2'),
('libero', '79', 'node', '4.82861'),
('libero', '82', 'node', '2'),
('libero', '83', 'node', '2.99315'),
('libero', '84', 'node', '2.99315'),
('libero', '85', 'node', '2.98493'),
('libero', '86', 'node', '2.98493'),
('libero', '87', 'node', '2.98902'),
('libero', '88', 'node', '2.98493'),
('libero', '89', 'node', '2.98493'),
('ligula', '12', 'node', '1.89272'),
('ligula', '14', 'node', '0.786915'),
('ligula', '16', 'node', '2.60876'),
('ligula', '17', 'node', '2'),
('ligula', '18', 'node', '1'),
('ligula', '19', 'node', '32.9236'),
('ligula', '20', 'node', '6.89272'),
('ligula', '21', 'node', '3.94602'),
('ligula', '22', 'node', '1.94209'),
('ligula', '23', 'node', '3.94196'),
('ligula', '24', 'node', '1.89608'),
('ligula', '25', 'node', '4'),
('ligula', '26', 'node', '3.84907'),
('ligula', '28', 'node', '0.889397'),
('ligula', '29', 'node', '3'),
('ligula', '31', 'node', '1'),
('ligula', '32', 'node', '2'),
('ligula', '33', 'node', '1'),
('ligula', '34', 'node', '2'),
('ligula', '35', 'node', '2'),
('ligula', '36', 'node', '2.78003'),
('ligula', '37', 'node', '1.96498'),
('ligula', '39', 'node', '1'),
('ligula', '40', 'node', '1.91674'),
('ligula', '41', 'node', '4.02434'),
('ligula', '44', 'node', '26'),
('ligula', '47', 'node', '3'),
('ligula', '51', 'node', '4'),
('ligula', '52', 'node', '2'),
('ligula', '53', 'node', '2'),
('ligula', '54', 'node', '2'),
('ligula', '55', 'node', '2'),
('ligula', '56', 'node', '2'),
('ligula', '57', 'node', '2'),
('ligula', '58', 'node', '2'),
('ligula', '65', 'node', '5.96498'),
('ligula', '67', 'node', '15.9689'),
('ligula', '68', 'node', '19.0106'),
('ligula', '69', 'node', '3'),
('ligula', '71', 'node', '5.90289'),
('ligula', '73', 'node', '6.65021'),
('ligula', '76', 'node', '2'),
('ligula', '77', 'node', '3.87396'),
('ligula', '78', 'node', '0.953396'),
('ligula', '79', 'node', '2.68278'),
('ligula', '82', 'node', '2'),
('ligula', '83', 'node', '6.68109'),
('ligula', '84', 'node', '6.68109'),
('ligula', '85', 'node', '6.65021'),
('ligula', '86', 'node', '6.65021'),
('ligula', '87', 'node', '6.66694'),
('ligula', '88', 'node', '6.65021'),
('ligula', '89', 'node', '6.65021'),
('lisa', '89', 'node', '26'),
('litora', '12', 'node', '1.77466'),
('litora', '14', 'node', '0.76188'),
('litora', '15', 'node', '0.945829'),
('litora', '16', 'node', '0.808176'),
('litora', '20', 'node', '0.916736'),
('litora', '22', 'node', '0.896076'),
('litora', '24', 'node', '1'),
('litora', '33', 'node', '1'),
('litora', '36', 'node', '1.95813'),
('litora', '41', 'node', '0.813674'),
('litora', '50', 'node', '0.989021'),
('litora', '51', 'node', '1'),
('litora', '65', 'node', '2'),
('litora', '68', 'node', '1'),
('litora', '69', 'node', '1'),
('litora', '73', 'node', '0.942091'),
('litora', '79', 'node', '0.873132'),
('litora', '83', 'node', '0.949597'),
('litora', '84', 'node', '0.949597'),
('litora', '85', 'node', '0.942091'),
('litora', '86', 'node', '0.942091'),
('litora', '87', 'node', '0.945829'),
('litora', '88', 'node', '0.942091'),
('litora', '89', 'node', '0.942091'),
('lobortis', '12', 'node', '3.35016'),
('lobortis', '13', 'node', '2'),
('lobortis', '14', 'node', '3.71904'),
('lobortis', '15', 'node', '1.86679'),
('lobortis', '16', 'node', '4.54533'),
('lobortis', '18', 'node', '1'),
('lobortis', '19', 'node', '1'),
('lobortis', '21', 'node', '11'),
('lobortis', '22', 'node', '12.7974'),
('lobortis', '23', 'node', '11'),
('lobortis', '24', 'node', '13.7789'),
('lobortis', '25', 'node', '3'),
('lobortis', '26', 'node', '2.92384'),
('lobortis', '27', 'node', '1'),
('lobortis', '28', 'node', '1'),
('lobortis', '29', 'node', '0.931053'),
('lobortis', '30', 'node', '1'),
('lobortis', '31', 'node', '0.98493'),
('lobortis', '34', 'node', '1'),
('lobortis', '36', 'node', '1'),
('lobortis', '37', 'node', '1'),
('lobortis', '38', 'node', '0.909743'),
('lobortis', '40', 'node', '3'),
('lobortis', '41', 'node', '2.53548'),
('lobortis', '47', 'node', '3'),
('lobortis', '50', 'node', '0.961087'),
('lobortis', '51', 'node', '1'),
('lobortis', '52', 'node', '1'),
('lobortis', '53', 'node', '1'),
('lobortis', '54', 'node', '1'),
('lobortis', '55', 'node', '1'),
('lobortis', '56', 'node', '1'),
('lobortis', '57', 'node', '1'),
('lobortis', '58', 'node', '1'),
('lobortis', '65', 'node', '2'),
('lobortis', '73', 'node', '2.92221'),
('lobortis', '76', 'node', '1.89272'),
('lobortis', '77', 'node', '1'),
('lobortis', '78', 'node', '0.997306'),
('lobortis', '82', 'node', '1'),
('lobortis', '83', 'node', '2.93784'),
('lobortis', '84', 'node', '2.93784'),
('lobortis', '85', 'node', '2.92221'),
('lobortis', '86', 'node', '2.92221'),
('lobortis', '87', 'node', '2.92999'),
('lobortis', '88', 'node', '2.92221'),
('lobortis', '89', 'node', '2.92221'),
('location', '81', 'node', '26'),
('log', '12', 'node', '5.26102'),
('log', '13', 'node', '2.00143'),
('log', '14', 'node', '8.52055'),
('lorem', '12', 'node', '54.937'),
('lorem', '13', 'node', '1.91323'),
('lorem', '14', 'node', '27.8489'),
('lorem', '15', 'node', '0.920273'),
('lorem', '16', 'node', '3.37797'),
('lorem', '17', 'node', '1'),
('lorem', '19', 'node', '0.961087'),
('lorem', '20', 'node', '2.90707'),
('lorem', '21', 'node', '29.9274'),
('lorem', '22', 'node', '2'),
('lorem', '23', 'node', '3.92743'),
('lorem', '24', 'node', '1.89608'),
('lorem', '25', 'node', '4.97017'),
('lorem', '26', 'node', '3.83242'),
('lorem', '28', 'node', '1'),
('lorem', '29', 'node', '2'),
('lorem', '30', 'node', '0.997306'),
('lorem', '32', 'node', '1'),
('lorem', '33', 'node', '1'),
('lorem', '34', 'node', '28'),
('lorem', '35', 'node', '1'),
('lorem', '36', 'node', '38.516'),
('lorem', '37', 'node', '16.6407'),
('lorem', '38', 'node', '5.66231'),
('lorem', '39', 'node', '1'),
('lorem', '40', 'node', '22.1107'),
('lorem', '41', 'node', '34.0193'),
('lorem', '42', 'node', '26'),
('lorem', '45', 'node', '1'),
('lorem', '47', 'node', '3'),
('lorem', '50', 'node', '1.90974'),
('lorem', '52', 'node', '27'),
('lorem', '53', 'node', '1'),
('lorem', '54', 'node', '1'),
('lorem', '55', 'node', '1'),
('lorem', '56', 'node', '1'),
('lorem', '57', 'node', '1'),
('lorem', '58', 'node', '1'),
('lorem', '65', 'node', '1'),
('lorem', '67', 'node', '5.92743'),
('lorem', '68', 'node', '1.94274'),
('lorem', '69', 'node', '5.93105'),
('lorem', '71', 'node', '0.993146'),
('lorem', '73', 'node', '1'),
('lorem', '76', 'node', '15.3037'),
('lorem', '77', 'node', '2.89272'),
('lorem', '78', 'node', '4'),
('lorem', '79', 'node', '6.86498'),
('lorem', '82', 'node', '27'),
('lorem', '83', 'node', '1'),
('lorem', '84', 'node', '27'),
('lorem', '85', 'node', '1'),
('lorem', '86', 'node', '1'),
('lorem', '87', 'node', '1'),
('lorem', '88', 'node', '1'),
('lorem', '89', 'node', '1'),
('luctus', '12', 'node', '6.25403'),
('luctus', '13', 'node', '1.9347'),
('luctus', '14', 'node', '4.47582'),
('luctus', '15', 'node', '1.82636'),
('luctus', '16', 'node', '1.89272'),
('luctus', '17', 'node', '2.9496'),
('luctus', '18', 'node', '1'),
('luctus', '19', 'node', '0.989021'),
('luctus', '20', 'node', '1.96109'),
('luctus', '21', 'node', '1.86581'),
('luctus', '22', 'node', '3.9347'),
('luctus', '23', 'node', '1.86581'),
('luctus', '24', 'node', '1.89608'),
('luctus', '25', 'node', '1'),
('luctus', '26', 'node', '1'),
('luctus', '27', 'node', '5'),
('luctus', '28', 'node', '8.93047'),
('luctus', '29', 'node', '6.74153'),
('luctus', '30', 'node', '8.91495'),
('luctus', '31', 'node', '3'),
('luctus', '32', 'node', '1.96989'),
('luctus', '33', 'node', '4'),
('luctus', '34', 'node', '1'),
('luctus', '35', 'node', '1.97808'),
('luctus', '36', 'node', '1'),
('luctus', '37', 'node', '3.9347'),
('luctus', '38', 'node', '1'),
('luctus', '40', 'node', '0.909743'),
('luctus', '41', 'node', '2.92384'),
('luctus', '45', 'node', '1'),
('luctus', '47', 'node', '3'),
('luctus', '50', 'node', '1'),
('luctus', '65', 'node', '1.86593'),
('luctus', '67', 'node', '3.95608'),
('luctus', '71', 'node', '1.99315'),
('luctus', '76', 'node', '1'),
('luctus', '77', 'node', '2.78545'),
('luctus', '78', 'node', '0.949597'),
('maecenas', '12', 'node', '0.968904'),
('maecenas', '14', 'node', '5.12549'),
('maecenas', '15', 'node', '1'),
('maecenas', '16', 'node', '0.957226'),
('maecenas', '19', 'node', '1'),
('maecenas', '20', 'node', '1'),
('maecenas', '21', 'node', '1'),
('maecenas', '23', 'node', '1'),
('maecenas', '24', 'node', '3.76889'),
('maecenas', '25', 'node', '1.93838'),
('maecenas', '26', 'node', '4'),
('maecenas', '31', 'node', '0.96498'),
('maecenas', '32', 'node', '1'),
('maecenas', '33', 'node', '1'),
('maecenas', '34', 'node', '0.980874'),
('maecenas', '35', 'node', '12'),
('maecenas', '36', 'node', '2'),
('maecenas', '37', 'node', '0.906287'),
('maecenas', '38', 'node', '1'),
('maecenas', '39', 'node', '0.972861'),
('maecenas', '40', 'node', '0.892724'),
('maecenas', '41', 'node', '3.60093'),
('maecenas', '47', 'node', '2'),
('maecenas', '51', 'node', '1'),
('maecenas', '52', 'node', '2'),
('maecenas', '53', 'node', '13'),
('maecenas', '54', 'node', '2'),
('maecenas', '55', 'node', '2'),
('maecenas', '56', 'node', '2'),
('maecenas', '57', 'node', '2'),
('maecenas', '58', 'node', '2'),
('maecenas', '65', 'node', '2.88282'),
('maecenas', '67', 'node', '8.81089'),
('maecenas', '68', 'node', '2.69249'),
('maecenas', '71', 'node', '2'),
('maecenas', '73', 'node', '3.99461'),
('maecenas', '76', 'node', '2'),
('maecenas', '77', 'node', '12.9809'),
('maecenas', '78', 'node', '12'),
('maecenas', '79', 'node', '2.69369'),
('maecenas', '82', 'node', '2'),
('maecenas', '83', 'node', '4'),
('maecenas', '84', 'node', '4'),
('maecenas', '85', 'node', '3.99461'),
('maecenas', '86', 'node', '3.99461'),
('maecenas', '87', 'node', '4'),
('maecenas', '88', 'node', '3.99461'),
('maecenas', '89', 'node', '3.99461'),
('magna', '12', 'node', '2.81224'),
('magna', '14', 'node', '33.9195'),
('magna', '15', 'node', '0.869951'),
('magna', '16', 'node', '1'),
('magna', '17', 'node', '2.9347'),
('magna', '18', 'node', '1'),
('magna', '19', 'node', '1.9534'),
('magna', '20', 'node', '1'),
('magna', '21', 'node', '3.84768'),
('magna', '22', 'node', '2.92027'),
('magna', '23', 'node', '3.84768'),
('magna', '24', 'node', '1'),
('magna', '25', 'node', '1'),
('magna', '26', 'node', '0.934703'),
('magna', '27', 'node', '2'),
('magna', '28', 'node', '1.88282'),
('magna', '29', 'node', '1.9689'),
('magna', '30', 'node', '1'),
('magna', '31', 'node', '4.89938'),
('magna', '32', 'node', '4'),
('magna', '33', 'node', '2'),
('magna', '34', 'node', '4'),
('magna', '35', 'node', '4'),
('magna', '36', 'node', '2.61805'),
('magna', '37', 'node', '1.92384'),
('magna', '38', 'node', '6.67146'),
('magna', '39', 'node', '1'),
('magna', '40', 'node', '1.85439'),
('magna', '41', 'node', '3.69803'),
('magna', '42', 'node', '1'),
('magna', '43', 'node', '26'),
('magna', '44', 'node', '1'),
('magna', '45', 'node', '1'),
('magna', '47', 'node', '1'),
('magna', '50', 'node', '3.86581'),
('magna', '51', 'node', '1'),
('magna', '52', 'node', '8'),
('magna', '53', 'node', '8'),
('magna', '54', 'node', '8'),
('magna', '55', 'node', '8'),
('magna', '56', 'node', '8'),
('magna', '57', 'node', '8'),
('magna', '58', 'node', '8'),
('magna', '65', 'node', '2.88012'),
('magna', '67', 'node', '1.94583'),
('magna', '68', 'node', '1.90629'),
('magna', '69', 'node', '0.96498'),
('magna', '71', 'node', '7.48842'),
('magna', '73', 'node', '8.95723'),
('magna', '76', 'node', '8.52192'),
('magna', '77', 'node', '3.67833'),
('magna', '79', 'node', '4.57484'),
('magna', '82', 'node', '8'),
('magna', '83', 'node', '8.96498'),
('magna', '84', 'node', '8.96498'),
('magna', '85', 'node', '8.95723'),
('magna', '86', 'node', '8.95723'),
('magna', '87', 'node', '8.96109'),
('magna', '88', 'node', '8.95723'),
('magna', '89', 'node', '8.95723'),
('magnis', '14', 'node', '0.876337'),
('magnis', '16', 'node', '0.854391'),
('magnis', '22', 'node', '0.854391'),
('magnis', '34', 'node', '1'),
('magnis', '39', 'node', '0.953396'),
('magnis', '40', 'node', '1'),
('magnis', '50', 'node', '1'),
('magnis', '76', 'node', '0.927431'),
('malesuada', '12', 'node', '2.48769'),
('malesuada', '13', 'node', '2'),
('malesuada', '14', 'node', '5.18652'),
('malesuada', '15', 'node', '4'),
('malesuada', '16', 'node', '5.70053'),
('malesuada', '17', 'node', '2'),
('malesuada', '18', 'node', '1'),
('malesuada', '19', 'node', '2.97416'),
('malesuada', '20', 'node', '2'),
('malesuada', '21', 'node', '2'),
('malesuada', '22', 'node', '0.997306'),
('malesuada', '23', 'node', '2'),
('malesuada', '25', 'node', '3.94585'),
('malesuada', '26', 'node', '2.78509'),
('malesuada', '27', 'node', '1'),
('malesuada', '28', 'node', '1'),
('malesuada', '29', 'node', '1'),
('malesuada', '30', 'node', '1'),
('malesuada', '32', 'node', '1'),
('malesuada', '34', 'node', '1'),
('malesuada', '35', 'node', '1'),
('malesuada', '36', 'node', '1'),
('malesuada', '37', 'node', '2'),
('malesuada', '38', 'node', '15.2884'),
('malesuada', '39', 'node', '10.6166'),
('malesuada', '40', 'node', '10.1053'),
('malesuada', '41', 'node', '3.66428'),
('malesuada', '43', 'node', '2'),
('malesuada', '47', 'node', '2'),
('malesuada', '50', 'node', '0.931053'),
('malesuada', '51', 'node', '4'),
('malesuada', '52', 'node', '6'),
('malesuada', '53', 'node', '6'),
('malesuada', '54', 'node', '6'),
('malesuada', '55', 'node', '6'),
('malesuada', '56', 'node', '6'),
('malesuada', '57', 'node', '6'),
('malesuada', '58', 'node', '6'),
('malesuada', '65', 'node', '4.76625'),
('malesuada', '68', 'node', '1'),
('malesuada', '69', 'node', '9'),
('malesuada', '71', 'node', '2'),
('malesuada', '73', 'node', '7.94602'),
('malesuada', '76', 'node', '3.88282'),
('malesuada', '77', 'node', '3.87957'),
('malesuada', '78', 'node', '0.934703'),
('malesuada', '79', 'node', '1'),
('malesuada', '82', 'node', '6'),
('malesuada', '83', 'node', '7.96205'),
('malesuada', '84', 'node', '7.96205'),
('malesuada', '85', 'node', '7.94602'),
('malesuada', '86', 'node', '7.94602'),
('malesuada', '87', 'node', '7.954'),
('malesuada', '88', 'node', '7.94602'),
('malesuada', '89', 'node', '7.94602'),
('manager', '67', 'node', '0.927431'),
('massa', '12', 'node', '3.281'),
('massa', '13', 'node', '2.98902'),
('massa', '14', 'node', '5.34743'),
('massa', '15', 'node', '5.79022'),
('massa', '16', 'node', '6.64395'),
('massa', '17', 'node', '1.88792'),
('massa', '18', 'node', '3.9689'),
('massa', '19', 'node', '28'),
('massa', '20', 'node', '4.72097'),
('massa', '21', 'node', '6.83049'),
('massa', '22', 'node', '30.9097'),
('massa', '23', 'node', '32.8264'),
('massa', '24', 'node', '0.902857'),
('massa', '25', 'node', '4.93105'),
('massa', '26', 'node', '3.8453'),
('massa', '28', 'node', '3.70888'),
('massa', '30', 'node', '1'),
('massa', '31', 'node', '4.84595'),
('massa', '32', 'node', '2'),
('massa', '33', 'node', '1.9689'),
('massa', '34', 'node', '3'),
('massa', '35', 'node', '2'),
('massa', '36', 'node', '1.79893'),
('massa', '37', 'node', '1'),
('massa', '38', 'node', '2.94209'),
('massa', '39', 'node', '2.99731'),
('massa', '40', 'node', '0.869951'),
('massa', '41', 'node', '3.69224'),
('massa', '44', 'node', '1'),
('massa', '47', 'node', '3'),
('massa', '50', 'node', '2.95723'),
('massa', '51', 'node', '1.99731'),
('massa', '52', 'node', '2'),
('massa', '53', 'node', '2'),
('massa', '54', 'node', '2'),
('massa', '55', 'node', '2'),
('massa', '56', 'node', '2'),
('massa', '57', 'node', '2'),
('massa', '58', 'node', '2'),
('massa', '65', 'node', '1'),
('massa', '67', 'node', '16'),
('massa', '68', 'node', '5.9347'),
('massa', '69', 'node', '5'),
('massa', '73', 'node', '2'),
('massa', '76', 'node', '0.889397'),
('massa', '77', 'node', '1.89945'),
('massa', '78', 'node', '1'),
('massa', '79', 'node', '2.80422'),
('massa', '82', 'node', '2'),
('massa', '83', 'node', '2'),
('massa', '84', 'node', '2'),
('massa', '85', 'node', '2'),
('massa', '86', 'node', '2'),
('massa', '87', 'node', '2'),
('massa', '88', 'node', '2'),
('massa', '89', 'node', '2'),
('mattis', '12', 'node', '2.43483'),
('mattis', '14', 'node', '0.902857'),
('mattis', '15', 'node', '3.86366'),
('mattis', '16', 'node', '2.84055'),
('mattis', '17', 'node', '1'),
('mattis', '19', 'node', '2'),
('mattis', '20', 'node', '2.8861'),
('mattis', '21', 'node', '5.82413'),
('mattis', '22', 'node', '3.93105'),
('mattis', '23', 'node', '5.82413'),
('mattis', '24', 'node', '0.896076'),
('mattis', '25', 'node', '2.92384'),
('mattis', '26', 'node', '1.9496'),
('mattis', '27', 'node', '2'),
('mattis', '28', 'node', '2.94583'),
('mattis', '29', 'node', '1.89932'),
('mattis', '30', 'node', '2.93838'),
('mattis', '31', 'node', '1'),
('mattis', '32', 'node', '2.98087'),
('mattis', '33', 'node', '1.99315'),
('mattis', '34', 'node', '1'),
('mattis', '35', 'node', '2.98493'),
('mattis', '36', 'node', '3'),
('mattis', '39', 'node', '2'),
('mattis', '40', 'node', '1.85746'),
('mattis', '41', 'node', '5.8249'),
('mattis', '46', 'node', '1'),
('mattis', '47', 'node', '4'),
('mattis', '65', 'node', '1.91323'),
('mattis', '67', 'node', '12.8808'),
('mattis', '68', 'node', '10.0455'),
('mattis', '69', 'node', '4'),
('mattis', '71', 'node', '1.91323'),
('mattis', '73', 'node', '0.961087'),
('mattis', '76', 'node', '2.97'),
('mattis', '77', 'node', '1.93838'),
('mattis', '78', 'node', '0.945829'),
('mattis', '79', 'node', '3.83938'),
('mattis', '83', 'node', '0.968904'),
('mattis', '84', 'node', '0.968904'),
('mattis', '85', 'node', '0.961087'),
('mattis', '86', 'node', '0.961087'),
('mattis', '87', 'node', '0.96498'),
('mattis', '88', 'node', '0.961087'),
('mattis', '89', 'node', '0.961087'),
('mauris', '12', 'node', '3.60203'),
('mauris', '13', 'node', '4.97685'),
('mauris', '14', 'node', '38.3308'),
('mauris', '15', 'node', '2.86366'),
('mauris', '16', 'node', '6.46447'),
('mauris', '17', 'node', '1'),
('mauris', '18', 'node', '5.9658'),
('mauris', '19', 'node', '6.93893'),
('mauris', '20', 'node', '6.72091'),
('mauris', '21', 'node', '15.8345'),
('mauris', '22', 'node', '15.9203'),
('mauris', '23', 'node', '15.8345'),
('mauris', '24', 'node', '43.7676'),
('mauris', '25', 'node', '3'),
('mauris', '26', 'node', '4.93838'),
('mauris', '27', 'node', '3'),
('mauris', '28', 'node', '1.88282'),
('mauris', '29', 'node', '2.93153'),
('mauris', '30', 'node', '1'),
('mauris', '31', 'node', '2'),
('mauris', '32', 'node', '3'),
('mauris', '33', 'node', '4.94216'),
('mauris', '34', 'node', '1'),
('mauris', '35', 'node', '3'),
('mauris', '36', 'node', '2.59681'),
('mauris', '37', 'node', '3.84445'),
('mauris', '38', 'node', '6.74377'),
('mauris', '39', 'node', '3'),
('mauris', '40', 'node', '1.84648'),
('mauris', '41', 'node', '18.2811'),
('mauris', '42', 'node', '1'),
('mauris', '47', 'node', '1'),
('mauris', '50', 'node', '2'),
('mauris', '52', 'node', '6'),
('mauris', '53', 'node', '6'),
('mauris', '54', 'node', '6'),
('mauris', '55', 'node', '6'),
('mauris', '56', 'node', '6'),
('mauris', '57', 'node', '6'),
('mauris', '58', 'node', '6'),
('mauris', '65', 'node', '23.5569'),
('mauris', '67', 'node', '2.9534'),
('mauris', '68', 'node', '2.80353'),
('mauris', '69', 'node', '1'),
('mauris', '71', 'node', '5.82645'),
('mauris', '73', 'node', '22.6179'),
('mauris', '76', 'node', '2.9496'),
('mauris', '77', 'node', '2.89241'),
('mauris', '78', 'node', '3.92027'),
('mauris', '79', 'node', '8.28367'),
('mauris', '82', 'node', '6'),
('mauris', '83', 'node', '22.7392'),
('mauris', '84', 'node', '22.7392'),
('mauris', '85', 'node', '22.6179'),
('mauris', '86', 'node', '22.6179'),
('mauris', '87', 'node', '22.6783'),
('mauris', '88', 'node', '22.6179'),
('mauris', '89', 'node', '22.6179'),
('metho', '88', 'node', '0.906287'),
('metho', '89', 'node', '0.906287'),
('metu', '26', 'node', '26'),
('metus', '12', 'node', '3.45187'),
('metus', '13', 'node', '1'),
('metus', '14', 'node', '5.92463'),
('metus', '15', 'node', '1.74379'),
('metus', '16', 'node', '1'),
('metus', '17', 'node', '2.85486'),
('metus', '18', 'node', '4'),
('metus', '19', 'node', '1'),
('metus', '20', 'node', '2.70775'),
('metus', '21', 'node', '2.96498'),
('metus', '22', 'node', '3.87326'),
('metus', '23', 'node', '2.96498'),
('metus', '24', 'node', '0.916736'),
('metus', '25', 'node', '13'),
('metus', '26', 'node', '12.9809'),
('metus', '27', 'node', '13'),
('metus', '28', 'node', '0.989021'),
('metus', '29', 'node', '3.98902'),
('metus', '30', 'node', '0.980874'),
('metus', '31', 'node', '30.9263'),
('metus', '32', 'node', '28'),
('metus', '33', 'node', '2'),
('metus', '35', 'node', '2'),
('metus', '36', 'node', '1.72336'),
('metus', '37', 'node', '3.81731'),
('metus', '38', 'node', '1'),
('metus', '39', 'node', '1.98493'),
('metus', '40', 'node', '1'),
('metus', '41', 'node', '1.67322'),
('metus', '44', 'node', '1'),
('metus', '47', 'node', '1'),
('metus', '51', 'node', '1'),
('metus', '52', 'node', '6'),
('metus', '53', 'node', '6'),
('metus', '54', 'node', '6'),
('metus', '55', 'node', '6'),
('metus', '56', 'node', '6'),
('metus', '57', 'node', '6'),
('metus', '58', 'node', '6'),
('metus', '65', 'node', '3'),
('metus', '67', 'node', '2'),
('metus', '68', 'node', '0.886095'),
('metus', '69', 'node', '16'),
('metus', '71', 'node', '12.3639'),
('metus', '73', 'node', '7.95453'),
('metus', '76', 'node', '1.86995'),
('metus', '77', 'node', '1.98087'),
('metus', '78', 'node', '2.87676'),
('metus', '79', 'node', '3.92246'),
('metus', '82', 'node', '6'),
('metus', '83', 'node', '7.96498'),
('metus', '84', 'node', '7.96498'),
('metus', '85', 'node', '7.95453'),
('metus', '86', 'node', '7.95453'),
('metus', '87', 'node', '7.96109'),
('metus', '88', 'node', '7.95453'),
('metus', '89', 'node', '7.95453'),
('minima', '54', 'node', '26'),
('minima', '85', 'node', '26'),
('molestie', '12', 'node', '2.58453'),
('molestie', '13', 'node', '1'),
('molestie', '14', 'node', '1.59344'),
('molestie', '15', 'node', '2'),
('molestie', '16', 'node', '2.79697'),
('molestie', '17', 'node', '0.98493'),
('molestie', '18', 'node', '1'),
('molestie', '19', 'node', '3'),
('molestie', '20', 'node', '5.7959'),
('molestie', '21', 'node', '1'),
('molestie', '22', 'node', '1.93105'),
('molestie', '23', 'node', '1'),
('molestie', '24', 'node', '3.76101'),
('molestie', '25', 'node', '1'),
('molestie', '26', 'node', '3'),
('molestie', '28', 'node', '0.927431'),
('molestie', '29', 'node', '1'),
('molestie', '31', 'node', '1.96498'),
('molestie', '32', 'node', '2'),
('molestie', '33', 'node', '1'),
('molestie', '34', 'node', '2'),
('molestie', '35', 'node', '2'),
('molestie', '36', 'node', '0.882818'),
('molestie', '37', 'node', '0.989021'),
('molestie', '38', 'node', '4.78212'),
('molestie', '39', 'node', '3.92384'),
('molestie', '40', 'node', '1.77466'),
('molestie', '41', 'node', '1'),
('molestie', '45', 'node', '2'),
('molestie', '46', 'node', '1'),
('molestie', '47', 'node', '3'),
('molestie', '50', 'node', '3.90974'),
('molestie', '51', 'node', '1'),
('molestie', '52', 'node', '2'),
('molestie', '53', 'node', '2'),
('molestie', '54', 'node', '2'),
('molestie', '55', 'node', '2'),
('molestie', '56', 'node', '2'),
('molestie', '57', 'node', '2'),
('molestie', '58', 'node', '2'),
('molestie', '65', 'node', '3.54438'),
('molestie', '67', 'node', '14.8792'),
('molestie', '68', 'node', '7.44686'),
('molestie', '69', 'node', '3'),
('molestie', '71', 'node', '5'),
('molestie', '73', 'node', '2'),
('molestie', '76', 'node', '0.953396'),
('molestie', '77', 'node', '1'),
('molestie', '78', 'node', '1'),
('molestie', '79', 'node', '5.54064'),
('molestie', '82', 'node', '2'),
('molestie', '83', 'node', '2'),
('molestie', '84', 'node', '2'),
('molestie', '85', 'node', '2'),
('molestie', '86', 'node', '2'),
('molestie', '87', 'node', '2'),
('molestie', '88', 'node', '2'),
('molestie', '89', 'node', '2'),
('mollis', '12', 'node', '3.6887'),
('mollis', '14', 'node', '4.52055'),
('mollis', '15', 'node', '3.89313'),
('mollis', '16', 'node', '3.85127'),
('mollis', '17', 'node', '1.89968'),
('mollis', '18', 'node', '2'),
('mollis', '19', 'node', '1'),
('mollis', '20', 'node', '1.94209'),
('mollis', '21', 'node', '3'),
('mollis', '23', 'node', '3'),
('mollis', '24', 'node', '1.90286'),
('mollis', '25', 'node', '1'),
('mollis', '26', 'node', '1'),
('mollis', '28', 'node', '3.62001'),
('mollis', '29', 'node', '2'),
('mollis', '30', 'node', '0.957226'),
('mollis', '31', 'node', '0.989021'),
('mollis', '33', 'node', '1.99315'),
('mollis', '36', 'node', '3'),
('mollis', '38', 'node', '1.9534'),
('mollis', '40', 'node', '3.71512'),
('mollis', '41', 'node', '1.81795'),
('mollis', '43', 'node', '26'),
('mollis', '47', 'node', '2'),
('mollis', '50', 'node', '0.934703'),
('mollis', '51', 'node', '2'),
('mollis', '65', 'node', '1.90637'),
('mollis', '67', 'node', '3.9083'),
('mollis', '68', 'node', '11.8894'),
('mollis', '69', 'node', '11'),
('mollis', '71', 'node', '1.94209'),
('mollis', '76', 'node', '1'),
('mollis', '77', 'node', '2.98087'),
('mollis', '78', 'node', '1.9496'),
('mollis', '79', 'node', '1'),
('montes', '14', 'node', '0.866793'),
('montes', '16', 'node', '0.845322'),
('montes', '22', 'node', '0.845322'),
('montes', '34', 'node', '1'),
('montes', '39', 'node', '0.942091'),
('montes', '40', 'node', '1'),
('montes', '50', 'node', '1'),
('montes', '76', 'node', '0.916736'),
('morbi', '12', 'node', '3.14536'),
('morbi', '13', 'node', '1'),
('morbi', '14', 'node', '6.05937'),
('morbi', '15', 'node', '3'),
('morbi', '16', 'node', '29.8618'),
('morbi', '17', 'node', '2'),
('morbi', '19', 'node', '1'),
('morbi', '20', 'node', '0.968904'),
('morbi', '22', 'node', '0.968904'),
('morbi', '24', 'node', '2.91674'),
('morbi', '25', 'node', '2'),
('morbi', '26', 'node', '2.87782'),
('morbi', '27', 'node', '1'),
('morbi', '28', 'node', '3'),
('morbi', '29', 'node', '0.96498'),
('morbi', '30', 'node', '3'),
('morbi', '31', 'node', '1'),
('morbi', '32', 'node', '1'),
('morbi', '33', 'node', '2'),
('morbi', '35', 'node', '1'),
('morbi', '36', 'node', '4.68146'),
('morbi', '37', 'node', '3'),
('morbi', '38', 'node', '2.83919'),
('morbi', '39', 'node', '0.927431'),
('morbi', '40', 'node', '2'),
('morbi', '41', 'node', '11.3642'),
('morbi', '65', 'node', '1'),
('morbi', '73', 'node', '0.916736'),
('morbi', '76', 'node', '0.899454'),
('morbi', '77', 'node', '2.73037'),
('morbi', '78', 'node', '0.961087'),
('morbi', '79', 'node', '1.83938'),
('morbi', '83', 'node', '0.923838'),
('morbi', '84', 'node', '0.923838'),
('morbi', '85', 'node', '0.916736'),
('morbi', '86', 'node', '0.916736'),
('morbi', '87', 'node', '0.920273'),
('morbi', '88', 'node', '0.916736'),
('morbi', '89', 'node', '0.916736'),
('mus', '14', 'node', '0.857458'),
('mus', '16', 'node', '0.836446'),
('mus', '22', 'node', '0.836446'),
('mus', '34', 'node', '1'),
('mus', '39', 'node', '0.931053'),
('mus', '40', 'node', '1'),
('mus', '50', 'node', '1'),
('musvivamus', '76', 'node', '0.906287'),
('nam', '12', 'node', '1.81367'),
('nam', '13', 'node', '2.98224'),
('nam', '14', 'node', '5.11306'),
('nam', '15', 'node', '1'),
('nam', '16', 'node', '1.89272'),
('nam', '17', 'node', '3.93201'),
('nam', '18', 'node', '28.9729'),
('nam', '19', 'node', '2'),
('nam', '20', 'node', '1'),
('nam', '22', 'node', '1'),
('nam', '24', 'node', '2'),
('nam', '27', 'node', '4'),
('nam', '28', 'node', '12.8961'),
('nam', '29', 'node', '14.9096'),
('nam', '30', 'node', '12'),
('nam', '31', 'node', '12'),
('nam', '32', 'node', '11.9809'),
('nam', '33', 'node', '1.98493'),
('nam', '35', 'node', '0.98493'),
('nam', '36', 'node', '2.5763'),
('nam', '37', 'node', '2'),
('nam', '38', 'node', '0.989021'),
('nam', '40', 'node', '2.85135'),
('nam', '41', 'node', '0.876337'),
('nam', '45', 'node', '1'),
('nam', '47', 'node', '1'),
('nam', '50', 'node', '1'),
('nam', '67', 'node', '5.92981'),
('nam', '68', 'node', '1'),
('nam', '69', 'node', '0.98493'),
('nam', '71', 'node', '1'),
('nam', '77', 'node', '2.82313'),
('nam', '78', 'node', '1.93838'),
('nam', '79', 'node', '4.59818'),
('nascetur', '14', 'node', '0.863659'),
('nascetur', '16', 'node', '0.842342'),
('nascetur', '22', 'node', '0.842342'),
('nascetur', '34', 'node', '1'),
('nascetur', '39', 'node', '0.938382'),
('nascetur', '40', 'node', '1'),
('nascetur', '50', 'node', '1'),
('nascetur', '76', 'node', '0.913226'),
('natoque', '14', 'node', '0.882818'),
('natoque', '16', 'node', '23.3095'),
('natoque', '22', 'node', '0.860547'),
('natoque', '34', 'node', '1'),
('natoque', '39', 'node', '0.961087'),
('natoque', '40', 'node', '1'),
('natoque', '50', 'node', '1'),
('natoque', '76', 'node', '0.934703'),
('nec', '12', 'node', '5.34302'),
('nec', '13', 'node', '33.0338'),
('nec', '14', 'node', '1.65852'),
('nec', '15', 'node', '3'),
('nec', '16', 'node', '9.02095'),
('nec', '17', 'node', '2.99731'),
('nec', '18', 'node', '31.989'),
('nec', '19', 'node', '2.98493'),
('nec', '20', 'node', '2.9496'),
('nec', '21', 'node', '4.92058'),
('nec', '22', 'node', '5.68485'),
('nec', '23', 'node', '4.91645'),
('nec', '24', 'node', '4.66161'),
('nec', '25', 'node', '3.98087'),
('nec', '26', 'node', '3.89945'),
('nec', '28', 'node', '17.6752'),
('nec', '29', 'node', '12'),
('nec', '30', 'node', '15.8737'),
('nec', '31', 'node', '12.9769'),
('nec', '32', 'node', '14'),
('nec', '33', 'node', '3.98633'),
('nec', '34', 'node', '1'),
('nec', '35', 'node', '3'),
('nec', '36', 'node', '16.5256'),
('nec', '37', 'node', '2.9689'),
('nec', '38', 'node', '3.68165'),
('nec', '39', 'node', '4.89003'),
('nec', '40', 'node', '4.57524'),
('nec', '41', 'node', '7.91461'),
('nec', '42', 'node', '1'),
('nec', '46', 'node', '1'),
('nec', '47', 'node', '1'),
('nec', '50', 'node', '5.92027'),
('nec', '51', 'node', '2'),
('nec', '52', 'node', '3'),
('nec', '53', 'node', '3'),
('nec', '54', 'node', '3'),
('nec', '55', 'node', '3'),
('nec', '56', 'node', '3'),
('nec', '57', 'node', '3'),
('nec', '58', 'node', '3'),
('nec', '65', 'node', '6.80833'),
('nec', '67', 'node', '6.9347'),
('nec', '68', 'node', '7.67465'),
('nec', '69', 'node', '4'),
('nec', '71', 'node', '3.88852'),
('nec', '73', 'node', '7.90055'),
('nec', '76', 'node', '5.8965'),
('nec', '77', 'node', '6.63788'),
('nec', '78', 'node', '4.77893'),
('nec', '79', 'node', '12.7125'),
('nec', '82', 'node', '3'),
('nec', '83', 'node', '7.93972'),
('nec', '84', 'node', '7.93972'),
('nec', '85', 'node', '7.90055'),
('nec', '86', 'node', '7.90055'),
('nec', '87', 'node', '7.9208'),
('nec', '88', 'node', '7.90055'),
('nec', '89', 'node', '7.90055'),
('neque', '12', 'node', '2'),
('neque', '13', 'node', '3.9242'),
('neque', '14', 'node', '6.00017'),
('neque', '15', 'node', '2.99315'),
('neque', '16', 'node', '3.66789'),
('neque', '18', 'node', '1.97395'),
('neque', '19', 'node', '6.99315'),
('neque', '20', 'node', '6.76832'),
('neque', '21', 'node', '3.90428'),
('neque', '22', 'node', '4.97685'),
('neque', '23', 'node', '3.90428'),
('neque', '24', 'node', '2.93076'),
('neque', '26', 'node', '2'),
('neque', '27', 'node', '5'),
('neque', '28', 'node', '6'),
('neque', '29', 'node', '4.78137'),
('neque', '30', 'node', '6'),
('neque', '31', 'node', '4.9046'),
('neque', '32', 'node', '1'),
('neque', '33', 'node', '2'),
('neque', '34', 'node', '1'),
('neque', '35', 'node', '1'),
('neque', '36', 'node', '25.4322'),
('neque', '37', 'node', '2.85968'),
('neque', '38', 'node', '0.993146'),
('neque', '39', 'node', '2.89945'),
('neque', '40', 'node', '0.968904'),
('neque', '41', 'node', '4.79668'),
('neque', '42', 'node', '1'),
('neque', '45', 'node', '1'),
('neque', '46', 'node', '1'),
('neque', '47', 'node', '4'),
('neque', '51', 'node', '1'),
('neque', '65', 'node', '2.79604'),
('neque', '67', 'node', '2'),
('neque', '68', 'node', '14.8091'),
('neque', '69', 'node', '12.4612'),
('neque', '71', 'node', '2.94209'),
('neque', '76', 'node', '5.74309'),
('neque', '77', 'node', '2.83358'),
('neque', '78', 'node', '2.99315'),
('neque', '79', 'node', '1'),
('netus', '12', 'node', '0.792123'),
('netus', '14', 'node', '1.58511'),
('netus', '15', 'node', '2'),
('netus', '16', 'node', '2.90069'),
('netus', '17', 'node', '1'),
('netus', '28', 'node', '1'),
('netus', '30', 'node', '1'),
('netus', '37', 'node', '1'),
('netus', '38', 'node', '11.6616'),
('netus', '39', 'node', '9.67522'),
('netus', '40', 'node', '9.13696'),
('netus', '41', 'node', '1'),
('netus', '77', 'node', '0.882818'),
('netus', '79', 'node', '1'),
('nibh', '12', 'node', '1'),
('nibh', '13', 'node', '6.92384'),
('nibh', '14', 'node', '4.82311'),
('nibh', '16', 'node', '1.83353'),
('nibh', '17', 'node', '1.9347'),
('nibh', '18', 'node', '2'),
('nibh', '19', 'node', '1.98493'),
('nibh', '20', 'node', '7.60525'),
('nibh', '21', 'node', '1'),
('nibh', '22', 'node', '4.71774'),
('nibh', '23', 'node', '1'),
('nibh', '24', 'node', '1'),
('nibh', '25', 'node', '0.980874'),
('nibh', '26', 'node', '0.899454'),
('nibh', '28', 'node', '3.86351'),
('nibh', '30', 'node', '2.9496'),
('nibh', '31', 'node', '4.94572'),
('nibh', '32', 'node', '1'),
('nibh', '33', 'node', '1.98493'),
('nibh', '34', 'node', '1'),
('nibh', '35', 'node', '27'),
('nibh', '36', 'node', '3.63225'),
('nibh', '37', 'node', '2.91323'),
('nibh', '38', 'node', '2.91674'),
('nibh', '39', 'node', '1.88922'),
('nibh', '40', 'node', '1.74742'),
('nibh', '41', 'node', '2.92384'),
('nibh', '42', 'node', '1'),
('nibh', '43', 'node', '2'),
('nibh', '47', 'node', '1'),
('nibh', '50', 'node', '1'),
('nibh', '51', 'node', '2'),
('nibh', '52', 'node', '1'),
('nibh', '53', 'node', '1'),
('nibh', '54', 'node', '1'),
('nibh', '55', 'node', '1'),
('nibh', '56', 'node', '1'),
('nibh', '57', 'node', '1'),
('nibh', '58', 'node', '1'),
('nibh', '65', 'node', '1'),
('nibh', '67', 'node', '13.9274'),
('nibh', '68', 'node', '3.82491'),
('nibh', '69', 'node', '6'),
('nibh', '71', 'node', '2.82818'),
('nibh', '73', 'node', '1'),
('nibh', '76', 'node', '0.902857'),
('nibh', '77', 'node', '2.87313'),
('nibh', '78', 'node', '1'),
('nibh', '79', 'node', '6'),
('nibh', '82', 'node', '1'),
('nibh', '83', 'node', '1'),
('nibh', '84', 'node', '1'),
('nibh', '85', 'node', '1'),
('nibh', '86', 'node', '1'),
('nibh', '87', 'node', '1'),
('nibh', '88', 'node', '1'),
('nibh', '89', 'node', '1'),
('nisi', '12', 'node', '4.25286'),
('nisi', '13', 'node', '2.94209'),
('nisi', '14', 'node', '7.85417'),
('nisi', '15', 'node', '3.58171'),
('nisi', '16', 'node', '2.92027'),
('nisi', '17', 'node', '3'),
('nisi', '18', 'node', '1'),
('nisi', '19', 'node', '1'),
('nisi', '20', 'node', '3.70873'),
('nisi', '21', 'node', '3.92027'),
('nisi', '22', 'node', '1.97685'),
('nisi', '23', 'node', '3.92027'),
('nisi', '24', 'node', '29.7996'),
('nisi', '25', 'node', '2.93453'),
('nisi', '26', 'node', '3.90286'),
('nisi', '27', 'node', '2'),
('nisi', '28', 'node', '2.8894'),
('nisi', '29', 'node', '1.91894'),
('nisi', '30', 'node', '2'),
('nisi', '32', 'node', '1'),
('nisi', '34', 'node', '1.92384'),
('nisi', '35', 'node', '1'),
('nisi', '36', 'node', '2.57822'),
('nisi', '37', 'node', '1.89816'),
('nisi', '38', 'node', '0.938382'),
('nisi', '39', 'node', '2.92027'),
('nisi', '40', 'node', '5.70578'),
('nisi', '41', 'node', '4.55464'),
('nisi', '44', 'node', '27'),
('nisi', '47', 'node', '4'),
('nisi', '50', 'node', '1'),
('nisi', '65', 'node', '1'),
('nisi', '68', 'node', '0.931053'),
('nisi', '69', 'node', '1'),
('nisi', '71', 'node', '4.92743'),
('nisi', '73', 'node', '1'),
('nisi', '76', 'node', '3'),
('nisi', '77', 'node', '3.96109'),
('nisi', '78', 'node', '3'),
('nisi', '79', 'node', '2.86443'),
('nisi', '83', 'node', '1'),
('nisi', '84', 'node', '1'),
('nisi', '85', 'node', '1'),
('nisi', '86', 'node', '1'),
('nisi', '87', 'node', '1'),
('nisi', '88', 'node', '1'),
('nisi', '89', 'node', '1'),
('nisifes', '38', 'node', '9.78337'),
('nisifes', '39', 'node', '9.711'),
('nisifes', '40', 'node', '9.16882'),
('nisifes', '41', 'node', '9.60445'),
('nisl', '12', 'node', '5.27005'),
('nisl', '13', 'node', '3.92702'),
('nisl', '14', 'node', '7.84898'),
('nisl', '15', 'node', '0.899454'),
('nisl', '16', 'node', '2'),
('nisl', '17', 'node', '1.92384'),
('nisl', '18', 'node', '2.98493'),
('nisl', '19', 'node', '1'),
('nisl', '20', 'node', '1.8894'),
('nisl', '21', 'node', '2'),
('nisl', '23', 'node', '2'),
('nisl', '24', 'node', '1'),
('nisl', '27', 'node', '2'),
('nisl', '28', 'node', '2.99315'),
('nisl', '29', 'node', '1.9534'),
('nisl', '30', 'node', '2.98493'),
('nisl', '31', 'node', '1.94583'),
('nisl', '32', 'node', '1.95772'),
('nisl', '33', 'node', '3'),
('nisl', '35', 'node', '1.95772'),
('nisl', '36', 'node', '5.491'),
('nisl', '37', 'node', '0.945829'),
('nisl', '38', 'node', '2.87765'),
('nisl', '39', 'node', '4.87765'),
('nisl', '40', 'node', '1.84532'),
('nisl', '41', 'node', '1'),
('nisl', '43', 'node', '1'),
('nisl', '50', 'node', '2'),
('nisl', '51', 'node', '1'),
('nisl', '65', 'node', '2.71765'),
('nisl', '67', 'node', '0.980874'),
('nisl', '68', 'node', '3.76836'),
('nisl', '71', 'node', '3.86213'),
('nisl', '77', 'node', '2.89543'),
('nisl', '78', 'node', '1'),
('nisl', '79', 'node', '2.80231'),
('nislum', '56', 'node', '26'),
('non', '12', 'node', '5.23395'),
('non', '13', 'node', '2.92027'),
('non', '14', 'node', '7.53935'),
('non', '15', 'node', '1.72425'),
('non', '16', 'node', '2.5784'),
('non', '17', 'node', '1.94209'),
('non', '18', 'node', '2'),
('non', '19', 'node', '2.91448'),
('non', '20', 'node', '4'),
('non', '21', 'node', '7.85704'),
('non', '22', 'node', '6.88142'),
('non', '23', 'node', '7.85704'),
('non', '24', 'node', '32.8478'),
('non', '25', 'node', '2'),
('non', '26', 'node', '3.9534'),
('non', '27', 'node', '4'),
('non', '28', 'node', '5.89945'),
('non', '29', 'node', '4.8085'),
('non', '30', 'node', '5'),
('non', '31', 'node', '6.86084'),
('non', '32', 'node', '3'),
('non', '33', 'node', '4'),
('non', '34', 'node', '0.993146'),
('non', '35', 'node', '3'),
('non', '36', 'node', '26.4797'),
('non', '37', 'node', '5.85144'),
('non', '38', 'node', '4.84568'),
('non', '39', 'node', '2.80231'),
('non', '40', 'node', '0.863659'),
('non', '41', 'node', '12.3277'),
('non', '42', 'node', '1'),
('non', '43', 'node', '26'),
('non', '44', 'node', '1'),
('non', '45', 'node', '1'),
('non', '47', 'node', '6'),
('non', '50', 'node', '2.93838'),
('non', '51', 'node', '4.97685'),
('non', '52', 'node', '1'),
('non', '53', 'node', '1'),
('non', '54', 'node', '1'),
('non', '55', 'node', '1'),
('non', '56', 'node', '1'),
('non', '57', 'node', '1'),
('non', '58', 'node', '1'),
('non', '65', 'node', '12.4255'),
('non', '67', 'node', '12.9274'),
('non', '68', 'node', '38.0568'),
('non', '69', 'node', '25.43'),
('non', '71', 'node', '8.80572'),
('non', '73', 'node', '7.64752'),
('non', '76', 'node', '4.67177'),
('non', '77', 'node', '5.84057'),
('non', '78', 'node', '1.99315'),
('non', '79', 'node', '7.52394'),
('non', '82', 'node', '1'),
('non', '83', 'node', '7.68109'),
('non', '84', 'node', '7.68109'),
('non', '85', 'node', '7.64752'),
('non', '86', 'node', '7.64752'),
('non', '87', 'node', '7.66694'),
('non', '88', 'node', '7.64752'),
('non', '89', 'node', '7.64752'),
('normal', '11', 'node', '1'),
('nostra', '12', 'node', '1.76068'),
('nostra', '14', 'node', '0.752312'),
('nostra', '15', 'node', '0.931053'),
('nostra', '16', 'node', '0.797402'),
('nostra', '20', 'node', '0.902857'),
('nostra', '22', 'node', '0.882818'),
('nostra', '24', 'node', '1'),
('nostra', '33', 'node', '1'),
('nostra', '36', 'node', '1.94183'),
('nostra', '41', 'node', '0.802752'),
('nostra', '50', 'node', '0.972861'),
('nostra', '51', 'node', '1'),
('nostra', '65', 'node', '2'),
('nostra', '68', 'node', '1'),
('nostra', '69', 'node', '1'),
('nostra', '73', 'node', '0.927431'),
('nostra', '79', 'node', '0.860547'),
('nostra', '83', 'node', '0.934703'),
('nostra', '84', 'node', '0.934703'),
('nostra', '85', 'node', '0.927431'),
('nostra', '86', 'node', '0.927431'),
('nostra', '87', 'node', '0.931053'),
('nostra', '88', 'node', '0.927431'),
('nostra', '89', 'node', '0.927431'),
('nulla', '12', 'node', '11.5515'),
('nulla', '13', 'node', '6.91674'),
('nulla', '14', 'node', '5.08154'),
('nulla', '15', 'node', '8.70543'),
('nulla', '16', 'node', '8.45989'),
('nulla', '17', 'node', '4.88899'),
('nulla', '18', 'node', '29'),
('nulla', '19', 'node', '3'),
('nulla', '20', 'node', '30.9931'),
('nulla', '21', 'node', '1.9496'),
('nulla', '22', 'node', '2.88659'),
('nulla', '23', 'node', '1.9496'),
('nulla', '24', 'node', '1'),
('nulla', '25', 'node', '2.9534'),
('nulla', '26', 'node', '2.93794'),
('nulla', '27', 'node', '3'),
('nulla', '28', 'node', '15.816'),
('nulla', '29', 'node', '16.848'),
('nulla', '30', 'node', '14'),
('nulla', '31', 'node', '14.9378'),
('nulla', '32', 'node', '14.9973'),
('nulla', '33', 'node', '7.95543'),
('nulla', '34', 'node', '2.92384'),
('nulla', '35', 'node', '4'),
('nulla', '36', 'node', '5.65042'),
('nulla', '37', 'node', '3.94216'),
('nulla', '38', 'node', '7.6931'),
('nulla', '39', 'node', '3.89274'),
('nulla', '40', 'node', '8.30416'),
('nulla', '41', 'node', '2.71945'),
('nulla', '44', 'node', '26'),
('nulla', '45', 'node', '1'),
('nulla', '47', 'node', '3'),
('nulla', '50', 'node', '3'),
('nulla', '51', 'node', '2'),
('nulla', '52', 'node', '3'),
('nulla', '53', 'node', '3'),
('nulla', '54', 'node', '3'),
('nulla', '55', 'node', '3'),
('nulla', '56', 'node', '3'),
('nulla', '57', 'node', '3'),
('nulla', '58', 'node', '3'),
('nulla', '65', 'node', '4.67865'),
('nulla', '67', 'node', '10.8293'),
('nulla', '68', 'node', '13.8867'),
('nulla', '69', 'node', '12.9347'),
('nulla', '71', 'node', '9.70468'),
('nulla', '73', 'node', '3.97685'),
('nulla', '76', 'node', '6.8317'),
('nulla', '77', 'node', '5.9215'),
('nulla', '78', 'node', '1'),
('nulla', '79', 'node', '2.85625'),
('nulla', '82', 'node', '3'),
('nulla', '83', 'node', '3.98493'),
('nulla', '84', 'node', '3.98493'),
('nulla', '85', 'node', '3.97685'),
('nulla', '86', 'node', '3.97685'),
('nulla', '87', 'node', '3.98087'),
('nulla', '88', 'node', '3.97685'),
('nulla', '89', 'node', '3.97685'),
('nullam', '12', 'node', '4.10432'),
('nullam', '13', 'node', '2'),
('nullam', '14', 'node', '1'),
('nullam', '15', 'node', '1.86366'),
('nullam', '16', 'node', '1.81925'),
('nullam', '17', 'node', '0.980874'),
('nullam', '18', 'node', '2.98902'),
('nullam', '19', 'node', '2'),
('nullam', '20', 'node', '0.886095'),
('nullam', '21', 'node', '0.953396'),
('nullam', '22', 'node', '1'),
('nullam', '23', 'node', '0.953396'),
('nullam', '24', 'node', '3.81742'),
('nullam', '26', 'node', '3'),
('nullam', '27', 'node', '2'),
('nullam', '28', 'node', '3'),
('nullam', '29', 'node', '1.90756'),
('nullam', '30', 'node', '3'),
('nullam', '31', 'node', '0.945829'),
('nullam', '32', 'node', '2'),
('nullam', '33', 'node', '1'),
('nullam', '35', 'node', '28'),
('nullam', '36', 'node', '1.92027'),
('nullam', '38', 'node', '1'),
('nullam', '39', 'node', '1'),
('nullam', '40', 'node', '0.931053');
INSERT INTO `search_index` VALUES
('nullam', '43', 'node', '26'),
('nullam', '45', 'node', '2'),
('nullam', '50', 'node', '1.95723'),
('nullam', '51', 'node', '2'),
('nullam', '52', 'node', '1'),
('nullam', '53', 'node', '1'),
('nullam', '54', 'node', '1'),
('nullam', '55', 'node', '1'),
('nullam', '56', 'node', '1'),
('nullam', '57', 'node', '1'),
('nullam', '58', 'node', '1'),
('nullam', '71', 'node', '1'),
('nullam', '73', 'node', '1'),
('nullam', '76', 'node', '1'),
('nullam', '77', 'node', '2.9496'),
('nullam', '78', 'node', '1'),
('nullam', '79', 'node', '5.82861'),
('nullam', '82', 'node', '1'),
('nullam', '83', 'node', '1'),
('nullam', '84', 'node', '1'),
('nullam', '85', 'node', '1'),
('nullam', '86', 'node', '1'),
('nullam', '87', 'node', '1'),
('nullam', '88', 'node', '1'),
('nullam', '89', 'node', '1'),
('nunc', '12', 'node', '2.72553'),
('nunc', '13', 'node', '4.91236'),
('nunc', '14', 'node', '9.45795'),
('nunc', '15', 'node', '1'),
('nunc', '16', 'node', '3.60586'),
('nunc', '17', 'node', '2'),
('nunc', '18', 'node', '1.98493'),
('nunc', '19', 'node', '2.98493'),
('nunc', '20', 'node', '3.82166'),
('nunc', '21', 'node', '3.94209'),
('nunc', '22', 'node', '2.99315'),
('nunc', '23', 'node', '3.94209'),
('nunc', '24', 'node', '2.85532'),
('nunc', '25', 'node', '1.93105'),
('nunc', '26', 'node', '2'),
('nunc', '28', 'node', '3.60249'),
('nunc', '29', 'node', '2'),
('nunc', '31', 'node', '3'),
('nunc', '32', 'node', '27'),
('nunc', '34', 'node', '1'),
('nunc', '35', 'node', '1'),
('nunc', '36', 'node', '6.68198'),
('nunc', '37', 'node', '1.97286'),
('nunc', '38', 'node', '5.7515'),
('nunc', '39', 'node', '2'),
('nunc', '40', 'node', '5.90929'),
('nunc', '41', 'node', '7.12883'),
('nunc', '42', 'node', '1'),
('nunc', '44', 'node', '26'),
('nunc', '45', 'node', '1'),
('nunc', '47', 'node', '4.99731'),
('nunc', '50', 'node', '3.90974'),
('nunc', '51', 'node', '2'),
('nunc', '52', 'node', '3'),
('nunc', '53', 'node', '3'),
('nunc', '54', 'node', '3'),
('nunc', '55', 'node', '3'),
('nunc', '56', 'node', '3'),
('nunc', '57', 'node', '3'),
('nunc', '58', 'node', '3'),
('nunc', '65', 'node', '3.86726'),
('nunc', '67', 'node', '1.9689'),
('nunc', '68', 'node', '0.909743'),
('nunc', '71', 'node', '7.40731'),
('nunc', '73', 'node', '4.95839'),
('nunc', '76', 'node', '4.84767'),
('nunc', '77', 'node', '7.41772'),
('nunc', '78', 'node', '2.94209'),
('nunc', '79', 'node', '6.36814'),
('nunc', '82', 'node', '3'),
('nunc', '83', 'node', '4.9689'),
('nunc', '84', 'node', '4.9689'),
('nunc', '85', 'node', '4.95839'),
('nunc', '86', 'node', '4.95839'),
('nunc', '87', 'node', '4.96498'),
('nunc', '88', 'node', '4.95839'),
('nunc', '89', 'node', '4.95839'),
('odio', '12', 'node', '4'),
('odio', '13', 'node', '4'),
('odio', '14', 'node', '7.3611'),
('odio', '15', 'node', '2'),
('odio', '16', 'node', '1.85127'),
('odio', '17', 'node', '2.86941'),
('odio', '18', 'node', '2'),
('odio', '19', 'node', '2.97286'),
('odio', '20', 'node', '1'),
('odio', '21', 'node', '1.89932'),
('odio', '22', 'node', '3.93485'),
('odio', '23', 'node', '1.89932'),
('odio', '24', 'node', '3.84779'),
('odio', '25', 'node', '0.931053'),
('odio', '26', 'node', '2'),
('odio', '27', 'node', '1'),
('odio', '28', 'node', '4.65502'),
('odio', '29', 'node', '1.94209'),
('odio', '30', 'node', '1.94209'),
('odio', '31', 'node', '2.9347'),
('odio', '32', 'node', '1'),
('odio', '33', 'node', '0.989021'),
('odio', '34', 'node', '1.97685'),
('odio', '35', 'node', '1'),
('odio', '36', 'node', '5.45587'),
('odio', '38', 'node', '4.71041'),
('odio', '39', 'node', '1.92384'),
('odio', '40', 'node', '3.73359'),
('odio', '41', 'node', '1.8894'),
('odio', '42', 'node', '1'),
('odio', '44', 'node', '1'),
('odio', '45', 'node', '1'),
('odio', '50', 'node', '1'),
('odio', '52', 'node', '3'),
('odio', '53', 'node', '3'),
('odio', '54', 'node', '3'),
('odio', '55', 'node', '3'),
('odio', '56', 'node', '3'),
('odio', '57', 'node', '3'),
('odio', '58', 'node', '3'),
('odio', '65', 'node', '3.70463'),
('odio', '67', 'node', '3'),
('odio', '68', 'node', '2.79955'),
('odio', '69', 'node', '0.997306'),
('odio', '71', 'node', '2'),
('odio', '73', 'node', '3'),
('odio', '76', 'node', '2.88282'),
('odio', '77', 'node', '3.83358'),
('odio', '78', 'node', '1'),
('odio', '79', 'node', '1.87127'),
('odio', '82', 'node', '3'),
('odio', '83', 'node', '3'),
('odio', '84', 'node', '3'),
('odio', '85', 'node', '3'),
('odio', '86', 'node', '3'),
('odio', '87', 'node', '3'),
('odio', '88', 'node', '3'),
('odio', '89', 'node', '3'),
('orci', '12', 'node', '5.17452'),
('orci', '14', 'node', '5.26266'),
('orci', '15', 'node', '0.909743'),
('orci', '17', 'node', '1'),
('orci', '18', 'node', '1'),
('orci', '19', 'node', '1'),
('orci', '20', 'node', '3.77882'),
('orci', '21', 'node', '3.86581'),
('orci', '22', 'node', '4.86576'),
('orci', '23', 'node', '3.86581'),
('orci', '24', 'node', '3'),
('orci', '25', 'node', '13.9383'),
('orci', '26', 'node', '12.8639'),
('orci', '27', 'node', '12'),
('orci', '28', 'node', '1'),
('orci', '29', 'node', '1.92384'),
('orci', '30', 'node', '1'),
('orci', '31', 'node', '0.942091'),
('orci', '33', 'node', '1'),
('orci', '34', 'node', '1'),
('orci', '36', 'node', '3.70124'),
('orci', '37', 'node', '1'),
('orci', '38', 'node', '1'),
('orci', '39', 'node', '1'),
('orci', '40', 'node', '4.55391'),
('orci', '41', 'node', '8.83811'),
('orci', '43', 'node', '1'),
('orci', '45', 'node', '27'),
('orci', '46', 'node', '52'),
('orci', '47', 'node', '1'),
('orci', '50', 'node', '2.88466'),
('orci', '51', 'node', '1'),
('orci', '52', 'node', '2'),
('orci', '53', 'node', '2'),
('orci', '54', 'node', '2'),
('orci', '55', 'node', '2'),
('orci', '56', 'node', '2'),
('orci', '57', 'node', '2'),
('orci', '58', 'node', '2'),
('orci', '65', 'node', '0.927431'),
('orci', '67', 'node', '4.95608'),
('orci', '68', 'node', '0.876337'),
('orci', '71', 'node', '17.7604'),
('orci', '73', 'node', '2'),
('orci', '76', 'node', '1'),
('orci', '77', 'node', '2.77879'),
('orci', '78', 'node', '14.9203'),
('orci', '79', 'node', '3.47882'),
('orci', '82', 'node', '2'),
('orci', '83', 'node', '2'),
('orci', '84', 'node', '2'),
('orci', '85', 'node', '2'),
('orci', '86', 'node', '2'),
('orci', '87', 'node', '2'),
('orci', '88', 'node', '2'),
('orci', '89', 'node', '2'),
('org', '88', 'node', '0.902857'),
('org', '89', 'node', '0.902857'),
('ornare', '12', 'node', '1'),
('ornare', '13', 'node', '1.99731'),
('ornare', '14', 'node', '67.9837'),
('ornare', '17', 'node', '4.9496'),
('ornare', '18', 'node', '1'),
('ornare', '21', 'node', '3.91099'),
('ornare', '22', 'node', '2'),
('ornare', '23', 'node', '3.91099'),
('ornare', '24', 'node', '2.88282'),
('ornare', '25', 'node', '1'),
('ornare', '26', 'node', '1'),
('ornare', '27', 'node', '27'),
('ornare', '28', 'node', '1.91674'),
('ornare', '29', 'node', '27'),
('ornare', '30', 'node', '1'),
('ornare', '31', 'node', '2.9534'),
('ornare', '32', 'node', '2'),
('ornare', '34', 'node', '3'),
('ornare', '35', 'node', '2'),
('ornare', '36', 'node', '1.87634'),
('ornare', '38', 'node', '1.94209'),
('ornare', '39', 'node', '0.906287'),
('ornare', '40', 'node', '1'),
('ornare', '41', 'node', '2'),
('ornare', '44', 'node', '1'),
('ornare', '45', 'node', '2'),
('ornare', '46', 'node', '1'),
('ornare', '47', 'node', '1'),
('ornare', '51', 'node', '1'),
('ornare', '65', 'node', '0.873132'),
('ornare', '67', 'node', '1.99731'),
('ornare', '68', 'node', '16.9892'),
('ornare', '69', 'node', '16.4029'),
('ornare', '71', 'node', '4.97258'),
('ornare', '76', 'node', '1.73674'),
('ornare', '77', 'node', '3.71467'),
('ornare', '79', 'node', '0.892724'),
('our', '77', 'node', '26'),
('our', '81', 'node', '26'),
('parker', '69', 'node', '26'),
('parturient', '14', 'node', '0.869951'),
('parturient', '16', 'node', '0.848323'),
('parturient', '22', 'node', '0.848323'),
('parturient', '34', 'node', '1'),
('parturient', '39', 'node', '0.945829'),
('parturient', '40', 'node', '1'),
('parturient', '50', 'node', '1'),
('parturient', '76', 'node', '0.920273'),
('pellente', '37', 'node', '26'),
('pellente', '38', 'node', '26'),
('pellente', '39', 'node', '26'),
('pellente', '40', 'node', '26'),
('pellente', '41', 'node', '26'),
('pellentesque', '12', 'node', '5.42987'),
('pellentesque', '13', 'node', '29.9238'),
('pellentesque', '14', 'node', '12.3196'),
('pellentesque', '15', 'node', '4.77969'),
('pellentesque', '16', 'node', '30.7041'),
('pellentesque', '17', 'node', '2'),
('pellentesque', '18', 'node', '1'),
('pellentesque', '19', 'node', '28'),
('pellentesque', '20', 'node', '3.7406'),
('pellentesque', '21', 'node', '4.88792'),
('pellentesque', '22', 'node', '3.83353'),
('pellentesque', '23', 'node', '4.88792'),
('pellentesque', '24', 'node', '1.80666'),
('pellentesque', '25', 'node', '5.87074'),
('pellentesque', '26', 'node', '4.78651'),
('pellentesque', '27', 'node', '3'),
('pellentesque', '28', 'node', '4.79256'),
('pellentesque', '29', 'node', '4.94654'),
('pellentesque', '30', 'node', '3'),
('pellentesque', '31', 'node', '1'),
('pellentesque', '32', 'node', '3'),
('pellentesque', '33', 'node', '1'),
('pellentesque', '34', 'node', '1.9496'),
('pellentesque', '35', 'node', '3'),
('pellentesque', '36', 'node', '3.84532'),
('pellentesque', '37', 'node', '6.99731'),
('pellentesque', '38', 'node', '4.92645'),
('pellentesque', '39', 'node', '5.90167'),
('pellentesque', '40', 'node', '5.62655'),
('pellentesque', '41', 'node', '13.282'),
('pellentesque', '46', 'node', '1'),
('pellentesque', '47', 'node', '2'),
('pellentesque', '51', 'node', '3'),
('pellentesque', '52', 'node', '8'),
('pellentesque', '53', 'node', '8'),
('pellentesque', '54', 'node', '8'),
('pellentesque', '55', 'node', '8'),
('pellentesque', '56', 'node', '8'),
('pellentesque', '57', 'node', '8'),
('pellentesque', '58', 'node', '8'),
('pellentesque', '65', 'node', '5.65298'),
('pellentesque', '67', 'node', '5'),
('pellentesque', '68', 'node', '12'),
('pellentesque', '69', 'node', '11.7454'),
('pellentesque', '71', 'node', '8.79184'),
('pellentesque', '73', 'node', '8.99731'),
('pellentesque', '76', 'node', '3.72514'),
('pellentesque', '77', 'node', '1.78212'),
('pellentesque', '78', 'node', '4.93838'),
('pellentesque', '79', 'node', '4.72999'),
('pellentesque', '82', 'node', '8'),
('pellentesque', '83', 'node', '9'),
('pellentesque', '84', 'node', '9'),
('pellentesque', '85', 'node', '8.99731'),
('pellentesque', '86', 'node', '8.99731'),
('pellentesque', '87', 'node', '9'),
('pellentesque', '88', 'node', '8.99731'),
('pellentesque', '89', 'node', '8.99731'),
('penatibus', '14', 'node', '0.879565'),
('penatibus', '16', 'node', '23.2286'),
('penatibus', '22', 'node', '0.857458'),
('penatibus', '34', 'node', '1'),
('penatibus', '39', 'node', '0.957226'),
('penatibus', '40', 'node', '1'),
('penatibus', '50', 'node', '1'),
('penatibus', '76', 'node', '0.931053'),
('per', '12', 'node', '3.52486'),
('per', '14', 'node', '1.50702'),
('per', '15', 'node', '1.86581'),
('per', '16', 'node', '1.59751'),
('per', '20', 'node', '1.8092'),
('per', '22', 'node', '1.76896'),
('per', '24', 'node', '2'),
('per', '33', 'node', '2'),
('per', '36', 'node', '13.6164'),
('per', '41', 'node', '1.60824'),
('per', '50', 'node', '1.94978'),
('per', '51', 'node', '2'),
('per', '65', 'node', '4'),
('per', '68', 'node', '2'),
('per', '69', 'node', '2'),
('per', '73', 'node', '1.85854'),
('per', '79', 'node', '1.72425'),
('per', '83', 'node', '1.87314'),
('per', '84', 'node', '1.87314'),
('per', '85', 'node', '1.85854'),
('per', '86', 'node', '1.85854'),
('per', '87', 'node', '1.86581'),
('per', '88', 'node', '1.85854'),
('per', '89', 'node', '1.85854'),
('permalink', '12', 'node', '27.3535'),
('permalink', '13', 'node', '10.7015'),
('permalink', '14', 'node', '43.5914'),
('permalink', '16', 'node', '19.555'),
('permalink', '36', 'node', '28.0065'),
('permalink', '41', 'node', '9.53472'),
('perspiciatis', '55', 'node', '26'),
('perspiciatis', '86', 'node', '26'),
('pharetra', '12', 'node', '2.58453'),
('pharetra', '13', 'node', '2.98902'),
('pharetra', '14', 'node', '6.0812'),
('pharetra', '15', 'node', '1'),
('pharetra', '16', 'node', '2.7514'),
('pharetra', '17', 'node', '3'),
('pharetra', '20', 'node', '1.83111'),
('pharetra', '21', 'node', '3.92221'),
('pharetra', '22', 'node', '2'),
('pharetra', '23', 'node', '3.92221'),
('pharetra', '24', 'node', '1'),
('pharetra', '25', 'node', '1.91598'),
('pharetra', '26', 'node', '0.902857'),
('pharetra', '28', 'node', '3'),
('pharetra', '29', 'node', '1'),
('pharetra', '30', 'node', '3'),
('pharetra', '31', 'node', '2.8881'),
('pharetra', '32', 'node', '3'),
('pharetra', '33', 'node', '2'),
('pharetra', '34', 'node', '1'),
('pharetra', '35', 'node', '3'),
('pharetra', '36', 'node', '0.854391'),
('pharetra', '37', 'node', '1'),
('pharetra', '38', 'node', '1.8867'),
('pharetra', '39', 'node', '0.896076'),
('pharetra', '40', 'node', '1.84832'),
('pharetra', '41', 'node', '2'),
('pharetra', '44', 'node', '1'),
('pharetra', '46', 'node', '1'),
('pharetra', '47', 'node', '1'),
('pharetra', '50', 'node', '1'),
('pharetra', '51', 'node', '1'),
('pharetra', '65', 'node', '0.882818'),
('pharetra', '67', 'node', '2.94583'),
('pharetra', '68', 'node', '2.76375'),
('pharetra', '69', 'node', '0.927431'),
('pharetra', '71', 'node', '2.94209'),
('pharetra', '77', 'node', '1'),
('pharetra', '78', 'node', '3.92384'),
('pharetra', '79', 'node', '1'),
('phasellus', '12', 'node', '6.3556'),
('phasellus', '14', 'node', '0.993146'),
('phasellus', '15', 'node', '2'),
('phasellus', '16', 'node', '3.61483'),
('phasellus', '18', 'node', '1'),
('phasellus', '20', 'node', '0.889397'),
('phasellus', '21', 'node', '3.86081'),
('phasellus', '22', 'node', '6.91523'),
('phasellus', '23', 'node', '3.86081'),
('phasellus', '25', 'node', '1'),
('phasellus', '26', 'node', '0.923838'),
('phasellus', '27', 'node', '2'),
('phasellus', '28', 'node', '2.85183'),
('phasellus', '29', 'node', '2.99315'),
('phasellus', '30', 'node', '1.9347'),
('phasellus', '31', 'node', '2.90756'),
('phasellus', '32', 'node', '1'),
('phasellus', '33', 'node', '1'),
('phasellus', '34', 'node', '1'),
('phasellus', '35', 'node', '1'),
('phasellus', '38', 'node', '1'),
('phasellus', '39', 'node', '1.80582'),
('phasellus', '40', 'node', '2.79341'),
('phasellus', '41', 'node', '1.79279'),
('phasellus', '43', 'node', '26'),
('phasellus', '44', 'node', '1'),
('phasellus', '45', 'node', '26'),
('phasellus', '46', 'node', '1'),
('phasellus', '47', 'node', '2'),
('phasellus', '65', 'node', '0.949597'),
('phasellus', '67', 'node', '2'),
('phasellus', '68', 'node', '6.98922'),
('phasellus', '69', 'node', '6.73881'),
('phasellus', '71', 'node', '3.98922'),
('phasellus', '76', 'node', '0.972861'),
('phasellus', '77', 'node', '1.87313'),
('phasellus', '78', 'node', '3.9534'),
('phasellus', '79', 'node', '2.83938'),
('placerat', '12', 'node', '1.59525'),
('placerat', '14', 'node', '9.31886'),
('placerat', '15', 'node', '3'),
('placerat', '16', 'node', '3.85127'),
('placerat', '17', 'node', '1.91894'),
('placerat', '18', 'node', '3'),
('placerat', '19', 'node', '2'),
('placerat', '20', 'node', '1.94209'),
('placerat', '21', 'node', '1'),
('placerat', '22', 'node', '2'),
('placerat', '23', 'node', '1'),
('placerat', '25', 'node', '1.93105'),
('placerat', '26', 'node', '0.920273'),
('placerat', '27', 'node', '1'),
('placerat', '28', 'node', '4.57821'),
('placerat', '29', 'node', '0.923838'),
('placerat', '30', 'node', '1'),
('placerat', '31', 'node', '1'),
('placerat', '34', 'node', '2'),
('placerat', '36', 'node', '1.83938'),
('placerat', '38', 'node', '3.99315'),
('placerat', '39', 'node', '2.8867'),
('placerat', '40', 'node', '2.81522'),
('placerat', '41', 'node', '1.88438'),
('placerat', '42', 'node', '1'),
('placerat', '44', 'node', '1'),
('placerat', '65', 'node', '9.48716'),
('placerat', '67', 'node', '1'),
('placerat', '68', 'node', '2'),
('placerat', '69', 'node', '2'),
('placerat', '71', 'node', '6.88213'),
('placerat', '77', 'node', '2'),
('placerat', '79', 'node', '3.69181'),
('platea', '12', 'node', '1.84234'),
('platea', '14', 'node', '2.37329'),
('platea', '15', 'node', '0.876337'),
('platea', '16', 'node', '0.824901'),
('platea', '20', 'node', '0.98493'),
('platea', '32', 'node', '2'),
('platea', '34', 'node', '0.96498'),
('platea', '35', 'node', '2'),
('platea', '39', 'node', '1'),
('platea', '68', 'node', '1'),
('platea', '69', 'node', '1'),
('platea', '71', 'node', '1'),
('platea', '76', 'node', '0.876337'),
('platea', '78', 'node', '1'),
('policy', '79', 'node', '26'),
('porta', '12', 'node', '24.8486'),
('porta', '14', 'node', '30.4991'),
('porta', '15', 'node', '1.97402'),
('porta', '17', 'node', '2'),
('porta', '18', 'node', '0.972861'),
('porta', '21', 'node', '3.91894'),
('porta', '22', 'node', '2.97286'),
('porta', '23', 'node', '3.91894'),
('porta', '24', 'node', '2'),
('porta', '26', 'node', '1'),
('porta', '28', 'node', '1.85967'),
('porta', '29', 'node', '1'),
('porta', '30', 'node', '0.968904'),
('porta', '31', 'node', '4.8843'),
('porta', '32', 'node', '2'),
('porta', '33', 'node', '3'),
('porta', '34', 'node', '1'),
('porta', '35', 'node', '2'),
('porta', '36', 'node', '4.7102'),
('porta', '37', 'node', '1'),
('porta', '38', 'node', '3.80452'),
('porta', '39', 'node', '2.93781'),
('porta', '40', 'node', '1.82725'),
('porta', '41', 'node', '1.76566'),
('porta', '44', 'node', '1'),
('porta', '46', 'node', '26'),
('porta', '47', 'node', '1'),
('porta', '50', 'node', '0.942091'),
('porta', '52', 'node', '1'),
('porta', '53', 'node', '1'),
('porta', '54', 'node', '1'),
('porta', '55', 'node', '1'),
('porta', '56', 'node', '1'),
('porta', '57', 'node', '1'),
('porta', '58', 'node', '1'),
('porta', '65', 'node', '4.72243'),
('porta', '67', 'node', '13.9106'),
('porta', '68', 'node', '9.711'),
('porta', '71', 'node', '4'),
('porta', '73', 'node', '1'),
('porta', '76', 'node', '1.9689'),
('porta', '77', 'node', '0.920273'),
('porta', '79', 'node', '2.67799'),
('porta', '82', 'node', '1'),
('porta', '83', 'node', '1'),
('porta', '84', 'node', '1'),
('porta', '85', 'node', '1'),
('porta', '86', 'node', '1'),
('porta', '87', 'node', '1'),
('porta', '88', 'node', '1'),
('porta', '89', 'node', '1'),
('porttitor', '12', 'node', '28.6216'),
('porttitor', '13', 'node', '2.93111'),
('porttitor', '14', 'node', '8.32137'),
('porttitor', '15', 'node', '3.84754'),
('porttitor', '16', 'node', '4.72569'),
('porttitor', '17', 'node', '2'),
('porttitor', '20', 'node', '1.89272'),
('porttitor', '21', 'node', '3.88364'),
('porttitor', '22', 'node', '4.99315'),
('porttitor', '23', 'node', '3.88364'),
('porttitor', '24', 'node', '0.945829'),
('porttitor', '26', 'node', '1'),
('porttitor', '27', 'node', '1'),
('porttitor', '29', 'node', '3'),
('porttitor', '31', 'node', '2'),
('porttitor', '34', 'node', '2'),
('porttitor', '36', 'node', '1.83938'),
('porttitor', '37', 'node', '1.84812'),
('porttitor', '38', 'node', '0.931053'),
('porttitor', '39', 'node', '2'),
('porttitor', '40', 'node', '1'),
('porttitor', '41', 'node', '2.87957'),
('porttitor', '43', 'node', '1'),
('porttitor', '44', 'node', '1'),
('porttitor', '47', 'node', '2'),
('porttitor', '50', 'node', '1.90974'),
('porttitor', '51', 'node', '1'),
('porttitor', '52', 'node', '1'),
('porttitor', '53', 'node', '1'),
('porttitor', '54', 'node', '1'),
('porttitor', '55', 'node', '1'),
('porttitor', '56', 'node', '1'),
('porttitor', '57', 'node', '1'),
('porttitor', '58', 'node', '1'),
('porttitor', '67', 'node', '1.88083'),
('porttitor', '71', 'node', '1'),
('porttitor', '73', 'node', '1'),
('porttitor', '77', 'node', '1.98493'),
('porttitor', '78', 'node', '3.81161'),
('porttitor', '79', 'node', '1.85245'),
('porttitor', '82', 'node', '1'),
('porttitor', '83', 'node', '1'),
('porttitor', '84', 'node', '1'),
('porttitor', '85', 'node', '1'),
('porttitor', '86', 'node', '1'),
('porttitor', '87', 'node', '1'),
('porttitor', '88', 'node', '1'),
('porttitor', '89', 'node', '1'),
('post', '12', 'node', '2.38568'),
('post', '13', 'node', '0.902857'),
('post', '14', 'node', '3.86766'),
('posuere', '12', 'node', '2.6271'),
('posuere', '13', 'node', '1'),
('posuere', '14', 'node', '5.33278'),
('posuere', '15', 'node', '0.902857'),
('posuere', '16', 'node', '1'),
('posuere', '17', 'node', '2.8843'),
('posuere', '18', 'node', '2.98493'),
('posuere', '19', 'node', '1'),
('posuere', '20', 'node', '1.96498'),
('posuere', '21', 'node', '3.80796'),
('posuere', '22', 'node', '5.93201'),
('posuere', '23', 'node', '3.80796'),
('posuere', '24', 'node', '2'),
('posuere', '25', 'node', '1'),
('posuere', '26', 'node', '0.938382'),
('posuere', '27', 'node', '2'),
('posuere', '28', 'node', '1'),
('posuere', '29', 'node', '3.94654'),
('posuere', '30', 'node', '1'),
('posuere', '31', 'node', '0.968904'),
('posuere', '32', 'node', '1'),
('posuere', '35', 'node', '1'),
('posuere', '36', 'node', '3.60854'),
('posuere', '37', 'node', '1.90974'),
('posuere', '38', 'node', '1.99315'),
('posuere', '39', 'node', '1.99731'),
('posuere', '40', 'node', '1.76374'),
('posuere', '41', 'node', '1.92743'),
('posuere', '43', 'node', '1'),
('posuere', '44', 'node', '1'),
('posuere', '47', 'node', '2'),
('posuere', '51', 'node', '2'),
('posuere', '52', 'node', '1'),
('posuere', '53', 'node', '1'),
('posuere', '54', 'node', '1'),
('posuere', '55', 'node', '1'),
('posuere', '56', 'node', '1'),
('posuere', '57', 'node', '1'),
('posuere', '58', 'node', '1'),
('posuere', '65', 'node', '0.923838'),
('posuere', '68', 'node', '11.9849'),
('posuere', '69', 'node', '11.9311'),
('posuere', '71', 'node', '1'),
('posuere', '73', 'node', '1'),
('posuere', '76', 'node', '1'),
('posuere', '77', 'node', '3.88798'),
('posuere', '79', 'node', '1.74567'),
('posuere', '82', 'node', '1'),
('posuere', '83', 'node', '1'),
('posuere', '84', 'node', '1'),
('posuere', '85', 'node', '1'),
('posuere', '86', 'node', '1'),
('posuere', '87', 'node', '1'),
('posuere', '88', 'node', '1'),
('posuere', '89', 'node', '1'),
('potenti', '12', 'node', '22.0414'),
('potenti', '15', 'node', '27'),
('potenti', '16', 'node', '1.83353'),
('potenti', '22', 'node', '1.86314'),
('potenti', '27', 'node', '1'),
('potenti', '28', 'node', '27'),
('potenti', '29', 'node', '0.980874'),
('potenti', '30', 'node', '1'),
('potenti', '40', 'node', '1.97286'),
('potenti', '50', 'node', '1'),
('praesent', '12', 'node', '3.47862'),
('praesent', '13', 'node', '2.98493'),
('praesent', '14', 'node', '4.84694'),
('praesent', '15', 'node', '1.85082'),
('praesent', '16', 'node', '0.892724'),
('praesent', '17', 'node', '1.9347'),
('praesent', '18', 'node', '1'),
('praesent', '19', 'node', '2'),
('praesent', '20', 'node', '3'),
('praesent', '22', 'node', '1.88065'),
('praesent', '24', 'node', '29.9284'),
('praesent', '25', 'node', '1.94583'),
('praesent', '26', 'node', '3.9689'),
('praesent', '27', 'node', '1'),
('praesent', '28', 'node', '1'),
('praesent', '29', 'node', '1.9534'),
('praesent', '30', 'node', '1'),
('praesent', '32', 'node', '2'),
('praesent', '34', 'node', '1.94625'),
('praesent', '35', 'node', '2'),
('praesent', '36', 'node', '0.827757'),
('praesent', '37', 'node', '3.82996'),
('praesent', '38', 'node', '0.949597'),
('praesent', '40', 'node', '0.886095'),
('praesent', '41', 'node', '4.22539'),
('praesent', '46', 'node', '1'),
('praesent', '47', 'node', '3.98493'),
('praesent', '50', 'node', '1'),
('praesent', '51', 'node', '1'),
('praesent', '52', 'node', '1'),
('praesent', '53', 'node', '1'),
('praesent', '54', 'node', '1'),
('praesent', '55', 'node', '1'),
('praesent', '56', 'node', '1'),
('praesent', '57', 'node', '27'),
('praesent', '58', 'node', '27'),
('praesent', '65', 'node', '4'),
('praesent', '68', 'node', '0.968904'),
('praesent', '73', 'node', '4.9074'),
('praesent', '76', 'node', '2.86163'),
('praesent', '77', 'node', '1.91674'),
('praesent', '78', 'node', '2.92384'),
('praesent', '79', 'node', '1.87293'),
('praesent', '82', 'node', '1'),
('praesent', '83', 'node', '30.9397'),
('praesent', '84', 'node', '4.93972'),
('praesent', '85', 'node', '4.9074'),
('praesent', '86', 'node', '4.9074'),
('praesent', '87', 'node', '4.9235'),
('praesent', '88', 'node', '4.9074'),
('praesent', '89', 'node', '4.9074'),
('pretium', '12', 'node', '3.25965'),
('pretium', '13', 'node', '1'),
('pretium', '14', 'node', '5.5796'),
('pretium', '15', 'node', '2.71185'),
('pretium', '16', 'node', '1'),
('pretium', '19', 'node', '3'),
('pretium', '20', 'node', '3'),
('pretium', '21', 'node', '1.92743'),
('pretium', '22', 'node', '3.93105'),
('pretium', '23', 'node', '1.92743'),
('pretium', '24', 'node', '1.94209'),
('pretium', '25', 'node', '2'),
('pretium', '26', 'node', '2.89166'),
('pretium', '27', 'node', '2'),
('pretium', '28', 'node', '2'),
('pretium', '29', 'node', '1.86593'),
('pretium', '30', 'node', '2'),
('pretium', '31', 'node', '4.91155'),
('pretium', '32', 'node', '2'),
('pretium', '33', 'node', '3'),
('pretium', '35', 'node', '2'),
('pretium', '36', 'node', '2.90629'),
('pretium', '38', 'node', '1'),
('pretium', '39', 'node', '1'),
('pretium', '40', 'node', '3.8894'),
('pretium', '41', 'node', '1.9347'),
('pretium', '43', 'node', '1'),
('pretium', '45', 'node', '1'),
('pretium', '50', 'node', '1.90974'),
('pretium', '51', 'node', '1'),
('pretium', '52', 'node', '2'),
('pretium', '53', 'node', '2'),
('pretium', '54', 'node', '2'),
('pretium', '55', 'node', '2'),
('pretium', '56', 'node', '2'),
('pretium', '57', 'node', '2'),
('pretium', '58', 'node', '2'),
('pretium', '67', 'node', '12'),
('pretium', '68', 'node', '10.6037'),
('pretium', '73', 'node', '2'),
('pretium', '76', 'node', '1'),
('pretium', '78', 'node', '2.87585'),
('pretium', '79', 'node', '1.85133'),
('pretium', '82', 'node', '2'),
('pretium', '83', 'node', '2'),
('pretium', '84', 'node', '2'),
('pretium', '85', 'node', '2'),
('pretium', '86', 'node', '2'),
('pretium', '87', 'node', '2'),
('pretium', '88', 'node', '2'),
('pretium', '89', 'node', '2'),
('primis', '12', 'node', '1'),
('primis', '14', 'node', '0.931053'),
('primis', '17', 'node', '1'),
('primis', '21', 'node', '1.86952'),
('primis', '22', 'node', '2.9347'),
('primis', '23', 'node', '1.86952'),
('primis', '24', 'node', '1'),
('primis', '29', 'node', '1'),
('primis', '37', 'node', '1'),
('primis', '40', 'node', '0.913226'),
('primis', '41', 'node', '1'),
('primis', '65', 'node', '0.934703'),
('primis', '71', 'node', '1'),
('privacy', '79', 'node', '26'),
('programmer', '65', 'node', '0.866793'),
('proin', '12', 'node', '0.961087'),
('proin', '13', 'node', '1.98902'),
('proin', '14', 'node', '2.59075'),
('proin', '17', 'node', '0.953396'),
('proin', '18', 'node', '2'),
('proin', '19', 'node', '0.98493'),
('proin', '20', 'node', '1.9534'),
('proin', '21', 'node', '2'),
('proin', '22', 'node', '1.81896'),
('proin', '23', 'node', '2'),
('proin', '24', 'node', '0.953396'),
('proin', '25', 'node', '1'),
('proin', '26', 'node', '1.96109'),
('proin', '29', 'node', '1'),
('proin', '31', 'node', '2'),
('proin', '32', 'node', '2.98902'),
('proin', '33', 'node', '3.99045'),
('proin', '34', 'node', '0.934703'),
('proin', '35', 'node', '2.99315'),
('proin', '36', 'node', '2.6689'),
('proin', '37', 'node', '0.942091'),
('proin', '38', 'node', '0.906287'),
('proin', '39', 'node', '2'),
('proin', '41', 'node', '1.86957'),
('proin', '45', 'node', '26'),
('proin', '46', 'node', '1'),
('proin', '47', 'node', '2.99731'),
('proin', '50', 'node', '3'),
('proin', '51', 'node', '1'),
('proin', '65', 'node', '4'),
('proin', '71', 'node', '1'),
('proin', '76', 'node', '1'),
('proin', '77', 'node', '2.87083'),
('proin', '78', 'node', '1.93838'),
('proin', '79', 'node', '4'),
('pul', '27', 'node', '26'),
('pulv', '29', 'node', '26'),
('pulvinar', '12', 'node', '3.43476'),
('pulvinar', '13', 'node', '0.927431'),
('pulvinar', '14', 'node', '5.8407'),
('pulvinar', '15', 'node', '2.98902'),
('pulvinar', '16', 'node', '2.79984'),
('pulvinar', '17', 'node', '3.92474'),
('pulvinar', '18', 'node', '28'),
('pulvinar', '19', 'node', '2'),
('pulvinar', '20', 'node', '1.95723'),
('pulvinar', '21', 'node', '2'),
('pulvinar', '22', 'node', '1.97685'),
('pulvinar', '23', 'node', '2'),
('pulvinar', '24', 'node', '1.9689'),
('pulvinar', '25', 'node', '0.953396'),
('pulvinar', '26', 'node', '1'),
('pulvinar', '27', 'node', '3'),
('pulvinar', '28', 'node', '11'),
('pulvinar', '29', 'node', '13.9781'),
('pulvinar', '30', 'node', '11'),
('pulvinar', '31', 'node', '11.9534'),
('pulvinar', '32', 'node', '14'),
('pulvinar', '33', 'node', '3'),
('pulvinar', '34', 'node', '1'),
('pulvinar', '35', 'node', '3'),
('pulvinar', '36', 'node', '1'),
('pulvinar', '37', 'node', '1'),
('pulvinar', '40', 'node', '1.8894'),
('pulvinar', '43', 'node', '1'),
('pulvinar', '45', 'node', '1'),
('pulvinar', '46', 'node', '1'),
('pulvinar', '52', 'node', '4'),
('pulvinar', '53', 'node', '4'),
('pulvinar', '54', 'node', '4'),
('pulvinar', '55', 'node', '4'),
('pulvinar', '56', 'node', '4'),
('pulvinar', '57', 'node', '4'),
('pulvinar', '58', 'node', '4'),
('pulvinar', '67', 'node', '1'),
('pulvinar', '71', 'node', '0.949597'),
('pulvinar', '73', 'node', '4'),
('pulvinar', '77', 'node', '2.91674'),
('pulvinar', '78', 'node', '0.96498'),
('pulvinar', '79', 'node', '1.79553'),
('pulvinar', '82', 'node', '4'),
('pulvinar', '83', 'node', '4'),
('pulvinar', '84', 'node', '4'),
('pulvinar', '85', 'node', '4'),
('pulvinar', '86', 'node', '4'),
('pulvinar', '87', 'node', '4'),
('pulvinar', '88', 'node', '4'),
('pulvinar', '89', 'node', '4'),
('purus', '12', 'node', '5.54155'),
('purus', '13', 'node', '2.85127'),
('purus', '14', 'node', '4.14941'),
('purus', '15', 'node', '3.85746'),
('purus', '16', 'node', '4.64482'),
('purus', '17', 'node', '1'),
('purus', '19', 'node', '2.95723'),
('purus', '20', 'node', '3.92221'),
('purus', '21', 'node', '3'),
('purus', '23', 'node', '3'),
('purus', '24', 'node', '1.81635'),
('purus', '25', 'node', '1'),
('purus', '26', 'node', '2'),
('purus', '29', 'node', '3'),
('purus', '31', 'node', '1'),
('purus', '32', 'node', '2'),
('purus', '33', 'node', '3'),
('purus', '34', 'node', '1'),
('purus', '35', 'node', '2'),
('purus', '36', 'node', '5.47025'),
('purus', '37', 'node', '1'),
('purus', '38', 'node', '2.8894'),
('purus', '39', 'node', '1'),
('purus', '40', 'node', '0.945829'),
('purus', '41', 'node', '6.12207'),
('purus', '43', 'node', '1'),
('purus', '44', 'node', '26'),
('purus', '46', 'node', '1'),
('purus', '47', 'node', '1.98087'),
('purus', '50', 'node', '1'),
('purus', '51', 'node', '1'),
('purus', '52', 'node', '3'),
('purus', '53', 'node', '3'),
('purus', '54', 'node', '3'),
('purus', '55', 'node', '3'),
('purus', '56', 'node', '3'),
('purus', '57', 'node', '3'),
('purus', '58', 'node', '3'),
('purus', '65', 'node', '5.90629'),
('purus', '67', 'node', '1.92743'),
('purus', '68', 'node', '1.98493'),
('purus', '69', 'node', '1.93105'),
('purus', '71', 'node', '1.94209'),
('purus', '73', 'node', '7.88425'),
('purus', '76', 'node', '2.85245'),
('purus', '77', 'node', '0.902857'),
('purus', '79', 'node', '0.934703'),
('purus', '82', 'node', '3'),
('purus', '83', 'node', '7.92465'),
('purus', '84', 'node', '7.92465'),
('purus', '85', 'node', '7.88425'),
('purus', '86', 'node', '7.88425'),
('purus', '87', 'node', '7.90437'),
('purus', '88', 'node', '7.88425'),
('purus', '89', 'node', '7.88425'),
('quality', '47', 'node', '26'),
('quam', '12', 'node', '5.35231'),
('quam', '13', 'node', '0.938382'),
('quam', '14', 'node', '5.98327'),
('quam', '15', 'node', '4.76267'),
('quam', '16', 'node', '4.84916'),
('quam', '17', 'node', '30'),
('quam', '19', 'node', '1'),
('quam', '20', 'node', '1.8478'),
('quam', '22', 'node', '2.95813'),
('quam', '24', 'node', '2.85883'),
('quam', '25', 'node', '0.927431'),
('quam', '26', 'node', '2'),
('quam', '27', 'node', '2'),
('quam', '28', 'node', '2.77221'),
('quam', '29', 'node', '1.95723'),
('quam', '30', 'node', '1'),
('quam', '31', 'node', '1.97286'),
('quam', '33', 'node', '12'),
('quam', '34', 'node', '12'),
('quam', '36', 'node', '3.78003'),
('quam', '37', 'node', '0.923838'),
('quam', '38', 'node', '1.90974'),
('quam', '39', 'node', '4.98633'),
('quam', '40', 'node', '1.8894'),
('quam', '41', 'node', '3.61594'),
('quam', '44', 'node', '2'),
('quam', '50', 'node', '3'),
('quam', '51', 'node', '1.97685'),
('quam', '52', 'node', '2'),
('quam', '53', 'node', '2'),
('quam', '54', 'node', '2'),
('quam', '55', 'node', '2'),
('quam', '56', 'node', '2'),
('quam', '57', 'node', '2'),
('quam', '58', 'node', '2'),
('quam', '65', 'node', '1.93838'),
('quam', '67', 'node', '5.93201'),
('quam', '68', 'node', '18.5832'),
('quam', '69', 'node', '13.6038'),
('quam', '71', 'node', '1'),
('quam', '73', 'node', '2.99731'),
('quam', '76', 'node', '3.9689'),
('quam', '77', 'node', '3.82319'),
('quam', '78', 'node', '2.91081'),
('quam', '79', 'node', '1.9496'),
('quam', '82', 'node', '2'),
('quam', '83', 'node', '3'),
('quam', '84', 'node', '3'),
('quam', '85', 'node', '2.99731'),
('quam', '86', 'node', '2.99731'),
('quam', '87', 'node', '3'),
('quam', '88', 'node', '2.99731'),
('quam', '89', 'node', '2.99731'),
('quis', '12', 'node', '9.39434'),
('quis', '13', 'node', '4.85495'),
('quis', '14', 'node', '52.1625'),
('quis', '15', 'node', '5.58487'),
('quis', '16', 'node', '3.81083'),
('quis', '17', 'node', '3.93862'),
('quis', '18', 'node', '3.98087'),
('quis', '19', 'node', '1.97286'),
('quis', '20', 'node', '4.87957'),
('quis', '21', 'node', '4.89932'),
('quis', '22', 'node', '5.80837'),
('quis', '23', 'node', '4.89932'),
('quis', '24', 'node', '2.86593'),
('quis', '26', 'node', '2'),
('quis', '27', 'node', '3'),
('quis', '28', 'node', '7.7299'),
('quis', '29', 'node', '6.90729'),
('quis', '30', 'node', '4.99731'),
('quis', '31', 'node', '3.819'),
('quis', '32', 'node', '4.98087'),
('quis', '33', 'node', '3.99731'),
('quis', '34', 'node', '3.92743'),
('quis', '35', 'node', '4.98087'),
('quis', '36', 'node', '4.66076'),
('quis', '37', 'node', '9.60377'),
('quis', '38', 'node', '2.98902'),
('quis', '39', 'node', '4.74772'),
('quis', '40', 'node', '4.62086'),
('quis', '41', 'node', '9.07766'),
('quis', '43', 'node', '1'),
('quis', '45', 'node', '3'),
('quis', '47', 'node', '5'),
('quis', '50', 'node', '3'),
('quis', '51', 'node', '2'),
('quis', '52', 'node', '5'),
('quis', '53', 'node', '5'),
('quis', '54', 'node', '5'),
('quis', '55', 'node', '5'),
('quis', '56', 'node', '5'),
('quis', '57', 'node', '5'),
('quis', '58', 'node', '5'),
('quis', '65', 'node', '5'),
('quis', '67', 'node', '6.82934'),
('quis', '68', 'node', '3'),
('quis', '69', 'node', '2.9496'),
('quis', '71', 'node', '15.5431'),
('quis', '73', 'node', '9'),
('quis', '76', 'node', '5.92613'),
('quis', '77', 'node', '9.24872'),
('quis', '78', 'node', '3.85537'),
('quis', '79', 'node', '2.92836'),
('quis', '82', 'node', '5'),
('quis', '83', 'node', '9'),
('quis', '84', 'node', '9'),
('quis', '85', 'node', '9'),
('quis', '86', 'node', '9'),
('quis', '87', 'node', '9'),
('quis', '88', 'node', '9'),
('quis', '89', 'node', '9'),
('quisque', '12', 'node', '2.51695'),
('quisque', '13', 'node', '34.103'),
('quisque', '14', 'node', '8.58552'),
('quisque', '15', 'node', '1'),
('quisque', '16', 'node', '0.923838'),
('quisque', '17', 'node', '0.949597'),
('quisque', '18', 'node', '1'),
('quisque', '22', 'node', '2.76096'),
('quisque', '25', 'node', '1'),
('quisque', '26', 'node', '0.957226'),
('quisque', '28', 'node', '0.98493'),
('quisque', '29', 'node', '1'),
('quisque', '30', 'node', '0.976851'),
('quisque', '31', 'node', '1.92246'),
('quisque', '32', 'node', '1'),
('quisque', '35', 'node', '1'),
('quisque', '36', 'node', '2.70697'),
('quisque', '37', 'node', '1.92743'),
('quisque', '39', 'node', '1'),
('quisque', '40', 'node', '10.0739'),
('quisque', '41', 'node', '2'),
('quisque', '45', 'node', '1'),
('quisque', '47', 'node', '2'),
('quisque', '65', 'node', '1.95723'),
('quisque', '76', 'node', '2'),
('quisque', '77', 'node', '1.92384'),
('quisque', '78', 'node', '0.923838'),
('quisque', '79', 'node', '4.69535'),
('register', '12', 'node', '5.25474'),
('register', '13', 'node', '1.99383'),
('register', '14', 'node', '8.51468'),
('reply', '16', 'node', '18.2605'),
('reply', '36', 'node', '27.5406'),
('reply', '41', 'node', '8.74229'),
('rhoncus', '12', 'node', '0.781775'),
('rhoncus', '13', 'node', '3'),
('rhoncus', '14', 'node', '7.42661'),
('rhoncus', '16', 'node', '1.8861'),
('rhoncus', '18', 'node', '1'),
('rhoncus', '19', 'node', '1'),
('rhoncus', '20', 'node', '5.66391'),
('rhoncus', '21', 'node', '2'),
('rhoncus', '23', 'node', '2'),
('rhoncus', '24', 'node', '1.91674'),
('rhoncus', '25', 'node', '0.96498'),
('rhoncus', '26', 'node', '1'),
('rhoncus', '27', 'node', '1'),
('rhoncus', '28', 'node', '1'),
('rhoncus', '29', 'node', '1.94209'),
('rhoncus', '30', 'node', '1'),
('rhoncus', '31', 'node', '2'),
('rhoncus', '33', 'node', '0.980874'),
('rhoncus', '36', 'node', '4.83938'),
('rhoncus', '37', 'node', '2.82297'),
('rhoncus', '38', 'node', '2'),
('rhoncus', '39', 'node', '0.920273'),
('rhoncus', '40', 'node', '3.99315'),
('rhoncus', '41', 'node', '10.2746'),
('rhoncus', '47', 'node', '2'),
('rhoncus', '51', 'node', '1'),
('rhoncus', '52', 'node', '1'),
('rhoncus', '53', 'node', '1'),
('rhoncus', '54', 'node', '1'),
('rhoncus', '55', 'node', '1'),
('rhoncus', '56', 'node', '1'),
('rhoncus', '57', 'node', '1'),
('rhoncus', '58', 'node', '1'),
('rhoncus', '65', 'node', '11'),
('rhoncus', '67', 'node', '0.949597'),
('rhoncus', '68', 'node', '1'),
('rhoncus', '69', 'node', '0.993146'),
('rhoncus', '71', 'node', '1'),
('rhoncus', '73', 'node', '12'),
('rhoncus', '76', 'node', '1.8861'),
('rhoncus', '77', 'node', '1'),
('rhoncus', '79', 'node', '1'),
('rhoncus', '82', 'node', '1'),
('rhoncus', '83', 'node', '12'),
('rhoncus', '84', 'node', '12'),
('rhoncus', '85', 'node', '12'),
('rhoncus', '86', 'node', '12'),
('rhoncus', '87', 'node', '12'),
('rhoncus', '88', 'node', '12'),
('rhoncus', '89', 'node', '12'),
('ridiculus', '14', 'node', '0.860547'),
('ridiculus', '16', 'node', '0.839384'),
('ridiculus', '22', 'node', '0.839384'),
('ridiculus', '34', 'node', '1'),
('ridiculus', '39', 'node', '0.934703'),
('ridiculus', '40', 'node', '1'),
('ridiculus', '50', 'node', '1'),
('ridiculus', '76', 'node', '0.909743'),
('risus', '12', 'node', '7.21959'),
('risus', '13', 'node', '2'),
('risus', '14', 'node', '3.79146'),
('risus', '15', 'node', '3.72741'),
('risus', '16', 'node', '28.7094'),
('risus', '17', 'node', '1.9496'),
('risus', '18', 'node', '2'),
('risus', '19', 'node', '1'),
('risus', '20', 'node', '4.8263'),
('risus', '21', 'node', '3.97286'),
('risus', '22', 'node', '3.85133'),
('risus', '23', 'node', '3.97286'),
('risus', '24', 'node', '2.84872'),
('risus', '25', 'node', '1.99731'),
('risus', '26', 'node', '3.90974'),
('risus', '27', 'node', '2'),
('risus', '28', 'node', '3.80914'),
('risus', '29', 'node', '3.94654'),
('risus', '30', 'node', '2'),
('risus', '31', 'node', '1.98087'),
('risus', '34', 'node', '1'),
('risus', '36', 'node', '3.7783'),
('risus', '37', 'node', '1.90629'),
('risus', '38', 'node', '0.945829'),
('risus', '39', 'node', '3'),
('risus', '40', 'node', '1.83938'),
('risus', '41', 'node', '11.3648'),
('risus', '46', 'node', '28'),
('risus', '47', 'node', '5'),
('risus', '50', 'node', '1.9347'),
('risus', '51', 'node', '1'),
('risus', '65', 'node', '11'),
('risus', '67', 'node', '4.81358'),
('risus', '68', 'node', '1.89608'),
('risus', '69', 'node', '0.968904'),
('risus', '71', 'node', '3.87519'),
('risus', '73', 'node', '11'),
('risus', '76', 'node', '1.93047'),
('risus', '77', 'node', '2.91674'),
('risus', '79', 'node', '6.17808'),
('risus', '83', 'node', '11'),
('risus', '84', 'node', '11'),
('risus', '85', 'node', '11'),
('risus', '86', 'node', '11'),
('risus', '87', 'node', '11'),
('risus', '88', 'node', '11'),
('risus', '89', 'node', '11'),
('rius', '31', 'node', '26'),
('rutrum', '12', 'node', '2.57125'),
('rutrum', '13', 'node', '0.931053'),
('rutrum', '14', 'node', '4.71698'),
('rutrum', '15', 'node', '1'),
('rutrum', '16', 'node', '3.72289'),
('rutrum', '19', 'node', '1.98493'),
('rutrum', '20', 'node', '3'),
('rutrum', '21', 'node', '1'),
('rutrum', '22', 'node', '1.93153'),
('rutrum', '23', 'node', '1'),
('rutrum', '24', 'node', '1.92384'),
('rutrum', '26', 'node', '1'),
('rutrum', '28', 'node', '3.74804'),
('rutrum', '30', 'node', '1.9347'),
('rutrum', '32', 'node', '2.97402'),
('rutrum', '33', 'node', '2'),
('rutrum', '35', 'node', '2.97818'),
('rutrum', '36', 'node', '0.927431'),
('rutrum', '37', 'node', '0.949597'),
('rutrum', '38', 'node', '3'),
('rutrum', '39', 'node', '3.69181'),
('rutrum', '40', 'node', '1.81025'),
('rutrum', '41', 'node', '1.73298'),
('rutrum', '43', 'node', '1'),
('rutrum', '45', 'node', '1'),
('rutrum', '47', 'node', '1'),
('rutrum', '50', 'node', '2'),
('rutrum', '65', 'node', '2.84132'),
('rutrum', '69', 'node', '1'),
('rutrum', '71', 'node', '11.4456'),
('rutrum', '73', 'node', '0.98493'),
('rutrum', '76', 'node', '0.976851'),
('rutrum', '77', 'node', '13'),
('rutrum', '83', 'node', '0.993146'),
('rutrum', '84', 'node', '0.993146'),
('rutrum', '85', 'node', '0.98493'),
('rutrum', '86', 'node', '0.98493'),
('rutrum', '87', 'node', '0.989021'),
('rutrum', '88', 'node', '0.98493'),
('rutrum', '89', 'node', '0.98493'),
('sagittis', '12', 'node', '1.78691'),
('sagittis', '14', 'node', '3.23539'),
('sagittis', '15', 'node', '1'),
('sagittis', '16', 'node', '1.7506'),
('sagittis', '17', 'node', '1'),
('sagittis', '18', 'node', '1'),
('sagittis', '19', 'node', '3'),
('sagittis', '21', 'node', '1'),
('sagittis', '22', 'node', '0.96498'),
('sagittis', '23', 'node', '1'),
('sagittis', '25', 'node', '2.91286'),
('sagittis', '26', 'node', '1.82302'),
('sagittis', '27', 'node', '1'),
('sagittis', '28', 'node', '1.98902'),
('sagittis', '29', 'node', '3.97685'),
('sagittis', '30', 'node', '1.98087'),
('sagittis', '31', 'node', '3'),
('sagittis', '33', 'node', '1.99315'),
('sagittis', '34', 'node', '2'),
('sagittis', '36', 'node', '4.60582'),
('sagittis', '37', 'node', '1'),
('sagittis', '38', 'node', '2.82648'),
('sagittis', '39', 'node', '1.92114'),
('sagittis', '41', 'node', '15.0337'),
('sagittis', '42', 'node', '1'),
('sagittis', '47', 'node', '3'),
('sagittis', '52', 'node', '4'),
('sagittis', '53', 'node', '4'),
('sagittis', '54', 'node', '4'),
('sagittis', '55', 'node', '4'),
('sagittis', '56', 'node', '4'),
('sagittis', '57', 'node', '4'),
('sagittis', '58', 'node', '4'),
('sagittis', '65', 'node', '15'),
('sagittis', '67', 'node', '1.99315'),
('sagittis', '69', 'node', '2'),
('sagittis', '71', 'node', '1.90629'),
('sagittis', '73', 'node', '17.9146'),
('sagittis', '76', 'node', '0.896076'),
('sagittis', '77', 'node', '1.98087'),
('sagittis', '79', 'node', '2.79194'),
('sagittis', '82', 'node', '4'),
('sagittis', '83', 'node', '18.0238'),
('sagittis', '84', 'node', '18.0238'),
('sagittis', '85', 'node', '17.9146'),
('sagittis', '86', 'node', '17.9146'),
('sagittis', '87', 'node', '17.969'),
('sagittis', '88', 'node', '17.9146'),
('sagittis', '89', 'node', '17.9146'),
('sam', '73', 'node', '26'),
('samantha', '67', 'node', '26'),
('sapien', '12', 'node', '0.802752'),
('sapien', '13', 'node', '2.92702'),
('sapien', '14', 'node', '4.96878'),
('sapien', '15', 'node', '1'),
('sapien', '16', 'node', '4.36517'),
('sapien', '17', 'node', '3.86213'),
('sapien', '18', 'node', '2.98493'),
('sapien', '19', 'node', '1'),
('sapien', '20', 'node', '1'),
('sapien', '21', 'node', '0.945829'),
('sapien', '22', 'node', '2.78987'),
('sapien', '23', 'node', '0.945829'),
('sapien', '24', 'node', '2.79944'),
('sapien', '25', 'node', '1.9534'),
('sapien', '26', 'node', '3'),
('sapien', '27', 'node', '1'),
('sapien', '28', 'node', '1.90471'),
('sapien', '29', 'node', '2'),
('sapien', '30', 'node', '0.972861'),
('sapien', '31', 'node', '2.94971'),
('sapien', '32', 'node', '3'),
('sapien', '34', 'node', '1'),
('sapien', '35', 'node', '3'),
('sapien', '36', 'node', '1.84234'),
('sapien', '37', 'node', '3.8826'),
('sapien', '38', 'node', '3'),
('sapien', '39', 'node', '4.8861'),
('sapien', '40', 'node', '1.95453'),
('sapien', '41', 'node', '1.7516'),
('sapien', '43', 'node', '1'),
('sapien', '45', 'node', '1'),
('sapien', '46', 'node', '1'),
('sapien', '47', 'node', '1'),
('sapien', '50', 'node', '0.920273'),
('sapien', '51', 'node', '0.989021'),
('sapien', '65', 'node', '5.75353'),
('sapien', '68', 'node', '0.953396'),
('sapien', '71', 'node', '9.61008'),
('sapien', '73', 'node', '0.972861'),
('sapien', '76', 'node', '4.71046'),
('sapien', '77', 'node', '3.6638'),
('sapien', '78', 'node', '1.95723'),
('sapien', '79', 'node', '0.842342'),
('sapien', '83', 'node', '0.980874'),
('sapien', '84', 'node', '0.980874'),
('sapien', '85', 'node', '0.972861'),
('sapien', '86', 'node', '0.972861'),
('sapien', '87', 'node', '0.976851'),
('sapien', '88', 'node', '0.972861'),
('sapien', '89', 'node', '0.972861'),
('sarah', '68', 'node', '26'),
('scelerisque', '12', 'node', '0.786915'),
('scelerisque', '13', 'node', '1'),
('scelerisque', '14', 'node', '3.46643'),
('scelerisque', '16', 'node', '2.6226'),
('scelerisque', '17', 'node', '4.81888'),
('scelerisque', '18', 'node', '3'),
('scelerisque', '19', 'node', '0.957226'),
('scelerisque', '20', 'node', '1.94209'),
('scelerisque', '21', 'node', '1.98087'),
('scelerisque', '22', 'node', '27'),
('scelerisque', '23', 'node', '27.9809'),
('scelerisque', '24', 'node', '3.97286'),
('scelerisque', '25', 'node', '2.94209'),
('scelerisque', '26', 'node', '2.89166'),
('scelerisque', '27', 'node', '2'),
('scelerisque', '28', 'node', '4.83715'),
('scelerisque', '29', 'node', '2.89274'),
('scelerisque', '30', 'node', '3.91193'),
('scelerisque', '31', 'node', '1.97286'),
('scelerisque', '34', 'node', '1'),
('scelerisque', '36', 'node', '2.73725'),
('scelerisque', '37', 'node', '0.96498'),
('scelerisque', '39', 'node', '1.98493'),
('scelerisque', '40', 'node', '2.99315'),
('scelerisque', '41', 'node', '2.663'),
('scelerisque', '47', 'node', '1.98493'),
('scelerisque', '52', 'node', '1'),
('scelerisque', '53', 'node', '1'),
('scelerisque', '54', 'node', '1'),
('scelerisque', '55', 'node', '1'),
('scelerisque', '56', 'node', '1'),
('scelerisque', '57', 'node', '1'),
('scelerisque', '58', 'node', '1'),
('scelerisque', '67', 'node', '6.89144'),
('scelerisque', '68', 'node', '6.91674'),
('scelerisque', '69', 'node', '6'),
('scelerisque', '71', 'node', '1.91323'),
('scelerisque', '73', 'node', '1'),
('scelerisque', '76', 'node', '2'),
('scelerisque', '77', 'node', '2'),
('scelerisque', '78', 'node', '0.989021'),
('scelerisque', '79', 'node', '1'),
('scelerisque', '82', 'node', '1'),
('scelerisque', '83', 'node', '1'),
('scelerisque', '84', 'node', '1'),
('scelerisque', '85', 'node', '1'),
('scelerisque', '86', 'node', '1'),
('scelerisque', '87', 'node', '1'),
('scelerisque', '88', 'node', '1'),
('scelerisque', '89', 'node', '1'),
('sed', '12', 'node', '6.80665'),
('sed', '13', 'node', '7.9347'),
('sed', '14', 'node', '37.6268'),
('sed', '15', 'node', '7.66357'),
('sed', '16', 'node', '10.0948'),
('sed', '17', 'node', '4'),
('sed', '18', 'node', '1'),
('sed', '19', 'node', '12.8628'),
('sed', '20', 'node', '13.5935'),
('sed', '21', 'node', '7.94209'),
('sed', '22', 'node', '7.66882'),
('sed', '23', 'node', '7.94209'),
('sed', '24', 'node', '3.84646'),
('sed', '25', 'node', '29'),
('sed', '26', 'node', '4.94583'),
('sed', '27', 'node', '3'),
('sed', '28', 'node', '9.41114'),
('sed', '29', 'node', '5.89549'),
('sed', '30', 'node', '4.93427'),
('sed', '31', 'node', '4.89923'),
('sed', '32', 'node', '9.94804'),
('sed', '33', 'node', '7.94991'),
('sed', '34', 'node', '4.95723'),
('sed', '35', 'node', '9.95636'),
('sed', '36', 'node', '5.76682'),
('sed', '37', 'node', '4.93427'),
('sed', '38', 'node', '12.4339'),
('sed', '39', 'node', '5.7623'),
('sed', '40', 'node', '12.4288'),
('sed', '41', 'node', '20.5527'),
('sed', '42', 'node', '1'),
('sed', '43', 'node', '1'),
('sed', '45', 'node', '28'),
('sed', '46', 'node', '27'),
('sed', '47', 'node', '4'),
('sed', '50', 'node', '1'),
('sed', '51', 'node', '4'),
('sed', '52', 'node', '5'),
('sed', '53', 'node', '5'),
('sed', '54', 'node', '5'),
('sed', '55', 'node', '31'),
('sed', '56', 'node', '5'),
('sed', '57', 'node', '5'),
('sed', '58', 'node', '5'),
('sed', '65', 'node', '20.5738'),
('sed', '67', 'node', '2.8881'),
('sed', '68', 'node', '13.9347'),
('sed', '69', 'node', '14.9729'),
('sed', '71', 'node', '11.6533'),
('sed', '73', 'node', '17.9946'),
('sed', '76', 'node', '11.3291'),
('sed', '77', 'node', '12.3278'),
('sed', '78', 'node', '7.87679'),
('sed', '79', 'node', '16.0763'),
('sed', '82', 'node', '5'),
('sed', '83', 'node', '18'),
('sed', '84', 'node', '18'),
('sed', '85', 'node', '17.9946'),
('sed', '86', 'node', '43.9946'),
('sed', '87', 'node', '18'),
('sed', '88', 'node', '17.9946'),
('sed', '89', 'node', '17.9946'),
('seller', '68', 'node', '0.869951'),
('sem', '12', 'node', '4.16673'),
('sem', '13', 'node', '3'),
('sem', '14', 'node', '6.3364'),
('sem', '15', 'node', '5.5632'),
('sem', '16', 'node', '5.47248'),
('sem', '18', 'node', '1'),
('sem', '20', 'node', '4.66963'),
('sem', '21', 'node', '2.94583'),
('sem', '22', 'node', '1'),
('sem', '23', 'node', '2.94583'),
('sem', '24', 'node', '3.7262'),
('sem', '25', 'node', '4'),
('sem', '26', 'node', '5.93485'),
('sem', '27', 'node', '2'),
('sem', '28', 'node', '3.7312'),
('sem', '29', 'node', '2.97286'),
('sem', '30', 'node', '1.9347'),
('sem', '31', 'node', '1.98087'),
('sem', '32', 'node', '3'),
('sem', '34', 'node', '3.9496'),
('sem', '35', 'node', '3'),
('sem', '36', 'node', '4.58402'),
('sem', '37', 'node', '1.90629'),
('sem', '38', 'node', '4.76981'),
('sem', '39', 'node', '1.90471'),
('sem', '40', 'node', '2.74636'),
('sem', '41', 'node', '5.63775'),
('sem', '42', 'node', '2'),
('sem', '45', 'node', '1'),
('sem', '46', 'node', '26'),
('sem', '47', 'node', '1'),
('sem', '51', 'node', '1'),
('sem', '52', 'node', '4'),
('sem', '53', 'node', '4'),
('sem', '54', 'node', '4'),
('sem', '55', 'node', '4'),
('sem', '56', 'node', '4'),
('sem', '57', 'node', '4'),
('sem', '58', 'node', '4'),
('sem', '65', 'node', '3.89178'),
('sem', '67', 'node', '2'),
('sem', '68', 'node', '11'),
('sem', '69', 'node', '11'),
('sem', '71', 'node', '10.0841'),
('sem', '73', 'node', '4.99731'),
('sem', '76', 'node', '2'),
('sem', '77', 'node', '1.94209'),
('sem', '78', 'node', '2.95723'),
('sem', '79', 'node', '0.920273'),
('sem', '82', 'node', '4'),
('sem', '83', 'node', '5'),
('sem', '84', 'node', '5'),
('sem', '85', 'node', '4.99731'),
('sem', '86', 'node', '4.99731'),
('sem', '87', 'node', '5'),
('sem', '88', 'node', '4.99731'),
('sem', '89', 'node', '4.99731'),
('semper', '12', 'node', '5.90828'),
('semper', '13', 'node', '1'),
('semper', '14', 'node', '3.93078'),
('semper', '15', 'node', '3.98493'),
('semper', '16', 'node', '3.79807'),
('semper', '21', 'node', '0.96498'),
('semper', '22', 'node', '3.76458'),
('semper', '23', 'node', '0.96498'),
('semper', '25', 'node', '1'),
('semper', '26', 'node', '0.997306'),
('semper', '27', 'node', '2'),
('semper', '28', 'node', '2.90974'),
('semper', '29', 'node', '1.88852'),
('semper', '30', 'node', '2'),
('semper', '31', 'node', '1'),
('semper', '32', 'node', '2'),
('semper', '33', 'node', '0.96498'),
('semper', '34', 'node', '1.92743'),
('semper', '35', 'node', '13'),
('semper', '36', 'node', '23.5836'),
('semper', '37', 'node', '2'),
('semper', '38', 'node', '2.92384'),
('semper', '39', 'node', '2.87057'),
('semper', '40', 'node', '2.76322'),
('semper', '41', 'node', '5.42836'),
('semper', '42', 'node', '1'),
('semper', '46', 'node', '1'),
('semper', '50', 'node', '1'),
('semper', '65', 'node', '5'),
('semper', '67', 'node', '0.942091'),
('semper', '71', 'node', '1.85968'),
('semper', '73', 'node', '0.993146'),
('semper', '76', 'node', '1.89272'),
('semper', '77', 'node', '6.74994'),
('semper', '78', 'node', '1.94209'),
('semper', '79', 'node', '1.72878'),
('semper', '83', 'node', '1'),
('semper', '84', 'node', '1'),
('semper', '85', 'node', '0.993146'),
('semper', '86', 'node', '0.993146'),
('semper', '87', 'node', '0.997306'),
('semper', '88', 'node', '0.993146'),
('semper', '89', 'node', '0.993146'),
('senectus', '12', 'node', '0.794753'),
('senectus', '14', 'node', '1.58787'),
('senectus', '15', 'node', '2'),
('senectus', '16', 'node', '28.9007'),
('senectus', '17', 'node', '1'),
('senectus', '28', 'node', '1'),
('senectus', '30', 'node', '1'),
('senectus', '37', 'node', '1'),
('senectus', '38', 'node', '1.9185'),
('senectus', '40', 'node', '9.07391'),
('senectus', '41', 'node', '1'),
('senectus', '77', 'node', '0.886095'),
('senectus', '79', 'node', '1'),
('sit', '12', 'node', '63.5435'),
('sit', '13', 'node', '9.77264'),
('sit', '14', 'node', '38.8746'),
('sit', '15', 'node', '9.70706'),
('sit', '16', 'node', '9.47636'),
('sit', '17', 'node', '4.80814'),
('sit', '18', 'node', '4'),
('sit', '19', 'node', '4'),
('sit', '20', 'node', '9.72233'),
('sit', '21', 'node', '32.7738'),
('sit', '22', 'node', '4.93105'),
('sit', '23', 'node', '6.7738'),
('sit', '24', 'node', '4.80914'),
('sit', '25', 'node', '6.88076'),
('sit', '26', 'node', '4.79555');
INSERT INTO `search_index` VALUES
('sit', '27', 'node', '3'),
('sit', '28', 'node', '4.79568'),
('sit', '29', 'node', '4.89593'),
('sit', '30', 'node', '3'),
('sit', '31', 'node', '10.8029'),
('sit', '32', 'node', '5.99315'),
('sit', '33', 'node', '1'),
('sit', '34', 'node', '34.7727'),
('sit', '35', 'node', '5.99731'),
('sit', '36', 'node', '29.7826'),
('sit', '37', 'node', '15.8072'),
('sit', '38', 'node', '9.44927'),
('sit', '39', 'node', '9.7264'),
('sit', '40', 'node', '21.0425'),
('sit', '41', 'node', '19.7635'),
('sit', '42', 'node', '27'),
('sit', '43', 'node', '28'),
('sit', '45', 'node', '28'),
('sit', '47', 'node', '3'),
('sit', '50', 'node', '5.96109'),
('sit', '51', 'node', '3.97685'),
('sit', '52', 'node', '30'),
('sit', '53', 'node', '4'),
('sit', '54', 'node', '4'),
('sit', '55', 'node', '4'),
('sit', '56', 'node', '4'),
('sit', '57', 'node', '4'),
('sit', '58', 'node', '4'),
('sit', '65', 'node', '7.5843'),
('sit', '67', 'node', '2.99315'),
('sit', '68', 'node', '6.64532'),
('sit', '69', 'node', '5'),
('sit', '71', 'node', '5'),
('sit', '73', 'node', '5.99461'),
('sit', '76', 'node', '6.47531'),
('sit', '77', 'node', '6.68556'),
('sit', '78', 'node', '3.94209'),
('sit', '79', 'node', '7.84232'),
('sit', '82', 'node', '30'),
('sit', '83', 'node', '6'),
('sit', '84', 'node', '32'),
('sit', '85', 'node', '5.99461'),
('sit', '86', 'node', '5.99461'),
('sit', '87', 'node', '6'),
('sit', '88', 'node', '5.99461'),
('sit', '89', 'node', '5.99461'),
('smith', '88', 'node', '26'),
('sociis', '14', 'node', '0.886095'),
('sociis', '16', 'node', '23.391'),
('sociis', '22', 'node', '0.863659'),
('sociis', '34', 'node', '1'),
('sociis', '39', 'node', '0.96498'),
('sociis', '40', 'node', '1'),
('sociis', '50', 'node', '1'),
('sociis', '76', 'node', '0.938382'),
('sociosqu', '12', 'node', '1.77823'),
('sociosqu', '14', 'node', '0.76431'),
('sociosqu', '15', 'node', '0.949597'),
('sociosqu', '16', 'node', '0.810915'),
('sociosqu', '20', 'node', '0.920273'),
('sociosqu', '22', 'node', '0.899454'),
('sociosqu', '24', 'node', '1'),
('sociosqu', '33', 'node', '1'),
('sociosqu', '36', 'node', '1.96229'),
('sociosqu', '41', 'node', '0.816452'),
('sociosqu', '50', 'node', '0.993146'),
('sociosqu', '51', 'node', '1'),
('sociosqu', '65', 'node', '2'),
('sociosqu', '68', 'node', '1'),
('sociosqu', '69', 'node', '1'),
('sociosqu', '73', 'node', '0.945829'),
('sociosqu', '79', 'node', '0.876337'),
('sociosqu', '83', 'node', '0.953396'),
('sociosqu', '84', 'node', '0.953396'),
('sociosqu', '85', 'node', '0.945829'),
('sociosqu', '86', 'node', '0.945829'),
('sociosqu', '87', 'node', '0.949597'),
('sociosqu', '88', 'node', '0.945829'),
('sociosqu', '89', 'node', '0.945829'),
('sodales', '12', 'node', '1.78178'),
('sodales', '13', 'node', '1.90974'),
('sodales', '14', 'node', '1.51949'),
('sodales', '16', 'node', '0.78951'),
('sodales', '17', 'node', '0.934703'),
('sodales', '18', 'node', '3'),
('sodales', '19', 'node', '1'),
('sodales', '20', 'node', '0.934703'),
('sodales', '22', 'node', '0.873132'),
('sodales', '24', 'node', '3.79168'),
('sodales', '25', 'node', '1.9534'),
('sodales', '26', 'node', '4'),
('sodales', '28', 'node', '1.94209'),
('sodales', '30', 'node', '1.92785'),
('sodales', '31', 'node', '1.97286'),
('sodales', '33', 'node', '3.96498'),
('sodales', '34', 'node', '1'),
('sodales', '36', 'node', '1.76534'),
('sodales', '37', 'node', '2.85283'),
('sodales', '39', 'node', '1'),
('sodales', '40', 'node', '1.92027'),
('sodales', '41', 'node', '3.70001'),
('sodales', '42', 'node', '1'),
('sodales', '43', 'node', '1'),
('sodales', '47', 'node', '2'),
('sodales', '52', 'node', '2'),
('sodales', '53', 'node', '2'),
('sodales', '54', 'node', '2'),
('sodales', '55', 'node', '2'),
('sodales', '56', 'node', '2'),
('sodales', '57', 'node', '2'),
('sodales', '58', 'node', '2'),
('sodales', '65', 'node', '3.59781'),
('sodales', '67', 'node', '0.957226'),
('sodales', '68', 'node', '1'),
('sodales', '69', 'node', '1'),
('sodales', '71', 'node', '5.9496'),
('sodales', '73', 'node', '2'),
('sodales', '77', 'node', '3'),
('sodales', '78', 'node', '4'),
('sodales', '79', 'node', '1'),
('sodales', '82', 'node', '2'),
('sodales', '83', 'node', '2'),
('sodales', '84', 'node', '2'),
('sodales', '85', 'node', '2'),
('sodales', '86', 'node', '2'),
('sodales', '87', 'node', '2'),
('sodales', '88', 'node', '2'),
('sodales', '89', 'node', '2'),
('sollicit', '31', 'node', '26'),
('sollicitudin', '12', 'node', '0.779231'),
('sollicitudin', '14', 'node', '3.30836'),
('sollicitudin', '15', 'node', '1'),
('sollicitudin', '16', 'node', '0.942091'),
('sollicitudin', '18', 'node', '2'),
('sollicitudin', '21', 'node', '1'),
('sollicitudin', '22', 'node', '0.923838'),
('sollicitudin', '23', 'node', '1'),
('sollicitudin', '25', 'node', '1'),
('sollicitudin', '26', 'node', '0.98493'),
('sollicitudin', '28', 'node', '0.957226'),
('sollicitudin', '29', 'node', '1'),
('sollicitudin', '30', 'node', '0.949597'),
('sollicitudin', '31', 'node', '3.97286'),
('sollicitudin', '33', 'node', '0.993146'),
('sollicitudin', '34', 'node', '1'),
('sollicitudin', '36', 'node', '2.90629'),
('sollicitudin', '37', 'node', '1'),
('sollicitudin', '38', 'node', '5.8867'),
('sollicitudin', '39', 'node', '1'),
('sollicitudin', '40', 'node', '1.85498'),
('sollicitudin', '41', 'node', '1'),
('sollicitudin', '42', 'node', '1'),
('sollicitudin', '45', 'node', '1'),
('sollicitudin', '50', 'node', '1.92027'),
('sollicitudin', '67', 'node', '4'),
('sollicitudin', '68', 'node', '5.47181'),
('sollicitudin', '69', 'node', '0.980874'),
('sollicitudin', '71', 'node', '2'),
('sollicitudin', '76', 'node', '0.863659'),
('sollicitudin', '77', 'node', '1.8477'),
('sollicitudin', '78', 'node', '2.91445'),
('sollicitudin', '79', 'node', '1.84869'),
('style', '50', 'node', '26'),
('submitted', '12', 'node', '2.48341'),
('submitted', '13', 'node', '0.968904'),
('submitted', '14', 'node', '3.95985'),
('submitted', '16', 'node', '1.77419'),
('submitted', '36', 'node', '2.54286'),
('submitted', '41', 'node', '0.863659'),
('super', '11', 'node', '1'),
('support', '71', 'node', '0.902857'),
('suscipit', '13', 'node', '1.92058'),
('suscipit', '14', 'node', '0.916736'),
('suscipit', '16', 'node', '1'),
('suscipit', '17', 'node', '0.931053'),
('suscipit', '18', 'node', '1'),
('suscipit', '19', 'node', '2'),
('suscipit', '20', 'node', '1'),
('suscipit', '21', 'node', '0.989021'),
('suscipit', '22', 'node', '1.77191'),
('suscipit', '23', 'node', '0.98493'),
('suscipit', '24', 'node', '0.98493'),
('suscipit', '25', 'node', '1.9079'),
('suscipit', '26', 'node', '1.89608'),
('suscipit', '27', 'node', '1'),
('suscipit', '28', 'node', '1.90629'),
('suscipit', '29', 'node', '1.92384'),
('suscipit', '30', 'node', '1'),
('suscipit', '33', 'node', '2.95723'),
('suscipit', '34', 'node', '1'),
('suscipit', '36', 'node', '3.75091'),
('suscipit', '37', 'node', '1'),
('suscipit', '38', 'node', '2.94209'),
('suscipit', '40', 'node', '1.95723'),
('suscipit', '47', 'node', '2.99731'),
('suscipit', '50', 'node', '2'),
('suscipit', '51', 'node', '1'),
('suscipit', '52', 'node', '11'),
('suscipit', '53', 'node', '37'),
('suscipit', '54', 'node', '11'),
('suscipit', '55', 'node', '11'),
('suscipit', '56', 'node', '11'),
('suscipit', '57', 'node', '11'),
('suscipit', '58', 'node', '11'),
('suscipit', '65', 'node', '1'),
('suscipit', '67', 'node', '1.9689'),
('suscipit', '68', 'node', '1.88282'),
('suscipit', '69', 'node', '0.945829'),
('suscipit', '71', 'node', '6.82561'),
('suscipit', '73', 'node', '11'),
('suscipit', '76', 'node', '1.96109'),
('suscipit', '77', 'node', '1.97685'),
('suscipit', '78', 'node', '2'),
('suscipit', '79', 'node', '1.96498'),
('suscipit', '82', 'node', '11'),
('suscipit', '83', 'node', '11'),
('suscipit', '84', 'node', '11'),
('suscipit', '85', 'node', '11'),
('suscipit', '86', 'node', '11'),
('suscipit', '87', 'node', '11'),
('suscipit', '88', 'node', '11'),
('suscipit', '89', 'node', '11'),
('suspendisse', '12', 'node', '22.8838'),
('suspendisse', '13', 'node', '0.923838'),
('suspendisse', '14', 'node', '2.54838'),
('suspendisse', '15', 'node', '27.87'),
('suspendisse', '16', 'node', '27.4496'),
('suspendisse', '17', 'node', '1'),
('suspendisse', '19', 'node', '1.9534'),
('suspendisse', '20', 'node', '29'),
('suspendisse', '22', 'node', '2.73692'),
('suspendisse', '24', 'node', '2.8056'),
('suspendisse', '25', 'node', '29.9311'),
('suspendisse', '26', 'node', '4.98902'),
('suspendisse', '27', 'node', '4'),
('suspendisse', '28', 'node', '30.8995'),
('suspendisse', '29', 'node', '3.83431'),
('suspendisse', '30', 'node', '4'),
('suspendisse', '31', 'node', '1'),
('suspendisse', '32', 'node', '2'),
('suspendisse', '33', 'node', '2'),
('suspendisse', '34', 'node', '1'),
('suspendisse', '35', 'node', '2'),
('suspendisse', '36', 'node', '23.6168'),
('suspendisse', '38', 'node', '2'),
('suspendisse', '40', 'node', '1.97286'),
('suspendisse', '41', 'node', '3.66789'),
('suspendisse', '42', 'node', '1'),
('suspendisse', '44', 'node', '1'),
('suspendisse', '50', 'node', '1'),
('suspendisse', '65', 'node', '2'),
('suspendisse', '67', 'node', '5.87326'),
('suspendisse', '68', 'node', '4.54438'),
('suspendisse', '69', 'node', '0.953396'),
('suspendisse', '71', 'node', '0.913226'),
('suspendisse', '73', 'node', '0.913226'),
('suspendisse', '76', 'node', '1'),
('suspendisse', '77', 'node', '2'),
('suspendisse', '78', 'node', '0.993146'),
('suspendisse', '79', 'node', '1.8861'),
('suspendisse', '83', 'node', '0.920273'),
('suspendisse', '84', 'node', '0.920273'),
('suspendisse', '85', 'node', '0.913226'),
('suspendisse', '86', 'node', '0.913226'),
('suspendisse', '87', 'node', '0.916736'),
('suspendisse', '88', 'node', '0.913226'),
('suspendisse', '89', 'node', '0.913226'),
('taciti', '12', 'node', '1.78182'),
('taciti', '14', 'node', '0.766757'),
('taciti', '15', 'node', '0.953396'),
('taciti', '16', 'node', '0.813674'),
('taciti', '20', 'node', '0.923838'),
('taciti', '22', 'node', '0.902857'),
('taciti', '24', 'node', '1'),
('taciti', '33', 'node', '1'),
('taciti', '36', 'node', '1.96498'),
('taciti', '41', 'node', '0.819249'),
('taciti', '50', 'node', '0.997306'),
('taciti', '51', 'node', '1'),
('taciti', '65', 'node', '2'),
('taciti', '68', 'node', '1'),
('taciti', '69', 'node', '1'),
('taciti', '73', 'node', '0.949597'),
('taciti', '79', 'node', '0.879565'),
('taciti', '83', 'node', '0.957226'),
('taciti', '84', 'node', '0.957226'),
('taciti', '85', 'node', '0.949597'),
('taciti', '86', 'node', '0.949597'),
('taciti', '87', 'node', '0.953396'),
('taciti', '88', 'node', '0.949597'),
('taciti', '89', 'node', '0.949597'),
('team', '77', 'node', '26'),
('tellus', '12', 'node', '4.4319'),
('tellus', '13', 'node', '3'),
('tellus', '14', 'node', '47.4127'),
('tellus', '15', 'node', '2.86366'),
('tellus', '16', 'node', '3.82166'),
('tellus', '18', 'node', '2.94978'),
('tellus', '19', 'node', '1.96109'),
('tellus', '20', 'node', '1.94209'),
('tellus', '21', 'node', '1'),
('tellus', '22', 'node', '2.7536'),
('tellus', '23', 'node', '1'),
('tellus', '24', 'node', '2.97685'),
('tellus', '25', 'node', '1'),
('tellus', '26', 'node', '1.94583'),
('tellus', '31', 'node', '0.949597'),
('tellus', '32', 'node', '0.993146'),
('tellus', '33', 'node', '1.99731'),
('tellus', '34', 'node', '1'),
('tellus', '35', 'node', '0.997306'),
('tellus', '36', 'node', '0.916736'),
('tellus', '37', 'node', '13.6929'),
('tellus', '38', 'node', '12.6576'),
('tellus', '39', 'node', '1.90576'),
('tellus', '40', 'node', '28.3283'),
('tellus', '41', 'node', '20.1585'),
('tellus', '43', 'node', '1'),
('tellus', '44', 'node', '2'),
('tellus', '46', 'node', '1'),
('tellus', '47', 'node', '2'),
('tellus', '50', 'node', '1.9347'),
('tellus', '52', 'node', '2'),
('tellus', '53', 'node', '2'),
('tellus', '54', 'node', '2'),
('tellus', '55', 'node', '2'),
('tellus', '56', 'node', '2'),
('tellus', '57', 'node', '2'),
('tellus', '58', 'node', '2'),
('tellus', '65', 'node', '10.7562'),
('tellus', '67', 'node', '10.2416'),
('tellus', '68', 'node', '15.8136'),
('tellus', '69', 'node', '12'),
('tellus', '71', 'node', '15.6811'),
('tellus', '73', 'node', '2'),
('tellus', '77', 'node', '1.89272'),
('tellus', '78', 'node', '0.98493'),
('tellus', '79', 'node', '1'),
('tellus', '82', 'node', '2'),
('tellus', '83', 'node', '2'),
('tellus', '84', 'node', '2'),
('tellus', '85', 'node', '2'),
('tellus', '86', 'node', '2'),
('tellus', '87', 'node', '2'),
('tellus', '88', 'node', '2'),
('tellus', '89', 'node', '2'),
('tempor', '13', 'node', '2.8896'),
('tempor', '14', 'node', '5.94832'),
('tempor', '16', 'node', '1.73298'),
('tempor', '20', 'node', '1.90318'),
('tempor', '21', 'node', '1'),
('tempor', '22', 'node', '1.92027'),
('tempor', '23', 'node', '1'),
('tempor', '25', 'node', '27.989'),
('tempor', '26', 'node', '1.90629'),
('tempor', '27', 'node', '2'),
('tempor', '28', 'node', '1.8894'),
('tempor', '29', 'node', '2.97685'),
('tempor', '30', 'node', '1'),
('tempor', '31', 'node', '3.98087'),
('tempor', '32', 'node', '1'),
('tempor', '33', 'node', '2'),
('tempor', '34', 'node', '1'),
('tempor', '35', 'node', '1'),
('tempor', '36', 'node', '3.71804'),
('tempor', '38', 'node', '1'),
('tempor', '39', 'node', '3.86957'),
('tempor', '40', 'node', '0.848323'),
('tempor', '44', 'node', '1'),
('tempor', '46', 'node', '26'),
('tempor', '51', 'node', '1'),
('tempor', '65', 'node', '0.997306'),
('tempor', '69', 'node', '1'),
('tempor', '71', 'node', '3.69535'),
('tempor', '76', 'node', '3.73998'),
('tempor', '77', 'node', '2.99315'),
('tempor', '78', 'node', '1'),
('tempor', '79', 'node', '1.89608'),
('tempus', '12', 'node', '2.38998'),
('tempus', '13', 'node', '1.9347'),
('tempus', '14', 'node', '6.61014'),
('tempus', '15', 'node', '4'),
('tempus', '16', 'node', '5.72011'),
('tempus', '17', 'node', '3.9347'),
('tempus', '18', 'node', '2'),
('tempus', '19', 'node', '1.97286'),
('tempus', '20', 'node', '2.94209'),
('tempus', '21', 'node', '1'),
('tempus', '22', 'node', '0.920273'),
('tempus', '23', 'node', '1'),
('tempus', '24', 'node', '2.77889'),
('tempus', '25', 'node', '3.96109'),
('tempus', '26', 'node', '2.96109'),
('tempus', '27', 'node', '2'),
('tempus', '28', 'node', '2'),
('tempus', '29', 'node', '1.9534'),
('tempus', '30', 'node', '28'),
('tempus', '31', 'node', '2.94583'),
('tempus', '32', 'node', '2'),
('tempus', '33', 'node', '2'),
('tempus', '34', 'node', '1'),
('tempus', '35', 'node', '2'),
('tempus', '36', 'node', '3.75318'),
('tempus', '37', 'node', '2.74319'),
('tempus', '38', 'node', '1.84417'),
('tempus', '39', 'node', '1'),
('tempus', '40', 'node', '3.83481'),
('tempus', '41', 'node', '0.827757'),
('tempus', '45', 'node', '1'),
('tempus', '47', 'node', '1'),
('tempus', '50', 'node', '0.957226'),
('tempus', '51', 'node', '1'),
('tempus', '52', 'node', '1'),
('tempus', '53', 'node', '1'),
('tempus', '54', 'node', '1'),
('tempus', '55', 'node', '1'),
('tempus', '56', 'node', '1'),
('tempus', '57', 'node', '1'),
('tempus', '58', 'node', '1'),
('tempus', '65', 'node', '1'),
('tempus', '67', 'node', '1.99315'),
('tempus', '68', 'node', '0.879565'),
('tempus', '69', 'node', '3'),
('tempus', '73', 'node', '1.96498'),
('tempus', '76', 'node', '4.94654'),
('tempus', '77', 'node', '1.80574'),
('tempus', '79', 'node', '1'),
('tempus', '82', 'node', '1'),
('tempus', '83', 'node', '1.97286'),
('tempus', '84', 'node', '1.97286'),
('tempus', '85', 'node', '1.96498'),
('tempus', '86', 'node', '1.96498'),
('tempus', '87', 'node', '1.9689'),
('tempus', '88', 'node', '1.96498'),
('tempus', '89', 'node', '1.96498'),
('think', '11', 'node', '26'),
('tincidunt', '12', 'node', '7.00434'),
('tincidunt', '13', 'node', '2.94209'),
('tincidunt', '14', 'node', '4.43507'),
('tincidunt', '15', 'node', '3.80309'),
('tincidunt', '16', 'node', '4.42698'),
('tincidunt', '17', 'node', '2.92743'),
('tincidunt', '18', 'node', '2.98087'),
('tincidunt', '19', 'node', '3'),
('tincidunt', '20', 'node', '3.88421'),
('tincidunt', '21', 'node', '6.8414'),
('tincidunt', '22', 'node', '4.83353'),
('tincidunt', '23', 'node', '6.8414'),
('tincidunt', '25', 'node', '3.95839'),
('tincidunt', '26', 'node', '2.84768'),
('tincidunt', '28', 'node', '2.69249'),
('tincidunt', '31', 'node', '0.938382'),
('tincidunt', '32', 'node', '3'),
('tincidunt', '34', 'node', '3'),
('tincidunt', '35', 'node', '3'),
('tincidunt', '36', 'node', '5.85716'),
('tincidunt', '37', 'node', '16.7587'),
('tincidunt', '38', 'node', '15.6895'),
('tincidunt', '39', 'node', '2.94572'),
('tincidunt', '40', 'node', '21.8818'),
('tincidunt', '41', 'node', '4.61421'),
('tincidunt', '47', 'node', '0.997306'),
('tincidunt', '50', 'node', '4'),
('tincidunt', '51', 'node', '1'),
('tincidunt', '52', 'node', '17'),
('tincidunt', '53', 'node', '17'),
('tincidunt', '54', 'node', '17'),
('tincidunt', '55', 'node', '17'),
('tincidunt', '56', 'node', '17'),
('tincidunt', '57', 'node', '17'),
('tincidunt', '58', 'node', '17'),
('tincidunt', '65', 'node', '4.92246'),
('tincidunt', '67', 'node', '2.94654'),
('tincidunt', '68', 'node', '2.88852'),
('tincidunt', '69', 'node', '1.94583'),
('tincidunt', '71', 'node', '14.3101'),
('tincidunt', '73', 'node', '18.9822'),
('tincidunt', '76', 'node', '2.96205'),
('tincidunt', '77', 'node', '2'),
('tincidunt', '78', 'node', '1'),
('tincidunt', '79', 'node', '3.46424'),
('tincidunt', '82', 'node', '17'),
('tincidunt', '83', 'node', '18.9931'),
('tincidunt', '84', 'node', '18.9931'),
('tincidunt', '85', 'node', '18.9822'),
('tincidunt', '86', 'node', '18.9822'),
('tincidunt', '87', 'node', '18.989'),
('tincidunt', '88', 'node', '18.9822'),
('tincidunt', '89', 'node', '18.9822'),
('torquent', '12', 'node', '1.77113'),
('torquent', '14', 'node', '0.759465'),
('torquent', '15', 'node', '0.942091'),
('torquent', '16', 'node', '0.805455'),
('torquent', '20', 'node', '0.913226'),
('torquent', '22', 'node', '0.892724'),
('torquent', '24', 'node', '1'),
('torquent', '33', 'node', '1'),
('torquent', '36', 'node', '1.954'),
('torquent', '41', 'node', '0.810915'),
('torquent', '50', 'node', '0.98493'),
('torquent', '51', 'node', '1'),
('torquent', '65', 'node', '2'),
('torquent', '68', 'node', '1'),
('torquent', '69', 'node', '1'),
('torquent', '73', 'node', '0.938382'),
('torquent', '79', 'node', '0.869951'),
('torquent', '83', 'node', '0.945829'),
('torquent', '84', 'node', '0.945829'),
('torquent', '85', 'node', '0.938382'),
('torquent', '86', 'node', '0.938382'),
('torquent', '87', 'node', '0.942091'),
('torquent', '88', 'node', '0.938382'),
('torquent', '89', 'node', '0.938382'),
('tortor', '12', 'node', '26.5504'),
('tortor', '13', 'node', '0.997306'),
('tortor', '14', 'node', '9.38227'),
('tortor', '15', 'node', '2.88174'),
('tortor', '16', 'node', '1.87271'),
('tortor', '17', 'node', '2'),
('tortor', '19', 'node', '1'),
('tortor', '20', 'node', '1.77554'),
('tortor', '21', 'node', '2.94583'),
('tortor', '22', 'node', '4.74546'),
('tortor', '23', 'node', '2.94583'),
('tortor', '24', 'node', '2.83621'),
('tortor', '25', 'node', '6'),
('tortor', '26', 'node', '6.80481'),
('tortor', '28', 'node', '1'),
('tortor', '30', 'node', '1'),
('tortor', '31', 'node', '1'),
('tortor', '33', 'node', '1'),
('tortor', '34', 'node', '1'),
('tortor', '36', 'node', '5.40734'),
('tortor', '37', 'node', '3'),
('tortor', '38', 'node', '2.86211'),
('tortor', '40', 'node', '1.84832'),
('tortor', '41', 'node', '5.26277'),
('tortor', '42', 'node', '1'),
('tortor', '43', 'node', '1'),
('tortor', '44', 'node', '1'),
('tortor', '45', 'node', '1'),
('tortor', '46', 'node', '1'),
('tortor', '47', 'node', '0.98493'),
('tortor', '50', 'node', '3'),
('tortor', '52', 'node', '1'),
('tortor', '53', 'node', '1'),
('tortor', '54', 'node', '1'),
('tortor', '55', 'node', '1'),
('tortor', '56', 'node', '1'),
('tortor', '57', 'node', '1'),
('tortor', '58', 'node', '1'),
('tortor', '65', 'node', '3.99731'),
('tortor', '67', 'node', '3.89144'),
('tortor', '68', 'node', '2'),
('tortor', '69', 'node', '1.9689'),
('tortor', '71', 'node', '0.968904'),
('tortor', '73', 'node', '3.97416'),
('tortor', '76', 'node', '2'),
('tortor', '77', 'node', '1.87313'),
('tortor', '78', 'node', '3.93838'),
('tortor', '79', 'node', '14.1063'),
('tortor', '82', 'node', '1'),
('tortor', '83', 'node', '3.98493'),
('tortor', '84', 'node', '3.98493'),
('tortor', '85', 'node', '3.97416'),
('tortor', '86', 'node', '3.97416'),
('tortor', '87', 'node', '3.98087'),
('tortor', '88', 'node', '3.97416'),
('tortor', '89', 'node', '3.97416'),
('total', '11', 'node', '1'),
('tristique', '12', 'node', '4.19258'),
('tristique', '13', 'node', '1.91323'),
('tristique', '14', 'node', '4.48602'),
('tristique', '15', 'node', '5'),
('tristique', '16', 'node', '33.8618'),
('tristique', '17', 'node', '1.98087'),
('tristique', '18', 'node', '2'),
('tristique', '19', 'node', '1'),
('tristique', '20', 'node', '1.8894'),
('tristique', '21', 'node', '2.98493'),
('tristique', '22', 'node', '0.961087'),
('tristique', '23', 'node', '2.98087'),
('tristique', '25', 'node', '1'),
('tristique', '26', 'node', '0.953396'),
('tristique', '27', 'node', '2'),
('tristique', '28', 'node', '1'),
('tristique', '29', 'node', '2.99315'),
('tristique', '30', 'node', '1'),
('tristique', '31', 'node', '1.98902'),
('tristique', '34', 'node', '1'),
('tristique', '36', 'node', '1'),
('tristique', '37', 'node', '3'),
('tristique', '38', 'node', '2.9185'),
('tristique', '40', 'node', '9.9133'),
('tristique', '41', 'node', '5.61305'),
('tristique', '42', 'node', '1'),
('tristique', '47', 'node', '2'),
('tristique', '50', 'node', '2.95723'),
('tristique', '51', 'node', '2.97685'),
('tristique', '52', 'node', '2'),
('tristique', '53', 'node', '2'),
('tristique', '54', 'node', '2'),
('tristique', '55', 'node', '2'),
('tristique', '56', 'node', '2'),
('tristique', '57', 'node', '2'),
('tristique', '58', 'node', '2'),
('tristique', '67', 'node', '3.93025'),
('tristique', '68', 'node', '1.8439'),
('tristique', '73', 'node', '2'),
('tristique', '76', 'node', '0.968904'),
('tristique', '77', 'node', '1.83949'),
('tristique', '78', 'node', '1'),
('tristique', '79', 'node', '3.80582'),
('tristique', '82', 'node', '2'),
('tristique', '83', 'node', '2'),
('tristique', '84', 'node', '2'),
('tristique', '85', 'node', '2'),
('tristique', '86', 'node', '2'),
('tristique', '87', 'node', '2'),
('tristique', '88', 'node', '2'),
('tristique', '89', 'node', '2'),
('tue', '36', 'node', '2.53657'),
('turpis', '12', 'node', '4.21083'),
('turpis', '13', 'node', '2'),
('turpis', '14', 'node', '5.07603'),
('turpis', '15', 'node', '3.86995'),
('turpis', '16', 'node', '6.65016'),
('turpis', '17', 'node', '1'),
('turpis', '19', 'node', '1'),
('turpis', '20', 'node', '2.88792'),
('turpis', '21', 'node', '8.88418'),
('turpis', '22', 'node', '4.99315'),
('turpis', '23', 'node', '8.88418'),
('turpis', '24', 'node', '1'),
('turpis', '25', 'node', '1.9469'),
('turpis', '26', 'node', '0.909743'),
('turpis', '27', 'node', '2'),
('turpis', '28', 'node', '3.80505'),
('turpis', '29', 'node', '1.99731'),
('turpis', '30', 'node', '1.98087'),
('turpis', '31', 'node', '1'),
('turpis', '32', 'node', '3.97402'),
('turpis', '33', 'node', '4.99731'),
('turpis', '34', 'node', '2.9534'),
('turpis', '35', 'node', '3.98224'),
('turpis', '36', 'node', '2.67308'),
('turpis', '37', 'node', '3'),
('turpis', '38', 'node', '4.80585'),
('turpis', '39', 'node', '2.8834'),
('turpis', '40', 'node', '1.79041'),
('turpis', '41', 'node', '4.81547'),
('turpis', '43', 'node', '2'),
('turpis', '45', 'node', '2'),
('turpis', '50', 'node', '2.96109'),
('turpis', '65', 'node', '0.976851'),
('turpis', '67', 'node', '2.92743'),
('turpis', '68', 'node', '1.84662'),
('turpis', '71', 'node', '5.55626'),
('turpis', '76', 'node', '1.9689'),
('turpis', '77', 'node', '11.8763'),
('turpis', '78', 'node', '1'),
('turpis', '79', 'node', '6.59056'),
('ullamcorper', '13', 'node', '3'),
('ullamcorper', '14', 'node', '5.14155'),
('ullamcorper', '17', 'node', '0.927431'),
('ullamcorper', '18', 'node', '2'),
('ullamcorper', '19', 'node', '1'),
('ullamcorper', '20', 'node', '3.70775'),
('ullamcorper', '22', 'node', '2.76392'),
('ullamcorper', '24', 'node', '2.8867'),
('ullamcorper', '25', 'node', '2'),
('ullamcorper', '26', 'node', '2.97685'),
('ullamcorper', '27', 'node', '1'),
('ullamcorper', '28', 'node', '2.81949'),
('ullamcorper', '29', 'node', '1.9689'),
('ullamcorper', '30', 'node', '1'),
('ullamcorper', '32', 'node', '1'),
('ullamcorper', '34', 'node', '1'),
('ullamcorper', '35', 'node', '1'),
('ullamcorper', '36', 'node', '2.70697'),
('ullamcorper', '37', 'node', '0.961087'),
('ullamcorper', '38', 'node', '1'),
('ullamcorper', '39', 'node', '2.97286'),
('ullamcorper', '41', 'node', '0.839384'),
('ullamcorper', '44', 'node', '1'),
('ullamcorper', '45', 'node', '1'),
('ullamcorper', '50', 'node', '2'),
('ullamcorper', '51', 'node', '1.97685'),
('ullamcorper', '52', 'node', '3'),
('ullamcorper', '53', 'node', '3'),
('ullamcorper', '54', 'node', '3'),
('ullamcorper', '55', 'node', '3'),
('ullamcorper', '56', 'node', '3'),
('ullamcorper', '57', 'node', '3'),
('ullamcorper', '58', 'node', '3'),
('ullamcorper', '65', 'node', '1.93838'),
('ullamcorper', '67', 'node', '12'),
('ullamcorper', '68', 'node', '10.9669'),
('ullamcorper', '71', 'node', '1.98087'),
('ullamcorper', '73', 'node', '3.98493'),
('ullamcorper', '76', 'node', '12.7755'),
('ullamcorper', '77', 'node', '1.85183'),
('ullamcorper', '78', 'node', '1'),
('ullamcorper', '79', 'node', '1.68471'),
('ullamcorper', '82', 'node', '3'),
('ullamcorper', '83', 'node', '3.99315'),
('ullamcorper', '84', 'node', '3.99315'),
('ullamcorper', '85', 'node', '3.98493'),
('ullamcorper', '86', 'node', '3.98493'),
('ullamcorper', '87', 'node', '3.98902'),
('ullamcorper', '88', 'node', '3.98493'),
('ullamcorper', '89', 'node', '3.98493'),
('ullamcorpermoles', '38', 'node', '9.711'),
('ullamcorpermoles', '40', 'node', '9.04272'),
('ullamcorpermoles', '41', 'node', '9.56946'),
('ultrices', '12', 'node', '2.57125'),
('ultrices', '13', 'node', '1'),
('ultrices', '14', 'node', '4.45253'),
('ultrices', '16', 'node', '1'),
('ultrices', '17', 'node', '1.94209'),
('ultrices', '18', 'node', '2.97395'),
('ultrices', '21', 'node', '3.86213'),
('ultrices', '22', 'node', '3.85144'),
('ultrices', '23', 'node', '3.86213'),
('ultrices', '24', 'node', '2.88282'),
('ultrices', '25', 'node', '1.96498'),
('ultrices', '26', 'node', '1'),
('ultrices', '28', 'node', '1.90974'),
('ultrices', '29', 'node', '2'),
('ultrices', '30', 'node', '1'),
('ultrices', '31', 'node', '1.93838'),
('ultrices', '32', 'node', '1.99315'),
('ultrices', '33', 'node', '2'),
('ultrices', '34', 'node', '0.938382'),
('ultrices', '35', 'node', '1.99731'),
('ultrices', '36', 'node', '13.7277'),
('ultrices', '37', 'node', '1.94583'),
('ultrices', '38', 'node', '1.90629'),
('ultrices', '39', 'node', '2'),
('ultrices', '40', 'node', '2.74861'),
('ultrices', '41', 'node', '2.78956'),
('ultrices', '42', 'node', '2'),
('ultrices', '43', 'node', '1'),
('ultrices', '45', 'node', '1'),
('ultrices', '50', 'node', '0.923838'),
('ultrices', '51', 'node', '1.98902'),
('ultrices', '52', 'node', '1'),
('ultrices', '53', 'node', '1'),
('ultrices', '54', 'node', '1'),
('ultrices', '55', 'node', '1'),
('ultrices', '56', 'node', '1'),
('ultrices', '57', 'node', '1'),
('ultrices', '58', 'node', '1'),
('ultrices', '65', 'node', '11.7581'),
('ultrices', '67', 'node', '1'),
('ultrices', '68', 'node', '15.8914'),
('ultrices', '69', 'node', '15.6811'),
('ultrices', '71', 'node', '1.9496'),
('ultrices', '73', 'node', '1'),
('ultrices', '76', 'node', '1.9496'),
('ultrices', '77', 'node', '3.86633'),
('ultrices', '78', 'node', '4'),
('ultrices', '79', 'node', '3.78671'),
('ultrices', '82', 'node', '1'),
('ultrices', '83', 'node', '1'),
('ultrices', '84', 'node', '1'),
('ultrices', '85', 'node', '1'),
('ultrices', '86', 'node', '1'),
('ultrices', '87', 'node', '1'),
('ultrices', '88', 'node', '1'),
('ultrices', '89', 'node', '1'),
('ultricies', '12', 'node', '2.62323'),
('ultricies', '13', 'node', '2'),
('ultricies', '14', 'node', '4.69519'),
('ultricies', '15', 'node', '1.98087'),
('ultricies', '16', 'node', '2'),
('ultricies', '17', 'node', '2.82663'),
('ultricies', '18', 'node', '3'),
('ultricies', '21', 'node', '0.923838'),
('ultricies', '22', 'node', '2.801'),
('ultricies', '23', 'node', '0.923838'),
('ultricies', '24', 'node', '1'),
('ultricies', '25', 'node', '1.92384'),
('ultricies', '26', 'node', '0.949597'),
('ultricies', '27', 'node', '2'),
('ultricies', '28', 'node', '1.88282'),
('ultricies', '29', 'node', '2.95779'),
('ultricies', '30', 'node', '1'),
('ultricies', '31', 'node', '4'),
('ultricies', '32', 'node', '2'),
('ultricies', '33', 'node', '2'),
('ultricies', '34', 'node', '1'),
('ultricies', '35', 'node', '2'),
('ultricies', '36', 'node', '2'),
('ultricies', '37', 'node', '2.90629'),
('ultricies', '38', 'node', '0.916736'),
('ultricies', '40', 'node', '1.96109'),
('ultricies', '41', 'node', '0.906287'),
('ultricies', '44', 'node', '28'),
('ultricies', '47', 'node', '3'),
('ultricies', '67', 'node', '11'),
('ultricies', '68', 'node', '2.93453'),
('ultricies', '69', 'node', '1.93105'),
('ultricies', '71', 'node', '4.88609'),
('ultricies', '76', 'node', '1.96109'),
('ultricies', '77', 'node', '1.92607'),
('ultricies', '79', 'node', '0.848323'),
('unde', '86', 'node', '26'),
('urna', '12', 'node', '6.60947'),
('urna', '13', 'node', '31.0988'),
('urna', '14', 'node', '11.9495'),
('urna', '15', 'node', '1'),
('urna', '16', 'node', '1.87957'),
('urna', '17', 'node', '2.96498'),
('urna', '18', 'node', '2'),
('urna', '20', 'node', '3.72347'),
('urna', '21', 'node', '2.94583'),
('urna', '22', 'node', '5.82314'),
('urna', '23', 'node', '2.94583'),
('urna', '24', 'node', '1.95453'),
('urna', '25', 'node', '1'),
('urna', '26', 'node', '2.9347'),
('urna', '27', 'node', '1'),
('urna', '28', 'node', '2.75073'),
('urna', '29', 'node', '1'),
('urna', '30', 'node', '0.927431'),
('urna', '31', 'node', '3.9223'),
('urna', '32', 'node', '2'),
('urna', '33', 'node', '1'),
('urna', '34', 'node', '0.957226'),
('urna', '35', 'node', '2'),
('urna', '36', 'node', '2.96109'),
('urna', '37', 'node', '1.98902'),
('urna', '38', 'node', '3.76307'),
('urna', '39', 'node', '5.813'),
('urna', '40', 'node', '1'),
('urna', '41', 'node', '8.88337'),
('urna', '45', 'node', '26'),
('urna', '47', 'node', '3'),
('urna', '50', 'node', '1.96109'),
('urna', '51', 'node', '1'),
('urna', '52', 'node', '1'),
('urna', '53', 'node', '1'),
('urna', '54', 'node', '1'),
('urna', '55', 'node', '1'),
('urna', '56', 'node', '1'),
('urna', '57', 'node', '1'),
('urna', '58', 'node', '1'),
('urna', '65', 'node', '6.89945'),
('urna', '67', 'node', '3.98224'),
('urna', '68', 'node', '0.899454'),
('urna', '71', 'node', '2'),
('urna', '73', 'node', '6.90202'),
('urna', '76', 'node', '1.9496'),
('urna', '77', 'node', '4'),
('urna', '78', 'node', '1'),
('urna', '79', 'node', '1'),
('urna', '82', 'node', '1'),
('urna', '83', 'node', '6.93972'),
('urna', '84', 'node', '6.93972'),
('urna', '85', 'node', '6.90202'),
('urna', '86', 'node', '6.90202'),
('urna', '87', 'node', '6.9235'),
('urna', '88', 'node', '6.90202'),
('urna', '89', 'node', '6.90202'),
('utem', '55', 'node', '26'),
('varius', '12', 'node', '3.76119'),
('varius', '13', 'node', '2.98224'),
('varius', '14', 'node', '3.33839'),
('varius', '15', 'node', '1'),
('varius', '16', 'node', '2.83296'),
('varius', '17', 'node', '1.92743'),
('varius', '18', 'node', '2.98087'),
('varius', '19', 'node', '1'),
('varius', '20', 'node', '1.94583'),
('varius', '21', 'node', '2.86967'),
('varius', '22', 'node', '2.92743'),
('varius', '23', 'node', '2.86967'),
('varius', '24', 'node', '3.90684'),
('varius', '26', 'node', '3'),
('varius', '29', 'node', '1'),
('varius', '31', 'node', '0.976851'),
('varius', '36', 'node', '1'),
('varius', '37', 'node', '2'),
('varius', '38', 'node', '1.91674'),
('varius', '40', 'node', '2.94209'),
('varius', '41', 'node', '1'),
('varius', '44', 'node', '3'),
('varius', '47', 'node', '1'),
('varius', '50', 'node', '1'),
('varius', '53', 'node', '26'),
('varius', '65', 'node', '1.93838'),
('varius', '71', 'node', '1'),
('varius', '76', 'node', '2.88282'),
('varius', '77', 'node', '2.84905'),
('varius', '78', 'node', '1'),
('varius', '79', 'node', '0.980874'),
('vehicula', '12', 'node', '2.72584'),
('vehicula', '13', 'node', '1.97685'),
('vehicula', '14', 'node', '5.12533'),
('vehicula', '15', 'node', '0.860547'),
('vehicula', '17', 'node', '30.9729'),
('vehicula', '18', 'node', '3'),
('vehicula', '19', 'node', '0.976851'),
('vehicula', '20', 'node', '4.75573'),
('vehicula', '21', 'node', '1.92027'),
('vehicula', '22', 'node', '2'),
('vehicula', '23', 'node', '1.92027'),
('vehicula', '24', 'node', '2.90286'),
('vehicula', '25', 'node', '3'),
('vehicula', '26', 'node', '2.85512'),
('vehicula', '27', 'node', '1'),
('vehicula', '28', 'node', '1.88282'),
('vehicula', '29', 'node', '3.9534'),
('vehicula', '30', 'node', '1'),
('vehicula', '32', 'node', '1'),
('vehicula', '33', 'node', '11'),
('vehicula', '34', 'node', '11'),
('vehicula', '35', 'node', '1'),
('vehicula', '36', 'node', '2.56535'),
('vehicula', '37', 'node', '0.913226'),
('vehicula', '38', 'node', '3.91674'),
('vehicula', '41', 'node', '4.9984'),
('vehicula', '43', 'node', '1'),
('vehicula', '52', 'node', '1'),
('vehicula', '53', 'node', '1'),
('vehicula', '54', 'node', '1'),
('vehicula', '55', 'node', '1'),
('vehicula', '56', 'node', '1'),
('vehicula', '57', 'node', '1'),
('vehicula', '58', 'node', '1'),
('vehicula', '65', 'node', '7.87313'),
('vehicula', '67', 'node', '12.9689'),
('vehicula', '68', 'node', '11.6577'),
('vehicula', '69', 'node', '0.931053'),
('vehicula', '71', 'node', '2'),
('vehicula', '73', 'node', '6.88558'),
('vehicula', '76', 'node', '11'),
('vehicula', '77', 'node', '0.923838'),
('vehicula', '78', 'node', '1.92027'),
('vehicula', '79', 'node', '1'),
('vehicula', '82', 'node', '1'),
('vehicula', '83', 'node', '6.92874'),
('vehicula', '84', 'node', '6.92874'),
('vehicula', '85', 'node', '6.88558'),
('vehicula', '86', 'node', '6.88558'),
('vehicula', '87', 'node', '6.90843'),
('vehicula', '88', 'node', '6.88558'),
('vehicula', '89', 'node', '6.88558'),
('vel', '12', 'node', '4.51196'),
('vel', '13', 'node', '3.90471'),
('vel', '14', 'node', '10.061'),
('vel', '15', 'node', '1'),
('vel', '16', 'node', '4.71335'),
('vel', '17', 'node', '1.94583'),
('vel', '18', 'node', '1'),
('vel', '19', 'node', '2'),
('vel', '20', 'node', '1.99731'),
('vel', '21', 'node', '6.81926'),
('vel', '22', 'node', '10.6054'),
('vel', '23', 'node', '6.81926'),
('vel', '24', 'node', '6.84641'),
('vel', '25', 'node', '5.93862'),
('vel', '26', 'node', '7.74219'),
('vel', '27', 'node', '3'),
('vel', '28', 'node', '3.83655'),
('vel', '29', 'node', '7.91698'),
('vel', '30', 'node', '2.93784'),
('vel', '31', 'node', '4'),
('vel', '32', 'node', '3'),
('vel', '33', 'node', '3.98902'),
('vel', '34', 'node', '5'),
('vel', '35', 'node', '3'),
('vel', '36', 'node', '6.14309'),
('vel', '37', 'node', '2.90974'),
('vel', '38', 'node', '14.6424'),
('vel', '39', 'node', '13.6047'),
('vel', '40', 'node', '12.9446'),
('vel', '41', 'node', '11.4776'),
('vel', '43', 'node', '2'),
('vel', '44', 'node', '1'),
('vel', '47', 'node', '1'),
('vel', '50', 'node', '1.92027'),
('vel', '51', 'node', '0.993146'),
('vel', '52', 'node', '3'),
('vel', '53', 'node', '3'),
('vel', '54', 'node', '3'),
('vel', '55', 'node', '3'),
('vel', '56', 'node', '3'),
('vel', '57', 'node', '3'),
('vel', '58', 'node', '3'),
('vel', '65', 'node', '2.86995'),
('vel', '67', 'node', '2.9689'),
('vel', '68', 'node', '7.70773'),
('vel', '69', 'node', '28.7535'),
('vel', '71', 'node', '3.96621'),
('vel', '73', 'node', '3'),
('vel', '76', 'node', '3.86957'),
('vel', '77', 'node', '4.84528'),
('vel', '78', 'node', '4.86581'),
('vel', '79', 'node', '8.00721'),
('vel', '82', 'node', '3'),
('vel', '83', 'node', '3'),
('vel', '84', 'node', '3'),
('vel', '85', 'node', '3'),
('vel', '86', 'node', '3'),
('vel', '87', 'node', '3'),
('vel', '88', 'node', '3'),
('vel', '89', 'node', '3'),
('velit', '12', 'node', '9.00081'),
('velit', '13', 'node', '2.94583'),
('velit', '14', 'node', '1.93105'),
('velit', '15', 'node', '2.72732'),
('velit', '16', 'node', '3.44172'),
('velit', '17', 'node', '2.9496'),
('velit', '18', 'node', '2'),
('velit', '19', 'node', '1'),
('velit', '20', 'node', '1.88798'),
('velit', '21', 'node', '1.91894'),
('velit', '22', 'node', '2.93105'),
('velit', '23', 'node', '1.91894'),
('velit', '24', 'node', '1.80236'),
('velit', '25', 'node', '2'),
('velit', '26', 'node', '2'),
('velit', '27', 'node', '2'),
('velit', '28', 'node', '2.8894'),
('velit', '29', 'node', '2.85848'),
('velit', '30', 'node', '2'),
('velit', '34', 'node', '1'),
('velit', '36', 'node', '25.6092'),
('velit', '37', 'node', '5.7508'),
('velit', '38', 'node', '0.899454'),
('velit', '40', 'node', '2.92027'),
('velit', '41', 'node', '4.90318'),
('velit', '42', 'node', '1'),
('velit', '44', 'node', '1'),
('velit', '45', 'node', '26'),
('velit', '46', 'node', '2'),
('velit', '51', 'node', '2'),
('velit', '52', 'node', '2'),
('velit', '53', 'node', '2'),
('velit', '54', 'node', '2'),
('velit', '55', 'node', '2'),
('velit', '56', 'node', '2'),
('velit', '57', 'node', '2'),
('velit', '58', 'node', '2'),
('velit', '65', 'node', '2.85082'),
('velit', '67', 'node', '0.945829'),
('velit', '68', 'node', '4.89144'),
('velit', '69', 'node', '4.68109'),
('velit', '71', 'node', '2.95723'),
('velit', '73', 'node', '2'),
('velit', '76', 'node', '13.421'),
('velit', '77', 'node', '1.9347'),
('velit', '78', 'node', '2'),
('velit', '79', 'node', '1.8861'),
('velit', '82', 'node', '2'),
('velit', '83', 'node', '2'),
('velit', '84', 'node', '2'),
('velit', '85', 'node', '2'),
('velit', '86', 'node', '2'),
('velit', '87', 'node', '2'),
('velit', '88', 'node', '2'),
('velit', '89', 'node', '2'),
('venenatis', '12', 'node', '2.92996'),
('venenatis', '13', 'node', '0.916736'),
('venenatis', '14', 'node', '3.42642'),
('venenatis', '15', 'node', '1'),
('venenatis', '16', 'node', '2.61816'),
('venenatis', '17', 'node', '1'),
('venenatis', '18', 'node', '0.997306'),
('venenatis', '19', 'node', '2.98493'),
('venenatis', '20', 'node', '3.81795'),
('venenatis', '21', 'node', '2.94209'),
('venenatis', '22', 'node', '1'),
('venenatis', '23', 'node', '2.94209'),
('venenatis', '24', 'node', '0.889397'),
('venenatis', '25', 'node', '2'),
('venenatis', '26', 'node', '1.96109'),
('venenatis', '27', 'node', '1'),
('venenatis', '28', 'node', '0.993146'),
('venenatis', '29', 'node', '1.98493'),
('venenatis', '30', 'node', '0.98493'),
('venenatis', '31', 'node', '4.88045'),
('venenatis', '32', 'node', '1'),
('venenatis', '33', 'node', '1'),
('venenatis', '34', 'node', '2'),
('venenatis', '35', 'node', '1'),
('venenatis', '36', 'node', '2.53605'),
('venenatis', '37', 'node', '0.927431'),
('venenatis', '39', 'node', '2'),
('venenatis', '40', 'node', '0.851346'),
('venenatis', '46', 'node', '2'),
('venenatis', '47', 'node', '1'),
('venenatis', '50', 'node', '1'),
('venenatis', '51', 'node', '1'),
('venenatis', '65', 'node', '0.906287'),
('venenatis', '67', 'node', '4.98902'),
('venenatis', '69', 'node', '1'),
('venenatis', '71', 'node', '1'),
('venenatis', '77', 'node', '1'),
('venenatis', '79', 'node', '5.28937'),
('veniam', '54', 'node', '26'),
('veniam', '85', 'node', '26'),
('vestibulum', '12', 'node', '6.30236'),
('vestibulum', '13', 'node', '3.98087'),
('vestibulum', '14', 'node', '31.5502'),
('vestibulum', '15', 'node', '2.85746'),
('vestibulum', '16', 'node', '2.8034'),
('vestibulum', '17', 'node', '14.9496'),
('vestibulum', '18', 'node', '13'),
('vestibulum', '19', 'node', '12.9931'),
('vestibulum', '20', 'node', '14.888'),
('vestibulum', '21', 'node', '6.85445'),
('vestibulum', '22', 'node', '2.9347'),
('vestibulum', '23', 'node', '6.8504'),
('vestibulum', '24', 'node', '1'),
('vestibulum', '25', 'node', '11'),
('vestibulum', '26', 'node', '11'),
('vestibulum', '27', 'node', '11'),
('vestibulum', '28', 'node', '2.80309'),
('vestibulum', '29', 'node', '1'),
('vestibulum', '30', 'node', '1'),
('vestibulum', '31', 'node', '1'),
('vestibulum', '32', 'node', '3'),
('vestibulum', '33', 'node', '4'),
('vestibulum', '34', 'node', '1.98493'),
('vestibulum', '35', 'node', '3'),
('vestibulum', '36', 'node', '7.39888'),
('vestibulum', '37', 'node', '6.84793'),
('vestibulum', '38', 'node', '13.5594'),
('vestibulum', '39', 'node', '3.90225'),
('vestibulum', '40', 'node', '11.945'),
('vestibulum', '41', 'node', '15.0255'),
('vestibulum', '45', 'node', '1'),
('vestibulum', '46', 'node', '1'),
('vestibulum', '47', 'node', '1.99731'),
('vestibulum', '50', 'node', '1.91323'),
('vestibulum', '51', 'node', '1.98087'),
('vestibulum', '52', 'node', '8'),
('vestibulum', '53', 'node', '8'),
('vestibulum', '54', 'node', '8'),
('vestibulum', '55', 'node', '8'),
('vestibulum', '56', 'node', '34'),
('vestibulum', '57', 'node', '34'),
('vestibulum', '58', 'node', '34'),
('vestibulum', '65', 'node', '13.2217'),
('vestibulum', '67', 'node', '3.83768'),
('vestibulum', '68', 'node', '5.94583'),
('vestibulum', '69', 'node', '4.75353'),
('vestibulum', '71', 'node', '14.7905'),
('vestibulum', '73', 'node', '9.96229'),
('vestibulum', '76', 'node', '1.95723'),
('vestibulum', '77', 'node', '4.65024'),
('vestibulum', '78', 'node', '2.95723'),
('vestibulum', '79', 'node', '2.83847'),
('vestibulum', '82', 'node', '8'),
('vestibulum', '83', 'node', '35.9729'),
('vestibulum', '84', 'node', '9.97286'),
('vestibulum', '85', 'node', '9.96229'),
('vestibulum', '86', 'node', '9.96229'),
('vestibulum', '87', 'node', '35.9689'),
('vestibulum', '88', 'node', '9.96229'),
('vestibulum', '89', 'node', '9.96229'),
('vitae', '12', 'node', '8.47469'),
('vitae', '13', 'node', '1.9347'),
('vitae', '14', 'node', '6.79611'),
('vitae', '15', 'node', '2.9537'),
('vitae', '16', 'node', '5.19811'),
('vitae', '17', 'node', '2.92384'),
('vitae', '18', 'node', '2.98493'),
('vitae', '19', 'node', '4.99731'),
('vitae', '20', 'node', '4.88282'),
('vitae', '21', 'node', '4.74009'),
('vitae', '22', 'node', '5.83353'),
('vitae', '23', 'node', '4.74009'),
('vitae', '24', 'node', '5.55048'),
('vitae', '25', 'node', '5'),
('vitae', '26', 'node', '7.95011'),
('vitae', '27', 'node', '1'),
('vitae', '28', 'node', '1.85285'),
('vitae', '29', 'node', '3'),
('vitae', '30', 'node', '0.945829'),
('vitae', '32', 'node', '30'),
('vitae', '33', 'node', '4.97808'),
('vitae', '34', 'node', '1'),
('vitae', '35', 'node', '4'),
('vitae', '36', 'node', '5.54958'),
('vitae', '37', 'node', '4.7688'),
('vitae', '38', 'node', '4'),
('vitae', '39', 'node', '2.97395'),
('vitae', '40', 'node', '3.80518'),
('vitae', '41', 'node', '1.96109'),
('vitae', '42', 'node', '1'),
('vitae', '43', 'node', '1'),
('vitae', '44', 'node', '1'),
('vitae', '45', 'node', '1'),
('vitae', '46', 'node', '28'),
('vitae', '47', 'node', '2'),
('vitae', '50', 'node', '3.87083'),
('vitae', '51', 'node', '1'),
('vitae', '52', 'node', '4'),
('vitae', '53', 'node', '4'),
('vitae', '54', 'node', '4'),
('vitae', '55', 'node', '4'),
('vitae', '56', 'node', '4'),
('vitae', '57', 'node', '4'),
('vitae', '58', 'node', '4'),
('vitae', '65', 'node', '4.48579'),
('vitae', '67', 'node', '3.89634'),
('vitae', '68', 'node', '4.76801'),
('vitae', '69', 'node', '3.79715'),
('vitae', '71', 'node', '16.9689'),
('vitae', '73', 'node', '4'),
('vitae', '76', 'node', '4.9496'),
('vitae', '77', 'node', '7.70338'),
('vitae', '78', 'node', '2.92027'),
('vitae', '79', 'node', '2.79893'),
('vitae', '82', 'node', '4'),
('vitae', '83', 'node', '4'),
('vitae', '84', 'node', '4'),
('vitae', '85', 'node', '4'),
('vitae', '86', 'node', '4'),
('vitae', '87', 'node', '4'),
('vitae', '88', 'node', '4'),
('vitae', '89', 'node', '4'),
('vivamus', '12', 'node', '2.81367'),
('vivamus', '14', 'node', '3.35114'),
('vivamus', '15', 'node', '2'),
('vivamus', '16', 'node', '2.92384'),
('vivamus', '17', 'node', '1.9347'),
('vivamus', '18', 'node', '4'),
('vivamus', '19', 'node', '1.99731'),
('vivamus', '20', 'node', '1'),
('vivamus', '22', 'node', '0.913226'),
('vivamus', '24', 'node', '0.892724'),
('vivamus', '25', 'node', '2'),
('vivamus', '26', 'node', '1.97685'),
('vivamus', '28', 'node', '2.82491'),
('vivamus', '30', 'node', '1.9347'),
('vivamus', '31', 'node', '2.97395'),
('vivamus', '32', 'node', '1'),
('vivamus', '34', 'node', '1.92743'),
('vivamus', '35', 'node', '1'),
('vivamus', '36', 'node', '0.879565'),
('vivamus', '37', 'node', '0.953396'),
('vivamus', '38', 'node', '3.77385'),
('vivamus', '40', 'node', '0.866793'),
('vivamus', '41', 'node', '2.66169'),
('vivamus', '43', 'node', '1'),
('vivamus', '47', 'node', '2'),
('vivamus', '50', 'node', '0.949597'),
('vivamus', '51', 'node', '2'),
('vivamus', '52', 'node', '12'),
('vivamus', '53', 'node', '1'),
('vivamus', '54', 'node', '1'),
('vivamus', '55', 'node', '1'),
('vivamus', '56', 'node', '12'),
('vivamus', '57', 'node', '12'),
('vivamus', '58', 'node', '1'),
('vivamus', '67', 'node', '1'),
('vivamus', '68', 'node', '2.83621'),
('vivamus', '69', 'node', '1'),
('vivamus', '71', 'node', '1.88106'),
('vivamus', '73', 'node', '1'),
('vivamus', '76', 'node', '1'),
('vivamus', '77', 'node', '1'),
('vivamus', '82', 'node', '1'),
('vivamus', '83', 'node', '1'),
('vivamus', '84', 'node', '1'),
('vivamus', '85', 'node', '1'),
('vivamus', '86', 'node', '1'),
('vivamus', '87', 'node', '1'),
('vivamus', '88', 'node', '1'),
('vivamus', '89', 'node', '1'),
('viverra', '12', 'node', '4.73174'),
('viverra', '13', 'node', '0.934703'),
('viverra', '14', 'node', '2.77923'),
('viverra', '15', 'node', '0.886095'),
('viverra', '18', 'node', '1'),
('viverra', '19', 'node', '1'),
('viverra', '20', 'node', '1'),
('viverra', '21', 'node', '1.99731'),
('viverra', '23', 'node', '1.99315'),
('viverra', '25', 'node', '1.98493'),
('viverra', '26', 'node', '1.81608'),
('viverra', '27', 'node', '2'),
('viverra', '28', 'node', '1.94583'),
('viverra', '29', 'node', '1.92384'),
('viverra', '30', 'node', '1.93838'),
('viverra', '31', 'node', '1'),
('viverra', '33', 'node', '0.98493'),
('viverra', '36', 'node', '4.57618'),
('viverra', '37', 'node', '1'),
('viverra', '38', 'node', '1.83481'),
('viverra', '39', 'node', '0.902857'),
('viverra', '40', 'node', '15.6003'),
('viverra', '41', 'node', '2.58743'),
('viverra', '43', 'node', '1'),
('viverra', '45', 'node', '1'),
('viverra', '50', 'node', '1'),
('viverra', '51', 'node', '1'),
('viverra', '52', 'node', '1'),
('viverra', '53', 'node', '1'),
('viverra', '54', 'node', '1'),
('viverra', '55', 'node', '1'),
('viverra', '56', 'node', '1'),
('viverra', '57', 'node', '1'),
('viverra', '58', 'node', '1'),
('viverra', '65', 'node', '2'),
('viverra', '67', 'node', '2.93897'),
('viverra', '68', 'node', '1'),
('viverra', '69', 'node', '2'),
('viverra', '71', 'node', '0.909743'),
('viverra', '73', 'node', '1.96109'),
('viverra', '76', 'node', '3'),
('viverra', '77', 'node', '0.938382'),
('viverra', '78', 'node', '1.95723'),
('viverra', '79', 'node', '8.64865'),
('viverra', '82', 'node', '1'),
('viverra', '83', 'node', '1.9689'),
('viverra', '84', 'node', '1.9689'),
('viverra', '85', 'node', '1.96109'),
('viverra', '86', 'node', '1.96109'),
('viverra', '87', 'node', '1.96498'),
('viverra', '88', 'node', '1.96109'),
('viverra', '89', 'node', '1.96109'),
('volutpat', '12', 'node', '3.7276'),
('volutpat', '13', 'node', '1.93453'),
('volutpat', '14', 'node', '1.52452'),
('volutpat', '15', 'node', '1.99315'),
('volutpat', '16', 'node', '2.8661'),
('volutpat', '17', 'node', '0.961087'),
('volutpat', '18', 'node', '1'),
('volutpat', '19', 'node', '1.9534'),
('volutpat', '20', 'node', '2'),
('volutpat', '21', 'node', '1'),
('volutpat', '22', 'node', '2.96109'),
('volutpat', '23', 'node', '1'),
('volutpat', '24', 'node', '2.7136'),
('volutpat', '25', 'node', '3'),
('volutpat', '26', 'node', '3.96109'),
('volutpat', '31', 'node', '1.98493'),
('volutpat', '33', 'node', '2'),
('volutpat', '34', 'node', '1'),
('volutpat', '36', 'node', '4.5551'),
('volutpat', '38', 'node', '1'),
('volutpat', '39', 'node', '1.98493'),
('volutpat', '40', 'node', '0.923838'),
('volutpat', '41', 'node', '1.7559'),
('volutpat', '42', 'node', '1'),
('volutpat', '43', 'node', '1'),
('volutpat', '45', 'node', '53'),
('volutpat', '47', 'node', '2'),
('volutpat', '50', 'node', '3'),
('volutpat', '52', 'node', '4'),
('volutpat', '53', 'node', '4'),
('volutpat', '54', 'node', '4'),
('volutpat', '55', 'node', '4'),
('volutpat', '56', 'node', '4'),
('volutpat', '57', 'node', '4'),
('volutpat', '58', 'node', '4'),
('volutpat', '67', 'node', '11'),
('volutpat', '68', 'node', '11.7523'),
('volutpat', '69', 'node', '1.91674'),
('volutpat', '73', 'node', '4'),
('volutpat', '76', 'node', '3.81123'),
('volutpat', '78', 'node', '4.88047'),
('volutpat', '79', 'node', '1.79661'),
('volutpat', '82', 'node', '4'),
('volutpat', '83', 'node', '4'),
('volutpat', '84', 'node', '4'),
('volutpat', '85', 'node', '4'),
('volutpat', '86', 'node', '4'),
('volutpat', '87', 'node', '4'),
('volutpat', '88', 'node', '4'),
('volutpat', '89', 'node', '4'),
('votes', '11', 'node', '5'),
('vulputate', '12', 'node', '2.5481'),
('vulputate', '13', 'node', '4.82818'),
('vulputate', '14', 'node', '3.49323'),
('vulputate', '16', 'node', '2.78545'),
('vulputate', '18', 'node', '1'),
('vulputate', '19', 'node', '2.99315'),
('vulputate', '20', 'node', '32.6201'),
('vulputate', '21', 'node', '3'),
('vulputate', '23', 'node', '3'),
('vulputate', '24', 'node', '1.82491'),
('vulputate', '25', 'node', '1'),
('vulputate', '26', 'node', '2'),
('vulputate', '27', 'node', '1'),
('vulputate', '28', 'node', '1.90974'),
('vulputate', '29', 'node', '0.934703'),
('vulputate', '30', 'node', '1'),
('vulputate', '31', 'node', '1.91062'),
('vulputate', '36', 'node', '1.67022'),
('vulputate', '37', 'node', '2'),
('vulputate', '38', 'node', '2.91323'),
('vulputate', '39', 'node', '1.92384'),
('vulputate', '40', 'node', '2.84037'),
('vulputate', '41', 'node', '2.73546'),
('vulputate', '43', 'node', '1'),
('vulputate', '47', 'node', '1'),
('vulputate', '50', 'node', '1'),
('vulputate', '51', 'node', '1'),
('vulputate', '65', 'node', '1'),
('vulputate', '67', 'node', '1.98493'),
('vulputate', '68', 'node', '1.85897'),
('vulputate', '69', 'node', '8.93105'),
('vulputate', '73', 'node', '0.997306'),
('vulputate', '76', 'node', '0.957226'),
('vulputate', '77', 'node', '2.85048'),
('vulputate', '79', 'node', '1'),
('vulputate', '83', 'node', '1'),
('vulputate', '84', 'node', '1'),
('vulputate', '85', 'node', '0.997306'),
('vulputate', '86', 'node', '0.997306'),
('vulputate', '87', 'node', '1'),
('vulputate', '88', 'node', '0.997306'),
('vulputate', '89', 'node', '0.997306'),
('wed', '12', 'node', '2.47693'),
('wed', '13', 'node', '0.961087'),
('wed', '14', 'node', '3.95391'),
('wed', '16', 'node', '1.7672'),
('wed', '41', 'node', '0.860547'),
('what', '11', 'node', '26'),
('you', '11', 'node', '26');
/*!40000 ALTER TABLE search_index ENABLE KEYS */;

--
-- Table structure for table 'search_node_links'
--

CREATE TABLE IF NOT EXISTS `search_node_links` (
  `sid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The search_dataset.sid of the searchable item containing the link to the node.',
  `type` varchar(16) NOT NULL DEFAULT '' COMMENT 'The search_dataset.type of the searchable item containing the link to the node.',
  `nid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The node.nid that this item links to.',
  `caption` longtext COMMENT 'The text used to link to the node.nid.',
  PRIMARY KEY (`sid`,`type`,`nid`),
  KEY `nid` (`nid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores items (like nodes) that link to other nodes, used...';

--
-- Dumping data for table 'search_node_links'
--

/*!40000 ALTER TABLE search_node_links DISABLE KEYS */;
/*!40000 ALTER TABLE search_node_links ENABLE KEYS */;

--
-- Table structure for table 'search_total'
--

CREATE TABLE IF NOT EXISTS `search_total` (
  `word` varchar(50) NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique word in the search index.',
  `count` float DEFAULT NULL COMMENT 'The count of the word in the index using Zipf’s law to equalize the probability distribution.',
  PRIMARY KEY (`word`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores search totals for words.';

--
-- Dumping data for table 'search_total'
--

/*!40000 ALTER TABLE search_total DISABLE KEYS */;
INSERT INTO `search_total` VALUES
('11', '0.30103'),
('1535', '0.147605'),
('1537', '0.30103'),
('1538', '0.0980512'),
('1539', '0.30103'),
('1540', '0.30103'),
('1813', '0.144636'),
('1856', '0.30103'),
('20', '0.30103'),
('2192', '0.30103'),
('235', '0.30103'),
('31', '0.30103'),
('39', '0.30103'),
('432', '0.30103'),
('5112011', '0.0450652'),
('678', '0.30103'),
('7172013', '0.30103'),
('847', '0.30103'),
('9202011', '0.144486'),
('about', '0.0163904'),
('accumsan', '0.00379626'),
('adipiscing', '0.00337676'),
('adipisicing', '0.0163904'),
('admin', '0.00562261'),
('aenean', '0.00313201'),
('aliquam', '0.00125523'),
('aliquet', '0.00220908'),
('all', '0.00490733'),
('amet', '0.000643135'),
('ante', '0.00176535'),
('aptent', '0.0167197'),
('arcu', '0.00211571'),
('auctor', '0.00417646'),
('augue', '0.00320068'),
('bad', '0.30103'),
('bibendum', '0.00360807'),
('billing', '0.30103'),
('blandit', '0.00376817'),
('blog', '0.00782534'),
('ceo', '0.30103'),
('class', '0.0166832'),
('cole', '0.0163904'),
('comfort', '0.0163904'),
('comments', '0.0467926'),
('commodo', '0.00261358'),
('condimentum', '0.00462672'),
('congue', '0.0058227'),
('conor', '0.0163904'),
('consectetur', '0.00221959'),
('consequat', '0.00311012'),
('conubia', '0.0169638'),
('convallis', '0.0017395'),
('cras', '0.00314293'),
('cubilia', '0.0256909'),
('cum', '0.0141752'),
('curabitur', '0.00234652'),
('curae', '0.0257181'),
('cursus', '0.00419547'),
('dapibus', '0.00310829'),
('david', '0.0163904'),
('demolinkorg', '0.045106'),
('design', '0.00827253'),
('diam', '0.00320661'),
('dictum', '0.00334469'),
('dictumst', '0.0238381'),
('dignissim', '0.00282669'),
('dis', '0.0547055'),
('discussion', '0.00782534'),
('dolor', '0.000775248'),
('donec', '0.00221758'),
('donece', '0.00332794'),
('dui', '0.0024157'),
('duis', '0.0021961'),
('egestas', '0.00418088'),
('eget', '0.00139826'),
('eleifend', '0.00319831'),
('elementum', '0.00397674'),
('elit', '0.00110234'),
('email', '0.30103'),
('enim', '0.00188493'),
('entesque', '0.0163904'),
('erat', '0.0020785'),
('eratmorbi', '0.30103'),
('eros', '0.00198529'),
('est', '0.00151267'),
('etiam', '0.00452987'),
('euismo', '0.0163904'),
('euismod', '0.00181516'),
('facilisi', '0.0177162'),
('facilisis', '0.00278335'),
('fames', '0.00964045'),
('faucibus', '0.00244045'),
('felis', '0.00342584'),
('fermentum', '0.00298413'),
('feugiat', '0.00300385'),
('franklin', '0.0163904'),
('fringilla', '0.00404352'),
('fusce', '0.00202943'),
('general', '0.00782534'),
('good', '0.30103'),
('gravida', '0.00403345'),
('habitant', '0.00832379'),
('habitasse', '0.0237856'),
('hac', '0.0237591'),
('hend', '0.0163904'),
('hendrerit', '0.00222726'),
('himenaeos', '0.0123705'),
('iaculis', '0.00202383'),
('ideas', '0.0163904'),
('igula', '0.0110504'),
('imperdiet', '0.00574293'),
('inceptos', '0.0123352'),
('integer', '0.00428306'),
('interdum', '0.00234277'),
('interior', '0.0163904'),
('ipsum', '0.000752621'),
('jack', '0.0163904'),
('jacobs', '0.0163904'),
('jessica', '0.0163904'),
('john', '0.0163904'),
('johnson', '0.0163904'),
('justo', '0.00254677'),
('kronshtain', '0.0163904'),
('lacinia', '0.00328077'),
('lacus', '0.0026616'),
('laoreet', '0.00351692'),
('lectus', '0.00267192'),
('leo', '0.00219005'),
('libero', '0.00177062'),
('ligula', '0.00171392'),
('lisa', '0.0163904'),
('litora', '0.0168399'),
('lobortis', '0.00336376'),
('location', '0.0163904'),
('log', '0.0218085'),
('lorem', '0.000934709'),
('luctus', '0.00416796'),
('maecenas', '0.0027909'),
('magna', '0.0014213'),
('magnis', '0.0545906'),
('malesuada', '0.00183825'),
('manager', '0.30103'),
('massa', '0.00173246'),
('mattis', '0.00352067'),
('mauris', '0.000830137'),
('metho', '0.190808'),
('metu', '0.0163904'),
('metus', '0.00138517'),
('minima', '0.00827253'),
('molestie', '0.0030484'),
('mollis', '0.00356696'),
('montes', '0.0549342'),
('morbi', '0.00398957'),
('mus', '0.0624937'),
('musvivamus', '0.30103'),
('nam', '0.00282873'),
('nascetur', '0.0550479'),
('natoque', '0.0142645'),
('nec', '0.00108529'),
('neque', '0.00244328'),
('netus', '0.00962261'),
('nibh', '0.00274304'),
('nisi', '0.00256637'),
('nisifes', '0.0112031'),
('nisl', '0.00476724'),
('nislum', '0.0163904'),
('non', '0.0010507'),
('normal', '0.30103'),
('nostra', '0.0170048'),
('nulla', '0.00106202'),
('nullam', '0.0032336'),
('nunc', '0.00169624'),
('odio', '0.00285141'),
('orci', '0.00164776'),
('org', '0.191394'),
('ornare', '0.0019713'),
('our', '0.00827253'),
('parker', '0.0163904'),
('parturient', '0.0548201'),
('pellente', '0.00332794'),
('pellentesque', '0.00105644'),
('penatibus', '0.014309'),
('per', '0.00719323'),
('permalink', '0.00311899'),
('perspiciatis', '0.00827253'),
('pharetra', '0.00522247'),
('phasellus', '0.00305201'),
('placerat', '0.00499426'),
('platea', '0.0238119'),
('policy', '0.0163904'),
('porta', '0.00228316'),
('porttitor', '0.00363477'),
('post', '0.0467322'),
('posuere', '0.00373518'),
('potenti', '0.00503875'),
('praesent', '0.00189897'),
('pretium', '0.00333'),
('primis', '0.0256254'),
('privacy', '0.0163904'),
('programmer', '0.30103'),
('proin', '0.00468162'),
('pul', '0.0163904'),
('pulv', '0.0163904'),
('pulvinar', '0.00204162'),
('purus', '0.00209596'),
('quality', '0.0163904'),
('quam', '0.00201568'),
('quis', '0.00116473'),
('quisque', '0.00465038'),
('register', '0.0218378'),
('reply', '0.00789026'),
('rhoncus', '0.00231325'),
('ridiculus', '0.0551613'),
('risus', '0.00160043'),
('rius', '0.0163904'),
('rutrum', '0.0046602'),
('sagittis', '0.00161773'),
('sam', '0.0163904'),
('samantha', '0.0163904'),
('sapien', '0.00394126'),
('sarah', '0.0163904'),
('scelerisque', '0.00272259'),
('sed', '0.000620541'),
('seller', '0.30103'),
('sem', '0.00177872'),
('semper', '0.00347014'),
('senectus', '0.00840675'),
('sit', '0.000619291'),
('smith', '0.0163904'),
('sociis', '0.0142199'),
('sociosqu', '0.0167984'),
('sodales', '0.00427715'),
('sollicit', '0.0163904'),
('sollicitudin', '0.0072618'),
('style', '0.0163904'),
('submitted', '0.0331864'),
('super', '0.30103'),
('support', '0.30103'),
('suscipit', '0.00163414'),
('suspendisse', '0.00162615'),
('taciti', '0.0167577'),
('team', '0.0163904'),
('tellus', '0.00159984'),
('tempor', '0.00373125'),
('tempus', '0.00299825'),
('think', '0.0163904'),
('tincidunt', '0.000920257'),
('torquent', '0.0168813'),
('tortor', '0.00241048'),
('total', '0.30103'),
('tristique', '0.00284871'),
('tue', '0.144335'),
('turpis', '0.00309823'),
('ullamcorper', '0.00287142'),
('ullamcorpermoles', '0.0150691'),
('ultrices', '0.0028283'),
('ultricies', '0.00387191'),
('unde', '0.0163904'),
('urna', '0.00183788'),
('utem', '0.0163904'),
('varius', '0.00480795'),
('vehicula', '0.00193716'),
('vel', '0.00145944'),
('velit', '0.00226958'),
('venenatis', '0.0060095'),
('veniam', '0.00827253'),
('vestibulum', '0.000765275'),
('vitae', '0.00144546'),
('vivamus', '0.00392083'),
('viverra', '0.00402057'),
('volutpat', '0.00209341'),
('votes', '0.0791812'),
('vulputate', '0.00384332'),
('wed', '0.0413152'),
('what', '0.0163904'),
('you', '0.0163904');
/*!40000 ALTER TABLE search_total ENABLE KEYS */;

--
-- Table structure for table 'semaphore'
--

CREATE TABLE IF NOT EXISTS `semaphore` (
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique name.',
  `value` varchar(255) NOT NULL DEFAULT '' COMMENT 'A value for the semaphore.',
  `expire` double NOT NULL COMMENT 'A Unix timestamp with microseconds indicating when the semaphore should expire.',
  PRIMARY KEY (`name`),
  KEY `value` (`value`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Table for holding semaphores, locks, flags, etc. that...';

--
-- Dumping data for table 'semaphore'
--

/*!40000 ALTER TABLE semaphore DISABLE KEYS */;
/*!40000 ALTER TABLE semaphore ENABLE KEYS */;

--
-- Table structure for table 'sequences'
--

CREATE TABLE IF NOT EXISTS `sequences` (
  `value` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'The value of the sequence.',
  PRIMARY KEY (`value`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores IDs.';

--
-- Dumping data for table 'sequences'
--

/*!40000 ALTER TABLE sequences DISABLE KEYS */;
INSERT INTO `sequences` VALUES
('167');
/*!40000 ALTER TABLE sequences ENABLE KEYS */;

--
-- Table structure for table 'sessions'
--

CREATE TABLE IF NOT EXISTS `sessions` (
  `uid` int(10) unsigned NOT NULL COMMENT 'The users.uid corresponding to a session, or 0 for anonymous user.',
  `sid` varchar(128) NOT NULL COMMENT 'A session ID. The value is generated by Drupal’s session handlers.',
  `ssid` varchar(128) NOT NULL DEFAULT '' COMMENT 'Secure session ID. The value is generated by Drupal’s session handlers.',
  `hostname` varchar(128) NOT NULL DEFAULT '' COMMENT 'The IP address that last used this session ID (sid).',
  `timestamp` int(11) NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp when this session last requested a page. Old records are purged by PHP automatically.',
  `cache` int(11) NOT NULL DEFAULT '0' COMMENT 'The time of this user’s last post. This is used when the site has specified a minimum_cache_lifetime. See cache_get().',
  `session` longblob COMMENT 'The serialized contents of $_SESSION, an array of name/value pairs that persists across page requests by this session ID. Drupal loads $_SESSION from here at the start of each request and saves it at the end.',
  PRIMARY KEY (`sid`,`ssid`),
  KEY `timestamp` (`timestamp`),
  KEY `uid` (`uid`),
  KEY `ssid` (`ssid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Drupal’s session handlers read and write into the...';

--
-- Dumping data for table 'sessions'
--

/*!40000 ALTER TABLE sessions DISABLE KEYS */;
INSERT INTO `sessions` VALUES
('1', 'N3YDWUIIC1VPokpf76kYyFt3xJ4P_5QE7kWlrRZpe8o', '', '127.0.0.1', '1379069160', '0', 'batches|a:5:{i:163;b:1;i:164;b:1;i:165;b:1;i:166;b:1;i:167;b:1;}updates_remaining|a:0:{}node_overview_filter|a:1:{i:0;a:2:{i:0;s:4:"type";i:1;s:9:"portfolio";}}');
/*!40000 ALTER TABLE sessions ENABLE KEYS */;

--
-- Table structure for table 'shortcut_set'
--

CREATE TABLE IF NOT EXISTS `shortcut_set` (
  `set_name` varchar(32) NOT NULL DEFAULT '' COMMENT 'Primary Key: The menu_links.menu_name under which the set’s links are stored.',
  `title` varchar(255) NOT NULL DEFAULT '' COMMENT 'The title of the set.',
  PRIMARY KEY (`set_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores information about sets of shortcuts links.';

--
-- Dumping data for table 'shortcut_set'
--

/*!40000 ALTER TABLE shortcut_set DISABLE KEYS */;
INSERT INTO `shortcut_set` VALUES
('shortcut-set-1', 'Default');
/*!40000 ALTER TABLE shortcut_set ENABLE KEYS */;

--
-- Table structure for table 'shortcut_set_users'
--

CREATE TABLE IF NOT EXISTS `shortcut_set_users` (
  `uid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The users.uid for this set.',
  `set_name` varchar(32) NOT NULL DEFAULT '' COMMENT 'The shortcut_set.set_name that will be displayed for this user.',
  PRIMARY KEY (`uid`),
  KEY `set_name` (`set_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Maps users to shortcut sets.';

--
-- Dumping data for table 'shortcut_set_users'
--

/*!40000 ALTER TABLE shortcut_set_users DISABLE KEYS */;
/*!40000 ALTER TABLE shortcut_set_users ENABLE KEYS */;

--
-- Table structure for table 'simpletest'
--

CREATE TABLE IF NOT EXISTS `simpletest` (
  `message_id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique simpletest message ID.',
  `test_id` int(11) NOT NULL DEFAULT '0' COMMENT 'Test ID, messages belonging to the same ID are reported together',
  `test_class` varchar(255) NOT NULL DEFAULT '' COMMENT 'The name of the class that created this message.',
  `status` varchar(9) NOT NULL DEFAULT '' COMMENT 'Message status. Core understands pass, fail, exception.',
  `message` text NOT NULL COMMENT 'The message itself.',
  `message_group` varchar(255) NOT NULL DEFAULT '' COMMENT 'The message group this message belongs to. For example: warning, browser, user.',
  `function` varchar(255) NOT NULL DEFAULT '' COMMENT 'Name of the assertion function or method that created this message.',
  `line` int(11) NOT NULL DEFAULT '0' COMMENT 'Line number on which the function is called.',
  `file` varchar(255) NOT NULL DEFAULT '' COMMENT 'Name of the file where the function is called.',
  PRIMARY KEY (`message_id`),
  KEY `reporter` (`test_class`,`message_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores simpletest messages';

--
-- Dumping data for table 'simpletest'
--

/*!40000 ALTER TABLE simpletest DISABLE KEYS */;
/*!40000 ALTER TABLE simpletest ENABLE KEYS */;

--
-- Table structure for table 'simpletest_test_id'
--

CREATE TABLE IF NOT EXISTS `simpletest_test_id` (
  `test_id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique simpletest ID used to group test results together. Each time a set of tests\n                            are run a new test ID is used.',
  `last_prefix` varchar(60) DEFAULT '' COMMENT 'The last database prefix used during testing.',
  PRIMARY KEY (`test_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores simpletest test IDs, used to auto-incrament the...';

--
-- Dumping data for table 'simpletest_test_id'
--

/*!40000 ALTER TABLE simpletest_test_id DISABLE KEYS */;
/*!40000 ALTER TABLE simpletest_test_id ENABLE KEYS */;

--
-- Table structure for table 'system'
--

CREATE TABLE IF NOT EXISTS `system` (
  `filename` varchar(255) NOT NULL DEFAULT '' COMMENT 'The path of the primary file for this item, relative to the Drupal root; e.g. modules/node/node.module.',
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT 'The name of the item; e.g. node.',
  `type` varchar(12) NOT NULL DEFAULT '' COMMENT 'The type of the item, either module, theme, theme_engine, or profile.',
  `owner` varchar(255) NOT NULL DEFAULT '' COMMENT 'A theme’s ’parent’ . Can be either a theme or an engine.',
  `status` int(11) NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether or not this item is enabled.',
  `bootstrap` int(11) NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether this module is loaded during Drupal’s early bootstrapping phase (e.g. even before the page cache is consulted).',
  `schema_version` smallint(6) NOT NULL DEFAULT '-1' COMMENT 'The module’s database schema version number. -1 if the module is not installed (its tables do not exist); 0 or the largest N of the module’s hook_update_N() function that has either been run or existed when the module was first installed.',
  `weight` int(11) NOT NULL DEFAULT '0' COMMENT 'The order in which this module’s hooks should be invoked relative to other modules. Equal-weighted modules are ordered by name.',
  `info` blob COMMENT 'A serialized array containing information from the module’s .info file; keys can include name, description, package, version, core, dependencies, and php.',
  PRIMARY KEY (`filename`),
  KEY `system_list` (`status`,`bootstrap`,`type`,`weight`,`name`),
  KEY `type_name` (`type`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='A list of all modules, themes, and theme engines that are...';

--
-- Dumping data for table 'system'
--

/*!40000 ALTER TABLE system DISABLE KEYS */;
INSERT INTO `system` VALUES
('modules/aggregator/aggregator.module', 'aggregator', 'module', '', '1', '0', 7003, '0', 'a:13:{s:4:"name";s:10:"Aggregator";s:11:"description";s:57:"Aggregates syndicated content (RSS, RDF, and Atom feeds).";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:15:"aggregator.test";}s:9:"configure";s:41:"admin/config/services/aggregator/settings";s:11:"stylesheets";a:1:{s:3:"all";a:1:{s:14:"aggregator.css";s:33:"modules/aggregator/aggregator.css";}}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/aggregator/tests/aggregator_test.module', 'aggregator_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:23:"Aggregator module tests";s:11:"description";s:46:"Support module for aggregator related testing.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/block/block.module', 'block', 'module', '', '1', '0', 7008, '-5', 'a:12:{s:4:"name";s:5:"Block";s:11:"description";s:140:"Controls the visual building blocks a page is constructed with. Blocks are boxes of content rendered into an area, or region, of a web page.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:10:"block.test";}s:9:"configure";s:21:"admin/structure/block";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/block/tests/block_test.module', 'block_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:10:"Block test";s:11:"description";s:21:"Provides test blocks.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/blog/blog.module', 'blog', 'module', '', '1', '0', 0, '0', 'a:11:{s:4:"name";s:4:"Blog";s:11:"description";s:25:"Enables multi-user blogs.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:9:"blog.test";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/book/book.module', 'book', 'module', '', '1', '0', 0, '0', 'a:13:{s:4:"name";s:4:"Book";s:11:"description";s:66:"Allows users to create and organize related content in an outline.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:9:"book.test";}s:9:"configure";s:27:"admin/content/book/settings";s:11:"stylesheets";a:1:{s:3:"all";a:1:{s:8:"book.css";s:21:"modules/book/book.css";}}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/color/color.module', 'color', 'module', '', '0', '0', 7001, '0', 'a:11:{s:4:"name";s:5:"Color";s:11:"description";s:70:"Allows administrators to change the color scheme of compatible themes.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:10:"color.test";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/comment/comment.module', 'comment', 'module', '', '1', '0', 7009, '0', 'a:13:{s:4:"name";s:7:"Comment";s:11:"description";s:57:"Allows users to comment on and discuss published content.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:4:"text";}s:5:"files";a:2:{i:0;s:14:"comment.module";i:1;s:12:"comment.test";}s:9:"configure";s:21:"admin/content/comment";s:11:"stylesheets";a:1:{s:3:"all";a:1:{s:11:"comment.css";s:27:"modules/comment/comment.css";}}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/contact/contact.module', 'contact', 'module', '', '1', '0', 7003, '0', 'a:12:{s:4:"name";s:7:"Contact";s:11:"description";s:61:"Enables the use of both personal and site-wide contact forms.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:12:"contact.test";}s:9:"configure";s:23:"admin/structure/contact";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/contextual/contextual.module', 'contextual', 'module', '', '1', '0', 0, '0', 'a:11:{s:4:"name";s:16:"Contextual links";s:11:"description";s:75:"Provides contextual links to perform actions related to elements on a page.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:15:"contextual.test";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/dashboard/dashboard.module', 'dashboard', 'module', '', '0', '0', 0, '0', 'a:12:{s:4:"name";s:9:"Dashboard";s:11:"description";s:136:"Provides a dashboard page in the administrative interface for organizing administrative tasks and tracking information within your site.";s:4:"core";s:3:"7.x";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:5:"files";a:1:{i:0;s:14:"dashboard.test";}s:12:"dependencies";a:1:{i:0;s:5:"block";}s:9:"configure";s:25:"admin/dashboard/customize";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/dblog/dblog.module', 'dblog', 'module', '', '0', '0', 7002, '0', 'a:11:{s:4:"name";s:16:"Database logging";s:11:"description";s:47:"Logs and records system events to the database.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:10:"dblog.test";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/field/field.module', 'field', 'module', '', '1', '0', 7003, '0', 'a:13:{s:4:"name";s:5:"Field";s:11:"description";s:57:"Field API to add fields to entities like nodes and users.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:4:{i:0;s:12:"field.module";i:1;s:16:"field.attach.inc";i:2;s:20:"field.info.class.inc";i:3;s:16:"tests/field.test";}s:12:"dependencies";a:1:{i:0;s:17:"field_sql_storage";}s:8:"required";b:1;s:11:"stylesheets";a:1:{s:3:"all";a:1:{s:15:"theme/field.css";s:29:"modules/field/theme/field.css";}}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/field/modules/field_sql_storage/field_sql_storage.module', 'field_sql_storage', 'module', '', '1', '0', 7002, '0', 'a:12:{s:4:"name";s:17:"Field SQL storage";s:11:"description";s:37:"Stores field data in an SQL database.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:5:"field";}s:5:"files";a:1:{i:0;s:22:"field_sql_storage.test";}s:8:"required";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/field/modules/list/list.module', 'list', 'module', '', '1', '0', 7002, '0', 'a:11:{s:4:"name";s:4:"List";s:11:"description";s:69:"Defines list field types. Use with Options to create selection lists.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:12:"dependencies";a:2:{i:0;s:5:"field";i:1;s:7:"options";}s:5:"files";a:1:{i:0;s:15:"tests/list.test";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/field/modules/list/tests/list_test.module', 'list_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:9:"List test";s:11:"description";s:41:"Support module for the List module tests.";s:4:"core";s:3:"7.x";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/field/modules/number/number.module', 'number', 'module', '', '1', '0', 0, '0', 'a:11:{s:4:"name";s:6:"Number";s:11:"description";s:28:"Defines numeric field types.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:5:"field";}s:5:"files";a:1:{i:0;s:11:"number.test";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/field/modules/options/options.module', 'options', 'module', '', '1', '0', 0, '0', 'a:11:{s:4:"name";s:7:"Options";s:11:"description";s:82:"Defines selection, check box and radio button widgets for text and numeric fields.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:5:"field";}s:5:"files";a:1:{i:0;s:12:"options.test";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/field/modules/text/text.module', 'text', 'module', '', '1', '0', 7000, '0', 'a:13:{s:4:"name";s:4:"Text";s:11:"description";s:32:"Defines simple text field types.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:5:"field";}s:5:"files";a:1:{i:0;s:9:"text.test";}s:8:"required";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;s:11:"explanation";s:114:"Field type(s) in use - see <a href="/2013/09_September/theme822.freesample/?q=admin/reports/fields">Field list</a>";}'),
('modules/field/tests/field_test.module', 'field_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:14:"Field API Test";s:11:"description";s:39:"Support module for the Field API tests.";s:4:"core";s:3:"7.x";s:7:"package";s:7:"Testing";s:5:"files";a:1:{i:0;s:21:"field_test.entity.inc";}s:7:"version";s:4:"7.23";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/field_ui/field_ui.module', 'field_ui', 'module', '', '1', '0', 0, '0', 'a:11:{s:4:"name";s:8:"Field UI";s:11:"description";s:33:"User interface for the Field API.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:5:"field";}s:5:"files";a:1:{i:0;s:13:"field_ui.test";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/file/file.module', 'file', 'module', '', '1', '0', 0, '0', 'a:11:{s:4:"name";s:4:"File";s:11:"description";s:26:"Defines a file field type.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:5:"field";}s:5:"files";a:1:{i:0;s:15:"tests/file.test";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/file/tests/file_module_test.module', 'file_module_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:9:"File test";s:11:"description";s:53:"Provides hooks for testing File module functionality.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/filter/filter.module', 'filter', 'module', '', '1', '0', 7010, '0', 'a:13:{s:4:"name";s:6:"Filter";s:11:"description";s:43:"Filters content in preparation for display.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:11:"filter.test";}s:8:"required";b:1;s:9:"configure";s:28:"admin/config/content/formats";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/forum/forum.module', 'forum', 'module', '', '1', '0', 7012, '1', 'a:13:{s:4:"name";s:5:"Forum";s:11:"description";s:27:"Provides discussion forums.";s:12:"dependencies";a:2:{i:0;s:8:"taxonomy";i:1;s:7:"comment";}s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:10:"forum.test";}s:9:"configure";s:21:"admin/structure/forum";s:11:"stylesheets";a:1:{s:3:"all";a:1:{s:9:"forum.css";s:23:"modules/forum/forum.css";}}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/help/help.module', 'help', 'module', '', '0', '0', 0, '0', 'a:11:{s:4:"name";s:4:"Help";s:11:"description";s:35:"Manages the display of online help.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:9:"help.test";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/image/image.module', 'image', 'module', '', '1', '0', 7005, '0', 'a:14:{s:4:"name";s:5:"Image";s:11:"description";s:34:"Provides image manipulation tools.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:4:"file";}s:5:"files";a:1:{i:0;s:10:"image.test";}s:9:"configure";s:31:"admin/config/media/image-styles";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;s:8:"required";b:1;s:11:"explanation";s:114:"Field type(s) in use - see <a href="/2013/09_September/theme822.freesample/?q=admin/reports/fields">Field list</a>";}'),
('modules/image/tests/image_module_test.module', 'image_module_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:10:"Image test";s:11:"description";s:69:"Provides hook implementations for testing Image module functionality.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:24:"image_module_test.module";}s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/locale/locale.module', 'locale', 'module', '', '1', '0', 7005, '0', 'a:12:{s:4:"name";s:6:"Locale";s:11:"description";s:119:"Adds language handling functionality and enables the translation of the user interface to languages other than English.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:11:"locale.test";}s:9:"configure";s:30:"admin/config/regional/language";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/locale/tests/locale_test.module', 'locale_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:11:"Locale Test";s:11:"description";s:42:"Support module for the locale layer tests.";s:4:"core";s:3:"7.x";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/menu/menu.module', 'menu', 'module', '', '1', '0', 7003, '0', 'a:12:{s:4:"name";s:4:"Menu";s:11:"description";s:60:"Allows administrators to customize the site navigation menu.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:9:"menu.test";}s:9:"configure";s:20:"admin/structure/menu";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/node/node.module', 'node', 'module', '', '1', '0', 7013, '0', 'a:14:{s:4:"name";s:4:"Node";s:11:"description";s:66:"Allows content to be submitted to the site and displayed on pages.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:2:{i:0;s:11:"node.module";i:1;s:9:"node.test";}s:8:"required";b:1;s:9:"configure";s:21:"admin/structure/types";s:11:"stylesheets";a:1:{s:3:"all";a:1:{s:8:"node.css";s:21:"modules/node/node.css";}}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/node/tests/node_access_test.module', 'node_access_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:24:"Node module access tests";s:11:"description";s:43:"Support module for node permission testing.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/node/tests/node_test.module', 'node_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:17:"Node module tests";s:11:"description";s:40:"Support module for node related testing.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/node/tests/node_test_exception.module', 'node_test_exception', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:27:"Node module exception tests";s:11:"description";s:50:"Support module for node related exception testing.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/openid/openid.module', 'openid', 'module', '', '0', '0', -1, '0', 'a:11:{s:4:"name";s:6:"OpenID";s:11:"description";s:48:"Allows users to log into your site using OpenID.";s:7:"version";s:4:"7.23";s:7:"package";s:4:"Core";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:11:"openid.test";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/openid/tests/openid_test.module', 'openid_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:21:"OpenID dummy provider";s:11:"description";s:33:"OpenID provider used for testing.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:6:"openid";}s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/overlay/overlay.module', 'overlay', 'module', '', '0', '0', 0, '0', 'a:11:{s:4:"name";s:7:"Overlay";s:11:"description";s:59:"Displays the Drupal administration interface in an overlay.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/path/path.module', 'path', 'module', '', '1', '0', 0, '0', 'a:12:{s:4:"name";s:4:"Path";s:11:"description";s:28:"Allows users to rename URLs.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:9:"path.test";}s:9:"configure";s:24:"admin/config/search/path";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/php/php.module', 'php', 'module', '', '1', '0', 0, '0', 'a:11:{s:4:"name";s:10:"PHP filter";s:11:"description";s:50:"Allows embedded PHP code/snippets to be evaluated.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:8:"php.test";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/poll/poll.module', 'poll', 'module', '', '1', '0', 7004, '0', 'a:12:{s:4:"name";s:4:"Poll";s:11:"description";s:95:"Allows your site to capture votes on different topics in the form of multiple choice questions.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:9:"poll.test";}s:11:"stylesheets";a:1:{s:3:"all";a:1:{s:8:"poll.css";s:21:"modules/poll/poll.css";}}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/profile/profile.module', 'profile', 'module', '', '0', '0', -1, '0', 'a:13:{s:4:"name";s:7:"Profile";s:11:"description";s:36:"Supports configurable user profiles.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:12:"profile.test";}s:9:"configure";s:27:"admin/config/people/profile";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/rdf/rdf.module', 'rdf', 'module', '', '0', '0', 0, '0', 'a:11:{s:4:"name";s:3:"RDF";s:11:"description";s:148:"Enriches your content with metadata to let other applications (e.g. search engines, aggregators) better understand its relationships and attributes.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:8:"rdf.test";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/rdf/tests/rdf_test.module', 'rdf_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:16:"RDF module tests";s:11:"description";s:38:"Support module for RDF module testing.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/search/search.module', 'search', 'module', '', '1', '0', 7000, '0', 'a:13:{s:4:"name";s:6:"Search";s:11:"description";s:36:"Enables site-wide keyword searching.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:2:{i:0;s:19:"search.extender.inc";i:1;s:11:"search.test";}s:9:"configure";s:28:"admin/config/search/settings";s:11:"stylesheets";a:1:{s:3:"all";a:1:{s:10:"search.css";s:25:"modules/search/search.css";}}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/search/tests/search_embedded_form.module', 'search_embedded_form', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:20:"Search embedded form";s:11:"description";s:59:"Support module for search module testing of embedded forms.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/search/tests/search_extra_type.module', 'search_extra_type', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:16:"Test search type";s:11:"description";s:41:"Support module for search module testing.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/shortcut/shortcut.module', 'shortcut', 'module', '', '1', '0', 0, '0', 'a:12:{s:4:"name";s:8:"Shortcut";s:11:"description";s:60:"Allows users to manage customizable lists of shortcut links.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:13:"shortcut.test";}s:9:"configure";s:36:"admin/config/user-interface/shortcut";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/simpletest/simpletest.module', 'simpletest', 'module', '', '0', '0', 0, '0', 'a:12:{s:4:"name";s:7:"Testing";s:11:"description";s:53:"Provides a framework for unit and functional testing.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:48:{i:0;s:15:"simpletest.test";i:1;s:24:"drupal_web_test_case.php";i:2;s:18:"tests/actions.test";i:3;s:15:"tests/ajax.test";i:4;s:16:"tests/batch.test";i:5;s:20:"tests/bootstrap.test";i:6;s:16:"tests/cache.test";i:7;s:17:"tests/common.test";i:8;s:24:"tests/database_test.test";i:9;s:32:"tests/entity_crud_hook_test.test";i:10;s:23:"tests/entity_query.test";i:11;s:16:"tests/error.test";i:12;s:15:"tests/file.test";i:13;s:23:"tests/filetransfer.test";i:14;s:15:"tests/form.test";i:15;s:16:"tests/graph.test";i:16;s:16:"tests/image.test";i:17;s:15:"tests/lock.test";i:18;s:15:"tests/mail.test";i:19;s:15:"tests/menu.test";i:20;s:17:"tests/module.test";i:21;s:16:"tests/pager.test";i:22;s:19:"tests/password.test";i:23;s:15:"tests/path.test";i:24;s:19:"tests/registry.test";i:25;s:17:"tests/schema.test";i:26;s:18:"tests/session.test";i:27;s:20:"tests/tablesort.test";i:28;s:16:"tests/theme.test";i:29;s:18:"tests/unicode.test";i:30;s:17:"tests/update.test";i:31;s:17:"tests/xmlrpc.test";i:32;s:26:"tests/upgrade/upgrade.test";i:33;s:34:"tests/upgrade/upgrade.comment.test";i:34;s:33:"tests/upgrade/upgrade.filter.test";i:35;s:32:"tests/upgrade/upgrade.forum.test";i:36;s:33:"tests/upgrade/upgrade.locale.test";i:37;s:31:"tests/upgrade/upgrade.menu.test";i:38;s:31:"tests/upgrade/upgrade.node.test";i:39;s:35:"tests/upgrade/upgrade.taxonomy.test";i:40;s:34:"tests/upgrade/upgrade.trigger.test";i:41;s:39:"tests/upgrade/upgrade.translatable.test";i:42;s:33:"tests/upgrade/upgrade.upload.test";i:43;s:31:"tests/upgrade/upgrade.user.test";i:44;s:36:"tests/upgrade/update.aggregator.test";i:45;s:33:"tests/upgrade/update.trigger.test";i:46;s:31:"tests/upgrade/update.field.test";i:47;s:30:"tests/upgrade/update.user.test";}s:9:"configure";s:41:"admin/config/development/testing/settings";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/actions_loop_test.module', 'actions_loop_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:17:"Actions loop test";s:11:"description";s:39:"Support module for action loop testing.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/ajax_forms_test.module', 'ajax_forms_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:26:"AJAX form test mock module";s:11:"description";s:25:"Test for AJAX form calls.";s:4:"core";s:3:"7.x";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/ajax_test.module', 'ajax_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:9:"AJAX Test";s:11:"description";s:40:"Support module for AJAX framework tests.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/batch_test.module', 'batch_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:14:"Batch API test";s:11:"description";s:35:"Support module for Batch API tests.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/common_test.module', 'common_test', 'module', '', '0', '0', -1, '0', 'a:13:{s:4:"name";s:11:"Common Test";s:11:"description";s:32:"Support module for Common tests.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:11:"stylesheets";a:2:{s:3:"all";a:1:{s:15:"common_test.css";s:40:"modules/simpletest/tests/common_test.css";}s:5:"print";a:1:{s:21:"common_test.print.css";s:46:"modules/simpletest/tests/common_test.print.css";}}s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/common_test_cron_helper.module', 'common_test_cron_helper', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:23:"Common Test Cron Helper";s:11:"description";s:56:"Helper module for CronRunTestCase::testCronExceptions().";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/database_test.module', 'database_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:13:"Database Test";s:11:"description";s:40:"Support module for Database layer tests.";s:4:"core";s:3:"7.x";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/drupal_system_listing_compatible_test/drupal_system_listing_compatible_test.module', 'drupal_system_listing_compatible_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:37:"Drupal system listing compatible test";s:11:"description";s:62:"Support module for testing the drupal_system_listing function.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/drupal_system_listing_incompatible_test/drupal_system_listing_incompatible_test.module', 'drupal_system_listing_incompatible_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:39:"Drupal system listing incompatible test";s:11:"description";s:62:"Support module for testing the drupal_system_listing function.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/entity_cache_test.module', 'entity_cache_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:17:"Entity cache test";s:11:"description";s:40:"Support module for testing entity cache.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:28:"entity_cache_test_dependency";}s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/entity_cache_test_dependency.module', 'entity_cache_test_dependency', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:28:"Entity cache test dependency";s:11:"description";s:51:"Support dependency module for testing entity cache.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/entity_crud_hook_test.module', 'entity_crud_hook_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:22:"Entity CRUD Hooks Test";s:11:"description";s:35:"Support module for CRUD hook tests.";s:4:"core";s:3:"7.x";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/entity_query_access_test.module', 'entity_query_access_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:24:"Entity query access test";s:11:"description";s:49:"Support module for checking entity query results.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/error_test.module', 'error_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:10:"Error test";s:11:"description";s:47:"Support module for error and exception testing.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/file_test.module', 'file_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:9:"File test";s:11:"description";s:39:"Support module for file handling tests.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:16:"file_test.module";}s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/filter_test.module', 'filter_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:18:"Filter test module";s:11:"description";s:33:"Tests filter hooks and functions.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/form_test.module', 'form_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:12:"FormAPI Test";s:11:"description";s:34:"Support module for Form API tests.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/image_test.module', 'image_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:10:"Image test";s:11:"description";s:39:"Support module for image toolkit tests.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/menu_test.module', 'menu_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:15:"Hook menu tests";s:11:"description";s:37:"Support module for menu hook testing.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/module_test.module', 'module_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:11:"Module test";s:11:"description";s:41:"Support module for module system testing.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/path_test.module', 'path_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:15:"Hook path tests";s:11:"description";s:37:"Support module for path hook testing.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/psr_0_test/psr_0_test.module', 'psr_0_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:16:"PSR-0 Test cases";s:11:"description";s:44:"Test classes to be discovered by simpletest.";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/requirements1_test.module', 'requirements1_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:19:"Requirements 1 Test";s:11:"description";s:80:"Tests that a module is not installed when it fails hook_requirements(''install'').";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/requirements2_test.module', 'requirements2_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:19:"Requirements 2 Test";s:11:"description";s:98:"Tests that a module is not installed when the one it depends on fails hook_requirements(''install).";s:12:"dependencies";a:2:{i:0;s:18:"requirements1_test";i:1;s:7:"comment";}s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/session_test.module', 'session_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:12:"Session test";s:11:"description";s:40:"Support module for session data testing.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/system_dependencies_test.module', 'system_dependencies_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:22:"System dependency test";s:11:"description";s:47:"Support module for testing system dependencies.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:12:"dependencies";a:1:{i:0;s:19:"_missing_dependency";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/system_incompatible_core_version_dependencies_test.module', 'system_incompatible_core_version_dependencies_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:50:"System incompatible core version dependencies test";s:11:"description";s:47:"Support module for testing system dependencies.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:12:"dependencies";a:1:{i:0;s:37:"system_incompatible_core_version_test";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/system_incompatible_core_version_test.module', 'system_incompatible_core_version_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:37:"System incompatible core version test";s:11:"description";s:47:"Support module for testing system dependencies.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"5.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/system_incompatible_module_version_dependencies_test.module', 'system_incompatible_module_version_dependencies_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:52:"System incompatible module version dependencies test";s:11:"description";s:47:"Support module for testing system dependencies.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:12:"dependencies";a:1:{i:0;s:46:"system_incompatible_module_version_test (>2.0)";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/system_incompatible_module_version_test.module', 'system_incompatible_module_version_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:39:"System incompatible module version test";s:11:"description";s:47:"Support module for testing system dependencies.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/system_test.module', 'system_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:11:"System test";s:11:"description";s:34:"Support module for system testing.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:18:"system_test.module";}s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/taxonomy_test.module', 'taxonomy_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:20:"Taxonomy test module";s:11:"description";s:45:""Tests functions and hooks not used in core".";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:12:"dependencies";a:1:{i:0;s:8:"taxonomy";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/theme_test.module', 'theme_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:10:"Theme test";s:11:"description";s:40:"Support module for theme system testing.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/update_script_test.module', 'update_script_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:18:"Update script test";s:11:"description";s:41:"Support module for update script testing.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/update_test_1.module', 'update_test_1', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:11:"Update test";s:11:"description";s:34:"Support module for update testing.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/update_test_2.module', 'update_test_2', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:11:"Update test";s:11:"description";s:34:"Support module for update testing.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/update_test_3.module', 'update_test_3', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:11:"Update test";s:11:"description";s:34:"Support module for update testing.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/url_alter_test.module', 'url_alter_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:15:"Url_alter tests";s:11:"description";s:45:"A support modules for url_alter hook testing.";s:4:"core";s:3:"7.x";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/simpletest/tests/xmlrpc_test.module', 'xmlrpc_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:12:"XML-RPC Test";s:11:"description";s:75:"Support module for XML-RPC tests according to the validator1 specification.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/statistics/statistics.module', 'statistics', 'module', '', '0', '0', 7000, '0', 'a:12:{s:4:"name";s:10:"Statistics";s:11:"description";s:37:"Logs access statistics for your site.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:15:"statistics.test";}s:9:"configure";s:30:"admin/config/system/statistics";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/syslog/syslog.module', 'syslog', 'module', '', '0', '0', 0, '0', 'a:12:{s:4:"name";s:6:"Syslog";s:11:"description";s:41:"Logs and records system events to syslog.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:11:"syslog.test";}s:9:"configure";s:32:"admin/config/development/logging";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/system/system.module', 'system', 'module', '', '1', '0', 7078, '0', 'a:13:{s:4:"name";s:6:"System";s:11:"description";s:54:"Handles general site configuration for administrators.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:6:{i:0;s:19:"system.archiver.inc";i:1;s:15:"system.mail.inc";i:2;s:16:"system.queue.inc";i:3;s:14:"system.tar.inc";i:4;s:18:"system.updater.inc";i:5;s:11:"system.test";}s:8:"required";b:1;s:9:"configure";s:19:"admin/config/system";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/taxonomy/taxonomy.module', 'taxonomy', 'module', '', '1', '0', 7010, '0', 'a:14:{s:4:"name";s:8:"Taxonomy";s:11:"description";s:38:"Enables the categorization of content.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:7:"options";}s:5:"files";a:2:{i:0;s:15:"taxonomy.module";i:1;s:13:"taxonomy.test";}s:9:"configure";s:24:"admin/structure/taxonomy";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;s:8:"required";b:1;s:11:"explanation";s:114:"Field type(s) in use - see <a href="/2013/09_September/theme822.freesample/?q=admin/reports/fields">Field list</a>";}'),
('modules/toolbar/toolbar.module', 'toolbar', 'module', '', '1', '0', 0, '0', 'a:11:{s:4:"name";s:7:"Toolbar";s:11:"description";s:99:"Provides a toolbar that shows the top-level administration menu items and links from other modules.";s:4:"core";s:3:"7.x";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/tracker/tracker.module', 'tracker', 'module', '', '1', '0', 7000, '0', 'a:11:{s:4:"name";s:7:"Tracker";s:11:"description";s:45:"Enables tracking of recent content for users.";s:12:"dependencies";a:1:{i:0;s:7:"comment";}s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:12:"tracker.test";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/translation/tests/translation_test.module', 'translation_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:24:"Content Translation Test";s:11:"description";s:49:"Support module for the content translation tests.";s:4:"core";s:3:"7.x";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/translation/translation.module', 'translation', 'module', '', '0', '0', 0, '0', 'a:11:{s:4:"name";s:19:"Content translation";s:11:"description";s:57:"Allows content to be translated into different languages.";s:12:"dependencies";a:1:{i:0;s:6:"locale";}s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:16:"translation.test";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/trigger/tests/trigger_test.module', 'trigger_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:12:"Trigger Test";s:11:"description";s:33:"Support module for Trigger tests.";s:7:"package";s:7:"Testing";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"version";s:4:"7.23";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/trigger/trigger.module', 'trigger', 'module', '', '1', '0', 7002, '0', 'a:12:{s:4:"name";s:7:"Trigger";s:11:"description";s:90:"Enables actions to be fired on certain system events, such as when new content is created.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:12:"trigger.test";}s:9:"configure";s:23:"admin/structure/trigger";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}');
INSERT INTO `system` VALUES
('modules/update/tests/aaa_update_test.module', 'aaa_update_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:15:"AAA Update test";s:11:"description";s:41:"Support module for update module testing.";s:7:"package";s:7:"Testing";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"version";s:4:"7.23";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/update/tests/bbb_update_test.module', 'bbb_update_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:15:"BBB Update test";s:11:"description";s:41:"Support module for update module testing.";s:7:"package";s:7:"Testing";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"version";s:4:"7.23";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/update/tests/ccc_update_test.module', 'ccc_update_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:15:"CCC Update test";s:11:"description";s:41:"Support module for update module testing.";s:7:"package";s:7:"Testing";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"version";s:4:"7.23";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/update/tests/update_test.module', 'update_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:11:"Update test";s:11:"description";s:41:"Support module for update module testing.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/update/update.module', 'update', 'module', '', '1', '0', 7001, '0', 'a:12:{s:4:"name";s:14:"Update manager";s:11:"description";s:104:"Checks for available updates, and can securely install or update modules and themes via a web interface.";s:7:"version";s:4:"7.23";s:7:"package";s:4:"Core";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:11:"update.test";}s:9:"configure";s:30:"admin/reports/updates/settings";s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('modules/user/tests/user_form_test.module', 'user_form_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:22:"User module form tests";s:11:"description";s:37:"Support module for user form testing.";s:7:"package";s:7:"Testing";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:6:"hidden";b:1;s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('modules/user/user.module', 'user', 'module', '', '1', '0', 7018, '0', 'a:14:{s:4:"name";s:4:"User";s:11:"description";s:47:"Manages the user registration and login system.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:5:"files";a:2:{i:0;s:11:"user.module";i:1;s:9:"user.test";}s:8:"required";b:1;s:9:"configure";s:19:"admin/config/people";s:11:"stylesheets";a:1:{s:3:"all";a:1:{s:8:"user.css";s:21:"modules/user/user.css";}}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('profiles/demo_profile/demo_profile.profile', 'demo_profile', 'module', '', '0', '0', 0, '1000', 'a:14:{s:4:"name";s:18:"Demonstration site";s:11:"description";s:66:"Create a pre-setup and pre-configured Drupal site from a snapshot.";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:4:"demo";}s:5:"files";a:1:{i:0;s:20:"demo_profile.profile";}s:7:"version";s:11:"7.x-1.x-dev";s:7:"project";s:12:"demo_profile";s:9:"datestamp";s:10:"1298619105";s:7:"package";s:5:"Other";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;s:6:"hidden";b:1;s:8:"required";b:1;s:17:"distribution_name";s:6:"Drupal";}'),
('profiles/standard/standard.profile', 'standard', 'module', '', '0', '0', 0, '1000', 'a:14:{s:4:"name";s:8:"Standard";s:11:"description";s:51:"Install with commonly used features pre-configured.";s:7:"version";s:3:"7.2";s:4:"core";s:3:"7.x";s:12:"dependencies";a:21:{i:0;s:5:"block";i:1;s:5:"color";i:2;s:7:"comment";i:3;s:10:"contextual";i:4;s:9:"dashboard";i:5;s:4:"help";i:6;s:5:"image";i:7;s:4:"list";i:8;s:4:"menu";i:9;s:6:"number";i:10;s:7:"options";i:11;s:4:"path";i:12;s:8:"taxonomy";i:13;s:5:"dblog";i:14;s:6:"search";i:15;s:8:"shortcut";i:16;s:7:"toolbar";i:17;s:7:"overlay";i:18;s:8:"field_ui";i:19;s:4:"file";i:20;s:3:"rdf";}s:5:"files";a:1:{i:0;s:16:"standard.profile";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1306357016";s:7:"package";s:5:"Other";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;s:6:"hidden";b:1;s:8:"required";b:1;s:17:"distribution_name";s:6:"Drupal";}'),
('sites/all/modules/addthis/addthis.module', 'addthis', 'module', '', '1', '0', 0, '0', 'a:14:{s:4:"name";s:7:"AddThis";s:11:"description";s:70:"AddThis.com provides an easy way to share your content across the web.";s:4:"core";s:3:"7.x";s:7:"package";s:7:"Sharing";s:12:"dependencies";a:2:{i:0;s:5:"block";i:1;s:5:"field";}s:5:"files";a:8:{i:0;s:14:"addthis.module";i:1;s:15:"addthis.install";i:2;s:12:"addthis.test";i:3;s:26:"includes/addthis.admin.inc";i:4;s:26:"includes/addthis.block.inc";i:5;s:26:"includes/addthis.field.inc";i:6;s:19:"classes/AddThis.php";i:7;s:23:"classes/AddThisJson.php";}s:9:"configure";s:35:"admin/config/user-interface/addthis";s:7:"version";s:14:"7.x-4.0-alpha2";s:7:"project";s:7:"addthis";s:9:"datestamp";s:10:"1359545712";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;s:8:"required";b:1;s:11:"explanation";s:114:"Field type(s) in use - see <a href="/2013/09_September/theme822.freesample/?q=admin/reports/fields">Field list</a>";}'),
('sites/all/modules/addthis/addthis_displays/addthis_displays.module', 'addthis_displays', 'module', '', '1', '0', 0, '0', 'a:11:{s:4:"name";s:16:"AddThis Displays";s:11:"description";s:80:"Adds the AddThis display types to render several basic types of AddThis buttons.";s:4:"core";s:3:"7.x";s:7:"package";s:7:"Sharing";s:12:"dependencies";a:1:{i:0;s:7:"addthis";}s:5:"files";a:1:{i:0;s:26:"addthis_displays.field.inc";}s:7:"version";s:14:"7.x-4.0-alpha2";s:7:"project";s:7:"addthis";s:9:"datestamp";s:10:"1359545712";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/addtoany/addtoany.module', 'addtoany', 'module', '', '0', '0', 0, '0', 'a:12:{s:4:"name";s:8:"AddToAny";s:11:"description";s:227:"Helps readers share, bookmark, and email your articles and pages using any service, such as Facebook, Twitter, Delicious, Digg, and over 100 more using the <a href=''http://www.addtoany.com/'' target=''_blank''>AddToAny</a> widget.";s:4:"core";s:3:"7.x";s:5:"files";a:5:{i:0;s:15:"addtoany.module";i:1;s:12:"addtoany.css";i:2;s:18:"addtoany.admin.inc";i:3;s:46:"views/addtoany_handler_field_addtoany_link.inc";i:4;s:24:"views/addtoany.views.inc";}s:9:"configure";s:28:"admin/config/system/addtoany";s:7:"version";s:7:"7.x-3.1";s:7:"project";s:8:"addtoany";s:9:"datestamp";s:10:"1299485766";s:12:"dependencies";a:0:{}s:7:"package";s:5:"Other";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/admin_menu/admin_devel/admin_devel.module', 'admin_devel', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:32:"Administration Development tools";s:11:"description";s:76:"Administration and debugging functionality for developers and site builders.";s:7:"package";s:14:"Administration";s:4:"core";s:3:"7.x";s:7:"scripts";a:1:{s:14:"admin_devel.js";s:55:"sites/all/modules/admin_menu/admin_devel/admin_devel.js";}s:7:"version";s:11:"7.x-3.0-rc4";s:7:"project";s:10:"admin_menu";s:9:"datestamp";s:10:"1359651687";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/admin_menu/admin_menu.module', 'admin_menu', 'module', '', '1', '0', 7304, '100', 'a:12:{s:4:"name";s:19:"Administration menu";s:11:"description";s:123:"Provides a dropdown menu to most administrative tasks and other common destinations (to users with the proper permissions).";s:7:"package";s:14:"Administration";s:4:"core";s:3:"7.x";s:9:"configure";s:38:"admin/config/administration/admin_menu";s:12:"dependencies";a:1:{i:0;s:14:"system (>7.10)";}s:5:"files";a:1:{i:0;s:21:"tests/admin_menu.test";}s:7:"version";s:11:"7.x-3.0-rc4";s:7:"project";s:10:"admin_menu";s:9:"datestamp";s:10:"1359651687";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/admin_menu/admin_menu_toolbar/admin_menu_toolbar.module', 'admin_menu_toolbar', 'module', '', '1', '0', 6300, '101', 'a:11:{s:4:"name";s:33:"Administration menu Toolbar style";s:11:"description";s:17:"A better Toolbar.";s:7:"package";s:14:"Administration";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:10:"admin_menu";}s:7:"version";s:11:"7.x-3.0-rc4";s:7:"project";s:10:"admin_menu";s:9:"datestamp";s:10:"1359651687";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/back_to_top/back_to_top.module', 'back_to_top', 'module', '', '1', '0', 0, '0', 'a:12:{s:4:"name";s:11:"Back To Top";s:11:"description";s:127:"Back To Top adds a button that hovers in the bottom of your screen and allow users to smoothly scroll up the page using jQuery.";s:4:"core";s:3:"7.x";s:9:"configure";s:39:"admin/config/user-interface/back_to_top";s:7:"version";s:7:"7.x-1.3";s:7:"project";s:11:"back_to_top";s:9:"datestamp";s:10:"1342774580";s:12:"dependencies";a:0:{}s:7:"package";s:5:"Other";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/block_class/block_class.module', 'block_class', 'module', '', '1', '0', 7103, '0', 'a:12:{s:4:"name";s:11:"Block Class";s:11:"description";s:39:"Allows assigning CSS classes to blocks.";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:5:"block";}s:5:"files";a:1:{i:0;s:16:"block_class.test";}s:17:"test_dependencies";a:1:{i:0;s:7:"context";}s:7:"version";s:7:"7.x-2.1";s:7:"project";s:11:"block_class";s:9:"datestamp";s:10:"1377197769";s:7:"package";s:5:"Other";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/colorbox/colorbox.module', 'colorbox', 'module', '', '1', '0', 7202, '0', 'a:12:{s:4:"name";s:8:"Colorbox";s:11:"description";s:63:"A light-weight, customizable lightbox plugin for jQuery 1.4.3+.";s:12:"dependencies";a:1:{i:0;s:15:"libraries (2.x)";}s:4:"core";s:3:"7.x";s:9:"configure";s:27:"admin/config/media/colorbox";s:5:"files";a:1:{i:0;s:41:"views/colorbox_handler_field_colorbox.inc";}s:7:"version";s:7:"7.x-2.4";s:7:"project";s:8:"colorbox";s:9:"datestamp";s:10:"1365452412";s:7:"package";s:5:"Other";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/ctools/bulk_export/bulk_export.module', 'bulk_export', 'module', '', '0', '0', -1, '0', 'a:11:{s:4:"name";s:11:"Bulk Export";s:11:"description";s:67:"Performs bulk exporting of data objects known about by Chaos tools.";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:6:"ctools";}s:7:"package";s:16:"Chaos tool suite";s:7:"version";s:7:"7.x-1.3";s:7:"project";s:6:"ctools";s:9:"datestamp";s:10:"1365013512";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/ctools/ctools.module', 'ctools', 'module', '', '1', '0', 6008, '0', 'a:11:{s:4:"name";s:11:"Chaos tools";s:11:"description";s:46:"A library of helpful tools by Merlin of Chaos.";s:4:"core";s:3:"7.x";s:7:"package";s:16:"Chaos tool suite";s:5:"files";a:3:{i:0;s:20:"includes/context.inc";i:1;s:22:"includes/math-expr.inc";i:2;s:21:"includes/stylizer.inc";}s:7:"version";s:7:"7.x-1.3";s:7:"project";s:6:"ctools";s:9:"datestamp";s:10:"1365013512";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/ctools/ctools_access_ruleset/ctools_access_ruleset.module', 'ctools_access_ruleset', 'module', '', '0', '0', -1, '0', 'a:11:{s:4:"name";s:15:"Custom rulesets";s:11:"description";s:81:"Create custom, exportable, reusable access rulesets for applications like Panels.";s:4:"core";s:3:"7.x";s:7:"package";s:16:"Chaos tool suite";s:12:"dependencies";a:1:{i:0;s:6:"ctools";}s:7:"version";s:7:"7.x-1.3";s:7:"project";s:6:"ctools";s:9:"datestamp";s:10:"1365013512";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/ctools/ctools_ajax_sample/ctools_ajax_sample.module', 'ctools_ajax_sample', 'module', '', '0', '0', -1, '0', 'a:11:{s:4:"name";s:33:"Chaos Tools (CTools) AJAX Example";s:11:"description";s:41:"Shows how to use the power of Chaos AJAX.";s:7:"package";s:16:"Chaos tool suite";s:12:"dependencies";a:1:{i:0;s:6:"ctools";}s:4:"core";s:3:"7.x";s:7:"version";s:7:"7.x-1.3";s:7:"project";s:6:"ctools";s:9:"datestamp";s:10:"1365013512";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/ctools/ctools_custom_content/ctools_custom_content.module', 'ctools_custom_content', 'module', '', '0', '0', -1, '0', 'a:11:{s:4:"name";s:20:"Custom content panes";s:11:"description";s:79:"Create custom, exportable, reusable content panes for applications like Panels.";s:4:"core";s:3:"7.x";s:7:"package";s:16:"Chaos tool suite";s:12:"dependencies";a:1:{i:0;s:6:"ctools";}s:7:"version";s:7:"7.x-1.3";s:7:"project";s:6:"ctools";s:9:"datestamp";s:10:"1365013512";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/ctools/ctools_plugin_example/ctools_plugin_example.module', 'ctools_plugin_example', 'module', '', '0', '0', -1, '0', 'a:11:{s:4:"name";s:35:"Chaos Tools (CTools) Plugin Example";s:11:"description";s:75:"Shows how an external module can provide ctools plugins (for Panels, etc.).";s:7:"package";s:16:"Chaos tool suite";s:12:"dependencies";a:4:{i:0;s:6:"ctools";i:1;s:6:"panels";i:2;s:12:"page_manager";i:3;s:13:"advanced_help";}s:4:"core";s:3:"7.x";s:7:"version";s:7:"7.x-1.3";s:7:"project";s:6:"ctools";s:9:"datestamp";s:10:"1365013512";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/ctools/page_manager/page_manager.module', 'page_manager', 'module', '', '1', '0', 0, '99', 'a:11:{s:4:"name";s:12:"Page manager";s:11:"description";s:54:"Provides a UI and API to manage pages within the site.";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:6:"ctools";}s:7:"package";s:16:"Chaos tool suite";s:7:"version";s:7:"7.x-1.3";s:7:"project";s:6:"ctools";s:9:"datestamp";s:10:"1365013512";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/ctools/stylizer/stylizer.module', 'stylizer', 'module', '', '0', '0', -1, '0', 'a:11:{s:4:"name";s:8:"Stylizer";s:11:"description";s:53:"Create custom styles for applications such as Panels.";s:4:"core";s:3:"7.x";s:7:"package";s:16:"Chaos tool suite";s:12:"dependencies";a:2:{i:0;s:6:"ctools";i:1;s:5:"color";}s:7:"version";s:7:"7.x-1.3";s:7:"project";s:6:"ctools";s:9:"datestamp";s:10:"1365013512";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/ctools/tests/ctools_export_test/ctools_export_test.module', 'ctools_export_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:18:"CTools export test";s:11:"description";s:25:"CTools export test module";s:4:"core";s:3:"7.x";s:7:"package";s:16:"Chaos tool suite";s:12:"dependencies";a:1:{i:0;s:6:"ctools";}s:6:"hidden";b:1;s:5:"files";a:1:{i:0;s:18:"ctools_export.test";}s:7:"version";s:7:"7.x-1.3";s:7:"project";s:6:"ctools";s:9:"datestamp";s:10:"1365013512";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/ctools/tests/ctools_plugin_test.module', 'ctools_plugin_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:24:"Chaos tools plugins test";s:11:"description";s:42:"Provides hooks for testing ctools plugins.";s:7:"package";s:16:"Chaos tool suite";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:6:"ctools";}s:5:"files";a:6:{i:0;s:19:"ctools.plugins.test";i:1;s:17:"object_cache.test";i:2;s:8:"css.test";i:3;s:12:"context.test";i:4;s:20:"math_expression.test";i:5;s:26:"math_expression_stack.test";}s:6:"hidden";b:1;s:7:"version";s:7:"7.x-1.3";s:7:"project";s:6:"ctools";s:9:"datestamp";s:10:"1365013512";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/ctools/views_content/views_content.module', 'views_content', 'module', '', '0', '0', -1, '0', 'a:11:{s:4:"name";s:19:"Views content panes";s:11:"description";s:104:"Allows Views content to be used in Panels, Dashboard and other modules which use the CTools Content API.";s:7:"package";s:16:"Chaos tool suite";s:12:"dependencies";a:2:{i:0;s:6:"ctools";i:1;s:5:"views";}s:4:"core";s:3:"7.x";s:5:"files";a:3:{i:0;s:61:"plugins/views/views_content_plugin_display_ctools_context.inc";i:1;s:57:"plugins/views/views_content_plugin_display_panel_pane.inc";i:2;s:59:"plugins/views/views_content_plugin_style_ctools_context.inc";}s:7:"version";s:7:"7.x-1.3";s:7:"project";s:6:"ctools";s:9:"datestamp";s:10:"1365013512";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/cumulus/cumulus.module', 'cumulus', 'module', '', '0', '0', 7000, '0', 'a:11:{s:4:"name";s:7:"Cumulus";s:11:"description";s:36:"Provides a Flash-based 3D tag cloud.";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:9:"tagadelic";}s:7:"package";s:8:"Taxonomy";s:7:"version";s:11:"7.x-1.x-dev";s:7:"project";s:7:"cumulus";s:9:"datestamp";s:10:"1303085170";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/demo/demo.module', 'demo', 'module', '', '1', '0', 6100, '0', 'a:12:{s:4:"name";s:18:"Demonstration site";s:11:"description";s:74:"Create snapshots and reset the site for demonstration or testing purposes.";s:7:"package";s:11:"Development";s:4:"core";s:3:"7.x";s:9:"configure";s:20:"admin/structure/demo";s:5:"files";a:3:{i:0;s:11:"demo.module";i:1;s:14:"demo.admin.inc";i:2;s:23:"database_mysql_dump.inc";}s:7:"version";s:13:"7.x-1.0+6-dev";s:7:"project";s:4:"demo";s:9:"datestamp";s:10:"1338034161";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/demo/demo_reset.module', 'demo_reset', 'module', '', '0', '0', 0, '0', 'a:11:{s:4:"name";s:24:"Demonstration site reset";s:11:"description";s:176:"Allows to reset the site on cron runs and to <strong>reset the site WITHOUT CONFIRMATION.</strong> Only supposed to be used on public demonstration sites. Use at your own risk.";s:7:"package";s:11:"Development";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:4:"demo";}s:5:"files";a:1:{i:0;s:17:"demo_reset.module";}s:7:"version";s:13:"7.x-1.0+6-dev";s:7:"project";s:4:"demo";s:9:"datestamp";s:10:"1338034161";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/devel/devel.module', 'devel', 'module', '', '0', '0', 7004, '88', 'a:13:{s:4:"name";s:5:"Devel";s:11:"description";s:52:"Various blocks, pages, and functions for developers.";s:7:"package";s:11:"Development";s:4:"core";s:3:"7.x";s:9:"configure";s:30:"admin/config/development/devel";s:4:"tags";a:1:{i:0;s:9:"developer";}s:5:"files";a:2:{i:0;s:10:"devel.test";i:1;s:14:"devel.mail.inc";}s:7:"version";s:7:"7.x-1.3";s:7:"project";s:5:"devel";s:9:"datestamp";s:10:"1338940281";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/devel/devel_generate/devel_generate.module', 'devel_generate', 'module', '', '0', '0', 0, '0', 'a:13:{s:4:"name";s:14:"Devel generate";s:11:"description";s:48:"Generate dummy users, nodes, and taxonomy terms.";s:7:"package";s:11:"Development";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:5:"devel";}s:4:"tags";a:1:{i:0;s:9:"developer";}s:9:"configure";s:33:"admin/config/development/generate";s:7:"version";s:7:"7.x-1.3";s:7:"project";s:5:"devel";s:9:"datestamp";s:10:"1338940281";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/dismiss/dismiss.module', 'dismiss', 'module', '', '1', '0', 0, '0', 'a:13:{s:4:"name";s:7:"Dismiss";s:11:"description";s:65:"Adds a "Dismiss" button to Drupal messages, warnings, and errors.";s:4:"core";s:3:"7.x";s:7:"package";s:14:"User interface";s:5:"files";a:1:{i:0;s:14:"dismiss.module";}s:11:"stylesheets";a:1:{s:3:"all";a:1:{s:20:"css/dismiss.base.css";s:46:"sites/all/modules/dismiss/css/dismiss.base.css";}}s:7:"scripts";a:1:{s:13:"js/dismiss.js";s:39:"sites/all/modules/dismiss/js/dismiss.js";}s:7:"version";s:7:"7.x-1.1";s:7:"project";s:7:"dismiss";s:9:"datestamp";s:10:"1348238539";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/faq/faq.module', 'faq', 'module', '', '1', '0', 7001, '0', 'a:12:{s:4:"name";s:26:"Frequently Asked Questions";s:11:"description";s:50:"Manages configuration of questions for a FAQ page.";s:4:"core";s:3:"7.x";s:5:"files";a:18:{i:0;s:13:"faq.admin.inc";i:1;s:11:"faq.install";i:2;s:10:"faq.module";i:3;s:8:"faq.test";i:4;s:41:"includes/faq-category-hide-answer.tpl.php";i:5;s:38:"includes/faq-category-new-page.tpl.php";i:6;s:46:"includes/faq-category-questions-inline.tpl.php";i:7;s:51:"includes/faq-category-questions-top-answers.tpl.php";i:8;s:43:"includes/faq-category-questions-top.tpl.php";i:9;s:32:"includes/faq-hide-answer.tpl.php";i:10;s:29:"includes/faq-new-page.tpl.php";i:11;s:37:"includes/faq-questions-inline.tpl.php";i:12;s:34:"includes/faq-questions-top.tpl.php";i:13;s:28:"includes/faq.hide_answer.inc";i:14;s:25:"includes/faq.new_page.inc";i:15;s:33:"includes/faq.questions_inline.inc";i:16;s:30:"includes/faq.questions_top.inc";i:17;s:19:"views/faq.views.inc";}s:9:"configure";s:25:"/admin/config/content/faq";s:7:"version";s:11:"7.x-1.0-rc2";s:7:"project";s:3:"faq";s:9:"datestamp";s:10:"1329952549";s:12:"dependencies";a:0:{}s:7:"package";s:5:"Other";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/flexslider/flexslider.module', 'flexslider', 'module', '', '1', '0', 7201, '0', 'a:12:{s:4:"name";s:10:"FlexSlider";s:11:"description";s:46:"Integrate the FlexSlider 2 library with Drupal";s:4:"core";s:3:"7.x";s:7:"package";s:10:"FlexSlider";s:12:"dependencies";a:3:{i:0;s:17:"libraries (>=2.x)";i:1;s:6:"ctools";i:2;s:5:"image";}s:5:"files";a:2:{i:0;s:26:"theme/flexslider.theme.inc";i:1;s:15:"flexslider.test";}s:9:"configure";s:29:"admin/config/media/flexslider";s:7:"version";s:14:"7.x-2.0-alpha3";s:7:"project";s:10:"flexslider";s:9:"datestamp";s:10:"1378663043";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/flexslider/flexslider_example/flexslider_example.module', 'flexslider_example', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:18:"FlexSlider Example";s:11:"description";s:35:"Sample implementation of FlexSlider";s:4:"core";s:3:"7.x";s:7:"package";s:10:"FlexSlider";s:3:"php";s:5:"5.2.4";s:12:"dependencies";a:9:{i:0;s:7:"context";i:1;s:8:"features";i:2;s:10:"flexslider";i:3;s:17:"flexslider_fields";i:4;s:16:"flexslider_views";i:5;s:5:"image";i:6;s:4:"menu";i:7;s:9:"strongarm";i:8;s:5:"views";}s:8:"features";a:9:{s:7:"context";a:1:{i:0;s:28:"flexslider_example_thumbnail";}s:6:"ctools";a:4:{i:0;s:17:"context:context:3";i:1;s:38:"flexslider:flexslider_default_preset:1";i:2;s:21:"strongarm:strongarm:1";i:3;s:23:"views:views_default:3.0";}s:12:"features_api";a:1:{i:0;s:5:"api:1";}s:5:"field";a:2:{i:0;s:54:"node-flexslider_example-field_flexslider_example_image";i:1;s:56:"node-flexslider_example-field_flexslider_example_slidesh";}s:20:"flexslider_optionset";a:6:{i:0;s:43:"flexslider_carousel_with_min_and_max_ranges";i:1;s:33:"flexslider_default_basic_carousel";i:2;s:46:"flexslider_default_slider_thumbnail_controlnav";i:3;s:44:"flexslider_default_slider_w_thumbnail_slider";i:4;s:37:"flexslider_default_thumbnail_captions";i:5;s:35:"flexslider_default_thumbnail_slider";}s:11:"menu_custom";a:1:{i:0;s:23:"menu-flexslider-example";}s:4:"node";a:1:{i:0;s:18:"flexslider_example";}s:8:"variable";a:1:{i:0;s:46:"field_bundle_settings_node__flexslider_example";}s:10:"views_view";a:1:{i:0;s:24:"flexslider_views_example";}}s:7:"version";s:14:"7.x-2.0-alpha3";s:7:"project";s:10:"flexslider";s:9:"datestamp";s:10:"1378663043";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/flexslider/flexslider_fields/flexslider_fields.module', 'flexslider_fields', 'module', '', '1', '0', 0, '0', 'a:11:{s:4:"name";s:17:"FlexSlider Fields";s:11:"description";s:44:"Adds a display mode in Fields for FlexSlider";s:4:"core";s:3:"7.x";s:7:"package";s:10:"FlexSlider";s:12:"dependencies";a:1:{i:0;s:10:"flexslider";}s:7:"version";s:14:"7.x-2.0-alpha3";s:7:"project";s:10:"flexslider";s:9:"datestamp";s:10:"1378663043";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/flexslider/flexslider_views/flexslider_views.module', 'flexslider_views', 'module', '', '1', '0', 0, '0', 'a:11:{s:4:"name";s:22:"FlexSlider Views Style";s:11:"description";s:40:"Adds a Views style plugin for FlexSlider";s:4:"core";s:3:"7.x";s:7:"package";s:10:"FlexSlider";s:12:"dependencies";a:2:{i:0;s:5:"views";i:1;s:10:"flexslider";}s:5:"files";a:3:{i:0;s:23:"flexslider_views.module";i:1;s:26:"flexslider_views.views.inc";i:2;s:44:"flexslider_views_plugin_style_flexslider.inc";}s:7:"version";s:14:"7.x-2.0-alpha3";s:7:"project";s:10:"flexslider";s:9:"datestamp";s:10:"1378663043";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/flexslider_views_slideshow/flexslider_views_slideshow.module', 'flexslider_views_slideshow', 'module', '', '1', '0', 0, '0', 'a:11:{s:4:"name";s:26:"FlexSlider Views Slideshow";s:11:"description";s:70:"NOT FUNCTIONAL - Integrate the FlexSlider library with Views Slideshow";s:4:"core";s:3:"7.x";s:7:"package";s:10:"FlexSlider";s:12:"dependencies";a:2:{i:0;s:10:"flexslider";i:1;s:15:"views_slideshow";}s:5:"files";a:3:{i:0;s:33:"flexslider_views_slideshow.module";i:1;s:46:"flexslider_views_slideshow.views_slideshow.inc";i:2;s:42:"theme/flexslider_views_slideshow.theme.inc";}s:7:"version";s:11:"7.x-2.x-dev";s:7:"project";s:26:"flexslider_views_slideshow";s:9:"datestamp";s:10:"1363463413";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/flickr/block/flickr_block.module', 'flickr_block', 'module', '', '0', '0', 0, '0', 'a:11:{s:4:"name";s:12:"Flickr Block";s:11:"description";s:62:"Adds capability to display Flickr photos and sets into blocks.";s:12:"dependencies";a:1:{i:0;s:6:"flickr";}s:7:"package";s:6:"Flickr";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:19:"flickr_block.module";}s:7:"version";s:11:"7.x-1.x-dev";s:7:"project";s:6:"flickr";s:9:"datestamp";s:10:"1302091625";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/flickr/filter/flickr_filter.module', 'flickr_filter', 'module', '', '0', '0', 0, '0', 'a:11:{s:4:"name";s:13:"Flickr Filter";s:11:"description";s:60:"Adds a filter to insert Flickr photos and sets into content.";s:12:"dependencies";a:1:{i:0;s:6:"flickr";}s:7:"package";s:6:"Flickr";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:20:"flickr_filter.module";}s:7:"version";s:11:"7.x-1.x-dev";s:7:"project";s:6:"flickr";s:9:"datestamp";s:10:"1302091625";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/flickr/flickr.module', 'flickr', 'module', '', '0', '0', 0, '0', 'a:11:{s:4:"name";s:6:"Flickr";s:11:"description";s:30:"Flickr and Drupal integration.";s:7:"package";s:6:"Flickr";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:13:"flickr.module";}s:7:"version";s:11:"7.x-1.x-dev";s:7:"project";s:6:"flickr";s:9:"datestamp";s:10:"1302091625";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/flickr/sets/flickr_sets.module', 'flickr_sets', 'module', '', '0', '0', 0, '0', 'a:11:{s:4:"name";s:11:"Flickr Sets";s:11:"description";s:46:"Adds photoset capability to the Flickr module.";s:12:"dependencies";a:1:{i:0;s:6:"flickr";}s:7:"package";s:6:"Flickr";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:18:"flickr_sets.module";}s:7:"version";s:11:"7.x-1.x-dev";s:7:"project";s:6:"flickr";s:9:"datestamp";s:10:"1302091625";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/flickr/tags/flickr_tags.module', 'flickr_tags', 'module', '', '0', '0', 0, '0', 'a:11:{s:4:"name";s:11:"Flickr Tags";s:11:"description";s:38:"Adds tags capability to Flickr module.";s:12:"dependencies";a:1:{i:0;s:6:"flickr";}s:7:"package";s:6:"Flickr";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:17:"flickr_tag.module";}s:7:"version";s:11:"7.x-1.x-dev";s:7:"project";s:6:"flickr";s:9:"datestamp";s:10:"1302091625";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/follow/follow.module', 'follow', 'module', '', '1', '0', 7004, '0', 'a:12:{s:4:"name";s:6:"Follow";s:11:"description";s:59:"Add sitewide and per user links to social network profiles.";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:17:"tests/follow.test";}s:6:"config";s:28:"admin/config/services/follow";s:7:"version";s:14:"7.x-2.0-alpha1";s:7:"project";s:6:"follow";s:9:"datestamp";s:10:"1366924811";s:12:"dependencies";a:0:{}s:7:"package";s:5:"Other";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/follow/tests/follow_test/follow_test.module', 'follow_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:18:"Follow Test module";s:11:"description";s:31:"Used for Testing Follow module.";s:12:"dependencies";a:1:{i:0;s:6:"follow";}s:6:"hidden";b:1;s:4:"core";s:3:"7.x";s:7:"version";s:14:"7.x-2.0-alpha1";s:7:"project";s:6:"follow";s:9:"datestamp";s:10:"1366924811";s:7:"package";s:5:"Other";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/galleryformatter/galleryformatter.module', 'galleryformatter', 'module', '', '0', '0', 0, '0', 'a:11:{s:4:"name";s:17:"Gallery Formatter";s:11:"description";s:54:"Provides a jquery gallery CCK formatter for imagefield";s:12:"dependencies";a:2:{i:0;s:5:"image";i:1;s:4:"file";}s:4:"core";s:3:"7.x";s:7:"package";s:14:"User interface";s:5:"files";a:5:{i:0;s:24:"galleryformatter.install";i:1;s:23:"galleryformatter.module";i:2;s:35:"includes/galleryformatter.theme.inc";i:3;s:40:"includes/galleryformatter_imagecache.inc";i:4;s:30:"theme/galleryformatter.tpl.php";}s:7:"version";s:7:"7.x-1.0";s:7:"project";s:16:"galleryformatter";s:9:"datestamp";s:10:"1296418641";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/getlocations/getlocations.module', 'getlocations', 'module', '', '1', '0', 7101, '0', 'a:11:{s:4:"name";s:13:"Get Locations";s:11:"description";s:31:"Show locations on a Google map.";s:7:"package";s:8:"Location";s:4:"core";s:3:"7.x";s:3:"php";s:1:"5";s:12:"dependencies";a:1:{i:0;s:9:"libraries";}s:5:"files";a:1:{i:0;s:39:"views/getlocations_plugin_style_map.inc";}s:7:"version";s:7:"7.x-1.9";s:7:"project";s:12:"getlocations";s:9:"datestamp";s:10:"1377538292";s:9:"bootstrap";i:0;}'),
('sites/all/modules/getlocations/modules/getlocations_blocks/getlocations_blocks.module', 'getlocations_blocks', 'module', '', '0', '0', -1, '0', 'a:11:{s:4:"name";s:19:"Getlocations Blocks";s:11:"description";s:60:"Provides some blocks to help with getlocations_fields Views.";s:4:"core";s:3:"7.x";s:7:"package";s:8:"Location";s:3:"php";s:1:"5";s:12:"dependencies";a:3:{i:0;s:19:"getlocations_fields";i:1;s:5:"views";i:2;s:5:"block";}s:7:"version";s:7:"7.x-1.9";s:7:"project";s:12:"getlocations";s:9:"datestamp";s:10:"1377538292";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/getlocations/modules/getlocations_feeds/getlocations_feeds.module', 'getlocations_feeds', 'module', '', '0', '0', -1, '0', 'a:11:{s:4:"name";s:18:"Getlocations Feeds";s:11:"description";s:55:"Provides getlocations_fields mappers for feed importers";s:4:"core";s:3:"7.x";s:12:"dependencies";a:2:{i:0;s:5:"feeds";i:1;s:19:"getlocations_fields";}s:7:"package";s:5:"Feeds";s:7:"version";s:7:"7.x-1.9";s:7:"project";s:12:"getlocations";s:9:"datestamp";s:10:"1377538292";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/getlocations/modules/getlocations_fields/getlocations_fields.module', 'getlocations_fields', 'module', '', '1', '0', 7100, '0', 'a:13:{s:4:"name";s:19:"Getlocations Fields";s:11:"description";s:44:"Defines a Getlocations Geocoding Field type.";s:4:"core";s:3:"7.x";s:7:"package";s:6:"Fields";s:12:"dependencies";a:1:{i:0;s:12:"getlocations";}s:5:"files";a:14:{i:0;s:58:"handlers/getlocations_fields_handler_argument_distance.inc";i:1;s:57:"handlers/getlocations_fields_handler_argument_country.inc";i:2;s:58:"handlers/getlocations_fields_handler_argument_postcode.inc";i:3;s:58:"handlers/getlocations_fields_handler_argument_province.inc";i:4;s:54:"handlers/getlocations_fields_handler_argument_city.inc";i:5;s:54:"handlers/getlocations_fields_handler_argument_glid.inc";i:6;s:58:"handlers/getlocations_fields_handler_field_coordinates.inc";i:7;s:54:"handlers/getlocations_fields_handler_field_country.inc";i:8;s:55:"handlers/getlocations_fields_handler_field_distance.inc";i:9;s:55:"handlers/getlocations_fields_handler_field_latitude.inc";i:10;s:56:"handlers/getlocations_fields_handler_field_longitude.inc";i:11;s:55:"handlers/getlocations_fields_handler_filter_country.inc";i:12;s:56:"handlers/getlocations_fields_handler_filter_distance.inc";i:13;s:54:"handlers/getlocations_fields_handler_sort_distance.inc";}s:7:"version";s:7:"7.x-1.9";s:7:"project";s:12:"getlocations";s:9:"datestamp";s:10:"1377538292";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;s:8:"required";b:1;s:11:"explanation";s:114:"Field type(s) in use - see <a href="/2013/09_September/theme822.freesample/?q=admin/reports/fields">Field list</a>";}'),
('sites/all/modules/getlocations/modules/getlocations_fields_entity/getlocations_fields_entity.module', 'getlocations_fields_entity', 'module', '', '0', '0', -1, '0', 'a:11:{s:4:"name";s:26:"Getlocations Fields Entity";s:11:"description";s:63:"Provide information about Getlocations Fields to Entity module.";s:4:"core";s:3:"7.x";s:7:"package";s:6:"Fields";s:12:"dependencies";a:2:{i:0;s:6:"entity";i:1;s:19:"getlocations_fields";}s:7:"version";s:7:"7.x-1.9";s:7:"project";s:12:"getlocations";s:9:"datestamp";s:10:"1377538292";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/getlocations/modules/getlocations_location_taxonomize/getlocations_location_taxonomize.module', 'getlocations_location_taxonomize', 'module', '', '0', '0', -1, '0', 'a:11:{s:4:"name";s:34:"Getlocations - Location taxonomize";s:11:"description";s:73:"Enables Location Taxonomize to use Getlocation_fields module as a source.";s:4:"core";s:3:"7.x";s:12:"dependencies";a:3:{i:0;s:19:"location_taxonomize";i:1;s:12:"getlocations";i:2;s:19:"getlocations_fields";}s:7:"package";s:8:"Location";s:7:"version";s:7:"7.x-1.9";s:7:"project";s:12:"getlocations";s:9:"datestamp";s:10:"1377538292";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/getlocations/modules/getlocations_map/getlocations_map.module', 'getlocations_map', 'module', '', '0', '0', -1, '0', 'a:11:{s:4:"name";s:16:"GetLocations Map";s:11:"description";s:57:"Provides Field module integration for a Getlocations map.";s:4:"core";s:3:"7.x";s:3:"php";s:1:"5";s:7:"package";s:6:"Fields";s:12:"dependencies";a:1:{i:0;s:12:"getlocations";}s:7:"version";s:7:"7.x-1.9";s:7:"project";s:12:"getlocations";s:9:"datestamp";s:10:"1377538292";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/getlocations/modules/getlocations_search/getlocations_search.module', 'getlocations_search', 'module', '', '0', '0', -1, '0', 'a:11:{s:4:"name";s:19:"Getlocations Search";s:11:"description";s:34:"Provides a search page with a map.";s:4:"core";s:3:"7.x";s:7:"package";s:8:"Location";s:3:"php";s:1:"5";s:12:"dependencies";a:1:{i:0;s:12:"getlocations";}s:7:"version";s:7:"7.x-1.9";s:7:"project";s:12:"getlocations";s:9:"datestamp";s:10:"1377538292";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/gmap/gmap.module', 'gmap', 'module', '', '0', '0', 5003, '0', 'a:12:{s:4:"name";s:4:"GMap";s:11:"description";s:53:"Filter to allow insertion of a google map into a node";s:4:"core";s:3:"7.x";s:7:"package";s:8:"Location";s:9:"configure";s:26:"admin/config/services/gmap";s:5:"files";a:6:{i:0;s:11:"gmap.module";i:1;s:14:"gmap.views.inc";i:2;s:22:"gmap-view-gmap.tpl.php";i:3;s:26:"gmap_plugin_style_gmap.inc";i:4;s:34:"gmap_plugin_style_gmapextended.inc";i:5;s:15:"tests/gmap.test";}s:7:"version";s:11:"7.x-1.x-dev";s:7:"project";s:4:"gmap";s:9:"datestamp";s:10:"1319588186";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/gmap/gmap_macro_builder.module', 'gmap_macro_builder', 'module', '', '0', '0', 6100, '0', 'a:11:{s:4:"name";s:18:"GMap Macro Builder";s:11:"description";s:28:"UI for building GMap macros.";s:7:"package";s:8:"Location";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:4:"gmap";}s:5:"files";a:1:{i:0;s:25:"gmap_macro_builder.module";}s:7:"version";s:11:"7.x-1.x-dev";s:7:"project";s:4:"gmap";s:9:"datestamp";s:10:"1319588186";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/gmap/gmap_taxonomy.module', 'gmap_taxonomy', 'module', '', '0', '0', 6001, '0', 'a:11:{s:4:"name";s:21:"GMap Taxonomy Markers";s:11:"description";s:22:"Taxonomy based markers";s:7:"package";s:8:"Location";s:4:"core";s:3:"7.x";s:12:"dependencies";a:2:{i:0;s:8:"taxonomy";i:1;s:4:"gmap";}s:5:"files";a:1:{i:0;s:20:"gmap_taxonomy.module";}s:7:"version";s:11:"7.x-1.x-dev";s:7:"project";s:4:"gmap";s:9:"datestamp";s:10:"1319588186";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/jcarousel/jcarousel.module', 'jcarousel', 'module', '', '0', '0', 0, '0', 'a:11:{s:4:"name";s:9:"jCarousel";s:11:"description";s:38:"Create jQuery-based carousel rotators.";s:7:"package";s:14:"User interface";s:4:"core";s:3:"7.x";s:5:"files";a:3:{i:0;s:16:"jcarousel.module";i:1;s:28:"includes/jcarousel.views.inc";i:2;s:35:"includes/jcarousel_style_plugin.inc";}s:7:"version";s:7:"7.x-2.6";s:7:"project";s:9:"jcarousel";s:9:"datestamp";s:10:"1322116852";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/jqeasing/jqeasing.module', 'jqeasing', 'module', '', '1', '0', 0, '0', 'a:11:{s:4:"name";s:13:"jQuery Easing";s:11:"description";s:66:"Makes the ''jQuery Easing'' plugin available to Drupal as a library.";s:4:"core";s:3:"7.x";s:7:"package";s:14:"User interface";s:12:"dependencies";a:1:{i:0;s:17:"libraries (>=2.x)";}s:7:"version";s:7:"7.x-1.0";s:7:"project";s:8:"jqeasing";s:9:"datestamp";s:10:"1349493122";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/jquery_update/jquery_update.module', 'jquery_update', 'module', '', '1', '0', 7000, '0', 'a:12:{s:4:"name";s:13:"jQuery Update";s:11:"description";s:53:"Update jQuery and jQuery UI to a more recent version.";s:7:"package";s:14:"User interface";s:4:"core";s:3:"7.x";s:5:"files";a:2:{i:0;s:20:"jquery_update.module";i:1;s:21:"jquery_update.install";}s:9:"configure";s:38:"admin/config/development/jquery_update";s:7:"version";s:7:"7.x-2.3";s:7:"project";s:13:"jquery_update";s:9:"datestamp";s:10:"1360375905";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/libraries/libraries.module', 'libraries', 'module', '', '1', '0', 7200, '0', 'a:11:{s:4:"name";s:9:"Libraries";s:11:"description";s:64:"Allows version-dependent and shared usage of external libraries.";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:20:"tests/libraries.test";}s:7:"version";s:7:"7.x-2.1";s:7:"project";s:9:"libraries";s:9:"datestamp";s:10:"1362848412";s:12:"dependencies";a:0:{}s:7:"package";s:5:"Other";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/libraries/tests/libraries_test.module', 'libraries_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:21:"Libraries test module";s:11:"description";s:36:"Tests library detection and loading.";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:9:"libraries";}s:6:"hidden";b:1;s:7:"version";s:7:"7.x-2.1";s:7:"project";s:9:"libraries";s:9:"datestamp";s:10:"1362848412";s:7:"package";s:5:"Other";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/module_filter/module_filter.module', 'module_filter', 'module', '', '1', '0', 7100, '0', 'a:12:{s:4:"name";s:13:"Module filter";s:11:"description";s:24:"Filter the modules list.";s:4:"core";s:3:"7.x";s:5:"files";a:9:{i:0;s:21:"module_filter.install";i:1;s:16:"module_filter.js";i:2;s:20:"module_filter.module";i:3;s:23:"module_filter.admin.inc";i:4;s:23:"module_filter.theme.inc";i:5;s:21:"css/module_filter.css";i:6;s:25:"css/module_filter_tab.css";i:7;s:19:"js/module_filter.js";i:8;s:23:"js/module_filter_tab.js";}s:9:"configure";s:40:"admin/config/user-interface/modulefilter";s:7:"version";s:7:"7.x-1.8";s:7:"project";s:13:"module_filter";s:9:"datestamp";s:10:"1375995220";s:12:"dependencies";a:0:{}s:7:"package";s:5:"Other";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/omega_tools/omega_tools.module', 'omega_tools', 'module', '', '0', '0', 0, '0', 'a:11:{s:4:"name";s:11:"Omega Tools";s:11:"description";s:100:"Provides additional functionality for the <a href="http://drupal.org/project/omega">Omega Theme</a>.";s:7:"package";s:11:"Theme Tools";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:6:"ctools";}s:5:"files";a:4:{i:0;s:18:"omega_tools.module";i:1;s:30:"includes/omega_tools.admin.inc";i:2;s:30:"includes/omega_tools.drush.inc";i:3;s:31:"includes/omega_tools.wizard.inc";}s:7:"version";s:13:"7.x-3.0-beta2";s:7:"project";s:11:"omega_tools";s:9:"datestamp";s:10:"1310063221";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/panels/panels.module', 'panels', 'module', '', '1', '0', 7301, '0', 'a:12:{s:4:"name";s:6:"Panels";s:11:"description";s:107:"Core Panels display functions; provides no external UI, at least one other Panels module should be enabled.";s:4:"core";s:3:"7.x";s:7:"package";s:6:"Panels";s:9:"configure";s:22:"admin/structure/panels";s:12:"dependencies";a:1:{i:0;s:6:"ctools";}s:5:"files";a:5:{i:0;s:13:"panels.module";i:1;s:19:"includes/common.inc";i:2;s:19:"includes/legacy.inc";i:3;s:20:"includes/plugins.inc";i:4;s:48:"plugins/views/panels_views_plugin_row_fields.inc";}s:7:"version";s:7:"7.x-3.3";s:7:"project";s:6:"panels";s:9:"datestamp";s:10:"1345319572";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/panels/panels_ipe/panels_ipe.module', 'panels_ipe', 'module', '', '1', '0', 0, '0', 'a:12:{s:4:"name";s:22:"Panels In-Place Editor";s:11:"description";s:101:"Provide a UI for managing some Panels directly on the frontend, instead of having to use the backend.";s:7:"package";s:6:"Panels";s:12:"dependencies";a:1:{i:0;s:6:"panels";}s:4:"core";s:3:"7.x";s:9:"configure";s:22:"admin/structure/panels";s:5:"files";a:1:{i:0;s:17:"panels_ipe.module";}s:7:"version";s:7:"7.x-3.3";s:7:"project";s:6:"panels";s:9:"datestamp";s:10:"1345319572";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/panels/panels_mini/panels_mini.module', 'panels_mini', 'module', '', '1', '0', 0, '0', 'a:11:{s:4:"name";s:11:"Mini panels";s:11:"description";s:89:"Create mini panels that can be used as blocks by Drupal and panes by other panel modules.";s:7:"package";s:6:"Panels";s:12:"dependencies";a:1:{i:0;s:6:"panels";}s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:42:"plugins/export_ui/panels_mini_ui.class.php";}s:7:"version";s:7:"7.x-3.3";s:7:"project";s:6:"panels";s:9:"datestamp";s:10:"1345319572";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/panels/panels_node/panels_node.module', 'panels_node', 'module', '', '1', '0', 6001, '11', 'a:12:{s:4:"name";s:11:"Panel nodes";s:11:"description";s:65:"Create nodes that are divided into areas with selectable content.";s:7:"package";s:6:"Panels";s:12:"dependencies";a:1:{i:0;s:6:"panels";}s:9:"configure";s:22:"admin/structure/panels";s:4:"core";s:3:"7.x";s:5:"files";a:1:{i:0;s:18:"panels_node.module";}s:7:"version";s:7:"7.x-3.3";s:7:"project";s:6:"panels";s:9:"datestamp";s:10:"1345319572";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/quicktabs/quicktabs.module', 'quicktabs', 'module', '', '0', '0', 7302, '0', 'a:12:{s:4:"name";s:9:"Quicktabs";s:11:"description";s:49:"Render content with tabs and other display styles";s:4:"core";s:3:"7.x";s:5:"files";a:4:{i:0;s:16:"quicktabs.module";i:1;s:21:"quicktabs.classes.inc";i:2;s:35:"includes/quicktabs_style_plugin.inc";i:3;s:20:"tests/quicktabs.test";}s:9:"configure";s:25:"admin/structure/quicktabs";s:12:"dependencies";a:1:{i:0;s:6:"ctools";}s:7:"version";s:7:"7.x-3.3";s:7:"project";s:9:"quicktabs";s:9:"datestamp";s:10:"1326919545";s:7:"package";s:5:"Other";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/quicktabs/quicktabs_tabstyles/quicktabs_tabstyles.module', 'quicktabs_tabstyles', 'module', '', '0', '0', 0, '0', 'a:12:{s:4:"name";s:16:"Quicktabs Styles";s:11:"description";s:65:"Adds predefined tab styles to choose from per Quicktabs instance.";s:4:"core";s:3:"7.x";s:9:"configure";s:32:"admin/structure/quicktabs/styles";s:12:"dependencies";a:1:{i:0;s:9:"quicktabs";}s:7:"version";s:7:"7.x-3.3";s:7:"project";s:9:"quicktabs";s:9:"datestamp";s:10:"1326919545";s:7:"package";s:5:"Other";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/quotes/quotes.module', 'quotes', 'module', '', '0', '0', 0, '0', 'a:11:{s:4:"name";s:6:"Quotes";s:11:"description";s:95:"Allows users to maintain personal lists of quotations and display quotes in one or more blocks.";s:4:"core";s:3:"7.x";s:7:"version";s:11:"7.x-1.x-dev";s:7:"project";s:6:"quotes";s:9:"datestamp";s:10:"1302956222";s:5:"files";a:7:{i:0;s:16:"quotes.admin.inc";i:1;s:14:"quotes.install";i:2;s:13:"quotes.module";i:3;s:15:"quotes.node.inc";i:4;s:15:"quotes.user.inc";i:5;s:16:"quotes.views.inc";i:6;s:30:"views_handler_field_quotes.inc";}s:12:"dependencies";a:0:{}s:7:"package";s:5:"Other";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/retina_images/retina_images.module', 'retina_images', 'module', '', '1', '0', 0, '0', 'a:11:{s:4:"name";s:13:"Retina Images";s:11:"description";s:96:"Provide an image effect to output images in high resolution format for high resolution displays.";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:5:"image";}s:7:"version";s:13:"7.x-1.0-beta4";s:7:"project";s:13:"retina_images";s:9:"datestamp";s:10:"1365529216";s:7:"package";s:5:"Other";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/scroll_to_top/scroll_to_top.module', 'scroll_to_top', 'module', '', '0', '0', 0, '0', 'a:12:{s:4:"name";s:13:"Scroll to top";s:11:"description";s:21:"Scroll to top module.";s:7:"package";s:5:"Other";s:4:"core";s:3:"7.x";s:5:"files";a:2:{i:0;s:17:"scroll_to_top.css";i:1;s:16:"scroll_to_top.js";}s:9:"configure";s:39:"admin/config/user-interface/scrolltotop";s:7:"version";s:7:"7.x-2.1";s:7:"project";s:13:"scroll_to_top";s:9:"datestamp";s:10:"1354268940";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/semanticviews/semanticviews.module', 'semanticviews', 'module', '', '1', '0', 0, '0', 'a:11:{s:4:"name";s:14:"Semantic Views";s:11:"description";s:50:"Views 3 plugins for UI management of output markup";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:5:"views";}s:7:"package";s:5:"Views";s:5:"files";a:6:{i:0;s:20:"semanticviews.module";i:1;s:35:"semanticviews_plugin_row_fields.inc";i:2;s:38:"semanticviews_plugin_style_default.inc";i:3;s:23:"semanticviews.theme.inc";i:4;s:31:"semanticviews.views_default.inc";i:5;s:23:"semanticviews.views.inc";}s:7:"version";s:11:"7.x-1.x-dev";s:7:"project";s:13:"semanticviews";s:9:"datestamp";s:10:"1369453055";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/shortcode/shortcode.module', 'shortcode', 'module', '', '0', '0', 0, '0', 'a:11:{s:4:"name";s:9:"Shortcode";s:11:"description";s:65:"Provides shortcodes filter framework and API (like WP shortcodes)";s:7:"package";s:9:"Shortcode";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:6:"filter";}s:7:"version";s:11:"7.x-2.x-dev";s:7:"project";s:9:"shortcode";s:9:"datestamp";s:10:"1312677534";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/shortcode/shortcode_basic_tags/shortcode_basic_tags.module', 'shortcode_basic_tags', 'module', '', '0', '0', 0, '0', 'a:11:{s:4:"name";s:20:"Shortcode Basic Tags";s:11:"description";s:59:"Provides basic shortcode tags like highlight, dropcap, etc.";s:7:"package";s:9:"Shortcode";s:4:"core";s:3:"7.x";s:12:"dependencies";a:2:{i:0;s:6:"filter";i:1;s:9:"shortcode";}s:7:"version";s:11:"7.x-2.x-dev";s:7:"project";s:9:"shortcode";s:9:"datestamp";s:10:"1312677534";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/shortcode/shortcode_embed_contents/shortcode_embed_contents.module', 'shortcode_embed_contents', 'module', '', '0', '0', 0, '0', 'a:11:{s:4:"name";s:29:"Shortcode Embed Contents Tags";s:11:"description";s:80:"Provides a shortcode tags for embedding a node content (node, blog, views, etc.)";s:7:"package";s:9:"Shortcode";s:4:"core";s:3:"7.x";s:12:"dependencies";a:2:{i:0;s:6:"filter";i:1;s:9:"shortcode";}s:7:"version";s:11:"7.x-2.x-dev";s:7:"project";s:9:"shortcode";s:9:"datestamp";s:10:"1312677534";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/shortcode/shortcode_wysiwyg/shortcode_wysiwyg.module', 'shortcode_wysiwyg', 'module', '', '0', '0', 0, '0', 'a:11:{s:4:"name";s:30:"Shortcode wysiwyg EXPERIMENTAL";s:11:"description";s:29:"Shortcode wysiwyg integration";s:4:"core";s:3:"7.x";s:7:"package";s:9:"Shortcode";s:12:"dependencies";a:1:{i:0;s:9:"shortcode";}s:7:"version";s:11:"7.x-2.x-dev";s:7:"project";s:9:"shortcode";s:9:"datestamp";s:10:"1312677534";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}');
INSERT INTO `system` VALUES
('sites/all/modules/social-share/social_share.module', 'social_share', 'module', '', '0', '0', 7102, '0', 'a:11:{s:4:"name";s:12:"Social Share";s:11:"description";s:54:"Adds configurable social network share links to nodes.";s:4:"core";s:3:"7.x";s:5:"files";a:3:{i:0;s:19:"social_share.module";i:1;s:22:"social_share.admin.inc";i:2;s:16:"social_share.css";}s:7:"version";s:8:"7.x-1.13";s:7:"project";s:12:"social-share";s:9:"datestamp";s:10:"1350669713";s:12:"dependencies";a:0:{}s:7:"package";s:5:"Other";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/superfish/superfish.module', 'superfish', 'module', '', '1', '0', 7100, '0', 'a:12:{s:4:"name";s:9:"Superfish";s:11:"description";s:46:"jQuery Superfish plugin for your Drupal menus.";s:7:"package";s:14:"User interface";s:12:"dependencies";a:1:{i:0;s:4:"menu";}s:9:"configure";s:37:"admin/config/user-interface/superfish";s:4:"core";s:3:"7.x";s:7:"version";s:7:"7.x-1.9";s:7:"project";s:9:"superfish";s:9:"datestamp";s:10:"1367054112";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/tagadelic/tagadelic.module', 'tagadelic', 'module', '', '0', '0', 6100, '0', 'a:12:{s:4:"name";s:9:"Tagadelic";s:11:"description";s:61:"Tagadelic makes weighted tag clouds from your taxonomy terms.";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:8:"taxonomy";}s:7:"package";s:8:"Taxonomy";s:9:"configure";s:30:"admin/config/content/tagadelic";s:5:"files";a:2:{i:0;s:16:"tagadelic.module";i:1;s:17:"tagadelic.install";}s:7:"version";s:11:"7.x-1.x-dev";s:7:"project";s:9:"tagadelic";s:9:"datestamp";s:10:"1314793913";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/term_reference_tree/term_reference_tree.module', 'term_reference_tree', 'module', '', '1', '0', 0, '0', 'a:11:{s:4:"name";s:19:"Term Reference Tree";s:11:"description";s:91:"An expanding/collapsing tree widget for selecting terms in a taxonomy term reference field.";s:7:"package";s:6:"Fields";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:8:"taxonomy";}s:7:"version";s:8:"7.x-1.10";s:7:"project";s:19:"term_reference_tree";s:9:"datestamp";s:10:"1369842362";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/tipsy/tipsy.module', 'tipsy', 'module', '', '0', '0', 0, '999', 'a:12:{s:4:"name";s:14:"Tipsy tooltips";s:11:"description";s:141:"Integrates <a href="http://onehackoranother.com/projects/jquery/tipsy/">Tipsy</a> jQuery plugin for creating a Facebook-like tooltips effect.";s:4:"core";s:3:"7.x";s:9:"configure";s:33:"admin/config/user-interface/tipsy";s:7:"version";s:11:"7.x-1.0-rc1";s:7:"project";s:5:"tipsy";s:9:"datestamp";s:10:"1307366519";s:12:"dependencies";a:0:{}s:7:"package";s:5:"Other";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/toolbar_admin_menu/toolbar_admin_menu.module', 'toolbar_admin_menu', 'module', '', '1', '0', 0, '0', 'a:11:{s:4:"name";s:16:"Hide the Toolbar";s:11:"description";s:67:"Hides Drupal''s core Toolbar for users with the Administration Menu.";s:4:"core";s:3:"7.x";s:7:"package";s:14:"Administration";s:12:"dependencies";a:1:{i:0;s:10:"admin_menu";}s:7:"version";s:7:"7.x-1.0";s:7:"project";s:18:"toolbar_admin_menu";s:9:"datestamp";s:10:"1343300321";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/views/tests/views_test.module', 'views_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:10:"Views Test";s:11:"description";s:22:"Test module for Views.";s:7:"package";s:5:"Views";s:4:"core";s:3:"7.x";s:12:"dependencies";a:1:{i:0;s:5:"views";}s:6:"hidden";b:1;s:7:"version";s:7:"7.x-3.7";s:7:"project";s:5:"views";s:9:"datestamp";s:10:"1365499236";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/views/views.module', 'views', 'module', '', '1', '0', 7301, '10', 'a:12:{s:4:"name";s:5:"Views";s:11:"description";s:55:"Create customized lists and queries from your database.";s:7:"package";s:5:"Views";s:4:"core";s:3:"7.x";s:3:"php";s:3:"5.2";s:11:"stylesheets";a:1:{s:3:"all";a:1:{s:13:"css/views.css";s:37:"sites/all/modules/views/css/views.css";}}s:12:"dependencies";a:1:{i:0;s:6:"ctools";}s:5:"files";a:297:{i:0;s:31:"handlers/views_handler_area.inc";i:1;s:38:"handlers/views_handler_area_result.inc";i:2;s:36:"handlers/views_handler_area_text.inc";i:3;s:43:"handlers/views_handler_area_text_custom.inc";i:4;s:36:"handlers/views_handler_area_view.inc";i:5;s:35:"handlers/views_handler_argument.inc";i:6;s:40:"handlers/views_handler_argument_date.inc";i:7;s:43:"handlers/views_handler_argument_formula.inc";i:8;s:47:"handlers/views_handler_argument_many_to_one.inc";i:9;s:40:"handlers/views_handler_argument_null.inc";i:10;s:43:"handlers/views_handler_argument_numeric.inc";i:11;s:42:"handlers/views_handler_argument_string.inc";i:12;s:52:"handlers/views_handler_argument_group_by_numeric.inc";i:13;s:32:"handlers/views_handler_field.inc";i:14;s:40:"handlers/views_handler_field_counter.inc";i:15;s:40:"handlers/views_handler_field_boolean.inc";i:16;s:49:"handlers/views_handler_field_contextual_links.inc";i:17;s:39:"handlers/views_handler_field_custom.inc";i:18;s:37:"handlers/views_handler_field_date.inc";i:19;s:39:"handlers/views_handler_field_entity.inc";i:20;s:39:"handlers/views_handler_field_markup.inc";i:21;s:37:"handlers/views_handler_field_math.inc";i:22;s:40:"handlers/views_handler_field_numeric.inc";i:23;s:47:"handlers/views_handler_field_prerender_list.inc";i:24;s:46:"handlers/views_handler_field_time_interval.inc";i:25;s:43:"handlers/views_handler_field_serialized.inc";i:26;s:45:"handlers/views_handler_field_machine_name.inc";i:27;s:36:"handlers/views_handler_field_url.inc";i:28;s:33:"handlers/views_handler_filter.inc";i:29;s:50:"handlers/views_handler_filter_boolean_operator.inc";i:30;s:57:"handlers/views_handler_filter_boolean_operator_string.inc";i:31;s:41:"handlers/views_handler_filter_combine.inc";i:32;s:38:"handlers/views_handler_filter_date.inc";i:33;s:42:"handlers/views_handler_filter_equality.inc";i:34;s:47:"handlers/views_handler_filter_entity_bundle.inc";i:35;s:50:"handlers/views_handler_filter_group_by_numeric.inc";i:36;s:45:"handlers/views_handler_filter_in_operator.inc";i:37;s:45:"handlers/views_handler_filter_many_to_one.inc";i:38;s:41:"handlers/views_handler_filter_numeric.inc";i:39;s:40:"handlers/views_handler_filter_string.inc";i:40;s:39:"handlers/views_handler_relationship.inc";i:41;s:53:"handlers/views_handler_relationship_groupwise_max.inc";i:42;s:31:"handlers/views_handler_sort.inc";i:43;s:36:"handlers/views_handler_sort_date.inc";i:44;s:39:"handlers/views_handler_sort_formula.inc";i:45;s:48:"handlers/views_handler_sort_group_by_numeric.inc";i:46;s:46:"handlers/views_handler_sort_menu_hierarchy.inc";i:47;s:38:"handlers/views_handler_sort_random.inc";i:48;s:17:"includes/base.inc";i:49;s:21:"includes/handlers.inc";i:50;s:20:"includes/plugins.inc";i:51;s:17:"includes/view.inc";i:52;s:60:"modules/aggregator/views_handler_argument_aggregator_fid.inc";i:53;s:60:"modules/aggregator/views_handler_argument_aggregator_iid.inc";i:54;s:69:"modules/aggregator/views_handler_argument_aggregator_category_cid.inc";i:55;s:64:"modules/aggregator/views_handler_field_aggregator_title_link.inc";i:56;s:62:"modules/aggregator/views_handler_field_aggregator_category.inc";i:57;s:70:"modules/aggregator/views_handler_field_aggregator_item_description.inc";i:58;s:57:"modules/aggregator/views_handler_field_aggregator_xss.inc";i:59;s:67:"modules/aggregator/views_handler_filter_aggregator_category_cid.inc";i:60;s:54:"modules/aggregator/views_plugin_row_aggregator_rss.inc";i:61;s:56:"modules/book/views_plugin_argument_default_book_root.inc";i:62;s:59:"modules/comment/views_handler_argument_comment_user_uid.inc";i:63;s:47:"modules/comment/views_handler_field_comment.inc";i:64;s:53:"modules/comment/views_handler_field_comment_depth.inc";i:65;s:52:"modules/comment/views_handler_field_comment_link.inc";i:66;s:60:"modules/comment/views_handler_field_comment_link_approve.inc";i:67;s:59:"modules/comment/views_handler_field_comment_link_delete.inc";i:68;s:57:"modules/comment/views_handler_field_comment_link_edit.inc";i:69;s:58:"modules/comment/views_handler_field_comment_link_reply.inc";i:70;s:57:"modules/comment/views_handler_field_comment_node_link.inc";i:71;s:56:"modules/comment/views_handler_field_comment_username.inc";i:72;s:61:"modules/comment/views_handler_field_ncs_last_comment_name.inc";i:73;s:56:"modules/comment/views_handler_field_ncs_last_updated.inc";i:74;s:52:"modules/comment/views_handler_field_node_comment.inc";i:75;s:57:"modules/comment/views_handler_field_node_new_comments.inc";i:76;s:62:"modules/comment/views_handler_field_last_comment_timestamp.inc";i:77;s:57:"modules/comment/views_handler_filter_comment_user_uid.inc";i:78;s:57:"modules/comment/views_handler_filter_ncs_last_updated.inc";i:79;s:53:"modules/comment/views_handler_filter_node_comment.inc";i:80;s:53:"modules/comment/views_handler_sort_comment_thread.inc";i:81;s:60:"modules/comment/views_handler_sort_ncs_last_comment_name.inc";i:82;s:55:"modules/comment/views_handler_sort_ncs_last_updated.inc";i:83;s:48:"modules/comment/views_plugin_row_comment_rss.inc";i:84;s:49:"modules/comment/views_plugin_row_comment_view.inc";i:85;s:52:"modules/contact/views_handler_field_contact_link.inc";i:86;s:43:"modules/field/views_handler_field_field.inc";i:87;s:59:"modules/field/views_handler_relationship_entity_reverse.inc";i:88;s:51:"modules/field/views_handler_argument_field_list.inc";i:89;s:58:"modules/field/views_handler_argument_field_list_string.inc";i:90;s:49:"modules/field/views_handler_filter_field_list.inc";i:91;s:57:"modules/filter/views_handler_field_filter_format_name.inc";i:92;s:52:"modules/locale/views_handler_field_node_language.inc";i:93;s:53:"modules/locale/views_handler_filter_node_language.inc";i:94;s:54:"modules/locale/views_handler_argument_locale_group.inc";i:95;s:57:"modules/locale/views_handler_argument_locale_language.inc";i:96;s:51:"modules/locale/views_handler_field_locale_group.inc";i:97;s:54:"modules/locale/views_handler_field_locale_language.inc";i:98;s:55:"modules/locale/views_handler_field_locale_link_edit.inc";i:99;s:52:"modules/locale/views_handler_filter_locale_group.inc";i:100;s:55:"modules/locale/views_handler_filter_locale_language.inc";i:101;s:54:"modules/locale/views_handler_filter_locale_version.inc";i:102;s:53:"modules/node/views_handler_argument_dates_various.inc";i:103;s:53:"modules/node/views_handler_argument_node_language.inc";i:104;s:48:"modules/node/views_handler_argument_node_nid.inc";i:105;s:49:"modules/node/views_handler_argument_node_type.inc";i:106;s:48:"modules/node/views_handler_argument_node_vid.inc";i:107;s:57:"modules/node/views_handler_argument_node_uid_revision.inc";i:108;s:59:"modules/node/views_handler_field_history_user_timestamp.inc";i:109;s:41:"modules/node/views_handler_field_node.inc";i:110;s:46:"modules/node/views_handler_field_node_link.inc";i:111;s:53:"modules/node/views_handler_field_node_link_delete.inc";i:112;s:51:"modules/node/views_handler_field_node_link_edit.inc";i:113;s:50:"modules/node/views_handler_field_node_revision.inc";i:114;s:55:"modules/node/views_handler_field_node_revision_link.inc";i:115;s:62:"modules/node/views_handler_field_node_revision_link_delete.inc";i:116;s:62:"modules/node/views_handler_field_node_revision_link_revert.inc";i:117;s:46:"modules/node/views_handler_field_node_path.inc";i:118;s:46:"modules/node/views_handler_field_node_type.inc";i:119;s:60:"modules/node/views_handler_filter_history_user_timestamp.inc";i:120;s:49:"modules/node/views_handler_filter_node_access.inc";i:121;s:49:"modules/node/views_handler_filter_node_status.inc";i:122;s:47:"modules/node/views_handler_filter_node_type.inc";i:123;s:55:"modules/node/views_handler_filter_node_uid_revision.inc";i:124;s:51:"modules/node/views_plugin_argument_default_node.inc";i:125;s:52:"modules/node/views_plugin_argument_validate_node.inc";i:126;s:42:"modules/node/views_plugin_row_node_rss.inc";i:127;s:43:"modules/node/views_plugin_row_node_view.inc";i:128;s:52:"modules/profile/views_handler_field_profile_date.inc";i:129;s:52:"modules/profile/views_handler_field_profile_list.inc";i:130;s:58:"modules/profile/views_handler_filter_profile_selection.inc";i:131;s:48:"modules/search/views_handler_argument_search.inc";i:132;s:51:"modules/search/views_handler_field_search_score.inc";i:133;s:46:"modules/search/views_handler_filter_search.inc";i:134;s:50:"modules/search/views_handler_sort_search_score.inc";i:135;s:47:"modules/search/views_plugin_row_search_view.inc";i:136;s:57:"modules/statistics/views_handler_field_accesslog_path.inc";i:137;s:50:"modules/system/views_handler_argument_file_fid.inc";i:138;s:43:"modules/system/views_handler_field_file.inc";i:139;s:53:"modules/system/views_handler_field_file_extension.inc";i:140;s:52:"modules/system/views_handler_field_file_filemime.inc";i:141;s:47:"modules/system/views_handler_field_file_uri.inc";i:142;s:50:"modules/system/views_handler_field_file_status.inc";i:143;s:51:"modules/system/views_handler_filter_file_status.inc";i:144;s:52:"modules/taxonomy/views_handler_argument_taxonomy.inc";i:145;s:57:"modules/taxonomy/views_handler_argument_term_node_tid.inc";i:146;s:63:"modules/taxonomy/views_handler_argument_term_node_tid_depth.inc";i:147;s:72:"modules/taxonomy/views_handler_argument_term_node_tid_depth_modifier.inc";i:148;s:58:"modules/taxonomy/views_handler_argument_vocabulary_vid.inc";i:149;s:67:"modules/taxonomy/views_handler_argument_vocabulary_machine_name.inc";i:150;s:49:"modules/taxonomy/views_handler_field_taxonomy.inc";i:151;s:54:"modules/taxonomy/views_handler_field_term_node_tid.inc";i:152;s:55:"modules/taxonomy/views_handler_field_term_link_edit.inc";i:153;s:55:"modules/taxonomy/views_handler_filter_term_node_tid.inc";i:154;s:61:"modules/taxonomy/views_handler_filter_term_node_tid_depth.inc";i:155;s:56:"modules/taxonomy/views_handler_filter_vocabulary_vid.inc";i:156;s:65:"modules/taxonomy/views_handler_filter_vocabulary_machine_name.inc";i:157;s:62:"modules/taxonomy/views_handler_relationship_node_term_data.inc";i:158;s:65:"modules/taxonomy/views_plugin_argument_validate_taxonomy_term.inc";i:159;s:63:"modules/taxonomy/views_plugin_argument_default_taxonomy_tid.inc";i:160;s:67:"modules/tracker/views_handler_argument_tracker_comment_user_uid.inc";i:161;s:65:"modules/tracker/views_handler_filter_tracker_comment_user_uid.inc";i:162;s:65:"modules/tracker/views_handler_filter_tracker_boolean_operator.inc";i:163;s:51:"modules/system/views_handler_filter_system_type.inc";i:164;s:56:"modules/translation/views_handler_argument_node_tnid.inc";i:165;s:63:"modules/translation/views_handler_field_node_link_translate.inc";i:166;s:65:"modules/translation/views_handler_field_node_translation_link.inc";i:167;s:54:"modules/translation/views_handler_filter_node_tnid.inc";i:168;s:60:"modules/translation/views_handler_filter_node_tnid_child.inc";i:169;s:62:"modules/translation/views_handler_relationship_translation.inc";i:170;s:48:"modules/user/views_handler_argument_user_uid.inc";i:171;s:55:"modules/user/views_handler_argument_users_roles_rid.inc";i:172;s:41:"modules/user/views_handler_field_user.inc";i:173;s:50:"modules/user/views_handler_field_user_language.inc";i:174;s:46:"modules/user/views_handler_field_user_link.inc";i:175;s:53:"modules/user/views_handler_field_user_link_cancel.inc";i:176;s:51:"modules/user/views_handler_field_user_link_edit.inc";i:177;s:46:"modules/user/views_handler_field_user_mail.inc";i:178;s:46:"modules/user/views_handler_field_user_name.inc";i:179;s:53:"modules/user/views_handler_field_user_permissions.inc";i:180;s:49:"modules/user/views_handler_field_user_picture.inc";i:181;s:47:"modules/user/views_handler_field_user_roles.inc";i:182;s:50:"modules/user/views_handler_filter_user_current.inc";i:183;s:47:"modules/user/views_handler_filter_user_name.inc";i:184;s:54:"modules/user/views_handler_filter_user_permissions.inc";i:185;s:48:"modules/user/views_handler_filter_user_roles.inc";i:186;s:59:"modules/user/views_plugin_argument_default_current_user.inc";i:187;s:51:"modules/user/views_plugin_argument_default_user.inc";i:188;s:52:"modules/user/views_plugin_argument_validate_user.inc";i:189;s:43:"modules/user/views_plugin_row_user_view.inc";i:190;s:31:"plugins/views_plugin_access.inc";i:191;s:36:"plugins/views_plugin_access_none.inc";i:192;s:36:"plugins/views_plugin_access_perm.inc";i:193;s:36:"plugins/views_plugin_access_role.inc";i:194;s:41:"plugins/views_plugin_argument_default.inc";i:195;s:45:"plugins/views_plugin_argument_default_php.inc";i:196;s:47:"plugins/views_plugin_argument_default_fixed.inc";i:197;s:45:"plugins/views_plugin_argument_default_raw.inc";i:198;s:42:"plugins/views_plugin_argument_validate.inc";i:199;s:50:"plugins/views_plugin_argument_validate_numeric.inc";i:200;s:46:"plugins/views_plugin_argument_validate_php.inc";i:201;s:30:"plugins/views_plugin_cache.inc";i:202;s:35:"plugins/views_plugin_cache_none.inc";i:203;s:35:"plugins/views_plugin_cache_time.inc";i:204;s:32:"plugins/views_plugin_display.inc";i:205;s:43:"plugins/views_plugin_display_attachment.inc";i:206;s:38:"plugins/views_plugin_display_block.inc";i:207;s:40:"plugins/views_plugin_display_default.inc";i:208;s:38:"plugins/views_plugin_display_embed.inc";i:209;s:41:"plugins/views_plugin_display_extender.inc";i:210;s:37:"plugins/views_plugin_display_feed.inc";i:211;s:37:"plugins/views_plugin_display_page.inc";i:212;s:43:"plugins/views_plugin_exposed_form_basic.inc";i:213;s:37:"plugins/views_plugin_exposed_form.inc";i:214;s:52:"plugins/views_plugin_exposed_form_input_required.inc";i:215;s:42:"plugins/views_plugin_localization_core.inc";i:216;s:37:"plugins/views_plugin_localization.inc";i:217;s:42:"plugins/views_plugin_localization_none.inc";i:218;s:30:"plugins/views_plugin_pager.inc";i:219;s:35:"plugins/views_plugin_pager_full.inc";i:220;s:35:"plugins/views_plugin_pager_mini.inc";i:221;s:35:"plugins/views_plugin_pager_none.inc";i:222;s:35:"plugins/views_plugin_pager_some.inc";i:223;s:30:"plugins/views_plugin_query.inc";i:224;s:38:"plugins/views_plugin_query_default.inc";i:225;s:28:"plugins/views_plugin_row.inc";i:226;s:35:"plugins/views_plugin_row_fields.inc";i:227;s:39:"plugins/views_plugin_row_rss_fields.inc";i:228;s:30:"plugins/views_plugin_style.inc";i:229;s:38:"plugins/views_plugin_style_default.inc";i:230;s:35:"plugins/views_plugin_style_grid.inc";i:231;s:35:"plugins/views_plugin_style_list.inc";i:232;s:40:"plugins/views_plugin_style_jump_menu.inc";i:233;s:38:"plugins/views_plugin_style_mapping.inc";i:234;s:34:"plugins/views_plugin_style_rss.inc";i:235;s:38:"plugins/views_plugin_style_summary.inc";i:236;s:48:"plugins/views_plugin_style_summary_jump_menu.inc";i:237;s:50:"plugins/views_plugin_style_summary_unformatted.inc";i:238;s:36:"plugins/views_plugin_style_table.inc";i:239;s:43:"tests/handlers/views_handler_area_text.test";i:240;s:47:"tests/handlers/views_handler_argument_null.test";i:241;s:49:"tests/handlers/views_handler_argument_string.test";i:242;s:39:"tests/handlers/views_handler_field.test";i:243;s:47:"tests/handlers/views_handler_field_boolean.test";i:244;s:46:"tests/handlers/views_handler_field_custom.test";i:245;s:47:"tests/handlers/views_handler_field_counter.test";i:246;s:44:"tests/handlers/views_handler_field_date.test";i:247;s:49:"tests/handlers/views_handler_field_file_size.test";i:248;s:44:"tests/handlers/views_handler_field_math.test";i:249;s:43:"tests/handlers/views_handler_field_url.test";i:250;s:43:"tests/handlers/views_handler_field_xss.test";i:251;s:48:"tests/handlers/views_handler_filter_combine.test";i:252;s:45:"tests/handlers/views_handler_filter_date.test";i:253;s:49:"tests/handlers/views_handler_filter_equality.test";i:254;s:52:"tests/handlers/views_handler_filter_in_operator.test";i:255;s:48:"tests/handlers/views_handler_filter_numeric.test";i:256;s:47:"tests/handlers/views_handler_filter_string.test";i:257;s:45:"tests/handlers/views_handler_sort_random.test";i:258;s:43:"tests/handlers/views_handler_sort_date.test";i:259;s:38:"tests/handlers/views_handler_sort.test";i:260;s:60:"tests/test_plugins/views_test_plugin_access_test_dynamic.inc";i:261;s:59:"tests/test_plugins/views_test_plugin_access_test_static.inc";i:262;s:59:"tests/test_plugins/views_test_plugin_style_test_mapping.inc";i:263;s:39:"tests/plugins/views_plugin_display.test";i:264;s:46:"tests/styles/views_plugin_style_jump_menu.test";i:265;s:36:"tests/styles/views_plugin_style.test";i:266;s:41:"tests/styles/views_plugin_style_base.test";i:267;s:44:"tests/styles/views_plugin_style_mapping.test";i:268;s:48:"tests/styles/views_plugin_style_unformatted.test";i:269;s:23:"tests/views_access.test";i:270;s:24:"tests/views_analyze.test";i:271;s:22:"tests/views_basic.test";i:272;s:33:"tests/views_argument_default.test";i:273;s:35:"tests/views_argument_validator.test";i:274;s:29:"tests/views_exposed_form.test";i:275;s:31:"tests/field/views_fieldapi.test";i:276;s:25:"tests/views_glossary.test";i:277;s:24:"tests/views_groupby.test";i:278;s:25:"tests/views_handlers.test";i:279;s:23:"tests/views_module.test";i:280;s:22:"tests/views_pager.test";i:281;s:40:"tests/views_plugin_localization_test.inc";i:282;s:29:"tests/views_translatable.test";i:283;s:22:"tests/views_query.test";i:284;s:24:"tests/views_upgrade.test";i:285;s:34:"tests/views_test.views_default.inc";i:286;s:58:"tests/comment/views_handler_argument_comment_user_uid.test";i:287;s:56:"tests/comment/views_handler_filter_comment_user_uid.test";i:288;s:45:"tests/node/views_node_revision_relations.test";i:289;s:61:"tests/taxonomy/views_handler_relationship_node_term_data.test";i:290;s:45:"tests/user/views_handler_field_user_name.test";i:291;s:43:"tests/user/views_user_argument_default.test";i:292;s:44:"tests/user/views_user_argument_validate.test";i:293;s:26:"tests/user/views_user.test";i:294;s:22:"tests/views_cache.test";i:295;s:21:"tests/views_view.test";i:296;s:19:"tests/views_ui.test";}s:7:"version";s:7:"7.x-3.7";s:7:"project";s:5:"views";s:9:"datestamp";s:10:"1365499236";s:9:"bootstrap";i:0;}'),
('sites/all/modules/views/views_export/views_export.module', 'views_export', 'module', '', '0', '0', 0, '0', 'a:11:{s:4:"name";s:14:"Views exporter";s:11:"description";s:40:"Allows exporting multiple views at once.";s:7:"package";s:5:"Views";s:12:"dependencies";a:1:{i:0;s:5:"views";}s:4:"core";s:3:"7.x";s:7:"version";s:13:"7.x-3.0-beta3";s:7:"project";s:5:"views";s:9:"datestamp";s:10:"1301301970";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/views/views_ui.module', 'views_ui', 'module', '', '1', '0', 0, '0', 'a:12:{s:4:"name";s:8:"Views UI";s:11:"description";s:93:"Administrative interface to views. Without this module, you cannot create or edit your views.";s:7:"package";s:5:"Views";s:4:"core";s:3:"7.x";s:9:"configure";s:21:"admin/structure/views";s:12:"dependencies";a:1:{i:0;s:5:"views";}s:5:"files";a:2:{i:0;s:15:"views_ui.module";i:1;s:57:"plugins/views_wizard/views_ui_base_views_wizard.class.php";}s:7:"version";s:7:"7.x-3.7";s:7:"project";s:5:"views";s:9:"datestamp";s:10:"1365499236";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/views_isotope/isotope_example_feature/isotope_example_feature.module', 'isotope_example_feature', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"core";s:3:"7.x";s:12:"dependencies";a:5:{i:0;s:8:"features";i:1;s:5:"image";i:2;s:8:"taxonomy";i:3;s:5:"views";i:4;s:13:"views_isotope";}s:11:"description";s:48:"Sample Isotope Grid of Articles filtered by tags";s:8:"features";a:5:{s:6:"ctools";a:1:{i:0;s:23:"views:views_default:3.0";}s:5:"field";a:3:{i:0;s:17:"node-article-body";i:1;s:24:"node-article-field_image";i:2;s:23:"node-article-field_tags";}s:4:"node";a:1:{i:0;s:7:"article";}s:8:"taxonomy";a:1:{i:0;s:4:"tags";}s:10:"views_view";a:2:{i:0;s:15:"isotope_example";i:1;s:28:"isotope_example_filter_block";}}s:4:"name";s:15:"Isotope Example";s:7:"package";s:8:"Features";s:7:"version";s:13:"7.x-1.0-beta2";s:7:"project";s:13:"views_isotope";s:9:"datestamp";s:10:"1335546686";s:3:"php";s:5:"5.2.4";s:5:"files";a:0:{}s:9:"bootstrap";i:0;}'),
('sites/all/modules/views_isotope/views_isotope.module', 'views_isotope', 'module', '', '1', '0', 0, '0', 'a:11:{s:4:"name";s:13:"Views Isotope";s:11:"description";s:40:"Create isotope views from views queries.";s:7:"package";s:5:"Views";s:4:"core";s:3:"7.x";s:12:"dependencies";a:3:{i:0;s:5:"views";i:1;s:13:"jquery_update";i:2;s:9:"libraries";}s:5:"files";a:6:{i:0;s:21:"views-isotope.tpl.php";i:1;s:20:"views_isotope.module";i:2;s:23:"views_isotope.theme.inc";i:3;s:23:"views_isotope.views.inc";i:4;s:38:"views_isotope_plugin_style_isotope.inc";i:5;s:51:"views_isotope_plugin_style_isotope_filter_block.inc";}s:7:"version";s:13:"7.x-1.0-beta2";s:7:"project";s:13:"views_isotope";s:9:"datestamp";s:10:"1335546686";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/views_jqfx/views_jqfx.module', 'views_jqfx', 'module', '', '0', '0', 0, '0', 'a:11:{s:4:"name";s:10:"Views jQFX";s:11:"description";s:39:"Applies jQuery effects to views output.";s:12:"dependencies";a:1:{i:0;s:5:"views";}s:7:"package";s:5:"Views";s:4:"core";s:3:"7.x";s:5:"files";a:4:{i:0;s:17:"views_jqfx.module";i:1;s:20:"views_jqfx.theme.inc";i:2;s:20:"views_jqfx.views.inc";i:3;s:32:"views_jqfx_plugin_style_jqfx.inc";}s:7:"version";s:14:"7.x-1.0-alpha1";s:7:"project";s:10:"views_jqfx";s:9:"datestamp";s:10:"1315382533";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/views_jqfx_cycle/views_jqfx_cycle.module', 'views_jqfx_cycle', 'module', '', '0', '0', 0, '0', 'a:9:{s:4:"name";s:17:"Views jQFX: Cycle";s:11:"description";s:41:"Adds a Rotating Cycle mode to Views jQfx.";s:12:"dependencies";a:1:{i:0;s:10:"views_jqfx";}s:7:"package";s:5:"Views";s:4:"core";s:3:"7.x";s:5:"files";a:3:{i:0;s:23:"views_jqfx_cycle.module";i:1;s:31:"views_jqfx_cycle.views_jqfx.inc";i:2;s:32:"theme/views_jqfx_cycle.theme.inc";}s:7:"version";N;s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/views_jqfx_galleria/views_jqfx_galleria.module', 'views_jqfx_galleria', 'module', '', '0', '0', 0, '0', 'a:9:{s:4:"name";s:20:"Views jQfx: Galleria";s:11:"description";s:47:"Integrates the Galleria plugin with Views jQfx.";s:12:"dependencies";a:1:{i:0;s:10:"views_jqfx";}s:7:"package";s:5:"Views";s:4:"core";s:3:"7.x";s:5:"files";a:3:{i:0;s:25:"views_jqfx_galeria.module";i:1;s:34:"views_jqfx_galleria.views_jqfx.inc";i:2;s:35:"theme/views_jqfx_galleria.theme.inc";}s:7:"version";N;s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/views_jqfx_nivoslider/views_jqfx_nivoslider.module', 'views_jqfx_nivoslider', 'module', '', '0', '0', 0, '0', 'a:9:{s:4:"name";s:23:"Views jQFX: Nivo Slider";s:11:"description";s:50:"Integrates the Nivo Slider plugin with Views jQFX.";s:12:"dependencies";a:1:{i:0;s:10:"views_jqfx";}s:7:"package";s:5:"Views";s:4:"core";s:3:"7.x";s:5:"files";a:3:{i:0;s:28:"views_jqfx_nivoslider.module";i:1;s:36:"views_jqfx_nivoslider.views_jqfx.inc";i:2;s:37:"theme/views_jqfx_nivoslider.theme.inc";}s:7:"version";N;s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/views_nivo_slider/views_nivo_slider.module', 'views_nivo_slider', 'module', '', '0', '0', 0, '0', 'a:11:{s:4:"name";s:17:"Views Nivo Slider";s:11:"description";s:31:"Display a view with Nivo Slider";s:4:"core";s:3:"7.x";s:7:"package";s:5:"Views";s:12:"dependencies";a:1:{i:0;s:5:"views";}s:5:"files";a:2:{i:0;s:50:"views_nivo_slider_plugin_row_nivo_sliderfields.inc";i:1;s:34:"views_nivo_slider_style_plugin.inc";}s:7:"version";s:11:"7.x-2.x-dev";s:7:"project";s:17:"views_nivo_slider";s:9:"datestamp";s:10:"1310518009";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/views_slideshow/contrib/views_slideshow_cycle/views_slideshow_cycle.module', 'views_slideshow_cycle', 'module', '', '0', '0', -1, '0', 'a:11:{s:4:"name";s:22:"Views Slideshow: Cycle";s:11:"description";s:50:"Adds a Rotating slideshow mode to Views Slideshow.";s:12:"dependencies";a:2:{i:0;s:15:"views_slideshow";i:1;s:9:"libraries";}s:7:"package";s:5:"Views";s:4:"core";s:3:"7.x";s:5:"files";a:3:{i:0;s:28:"views_slideshow_cycle.module";i:1;s:41:"views_slideshow_cycle.views_slideshow.inc";i:2;s:37:"theme/views_slideshow_cycle.theme.inc";}s:7:"version";s:7:"7.x-3.0";s:7:"project";s:15:"views_slideshow";s:9:"datestamp";s:10:"1319589616";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/views_slideshow/views_slideshow.module', 'views_slideshow', 'module', '', '1', '0', 0, '0', 'a:11:{s:4:"name";s:15:"Views Slideshow";s:11:"description";s:155:"Provides a View style that displays rows as a jQuery slideshow.  This is an API and requires Views Slideshow Cycle or another module that supports the API.";s:12:"dependencies";a:1:{i:0;s:5:"views";}s:7:"package";s:5:"Views";s:4:"core";s:3:"7.x";s:5:"files";a:4:{i:0;s:22:"views_slideshow.module";i:1;s:31:"theme/views_slideshow.theme.inc";i:2;s:25:"views_slideshow.views.inc";i:3;s:42:"views_slideshow_plugin_style_slideshow.inc";}s:7:"version";s:7:"7.x-3.0";s:7:"project";s:15:"views_slideshow";s:9:"datestamp";s:10:"1319589616";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/wysiwyg/tests/wysiwyg_test.module', 'wysiwyg_test', 'module', '', '0', '0', -1, '0', 'a:12:{s:4:"name";s:15:"Wysiwyg testing";s:11:"description";s:50:"Tests Wysiwyg module functionality. Do not enable.";s:4:"core";s:3:"7.x";s:7:"package";s:7:"Testing";s:6:"hidden";b:1;s:12:"dependencies";a:1:{i:0;s:7:"wysiwyg";}s:5:"files";a:1:{i:0;s:19:"wysiwyg_test.module";}s:7:"version";s:7:"7.x-2.2";s:7:"project";s:7:"wysiwyg";s:9:"datestamp";s:10:"1349213776";s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/modules/wysiwyg/wysiwyg.module', 'wysiwyg', 'module', '', '1', '0', 7200, '0', 'a:12:{s:4:"name";s:7:"Wysiwyg";s:11:"description";s:48:"Allows to edit content with client-side editors.";s:7:"package";s:14:"User interface";s:4:"core";s:3:"7.x";s:9:"configure";s:28:"admin/config/content/wysiwyg";s:5:"files";a:2:{i:0;s:14:"wysiwyg.module";i:1;s:18:"tests/wysiwyg.test";}s:7:"version";s:7:"7.x-2.2";s:7:"project";s:7:"wysiwyg";s:9:"datestamp";s:10:"1349213776";s:12:"dependencies";a:0:{}s:3:"php";s:5:"5.2.4";s:9:"bootstrap";i:0;}'),
('sites/all/themes/theme822/theme822.info', 'theme822', 'theme', 'themes/engines/phptemplate/phptemplate.engine', '1', '0', -1, '0', 'a:16:{s:4:"name";s:8:"theme822";s:11:"description";s:81:"This template is made by <a href="http://template-help.com">template-help.com</a>";s:10:"screenshot";s:40:"sites/all/themes/theme822/screenshot.png";s:4:"core";s:3:"7.x";s:6:"engine";s:11:"phptemplate";s:11:"stylesheets";a:1:{s:6:"screen";a:4:{s:19:"css/boilerplate.css";s:45:"sites/all/themes/theme822/css/boilerplate.css";s:13:"css/style.css";s:39:"sites/all/themes/theme822/css/style.css";s:24:"css/maintenance-page.css";s:50:"sites/all/themes/theme822/css/maintenance-page.css";s:16:"css/skeleton.css";s:42:"sites/all/themes/theme822/css/skeleton.css";}}s:7:"scripts";a:4:{s:19:"js/theme822.core.js";s:45:"sites/all/themes/theme822/js/theme822.core.js";s:19:"js/jquery.loader.js";s:45:"sites/all/themes/theme822/js/jquery.loader.js";s:28:"js/jquery.debouncedresize.js";s:54:"sites/all/themes/theme822/js/jquery.debouncedresize.js";s:23:"js/jquery.mobilemenu.js";s:49:"sites/all/themes/theme822/js/jquery.mobilemenu.js";}s:7:"regions";a:16:{s:10:"header_top";s:10:"Header top";s:6:"header";s:6:"Header";s:13:"header_bottom";s:13:"Header Bottom";s:4:"menu";s:4:"Menu";s:4:"help";s:4:"Help";s:11:"content_top";s:11:"Content top";s:7:"content";s:7:"Content";s:14:"content_bottom";s:14:"Content bottom";s:18:"sidebar_first_wide";s:18:"Sidebar first wide";s:20:"sidebar_first_narrow";s:20:"Sidebar first narrow";s:19:"sidebar_second_wide";s:19:"Sidebar second wide";s:21:"sidebar_second_narrow";s:21:"Sidebar second narrow";s:6:"footer";s:6:"Footer";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";s:11:"highlighted";s:11:"Highlighted";}s:8:"settings";a:8:{s:19:"theme822_feed_icons";s:1:"0";s:23:"theme822_clear_registry";s:1:"0";s:19:"theme822_tabs_float";s:1:"0";s:18:"theme822_tabs_node";s:1:"1";s:27:"theme822_breadcrumb_display";s:2:"no";s:33:"theme822_breadcrumb_hideonlyfront";s:1:"1";s:29:"theme822_breadcrumb_showtitle";s:1:"0";s:29:"theme822_breadcrumb_separator";s:2:"»";}s:7:"version";s:7:"7.x-1.0";s:7:"project";s:8:"theme822";s:9:"datestamp";s:10:"1320946536";s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:3:"php";s:5:"5.2.4";s:14:"regions_hidden";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}s:28:"overlay_supplemental_regions";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}}'),
('sites/all/themes/tipsy/tipsy.info', 'tipsy', 'theme', 'themes/engines/phptemplate/phptemplate.engine', '0', '0', 0, '999', 'a:16:{s:4:"name";s:14:"Tipsy tooltips";s:11:"description";s:141:"Integrates <a href="http://onehackoranother.com/projects/jquery/tipsy/">Tipsy</a> jQuery plugin for creating a Facebook-like tooltips effect.";s:4:"core";s:3:"7.x";s:9:"configure";s:33:"admin/config/user-interface/tipsy";s:7:"version";s:11:"7.x-1.0-rc1";s:7:"project";s:5:"tipsy";s:9:"datestamp";s:10:"1307366519";s:6:"engine";s:11:"phptemplate";s:7:"regions";a:9:{s:13:"sidebar_first";s:12:"Left sidebar";s:14:"sidebar_second";s:13:"Right sidebar";s:7:"content";s:7:"Content";s:6:"header";s:6:"Header";s:6:"footer";s:6:"Footer";s:11:"highlighted";s:11:"Highlighted";s:4:"help";s:4:"Help";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";}s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:10:"screenshot";s:37:"sites/all/themes/tipsy/screenshot.png";s:3:"php";s:5:"5.2.4";s:11:"stylesheets";a:0:{}s:7:"scripts";a:0:{}s:14:"regions_hidden";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}s:28:"overlay_supplemental_regions";a:1:{i:0;s:8:"page_top";}}'),
('themes/bartik/bartik.info', 'bartik', 'theme', 'themes/engines/phptemplate/phptemplate.engine', '1', '0', -1, '0', 'a:17:{s:4:"name";s:6:"Bartik";s:11:"description";s:48:"A flexible, recolorable theme with many regions.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:11:"stylesheets";a:2:{s:3:"all";a:3:{s:14:"css/layout.css";s:28:"themes/bartik/css/layout.css";s:13:"css/style.css";s:27:"themes/bartik/css/style.css";s:14:"css/colors.css";s:28:"themes/bartik/css/colors.css";}s:5:"print";a:1:{s:13:"css/print.css";s:27:"themes/bartik/css/print.css";}}s:7:"regions";a:17:{s:6:"header";s:6:"Header";s:4:"help";s:4:"Help";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";s:11:"highlighted";s:11:"Highlighted";s:8:"featured";s:8:"Featured";s:7:"content";s:7:"Content";s:13:"sidebar_first";s:13:"Sidebar first";s:14:"sidebar_second";s:14:"Sidebar second";s:14:"triptych_first";s:14:"Triptych first";s:15:"triptych_middle";s:15:"Triptych middle";s:13:"triptych_last";s:13:"Triptych last";s:18:"footer_firstcolumn";s:19:"Footer first column";s:19:"footer_secondcolumn";s:20:"Footer second column";s:18:"footer_thirdcolumn";s:19:"Footer third column";s:19:"footer_fourthcolumn";s:20:"Footer fourth column";s:6:"footer";s:6:"Footer";}s:8:"settings";a:1:{s:20:"shortcut_module_link";s:1:"0";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:6:"engine";s:11:"phptemplate";s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:10:"screenshot";s:28:"themes/bartik/screenshot.png";s:3:"php";s:5:"5.2.4";s:7:"scripts";a:0:{}s:14:"regions_hidden";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}s:28:"overlay_supplemental_regions";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}}'),
('themes/garland/garland.info', 'garland', 'theme', 'themes/engines/phptemplate/phptemplate.engine', '0', '0', -1, '0', 'a:17:{s:4:"name";s:7:"Garland";s:11:"description";s:111:"A multi-column theme which can be configured to modify colors and switch between fixed and fluid width layouts.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:11:"stylesheets";a:2:{s:3:"all";a:1:{s:9:"style.css";s:24:"themes/garland/style.css";}s:5:"print";a:1:{s:9:"print.css";s:24:"themes/garland/print.css";}}s:8:"settings";a:1:{s:13:"garland_width";s:5:"fluid";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:6:"engine";s:11:"phptemplate";s:7:"regions";a:9:{s:13:"sidebar_first";s:12:"Left sidebar";s:14:"sidebar_second";s:13:"Right sidebar";s:7:"content";s:7:"Content";s:6:"header";s:6:"Header";s:6:"footer";s:6:"Footer";s:11:"highlighted";s:11:"Highlighted";s:4:"help";s:4:"Help";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";}s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:10:"screenshot";s:29:"themes/garland/screenshot.png";s:3:"php";s:5:"5.2.4";s:7:"scripts";a:0:{}s:14:"regions_hidden";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}s:28:"overlay_supplemental_regions";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}}'),
('themes/seven/seven.info', 'seven', 'theme', 'themes/engines/phptemplate/phptemplate.engine', '1', '0', -1, '0', 'a:17:{s:4:"name";s:5:"Seven";s:11:"description";s:65:"A simple one-column, tableless, fluid width administration theme.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:11:"stylesheets";a:1:{s:6:"screen";a:2:{s:9:"reset.css";s:22:"themes/seven/reset.css";s:9:"style.css";s:22:"themes/seven/style.css";}}s:8:"settings";a:1:{s:20:"shortcut_module_link";s:1:"1";}s:7:"regions";a:5:{s:7:"content";s:7:"Content";s:4:"help";s:4:"Help";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";s:13:"sidebar_first";s:13:"First sidebar";}s:14:"regions_hidden";a:3:{i:0;s:13:"sidebar_first";i:1;s:8:"page_top";i:2;s:11:"page_bottom";}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:6:"engine";s:11:"phptemplate";s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:10:"screenshot";s:27:"themes/seven/screenshot.png";s:3:"php";s:5:"5.2.4";s:7:"scripts";a:0:{}s:28:"overlay_supplemental_regions";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}}'),
('themes/stark/stark.info', 'stark', 'theme', 'themes/engines/phptemplate/phptemplate.engine', '0', '0', -1, '0', 'a:16:{s:4:"name";s:5:"Stark";s:11:"description";s:208:"This theme demonstrates Drupal''s default HTML markup and CSS styles. To learn how to build your own theme and override Drupal''s default code, see the <a href="http://drupal.org/theme-guide">Theming Guide</a>.";s:7:"package";s:4:"Core";s:7:"version";s:4:"7.23";s:4:"core";s:3:"7.x";s:11:"stylesheets";a:1:{s:3:"all";a:1:{s:10:"layout.css";s:23:"themes/stark/layout.css";}}s:7:"project";s:6:"drupal";s:9:"datestamp";s:10:"1375928238";s:6:"engine";s:11:"phptemplate";s:7:"regions";a:9:{s:13:"sidebar_first";s:12:"Left sidebar";s:14:"sidebar_second";s:13:"Right sidebar";s:7:"content";s:7:"Content";s:6:"header";s:6:"Header";s:6:"footer";s:6:"Footer";s:11:"highlighted";s:11:"Highlighted";s:4:"help";s:4:"Help";s:8:"page_top";s:8:"Page top";s:11:"page_bottom";s:11:"Page bottom";}s:8:"features";a:9:{i:0;s:4:"logo";i:1;s:7:"favicon";i:2;s:4:"name";i:3;s:6:"slogan";i:4;s:17:"node_user_picture";i:5;s:20:"comment_user_picture";i:6;s:25:"comment_user_verification";i:7;s:9:"main_menu";i:8;s:14:"secondary_menu";}s:10:"screenshot";s:27:"themes/stark/screenshot.png";s:3:"php";s:5:"5.2.4";s:7:"scripts";a:0:{}s:14:"regions_hidden";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}s:28:"overlay_supplemental_regions";a:2:{i:0;s:8:"page_top";i:1;s:11:"page_bottom";}}');
/*!40000 ALTER TABLE system ENABLE KEYS */;

--
-- Table structure for table 'taxonomy_index'
--

CREATE TABLE IF NOT EXISTS `taxonomy_index` (
  `nid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The node.nid this record tracks.',
  `tid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The term ID.',
  `sticky` tinyint(4) DEFAULT '0' COMMENT 'Boolean indicating whether the node is sticky.',
  `created` int(11) NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp when the node was created.',
  KEY `term_node` (`tid`,`sticky`,`created`),
  KEY `nid` (`nid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Maintains denormalized information about node/term...';

--
-- Dumping data for table 'taxonomy_index'
--

/*!40000 ALTER TABLE taxonomy_index DISABLE KEYS */;
INSERT INTO `taxonomy_index` VALUES
('12', '1', '0', '1305117326'),
('13', '1', '0', '1305117431'),
('14', '1', '0', '1305117493'),
('15', '1', '0', '1305117558'),
('16', '1', '0', '1305117592'),
('17', '5', '0', '1305117638'),
('18', '5', '0', '1305117661'),
('19', '5', '0', '1305117686'),
('20', '5', '0', '1305117721'),
('21', '6', '0', '1305117759'),
('22', '6', '0', '1305117790'),
('23', '6', '0', '1305117828'),
('24', '6', '0', '1305117855'),
('25', '7', '0', '1305117888'),
('26', '7', '0', '1305117913'),
('27', '7', '0', '1305117944'),
('28', '8', '0', '1305117979'),
('29', '8', '0', '1305118002'),
('30', '8', '0', '1305118030'),
('31', '8', '0', '1305118075'),
('32', '8', '0', '1305118101'),
('33', '9', '0', '1305118138'),
('34', '9', '0', '1305118163'),
('35', '10', '0', '1305118193'),
('36', '15', '0', '1333108028'),
('36', '16', '0', '1333108028'),
('36', '17', '0', '1333108028'),
('40', '25', '0', '1333108045'),
('40', '19', '0', '1333108045'),
('40', '18', '0', '1333108045'),
('40', '27', '0', '1333108045'),
('40', '23', '0', '1333108045'),
('40', '24', '0', '1333108045'),
('40', '26', '0', '1333108045'),
('40', '22', '0', '1333108045'),
('40', '20', '0', '1333108045'),
('39', '19', '0', '1333108052'),
('39', '23', '0', '1333108052'),
('37', '27', '0', '1333108059'),
('37', '26', '0', '1333108059'),
('38', '19', '0', '1333108072'),
('38', '23', '0', '1333108072'),
('38', '26', '0', '1333108072'),
('38', '20', '0', '1333108072'),
('41', '25', '0', '1333108079'),
('41', '19', '0', '1333108079'),
('41', '18', '0', '1333108079'),
('41', '21', '0', '1333108079'),
('41', '20', '0', '1333108079'),
('57', '28', '0', '1333107892'),
('57', '29', '0', '1333107892'),
('57', '31', '0', '1333107892'),
('52', '28', '0', '1333107871'),
('52', '29', '0', '1333107871'),
('53', '28', '0', '1333107913'),
('53', '30', '0', '1333107913'),
('54', '28', '0', '1333107906'),
('55', '28', '0', '1333107899'),
('55', '31', '0', '1333107899'),
('56', '28', '0', '1333107886'),
('56', '29', '0', '1333107886'),
('58', '28', '0', '1333107878'),
('58', '31', '0', '1333107878'),
('82', '28', '0', '1358522809');
/*!40000 ALTER TABLE taxonomy_index ENABLE KEYS */;

--
-- Table structure for table 'taxonomy_term_data'
--

CREATE TABLE IF NOT EXISTS `taxonomy_term_data` (
  `tid` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique term ID.',
  `vid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The taxonomy_vocabulary.vid of the vocabulary to which the term is assigned.',
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT 'The term name.',
  `description` longtext COMMENT 'A description of the term.',
  `format` varchar(255) DEFAULT NULL COMMENT 'The filter_format.format of the description.',
  `weight` int(11) NOT NULL DEFAULT '0' COMMENT 'The weight of this term in relation to other terms.',
  PRIMARY KEY (`tid`),
  KEY `taxonomy_tree` (`vid`,`weight`,`name`),
  KEY `vid_name` (`vid`,`name`),
  KEY `name` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores term information.';

--
-- Dumping data for table 'taxonomy_term_data'
--

/*!40000 ALTER TABLE taxonomy_term_data DISABLE KEYS */;
INSERT INTO `taxonomy_term_data` VALUES
('1', '2', 'General discussion', '', NULL, '0'),
('2', '2', 'Suspendisse convallis, risus', 'Praesent arcu ipsum, rhoncus nec tincidunt quis, rutrum a augue. Fusce congue, lacus nec pharetra venenatis, risus sapien congue purus, non dictum tellus sem id enim.', NULL, '0'),
('3', '2', 'Duis lobortis arcu dignissim mauris', 'Donec nisl risus, tincidunt at interdum nec, elementum vitae metus. Integer non diam nec est imperdiet sollicitudin.', NULL, '4'),
('4', '2', 'Cum sociis natoque penatibus', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam ac velit ligula. Aliquam aliquam est vitae dui faucibus consectetur non at sapien.', NULL, '8'),
('5', '2', 'Vestibulum eleifend convallis', 'estibulum eleifend convallis mi, id sodales ante varius ut. Vivamus at tristique.', NULL, '1'),
('6', '2', 'Duis lobortis arcu dignissim mauris', 'Donec nisl risus, tincidunt at interdum nec, elementum vitae metus. Integer non diam nec est imperdiet sollicitudin.', NULL, '0'),
('7', '2', 'Integer metus orci, vestibulum', 'Nulla congue placerat magna, eget auctor quam suscipit ut. In facilisis porta justo. Sed mattis aliquam diam, eget tempor ipsum blandit id.', NULL, '1'),
('8', '2', 'Nam nec est a nulla pulvinar', 'Quisque vel massa scelerisque erat ultrices placerat non id augue. Nulla commodo scelerisque massa', NULL, '0'),
('9', '2', 'Ut vehicula, quam aliquam', 'Sed ac risus ligula. Etiam tincidunt tempus est, sit amet mattis nibh fringilla sed. In augue sapien, congue et ornare', NULL, '1'),
('10', '2', 'Maecenas semper feugiat', 'Sed et risus lacus, id ultrices metus. Maecenas sollicitudin lobortis risus sit amet accumsan. Donec interdum nulla id velit consectetur lobortis.', NULL, '2'),
('15', '1', 'lorem', NULL, NULL, '0'),
('16', '1', 'ipsum', NULL, NULL, '0'),
('17', '1', 'dolor', NULL, NULL, '0'),
('18', '3', 'Lorem ipsum dolor sit amet', '', 'filtered_html', '0'),
('19', '3', 'Duis vel nisifes', '', 'filtered_html', '0'),
('20', '3', 'Vestibulum ullamcorpermoles', '', 'filtered_html', '0'),
('21', '3', 'Pellentesque habitant morbi', '', 'filtered_html', '0'),
('22', '3', 'Tristique senectus et', '', 'filtered_html', '0'),
('23', '3', 'Netus et malesuada fames', '', 'filtered_html', '0'),
('24', '3', 'Quisque viverra leo id tincidunt', '', 'filtered_html', '0'),
('25', '3', 'Condimentum tellus tellus', '', 'filtered_html', '0'),
('26', '3', 'Tincidunt tellus id euismod', '', 'filtered_html', '0'),
('27', '3', 'Lorem ipsum dolor sit amet', '', 'filtered_html', '0'),
('28', '4', 'All', '', 'filtered_html', '0'),
('29', '4', 'Vivamus', '', 'filtered_html', '1'),
('30', '4', 'Maecenas', '', 'filtered_html', '2'),
('31', '4', 'Aenean', '', 'filtered_html', '3');
/*!40000 ALTER TABLE taxonomy_term_data ENABLE KEYS */;

--
-- Table structure for table 'taxonomy_term_hierarchy'
--

CREATE TABLE IF NOT EXISTS `taxonomy_term_hierarchy` (
  `tid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'Primary Key: The taxonomy_term_data.tid of the term.',
  `parent` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'Primary Key: The taxonomy_term_data.tid of the term’s parent. 0 indicates no parent.',
  PRIMARY KEY (`tid`,`parent`),
  KEY `parent` (`parent`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores the hierarchical relationship between terms.';

--
-- Dumping data for table 'taxonomy_term_hierarchy'
--

/*!40000 ALTER TABLE taxonomy_term_hierarchy DISABLE KEYS */;
INSERT INTO `taxonomy_term_hierarchy` VALUES
('2', '0'),
('3', '0'),
('4', '0'),
('15', '0'),
('16', '0'),
('17', '0'),
('18', '0'),
('19', '0'),
('20', '0'),
('21', '0'),
('22', '0'),
('23', '0'),
('24', '0'),
('25', '0'),
('26', '0'),
('27', '0'),
('28', '0'),
('29', '0'),
('30', '0'),
('31', '0'),
('1', '2'),
('5', '2'),
('6', '3'),
('7', '3'),
('8', '4'),
('9', '4'),
('10', '4');
/*!40000 ALTER TABLE taxonomy_term_hierarchy ENABLE KEYS */;

--
-- Table structure for table 'taxonomy_vocabulary'
--

CREATE TABLE IF NOT EXISTS `taxonomy_vocabulary` (
  `vid` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique vocabulary ID.',
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT 'Name of the vocabulary.',
  `machine_name` varchar(255) NOT NULL DEFAULT '' COMMENT 'The vocabulary machine name.',
  `description` longtext COMMENT 'Description of the vocabulary.',
  `hierarchy` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT 'The type of hierarchy allowed within the vocabulary. (0 = disabled, 1 = single, 2 = multiple)',
  `module` varchar(255) NOT NULL DEFAULT '' COMMENT 'The module which created the vocabulary.',
  `weight` int(11) NOT NULL DEFAULT '0' COMMENT 'The weight of this vocabulary in relation to other vocabularies.',
  PRIMARY KEY (`vid`),
  UNIQUE KEY `machine_name` (`machine_name`),
  KEY `list` (`weight`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores vocabulary information.';

--
-- Dumping data for table 'taxonomy_vocabulary'
--

/*!40000 ALTER TABLE taxonomy_vocabulary DISABLE KEYS */;
INSERT INTO `taxonomy_vocabulary` VALUES
('1', 'Tags', 'tags', 'Use tags to group articles on similar topics into categories.', '0', 'taxonomy', '0'),
('2', 'Forums', 'forums', 'Forum navigation vocabulary', '1', 'forum', '-10'),
('3', 'Blog categories', 'blog_cetogory', '', '0', 'taxonomy', '0'),
('4', 'Portfolio categories', 'portfolio_categories', '', '0', 'taxonomy', '0');
/*!40000 ALTER TABLE taxonomy_vocabulary ENABLE KEYS */;

--
-- Table structure for table 'tracker_node'
--

CREATE TABLE IF NOT EXISTS `tracker_node` (
  `nid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The node.nid this record tracks.',
  `published` tinyint(4) DEFAULT '0' COMMENT 'Boolean indicating whether the node is published.',
  `changed` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp when the node was most recently saved or commented on.',
  PRIMARY KEY (`nid`),
  KEY `tracker` (`published`,`changed`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Tracks when nodes were last changed or commented on.';

--
-- Dumping data for table 'tracker_node'
--

/*!40000 ALTER TABLE tracker_node DISABLE KEYS */;
INSERT INTO `tracker_node` VALUES
('12', '1', '1305117353'),
('13', '1', '1305117437'),
('14', '1', '1305117530'),
('15', '1', '1305117558'),
('16', '1', '1305117601'),
('17', '1', '1305117638'),
('18', '1', '1305117661'),
('19', '1', '1305117686'),
('20', '1', '1305117721'),
('21', '1', '1305117759'),
('22', '1', '1305117790'),
('23', '1', '1305117828'),
('24', '1', '1305117855'),
('25', '1', '1305117888'),
('26', '1', '1305117913'),
('27', '1', '1305117944'),
('28', '1', '1305117979'),
('29', '1', '1305118002'),
('30', '1', '1305118030'),
('31', '1', '1305118075'),
('32', '1', '1305118101'),
('33', '1', '1305118138'),
('34', '1', '1305118163'),
('35', '1', '1305118193'),
('42', '1', '1311001382'),
('43', '1', '1311001570'),
('44', '1', '1311001635'),
('45', '1', '1311001697'),
('46', '1', '1311001731'),
('79', '1', '1322324835'),
('11', '1', '1333107995'),
('81', '1', '1353943550'),
('67', '1', '1354540838'),
('68', '1', '1354540862'),
('69', '1', '1354540870'),
('71', '1', '1354540885'),
('65', '1', '1354540903'),
('73', '1', '1354540936'),
('36', '1', '1374828279'),
('89', '1', '1375101372'),
('88', '1', '1375101468'),
('47', '1', '1378907751'),
('50', '1', '1378907811'),
('51', '1', '1378907850'),
('78', '1', '1378991281'),
('77', '1', '1378991290'),
('76', '1', '1378991299'),
('40', '1', '1378991805'),
('39', '1', '1378991807'),
('37', '1', '1378991808'),
('38', '1', '1378991809'),
('41', '1', '1378991811'),
('85', '1', '1378991996'),
('86', '1', '1378991997'),
('87', '1', '1378991999'),
('83', '1', '1378992001'),
('84', '1', '1378992051'),
('57', '1', '1378992218'),
('52', '1', '1378992221'),
('53', '1', '1378992222'),
('54', '1', '1378992224'),
('55', '1', '1378992225'),
('56', '1', '1378992228'),
('58', '1', '1378992230'),
('82', '1', '1379064099');
/*!40000 ALTER TABLE tracker_node ENABLE KEYS */;

--
-- Table structure for table 'tracker_user'
--

CREATE TABLE IF NOT EXISTS `tracker_user` (
  `nid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The node.nid this record tracks.',
  `uid` int(11) NOT NULL DEFAULT '0' COMMENT 'The users.uid of the node author or commenter.',
  `published` tinyint(4) DEFAULT '0' COMMENT 'Boolean indicating whether the node is published.',
  `changed` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp when the node was most recently saved or commented on.',
  PRIMARY KEY (`nid`,`uid`),
  KEY `tracker` (`uid`,`published`,`changed`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Tracks when nodes were last changed or commented on, for...';

--
-- Dumping data for table 'tracker_user'
--

/*!40000 ALTER TABLE tracker_user DISABLE KEYS */;
INSERT INTO `tracker_user` VALUES
('12', '1', '1', '1305117353'),
('13', '1', '1', '1305117437'),
('14', '1', '1', '1305117530'),
('15', '1', '1', '1305117558'),
('16', '1', '1', '1305117601'),
('17', '1', '1', '1305117638'),
('18', '1', '1', '1305117661'),
('19', '1', '1', '1305117686'),
('20', '1', '1', '1305117721'),
('21', '1', '1', '1305117759'),
('22', '1', '1', '1305117790'),
('23', '1', '1', '1305117828'),
('24', '1', '1', '1305117855'),
('25', '1', '1', '1305117888'),
('26', '1', '1', '1305117913'),
('27', '1', '1', '1305117944'),
('28', '1', '1', '1305117979'),
('29', '1', '1', '1305118002'),
('30', '1', '1', '1305118030'),
('31', '1', '1', '1305118075'),
('32', '1', '1', '1305118101'),
('33', '1', '1', '1305118138'),
('34', '1', '1', '1305118163'),
('35', '1', '1', '1305118193'),
('42', '1', '1', '1311001382'),
('43', '1', '1', '1311001570'),
('44', '1', '1', '1311001635'),
('45', '1', '1', '1311001697'),
('46', '1', '1', '1311001731'),
('79', '1', '1', '1322324835'),
('11', '1', '1', '1333107995'),
('81', '1', '1', '1353943550'),
('67', '1', '1', '1354540838'),
('68', '1', '1', '1354540862'),
('69', '1', '1', '1354540870'),
('71', '1', '1', '1354540885'),
('65', '1', '1', '1354540903'),
('73', '1', '1', '1354540936'),
('36', '1', '1', '1374828279'),
('47', '1', '1', '1378907751'),
('50', '1', '1', '1378907811'),
('51', '1', '1', '1378907850'),
('78', '1', '1', '1378991281'),
('77', '1', '1', '1378991290'),
('76', '1', '1', '1378991299'),
('40', '1', '1', '1378991805'),
('39', '1', '1', '1378991807'),
('37', '1', '1', '1378991808'),
('38', '1', '1', '1378991809'),
('41', '1', '1', '1378991811'),
('85', '1', '1', '1378991996'),
('86', '1', '1', '1378991997'),
('87', '1', '1', '1378991999'),
('83', '1', '1', '1378992001'),
('84', '1', '1', '1378992051'),
('57', '1', '1', '1378992218'),
('52', '1', '1', '1378992221'),
('53', '1', '1', '1378992222'),
('54', '1', '1', '1378992224'),
('55', '1', '1', '1378992225'),
('56', '1', '1', '1378992228'),
('58', '1', '1', '1378992230'),
('82', '1', '1', '1379064099'),
('88', '157', '1', '1375101468'),
('89', '158', '1', '1375101372');
/*!40000 ALTER TABLE tracker_user ENABLE KEYS */;

--
-- Table structure for table 'trigger_assignments'
--

CREATE TABLE IF NOT EXISTS `trigger_assignments` (
  `hook` varchar(78) NOT NULL DEFAULT '' COMMENT 'Primary Key: The name of the internal Drupal hook; for example, node_insert.',
  `aid` varchar(255) NOT NULL DEFAULT '' COMMENT 'Primary Key: Action’s actions.aid.',
  `weight` int(11) NOT NULL DEFAULT '0' COMMENT 'The weight of the trigger assignment in relation to other triggers.',
  PRIMARY KEY (`hook`,`aid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Maps trigger to hook and operation assignments from...';

--
-- Dumping data for table 'trigger_assignments'
--

/*!40000 ALTER TABLE trigger_assignments DISABLE KEYS */;
/*!40000 ALTER TABLE trigger_assignments ENABLE KEYS */;

--
-- Table structure for table 'url_alias'
--

CREATE TABLE IF NOT EXISTS `url_alias` (
  `pid` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'A unique path alias identifier.',
  `source` varchar(255) NOT NULL DEFAULT '' COMMENT 'The Drupal path this alias is for; e.g. node/12.',
  `alias` varchar(255) NOT NULL DEFAULT '' COMMENT 'The alias for this path; e.g. title-of-the-story.',
  `language` varchar(12) NOT NULL DEFAULT '' COMMENT 'The language this alias is for; if ’und’, the alias will be used for unknown languages. Each Drupal path can have an alias for each supported language.',
  PRIMARY KEY (`pid`),
  KEY `alias_language_pid` (`alias`,`language`,`pid`),
  KEY `source_language_pid` (`source`,`language`,`pid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='A list of URL aliases for Drupal paths; a user may visit...';

--
-- Dumping data for table 'url_alias'
--

/*!40000 ALTER TABLE url_alias DISABLE KEYS */;
/*!40000 ALTER TABLE url_alias ENABLE KEYS */;

--
-- Table structure for table 'users'
--

CREATE TABLE IF NOT EXISTS `users` (
  `uid` int(10) unsigned NOT NULL DEFAULT '0',
  `name` varchar(60) NOT NULL DEFAULT '' COMMENT 'Unique user name.',
  `pass` varchar(128) NOT NULL DEFAULT '' COMMENT 'User’s password (hashed).',
  `mail` varchar(254) DEFAULT '' COMMENT 'User’s e-mail address.',
  `theme` varchar(255) NOT NULL DEFAULT '' COMMENT 'User’s default theme.',
  `signature` varchar(255) NOT NULL DEFAULT '' COMMENT 'User’s signature.',
  `signature_format` varchar(255) DEFAULT NULL COMMENT 'The filter_format.format of the signature.',
  `created` int(11) NOT NULL DEFAULT '0' COMMENT 'Timestamp for when user was created.',
  `access` int(11) NOT NULL DEFAULT '0' COMMENT 'Timestamp for previous time user accessed the site.',
  `login` int(11) NOT NULL DEFAULT '0' COMMENT 'Timestamp for user’s last login.',
  `status` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'Whether the user is active(1) or blocked(0).',
  `timezone` varchar(32) DEFAULT NULL COMMENT 'User’s time zone.',
  `language` varchar(12) NOT NULL DEFAULT '' COMMENT 'User’s default language.',
  `picture` int(11) NOT NULL DEFAULT '0' COMMENT 'Foreign key: file_managed.fid of user’s picture.',
  `init` varchar(254) DEFAULT '' COMMENT 'E-mail address used for initial account creation.',
  `data` longblob COMMENT 'A serialized array of name value pairs that are related to the user. Any form values posted during user edit are stored and are loaded into the $user object during user_load(). Use of this field is discouraged and it will likely disappear in a future...',
  PRIMARY KEY (`uid`),
  UNIQUE KEY `name` (`name`),
  KEY `access` (`access`),
  KEY `created` (`created`),
  KEY `mail` (`mail`),
  KEY `picture` (`picture`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores user data.';

--
-- Dumping data for table 'users'
--

/*!40000 ALTER TABLE users DISABLE KEYS */;
INSERT INTO `users` VALUES
('0', '', '', '', '', '', NULL, '0', '0', '0', '0', NULL, '', '0', '', NULL),
('1', 'admin', '$S$DnvLQiB/nnM8o2WejOnJW5awsfzXejjYMRYHIHQnMUWexAYVcOl.', 'admin@admin.com', '', '', NULL, '1308670632', '1379069160', '1378903057', '1', NULL, '', '0', 'admin@admin.com', 'a:1:{s:7:"contact";i:1;}'),
('155', 'mukitriwidr', '', 'mukitriwidr@localhost', '', '', NULL, '1373782737', '0', '0', '1', NULL, 'und', '52', '', 'a:1:{s:7:"contact";i:1;}'),
('156', 'nasitrowohi', '', 'nasitrowohi@localhost', '', '', NULL, '1373472986', '0', '0', '1', NULL, 'und', '53', '', 'a:1:{s:7:"contact";i:1;}'),
('157', 'Jack Smith', '$S$D/iL637Z4kLaiAkxplzxPUSrxlMzn2ZNMZGfSBX95T9LY1p9OQ5H', 'wraspit@gmail.com', '', '', 'full_html', '1373925635', '1375100858', '1375100858', '1', '', 'und', '93', '', 'a:1:{s:7:"contact";i:1;}'),
('158', 'Lisa cole', '$S$DcAzoJWE9268RoIQErDxK9WwUo97zrMjo7BY2JxKlD3/HjKdg01c', 'jihifric@gmail.com', '', '', 'full_html', '1373841129', '0', '0', '1', '', 'und', '94', '', 'a:1:{s:7:"contact";i:1;}'),
('159', 'sibruwi', '', 'sibruwi@localhost', '', '', NULL, '1373776941', '0', '0', '1', NULL, 'und', '56', '', 'a:1:{s:7:"contact";i:1;}');
/*!40000 ALTER TABLE users ENABLE KEYS */;

--
-- Table structure for table 'users_roles'
--

CREATE TABLE IF NOT EXISTS `users_roles` (
  `uid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'Primary Key: users.uid for user.',
  `rid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'Primary Key: role.rid for role.',
  PRIMARY KEY (`uid`,`rid`),
  KEY `rid` (`rid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Maps users to roles.';

--
-- Dumping data for table 'users_roles'
--

/*!40000 ALTER TABLE users_roles DISABLE KEYS */;
INSERT INTO `users_roles` VALUES
('1', '3');
/*!40000 ALTER TABLE users_roles ENABLE KEYS */;

--
-- Table structure for table 'variable'
--

CREATE TABLE IF NOT EXISTS `variable` (
  `name` varchar(128) NOT NULL DEFAULT '' COMMENT 'The name of the variable.',
  `value` longblob NOT NULL COMMENT 'The value of the variable.',
  PRIMARY KEY (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Named variable/value pairs created by Drupal core or any...';

--
-- Dumping data for table 'variable'
--

/*!40000 ALTER TABLE variable DISABLE KEYS */;
INSERT INTO `variable` VALUES
('additional_settings__active_tab_carousel', 's:15:"edit-submission";'),
('additional_settings__active_tab_employee', 's:9:"edit-menu";'),
('additional_settings__active_tab_faq', 's:13:"edit-workflow";'),
('additional_settings__active_tab_maps', 's:9:"edit-menu";'),
('additional_settings__active_tab_partners', 's:9:"edit-menu";'),
('additional_settings__active_tab_popular_services', 's:12:"edit-comment";'),
('additional_settings__active_tab_portfolio', 's:9:"edit-menu";'),
('additional_settings__active_tab_services', 's:9:"edit-menu";'),
('additional_settings__active_tab_slider', 's:15:"edit-submission";'),
('additional_settings__active_tab_testimonials', 's:12:"edit-comment";'),
('addthis_508_compliant', 'i:0;'),
('addthis_addressbook_enabled', 'i:0;'),
('addthis_bookmark_url', 's:41:"http://www.addthis.com/bookmark.php?v=250";'),
('addthis_brand', 's:0:"";'),
('addthis_clickback_tracking_enabled', 'i:0;'),
('addthis_click_to_open_compact_menu_enabled', 'i:0;'),
('addthis_co_brand', 's:0:"";'),
('addthis_custom_configuration_code', 's:23:"var addthis_config = {}";'),
('addthis_custom_configuration_code_enabled', 'i:0;'),
('addthis_disable_flash', 'i:0;'),
('addthis_display_in_links', 'i:1;'),
('addthis_display_in_teasers', 'i:1;'),
('addthis_dropdown_disabled', 'i:1;'),
('addthis_enabled_services', 'a:330:{s:7:"blogger";s:7:"blogger";s:9:"delicious";s:9:"delicious";s:4:"digg";s:4:"digg";s:8:"evernote";s:8:"evernote";s:10:"friendfeed";s:10:"friendfeed";s:8:"linkedin";s:8:"linkedin";s:7:"myspace";s:7:"myspace";s:11:"stumbleupon";s:11:"stumbleupon";s:6:"tumblr";s:6:"tumblr";s:4:"virb";s:4:"virb";s:11:"100zakladok";i:0;s:4:"2tag";i:0;s:7:"2linkme";i:0;s:6:"7live7";i:0;s:6:"a97abi";i:0;s:10:"addressbar";i:0;s:5:"adfty";i:0;s:6:"adifni";i:0;s:14:"amazonwishlist";i:0;s:6:"amenme";i:0;s:3:"aim";i:0;s:7:"aolmail";i:0;s:7:"armenix";i:0;s:4:"arto";i:0;s:6:"aviary";i:0;s:7:"azadegi";i:0;s:5:"baang";i:0;s:5:"baidu";i:0;s:7:"beat100";i:0;s:4:"bebo";i:0;s:6:"bentio";i:0;s:13:"biggerpockets";i:0;s:5:"bitly";i:0;s:8:"bizsugar";i:0;s:5:"bland";i:0;s:9:"blinklist";i:0;s:4:"blip";i:0;s:6:"bloggy";i:0;s:8:"blogkeen";i:0;s:9:"blogmarks";i:0;s:10:"blogtrottr";i:0;s:13:"blurpalicious";i:0;s:4:"bolt";i:0;s:8:"bobrdobr";i:0;s:8:"bonzobox";i:0;s:20:"socialbookmarkingnet";i:0;s:11:"bookmarkycz";i:0;s:12:"bookmerkende";i:0;s:6:"bordom";i:0;s:3:"box";i:0;s:8:"brainify";i:0;s:7:"bryderi";i:0;s:10:"buddymarks";i:0;s:6:"buffer";i:0;s:6:"buzzzy";i:0;s:6:"camyoo";i:0;s:8:"cardthis";i:0;s:5:"care2";i:0;s:7:"chimein";i:0;s:4:"chiq";i:0;s:5:"cirip";i:0;s:9:"citeulike";i:0;s:14:"classicalplace";i:0;s:10:"cleanprint";i:0;s:6:"clipdo";i:0;s:5:"cndig";i:0;s:7:"colivia";i:0;s:8:"technerd";i:0;s:8:"connotea";i:0;s:8:"cootopia";i:0;s:6:"cosmiq";i:0;s:8:"curateus";i:0;s:10:"designbump";i:0;s:14:"digthiswebhost";i:0;s:14:"digaculturanet";i:0;s:7:"diggita";i:0;s:4:"digo";i:0;s:7:"digzign";i:0;s:5:"diigo";i:0;s:7:"dipdive";i:0;s:8:"domelhor";i:0;s:5:"dosti";i:0;s:11:"dotnetkicks";i:0;s:14:"dotnetshoutout";i:0;s:6:"douban";i:0;s:8:"draugiem";i:0;s:6:"drimio";i:0;s:8:"dropjack";i:0;s:5:"dzone";i:0;s:8:"edelight";i:0;s:7:"efactor";i:0;s:6:"ekudos";i:0;s:10:"elefantapl";i:0;s:5:"email";i:0;s:6:"mailto";i:0;s:9:"embarkons";i:0;s:9:"eucliquei";i:0;s:9:"extraplay";i:0;s:7:"ezyspot";i:0;s:11:"stylishhome";i:0;s:12:"fabulously40";i:0;s:8:"facebook";i:0;s:13:"facebook_like";i:0;s:12:"informazione";i:0;s:4:"fark";i:0;s:8:"farkinda";i:0;s:11:"fashiolista";i:0;s:13:"fashionburner";i:0;s:7:"favable";i:0;s:5:"faves";i:0;s:8:"favlogde";i:0;s:11:"favoritende";i:0;s:9:"favorites";i:0;s:9:"favoritus";i:0;s:6:"flaker";i:0;s:8:"flosspro";i:0;s:5:"folkd";i:0;s:10:"formspring";i:0;s:17:"thefreedictionary";i:0;s:7:"fresqui";i:0;s:4:"funp";i:0;s:5:"fwisp";i:0;s:5:"gabbr";i:0;s:10:"gamekicker";i:0;s:9:"givealink";i:0;s:11:"globalgrind";i:0;s:5:"gmail";i:0;s:4:"govn";i:0;s:6:"godudu";i:0;s:9:"goodnoows";i:0;s:6:"google";i:0;s:14:"google_plusone";i:0;s:15:"googletranslate";i:0;s:20:"google_plusone_share";i:0;s:14:"greaterdebater";i:0;s:5:"grono";i:0;s:10:"habergentr";i:0;s:10:"hackernews";i:0;s:9:"hadashhot";i:0;s:6:"hatena";i:0;s:8:"gluvsnap";i:0;s:9:"hedgehogs";i:0;s:8:"hellotxt";i:0;s:10:"historious";i:0;s:11:"hotbookmark";i:0;s:7:"hotklix";i:0;s:7:"hotmail";i:0;s:11:"w3validator";i:0;s:5:"hyves";i:0;s:8:"identica";i:0;s:7:"igoogle";i:0;s:8:"ihavegot";i:0;s:6:"index4";i:0;s:7:"indexor";i:0;s:10:"instapaper";i:0;s:13:"investorlinks";i:0;s:6:"iorbix";i:0;s:8:"isociety";i:0;s:4:"iwiw";i:0;s:8:"jamespot";i:0;s:5:"jappy";i:0;s:9:"joliprint";i:0;s:5:"jolly";i:0;s:8:"jumptags";i:0;s:8:"kaboodle";i:0;s:6:"kaevur";i:0;s:6:"kaixin";i:0;s:7:"ketnooi";i:0;s:8:"kindleit";i:0;s:5:"kipup";i:0;s:5:"kledy";i:0;s:10:"kommenting";i:0;s:13:"latafaneracat";i:0;s:8:"librerio";i:0;s:9:"linkninja";i:0;s:9:"linkagogo";i:0;s:11:"linksgutter";i:0;s:10:"linkshares";i:0;s:6:"linkuj";i:0;s:11:"livejournal";i:0;s:13:"lockerblogger";i:0;s:8:"logger24";i:0;s:8:"mymailru";i:0;s:6:"markme";i:0;s:8:"mashbord";i:0;s:6:"meinvz";i:0;s:10:"mekusharim";i:0;s:7:"memonic";i:0;s:6:"memori";i:0;s:8:"mendeley";i:0;s:7:"meneame";i:0;s:4:"live";i:0;s:13:"mindbodygreen";i:0;s:10:"misterwong";i:0;s:13:"misterwong_de";i:0;s:8:"moemesto";i:0;s:7:"moikrug";i:0;s:8:"mototagz";i:0;s:12:"mrcnetworkit";i:0;s:8:"multiply";i:0;s:5:"myaol";i:0;s:10:"myhayastan";i:0;s:11:"mylinkvault";i:0;s:3:"n4g";i:0;s:10:"naszaklasa";i:0;s:6:"netlog";i:0;s:8:"netvibes";i:0;s:7:"netvouz";i:0;s:10:"newsmeback";i:0;s:9:"newstrust";i:0;s:8:"newsvine";i:0;s:5:"nujij";i:0;s:16:"odnoklassniki_ru";i:0;s:9:"oknotizie";i:0;s:7:"oneview";i:0;s:5:"orkut";i:0;s:9:"dashboard";i:0;s:5:"oyyla";i:0;s:5:"packg";i:0;s:8:"pafnetde";i:0;s:9:"pdfonline";i:0;s:8:"pdfmyurl";i:0;s:9:"phonefavs";i:0;s:6:"pingfm";i:0;s:9:"pinterest";i:0;s:8:"planypus";i:0;s:5:"plaxo";i:0;s:5:"plurk";i:0;s:9:"pochvalcz";i:0;s:11:"politicnote";i:0;s:8:"posteezy";i:0;s:9:"posterous";i:0;s:7:"pratiba";i:0;s:5:"print";i:0;s:13:"printfriendly";i:0;s:5:"pusha";i:0;s:5:"qrfin";i:0;s:5:"qrsrc";i:0;s:9:"quantcast";i:0;s:5:"qzone";i:0;s:11:"readitlater";i:0;s:6:"reddit";i:0;s:6:"rediff";i:0;s:6:"redkum";i:0;s:12:"researchgate";i:0;s:7:"ridefix";i:0;s:7:"scoopat";i:0;s:7:"scoopit";i:0;s:7:"sekoman";i:0;s:13:"select2gether";i:0;s:6:"sharer";i:0;s:6:"shaveh";i:0;s:9:"shetoldme";i:0;s:9:"sinaweibo";i:0;s:7:"skyrock";i:0;s:5:"smiru";i:0;s:8:"sodahead";i:0;s:6:"sonico";i:0;s:9:"speedtile";i:0;s:6:"sphinn";i:0;s:8:"spinsnap";i:0;s:11:"spokentoyou";i:0;s:4:"yiid";i:0;s:9:"springpad";i:0;s:7:"squidoo";i:0;s:8:"startaid";i:0;s:8:"startlap";i:0;s:13:"storyfollower";i:0;s:7:"studivz";i:0;s:8:"stuffpit";i:0;s:9:"stumpedia";i:0;s:11:"surfingbird";i:0;s:5:"svejo";i:0;s:8:"symbaloo";i:0;s:5:"taaza";i:0;s:5:"tagza";i:0;s:7:"tarpipe";i:0;s:11:"thewebblend";i:0;s:11:"thinkfinity";i:0;s:8:"thisnext";i:0;s:9:"throwpile";i:0;s:4:"tipd";i:0;s:4:"toly";i:0;s:13:"topsitelernet";i:0;s:9:"transferr";i:0;s:6:"tuenti";i:0;s:6:"tulinq";i:0;s:5:"tusul";i:0;s:5:"tvinx";i:0;s:9:"tweetmeme";i:0;s:7:"twitter";i:0;s:8:"twitthis";i:0;s:7:"typepad";i:0;s:6:"upnews";i:0;s:13:"urlaubswerkde";i:0;s:7:"urlcapt";i:0;s:6:"viadeo";i:0;s:14:"visitezmonsite";i:0;s:2:"vk";i:0;s:12:"vkrugudruzei";i:0;s:9:"voxopolis";i:0;s:10:"vybralisme";i:0;s:5:"vyoom";i:0;s:7:"webnews";i:0;s:8:"webshare";i:0;s:16:"domaintoolswhois";i:0;s:7:"windows";i:0;s:12:"windycitizen";i:0;s:7:"wirefan";i:0;s:9:"wordpress";i:0;s:5:"worio";i:0;s:14:"raiseyourvoice";i:0;s:5:"wykop";i:0;s:5:"xanga";i:0;s:4:"xing";i:0;s:8:"yahoobkm";i:0;s:9:"yahoomail";i:0;s:6:"yammer";i:0;s:10:"yardbarker";i:0;s:5:"yemle";i:0;s:4:"yigg";i:0;s:7:"yoolink";i:0;s:10:"yorumcuyum";i:0;s:6:"youblr";i:0;s:12:"youbookmarks";i:0;s:6:"youmob";i:0;s:5:"yuuby";i:0;s:11:"zakladoknet";i:0;s:6:"ziczac";i:0;s:6:"zingme";i:0;}'),
('addthis_facebook_like_count_support_enabled', 'b:1;'),
('addthis_image', 's:39:"http://s9.addthis.com/button1-share.gif";'),
('addthis_image_attributes', 's:6:"alt=""";'),
('addthis_image_height', 's:2:"16";'),
('addthis_image_secure', 's:44:"https://secure.addthis.com/button1-share.gif";'),
('addthis_image_width', 's:3:"125";'),
('addthis_logo', 's:42:"http://www.addthis.com/images/yourlogo.png";'),
('addthis_logo_background', 's:6:"EFEFFF";'),
('addthis_logo_color', 's:6:"666699";'),
('addthis_offset_left', 's:1:"2";'),
('addthis_offset_top', 's:1:"2";'),
('addthis_open_windows_enabled', 'i:0;'),
('addthis_options', 's:72:"favorites, email, digg, delicious, myspace, facebook, google, live, more";'),
('addthis_profile_id', 's:0:"";'),
('addthis_services_css_url', 's:57:"http://cache.addthiscdn.com/icons/v1/sprites/services.css";'),
('addthis_services_json_url', 's:55:"http://cache.addthiscdn.com/services/v1/sharing.en.json";'),
('addthis_standard_css_enabled', 'i:1;'),
('addthis_twitter_template', 's:30:"{{title}} {{url}} via @AddThis";'),
('addthis_twitter_via', 's:7:"AddThis";'),
('addthis_ui_delay', 's:1:"0";'),
('addthis_ui_header_background_color', 's:0:"";'),
('addthis_ui_header_color', 's:0:"";'),
('addthis_username', 's:11:"my-username";'),
('addthis_widget_js_url', 's:46:"http://s7.addthis.com/js/250/addthis_widget.js";'),
('addthis_widget_version', 's:3:"152";'),
('addtoany_additional_js', 's:0:"";'),
('addtoany_custom_image', 's:0:"";'),
('addtoany_display_in_nodecont', 'i:1;'),
('addtoany_display_in_nodelink', 'i:1;'),
('addtoany_display_in_teasers', 'i:1;'),
('addtoany_display_weight', 's:2:"40";'),
('addtoany_dropdown_disabled', 'i:1;'),
('addtoany_image', 's:21:"share_16_16.png|16|16";'),
('addtoany_image_attributes', 's:16:"alt="Share/Save"";'),
('addtoany_link_text', 's:5:"Share";'),
('addtoany_nodetypes', 'a:12:{s:7:"article";s:7:"article";s:4:"page";s:4:"page";s:4:"blog";s:4:"blog";s:4:"book";i:0;s:8:"employee";i:0;s:3:"faq";i:0;s:5:"forum";i:0;s:8:"carousel";i:0;s:5:"panel";i:0;s:4:"poll";i:0;s:9:"portfolio";i:0;s:6:"slider";i:0;}'),
('admin_theme', 's:5:"seven";'),
('anonymous', 's:9:"Anonymous";'),
('back_to_top_bg_color', 's:7:"#F7F7F7";'),
('back_to_top_border_color', 's:7:"#CCCCCC";'),
('back_to_top_button_place', 's:1:"1";'),
('back_to_top_button_trigger', 's:3:"100";'),
('back_to_top_button_type', 's:5:"image";'),
('back_to_top_hover_color', 's:7:"#EEEEEE";'),
('back_to_top_prevent_in_admin', 'i:1;'),
('back_to_top_prevent_on_mobile', 'i:1;'),
('back_to_top_text_color', 's:7:"#333333";'),
('book_allowed_types', 'a:1:{i:0;s:4:"book";}'),
('book_child_type', 's:4:"book";'),
('clean_url', 's:1:"0";'),
('colorbox_caption_trim', 's:1:"0";'),
('colorbox_caption_trim_length', 's:2:"75";'),
('colorbox_compression_type', 's:8:"minified";'),
('colorbox_custom_settings_activate', 's:1:"0";'),
('colorbox_fixed', 'i:1;'),
('colorbox_imagefield_gallery', 's:1:"1";'),
('colorbox_initialheight', 's:3:"100";'),
('colorbox_initialwidth', 's:3:"300";'),
('colorbox_inline', 'i:0;'),
('colorbox_load', 'i:0;'),
('colorbox_maxheight', 's:4:"100%";'),
('colorbox_maxwidth', 's:4:"100%";'),
('colorbox_opacity', 's:4:"0.90";'),
('colorbox_overlayclose', 'i:1;'),
('colorbox_pages', 's:51:"admin*\r\nimg_assist*\r\nimce*\r\nnode/add/*\r\nnode/*/edit";'),
('colorbox_path', 's:28:"sites/all/libraries/colorbox";'),
('colorbox_scrolling', 's:1:"1";'),
('colorbox_slideshow', 's:1:"0";'),
('colorbox_slideshowauto', 'i:1;'),
('colorbox_slideshowspeed', 's:4:"2500";'),
('colorbox_style', 's:37:"sites/all/libraries/colorbox/example1";'),
('colorbox_text_close', 's:5:"Close";'),
('colorbox_text_current', 's:20:"{current} of {total}";'),
('colorbox_text_next', 's:7:"Next »";'),
('colorbox_text_previous', 's:7:"« Prev";'),
('colorbox_text_start', 's:15:"start slideshow";'),
('colorbox_text_stop', 's:14:"stop slideshow";'),
('colorbox_transition_speed', 's:3:"350";'),
('colorbox_transition_type', 's:7:"elastic";'),
('colorbox_visibility', 's:1:"0";'),
('comment_anonymous_employee', 'i:0;'),
('comment_anonymous_faq', 'i:0;'),
('comment_anonymous_maps', 's:1:"0";'),
('comment_anonymous_partners', 'i:0;'),
('comment_anonymous_popular_services', 's:1:"0";'),
('comment_anonymous_portfolio', 'i:0;'),
('comment_anonymous_services', 's:1:"0";'),
('comment_anonymous_slider', 'i:0;'),
('comment_anonymous_testimonials', 's:1:"0";'),
('comment_default_mode_employee', 'i:1;'),
('comment_default_mode_faq', 'i:1;'),
('comment_default_mode_maps', 'i:0;'),
('comment_default_mode_partners', 'i:1;'),
('comment_default_mode_popular_services', 'i:1;'),
('comment_default_mode_portfolio', 'i:1;'),
('comment_default_mode_services', 'i:1;'),
('comment_default_mode_slider', 'i:1;'),
('comment_default_mode_testimonials', 'i:1;'),
('comment_default_per_page_employee', 's:2:"50";'),
('comment_default_per_page_faq', 's:2:"50";'),
('comment_default_per_page_maps', 's:2:"50";'),
('comment_default_per_page_partners', 's:2:"50";'),
('comment_default_per_page_popular_services', 's:2:"50";'),
('comment_default_per_page_portfolio', 's:2:"50";'),
('comment_default_per_page_services', 's:2:"50";'),
('comment_default_per_page_slider', 's:2:"50";'),
('comment_default_per_page_testimonials', 's:2:"50";'),
('comment_employee', 's:1:"1";'),
('comment_faq', 's:1:"1";'),
('comment_form_location_employee', 'i:1;'),
('comment_form_location_faq', 'i:1;'),
('comment_form_location_maps', 'i:0;'),
('comment_form_location_partners', 'i:1;'),
('comment_form_location_popular_services', 'i:1;'),
('comment_form_location_portfolio', 'i:1;'),
('comment_form_location_services', 'i:1;'),
('comment_form_location_slider', 'i:1;'),
('comment_form_location_testimonials', 'i:1;'),
('comment_maps', 's:1:"1";'),
('comment_page', 'i:0;'),
('comment_partners', 's:1:"1";'),
('comment_popular_services', 's:1:"1";'),
('comment_portfolio', 's:1:"1";'),
('comment_preview_employee', 's:1:"1";'),
('comment_preview_faq', 's:1:"1";'),
('comment_preview_maps', 's:1:"1";'),
('comment_preview_partners', 's:1:"1";'),
('comment_preview_popular_services', 's:1:"1";'),
('comment_preview_portfolio', 's:1:"1";'),
('comment_preview_services', 's:1:"1";'),
('comment_preview_slider', 's:1:"1";'),
('comment_preview_testimonials', 's:1:"1";'),
('comment_services', 's:1:"2";'),
('comment_slider', 's:1:"1";'),
('comment_subject_field_employee', 'i:1;'),
('comment_subject_field_faq', 'i:1;'),
('comment_subject_field_maps', 'i:0;'),
('comment_subject_field_partners', 'i:1;'),
('comment_subject_field_popular_services', 'i:1;'),
('comment_subject_field_portfolio', 'i:1;'),
('comment_subject_field_services', 'i:1;'),
('comment_subject_field_slider', 'i:1;'),
('comment_subject_field_testimonials', 'i:1;'),
('comment_testimonials', 's:1:"1";'),
('contact_default_status', 'i:1;'),
('cron_key', 's:43:"rBWjTobUvSoO7mLBsANb_M7W5Ybss1hEaaSI37R08yc";'),
('cron_last', 'i:1379063734;'),
('css_js_query_string', 's:6:"mt2840";'),
('ctools_last_cron', 'i:1379063503;'),
('dashboard_stashed_blocks', 'a:9:{i:0;a:3:{s:6:"module";s:4:"node";s:5:"delta";s:6:"recent";s:6:"region";s:14:"dashboard_main";}i:1;a:3:{s:6:"module";s:4:"user";s:5:"delta";s:3:"new";s:6:"region";s:17:"dashboard_sidebar";}i:2;a:3:{s:6:"module";s:6:"search";s:5:"delta";s:4:"form";s:6:"region";s:17:"dashboard_sidebar";}i:3;a:3:{s:6:"module";s:7:"comment";s:5:"delta";s:6:"recent";s:6:"region";s:18:"dashboard_inactive";}i:4;a:3:{s:6:"module";s:4:"user";s:5:"delta";s:6:"online";s:6:"region";s:18:"dashboard_inactive";}i:5;a:3:{s:6:"module";s:4:"blog";s:5:"delta";s:6:"recent";s:6:"region";s:18:"dashboard_inactive";}i:6;a:3:{s:6:"module";s:4:"poll";s:5:"delta";s:6:"recent";s:6:"region";s:18:"dashboard_inactive";}i:7;a:3:{s:6:"module";s:5:"forum";s:5:"delta";s:6:"active";s:6:"region";s:18:"dashboard_inactive";}i:8;a:3:{s:6:"module";s:5:"forum";s:5:"delta";s:3:"new";s:6:"region";s:18:"dashboard_inactive";}}'),
('date_default_timezone', 's:15:"Europe/Helsinki";'),
('default_nodes_main', 's:1:"3";'),
('default_panels_layout', 'a:2:{s:7:"subpage";b:1;s:16:"subpage_backward";b:1;}'),
('demo_reset_last', 'i:1357203105;'),
('drupal_http_request_fails', 'b:0;'),
('drupal_private_key', 's:43:"yFYcqmtW6T16uoZleaO4XJDnj1VHC8-_0gksq5d6xmc";'),
('email__active_tab', 's:20:"edit-email-activated";'),
('faq_answer_category_name', 'i:0;'),
('faq_answer_label', 's:2:"A:";'),
('faq_back_to_top', 's:11:"Back to Top";'),
('faq_category_display', 's:4:"none";'),
('faq_category_hide_qa_accordion', 'i:0;'),
('faq_category_listing', 's:2:"ul";'),
('faq_count', 'i:0;'),
('faq_custom_breadcrumbs', 'i:1;'),
('faq_default_sorting', 's:4:"DESC";'),
('faq_description', 's:0:"";'),
('faq_disable_node_links', 'i:1;'),
('faq_display', 's:16:"questions_inline";'),
('faq_group_questions_top', 'i:0;'),
('faq_hide_child_terms', 'i:0;'),
('faq_hide_qa_accordion', 'i:0;'),
('faq_omit_vocabulary', 'a:2:{i:2;i:0;i:1;i:0;}'),
('faq_qa_mark', 'i:1;'),
('faq_question_label', 's:2:"Q:";'),
('faq_question_length', 's:5:"short";'),
('faq_question_listing', 's:2:"ul";'),
('faq_question_long_form', 'i:1;'),
('faq_show_expand_all', 'i:0;'),
('faq_show_node_links', 'i:0;'),
('faq_show_term_page_children', 'i:0;'),
('faq_title', 's:26:"Frequently Asked Questions";'),
('faq_use_categories', 'i:0;'),
('faq_use_teaser', 'i:0;'),
('field_bundle_settings_node__article', 'a:2:{s:10:"view_modes";a:6:{s:6:"teaser";a:1:{s:15:"custom_settings";b:1;}s:4:"full";a:1:{s:15:"custom_settings";b:0;}s:3:"rss";a:1:{s:15:"custom_settings";b:0;}s:12:"search_index";a:1:{s:15:"custom_settings";b:0;}s:13:"search_result";a:1:{s:15:"custom_settings";b:0;}s:5:"print";a:1:{s:15:"custom_settings";b:0;}}s:12:"extra_fields";a:2:{s:4:"form";a:1:{s:5:"title";a:1:{s:6:"weight";s:2:"-5";}}s:7:"display";a:0:{}}}'),
('field_bundle_settings_node__blog', 'a:2:{s:10:"view_modes";a:6:{s:6:"teaser";a:1:{s:15:"custom_settings";b:1;}s:4:"full";a:1:{s:15:"custom_settings";b:1;}s:3:"rss";a:1:{s:15:"custom_settings";b:0;}s:12:"search_index";a:1:{s:15:"custom_settings";b:0;}s:13:"search_result";a:1:{s:15:"custom_settings";b:0;}s:5:"print";a:1:{s:15:"custom_settings";b:0;}}s:12:"extra_fields";a:2:{s:4:"form";a:1:{s:5:"title";a:1:{s:6:"weight";s:1:"0";}}s:7:"display";a:0:{}}}'),
('field_bundle_settings_node__employee', 'a:2:{s:10:"view_modes";a:6:{s:6:"teaser";a:1:{s:15:"custom_settings";b:1;}s:4:"full";a:1:{s:15:"custom_settings";b:0;}s:3:"rss";a:1:{s:15:"custom_settings";b:0;}s:12:"search_index";a:1:{s:15:"custom_settings";b:0;}s:13:"search_result";a:1:{s:15:"custom_settings";b:0;}s:5:"print";a:1:{s:15:"custom_settings";b:0;}}s:12:"extra_fields";a:2:{s:4:"form";a:1:{s:5:"title";a:1:{s:6:"weight";s:2:"-5";}}s:7:"display";a:0:{}}}'),
('field_bundle_settings_node__forum', 'a:2:{s:10:"view_modes";a:6:{s:6:"teaser";a:1:{s:15:"custom_settings";b:1;}s:4:"full";a:1:{s:15:"custom_settings";b:0;}s:3:"rss";a:1:{s:15:"custom_settings";b:0;}s:12:"search_index";a:1:{s:15:"custom_settings";b:0;}s:13:"search_result";a:1:{s:15:"custom_settings";b:0;}s:5:"print";a:1:{s:15:"custom_settings";b:0;}}s:12:"extra_fields";a:2:{s:4:"form";a:0:{}s:7:"display";a:0:{}}}'),
('field_bundle_settings_node__maps', 'a:2:{s:10:"view_modes";a:6:{s:6:"teaser";a:1:{s:15:"custom_settings";b:1;}s:4:"full";a:1:{s:15:"custom_settings";b:0;}s:3:"rss";a:1:{s:15:"custom_settings";b:0;}s:12:"search_index";a:1:{s:15:"custom_settings";b:0;}s:13:"search_result";a:1:{s:15:"custom_settings";b:0;}s:5:"print";a:1:{s:15:"custom_settings";b:0;}}s:12:"extra_fields";a:2:{s:4:"form";a:1:{s:5:"title";a:1:{s:6:"weight";s:1:"0";}}s:7:"display";a:0:{}}}'),
('field_bundle_settings_node__partners', 'a:2:{s:10:"view_modes";a:6:{s:6:"teaser";a:1:{s:15:"custom_settings";b:1;}s:4:"full";a:1:{s:15:"custom_settings";b:0;}s:3:"rss";a:1:{s:15:"custom_settings";b:0;}s:12:"search_index";a:1:{s:15:"custom_settings";b:0;}s:13:"search_result";a:1:{s:15:"custom_settings";b:0;}s:5:"print";a:1:{s:15:"custom_settings";b:0;}}s:12:"extra_fields";a:2:{s:4:"form";a:1:{s:5:"title";a:1:{s:6:"weight";s:2:"-5";}}s:7:"display";a:0:{}}}'),
('field_bundle_settings_node__popular_services', 'a:2:{s:10:"view_modes";a:6:{s:6:"teaser";a:1:{s:15:"custom_settings";b:1;}s:4:"full";a:1:{s:15:"custom_settings";b:0;}s:3:"rss";a:1:{s:15:"custom_settings";b:0;}s:12:"search_index";a:1:{s:15:"custom_settings";b:0;}s:13:"search_result";a:1:{s:15:"custom_settings";b:0;}s:5:"print";a:1:{s:15:"custom_settings";b:0;}}s:12:"extra_fields";a:2:{s:4:"form";a:1:{s:5:"title";a:1:{s:6:"weight";s:2:"-5";}}s:7:"display";a:0:{}}}'),
('field_bundle_settings_node__portfolio', 'a:2:{s:10:"view_modes";a:6:{s:6:"teaser";a:1:{s:15:"custom_settings";b:1;}s:4:"full";a:1:{s:15:"custom_settings";b:0;}s:3:"rss";a:1:{s:15:"custom_settings";b:0;}s:12:"search_index";a:1:{s:15:"custom_settings";b:0;}s:13:"search_result";a:1:{s:15:"custom_settings";b:0;}s:5:"print";a:1:{s:15:"custom_settings";b:0;}}s:12:"extra_fields";a:2:{s:4:"form";a:1:{s:5:"title";a:1:{s:6:"weight";s:1:"0";}}s:7:"display";a:0:{}}}'),
('field_bundle_settings_node__services', 'a:2:{s:10:"view_modes";a:6:{s:6:"teaser";a:1:{s:15:"custom_settings";b:1;}s:4:"full";a:1:{s:15:"custom_settings";b:0;}s:3:"rss";a:1:{s:15:"custom_settings";b:0;}s:12:"search_index";a:1:{s:15:"custom_settings";b:0;}s:13:"search_result";a:1:{s:15:"custom_settings";b:0;}s:5:"print";a:1:{s:15:"custom_settings";b:0;}}s:12:"extra_fields";a:2:{s:4:"form";a:1:{s:5:"title";a:1:{s:6:"weight";s:2:"-5";}}s:7:"display";a:0:{}}}'),
('field_bundle_settings_node__slider', 'a:2:{s:10:"view_modes";a:6:{s:6:"teaser";a:1:{s:15:"custom_settings";b:1;}s:4:"full";a:1:{s:15:"custom_settings";b:0;}s:3:"rss";a:1:{s:15:"custom_settings";b:0;}s:12:"search_index";a:1:{s:15:"custom_settings";b:0;}s:13:"search_result";a:1:{s:15:"custom_settings";b:0;}s:5:"print";a:1:{s:15:"custom_settings";b:0;}}s:12:"extra_fields";a:2:{s:4:"form";a:1:{s:5:"title";a:1:{s:6:"weight";s:2:"-5";}}s:7:"display";a:0:{}}}'),
('field_bundle_settings_node__testimonials', 'a:2:{s:10:"view_modes";a:6:{s:6:"teaser";a:1:{s:15:"custom_settings";b:1;}s:4:"full";a:1:{s:15:"custom_settings";b:0;}s:3:"rss";a:1:{s:15:"custom_settings";b:0;}s:12:"search_index";a:1:{s:15:"custom_settings";b:0;}s:13:"search_result";a:1:{s:15:"custom_settings";b:0;}s:5:"print";a:1:{s:15:"custom_settings";b:0;}}s:12:"extra_fields";a:2:{s:4:"form";a:1:{s:5:"title";a:1:{s:6:"weight";s:1:"0";}}s:7:"display";a:0:{}}}'),
('file_default_scheme', 's:6:"public";'),
('file_private_path', 's:27:"sites/default/private/files";'),
('file_public_path', 's:19:"sites/default/files";'),
('file_temporary_path', 's:4:"/tmp";'),
('filter_fallback_format', 's:10:"plain_text";'),
('follow_site_alignment', 's:8:"vertical";'),
('follow_site_block_title', 's:1:"0";'),
('follow_site_block_user', 'i:1;'),
('follow_site_icon_style', 's:5:"small";'),
('forum_block_num_active', 's:1:"5";'),
('forum_containers', 'a:3:{i:0;s:1:"2";i:1;s:1:"3";i:2;s:1:"4";}'),
('forum_nav_vocabulary', 's:1:"2";'),
('getlocations_api3_key', 's:39:"AIzaSyAahvkN1EoX_n4-X0S9C2Z2Q564I1vB-5c";'),
('getlocations_colorbox', 'a:6:{s:6:"enable";i:0;s:5:"width";s:3:"600";s:6:"height";s:3:"600";s:13:"marker_enable";i:0;s:12:"marker_width";s:3:"600";s:13:"marker_height";s:3:"600";}'),
('getlocations_default', 'a:59:{s:5:"width";s:5:"400px";s:6:"height";s:5:"300px";s:6:"styles";s:0:"";s:7:"latlong";s:4:"40,0";s:4:"zoom";s:1:"3";s:11:"controltype";s:5:"small";s:10:"pancontrol";i:1;s:3:"mtc";s:8:"standard";s:7:"maptype";s:3:"Map";s:10:"baselayers";a:4:{s:3:"Map";i:1;s:9:"Satellite";i:1;s:6:"Hybrid";i:1;s:8:"Physical";i:1;}s:8:"behavior";a:4:{s:5:"scale";i:0;s:8:"overview";i:0;s:15:"overview_opened";i:0;s:11:"scrollwheel";i:0;}s:9:"draggable";i:1;s:15:"streetview_show";i:0;s:11:"trafficinfo";i:0;s:17:"trafficinfo_state";i:0;s:11:"bicycleinfo";i:0;s:17:"bicycleinfo_state";i:0;s:11:"transitinfo";i:0;s:17:"transitinfo_state";i:0;s:13:"panoramio_use";i:0;s:14:"panoramio_show";i:0;s:15:"panoramio_state";i:0;s:11:"weather_use";i:0;s:12:"weather_show";i:0;s:13:"weather_state";i:0;s:12:"weather_temp";s:1:"1";s:13:"weather_speed";s:1:"1";s:13:"weather_label";s:1:"0";s:13:"weather_cloud";i:1;s:19:"weather_cloud_state";i:0;s:17:"weather_clickable";i:1;s:12:"weather_info";i:1;s:8:"poi_show";i:1;s:12:"transit_show";i:1;s:15:"node_map_marker";s:12:"a_to_z red A";s:15:"user_map_marker";s:6:"drupal";s:21:"vocabulary_map_marker";s:6:"drupal";s:15:"term_map_marker";s:6:"drupal";s:18:"comment_map_marker";s:6:"drupal";s:16:"input_map_marker";s:6:"drupal";s:16:"markeractiontype";s:1:"1";s:12:"markeraction";s:1:"2";s:12:"preload_data";i:0;s:7:"minzoom";s:1:"6";s:7:"maxzoom";s:2:"16";s:8:"nodezoom";s:2:"12";s:17:"markermanagertype";s:1:"0";s:16:"usemarkermanager";i:0;s:17:"useclustermanager";i:0;s:21:"markerclusterer_style";s:2:"-1";s:21:"markerclusterer_title";s:22:"Click here to see more";s:20:"markerclusterer_zoom";s:2:"-1";s:20:"markerclusterer_size";s:2:"-1";s:23:"markerclusterer_minsize";s:2:"-1";s:10:"pansetting";s:1:"2";s:22:"returnlink_page_enable";i:0;s:20:"returnlink_page_link";s:14:"Return to Page";s:20:"returnlink_term_link";s:14:"Return to Term";s:22:"getlocations_js_weight";s:1:"0";}'),
('getlocations_node_marker', 'a:1:{s:6:"enable";i:0;}'),
('getlocations_paths', 'a:6:{s:15:"infobubble_path";s:47:"sites/all/modules/getlocations/js/infobubble.js";s:23:"infowindow_options_path";s:55:"sites/all/modules/getlocations/js/infowindow_options.js";s:23:"infobubble_options_path";s:55:"sites/all/modules/getlocations/js/infobubble_options.js";s:18:"markermanager_path";s:50:"sites/all/modules/getlocations/js/markermanager.js";s:20:"markerclusterer_path";s:52:"sites/all/modules/getlocations/js/markerclusterer.js";s:17:"getlocations_path";s:49:"sites/all/modules/getlocations/js/getlocations.js";}'),
('getlocations_term_marker', 'a:3:{s:6:"enable";i:0;s:4:"vids";i:0;s:9:"max_depth";s:0:"";}'),
('getlocations_ua', 'a:1:{s:9:"ua_string";s:179:"iphone|ipad|android|blackberry|blazer|bolt|symbian|mobile safari|fennec|gobrowser|iemobile|maemo browser|profile midp|minimo|kindle|opera mini|opera mobi|skyfire|teashark|uzardweb";}'),
('gmap_default', 'a:13:{s:5:"width";s:5:"300px";s:6:"height";s:5:"200px";s:7:"latlong";s:4:"40,0";s:4:"zoom";s:1:"3";s:7:"maxzoom";s:2:"14";s:6:"styles";a:3:{s:12:"line_default";a:5:{i:0;s:6:"0000ff";i:1;s:1:"5";i:2;s:2:"45";i:3;s:0:"";i:4;s:0:"";}s:12:"poly_default";a:5:{i:0;s:6:"000000";i:1;s:1:"3";i:2;s:2:"25";i:3;s:6:"ff0000";i:4;s:2:"45";}s:15:"highlight_color";s:6:"ff0000";}s:11:"controltype";s:5:"Small";s:3:"mtc";s:8:"standard";s:7:"maptype";s:3:"Map";s:10:"baselayers";a:4:{s:3:"Map";i:1;s:9:"Satellite";i:1;s:6:"Hybrid";i:1;s:8:"Physical";i:0;}s:8:"behavior";a:14:{s:7:"locpick";b:0;s:6:"nodrag";i:0;s:10:"nokeyboard";i:1;s:11:"nomousezoom";i:0;s:10:"nocontzoom";i:0;s:8:"autozoom";i:0;s:10:"dynmarkers";i:0;s:8:"overview";i:0;s:12:"collapsehack";i:0;s:5:"scale";i:0;s:17:"extramarkerevents";b:0;s:15:"clickableshapes";b:0;s:9:"googlebar";i:0;s:9:"highlight";i:0;}s:10:"markermode";s:1:"0";s:11:"line_colors";a:3:{i:0;s:7:"#00cc00";i:1;s:7:"#ff0000";i:2;s:7:"#0000ff";}}'),
('gmap_markermanager', 'a:5:{s:14:"gmarkermanager";a:5:{s:13:"borderPadding";s:3:"256";s:7:"maxZoom";s:1:"4";s:12:"trackMarkers";i:0;s:13:"markerMinZoom";s:1:"4";s:13:"markerMaxZoom";s:1:"0";}s:13:"markermanager";a:6:{s:8:"filename";s:23:"markermanager_packed.js";s:13:"borderPadding";s:3:"256";s:7:"maxZoom";s:1:"4";s:12:"trackMarkers";i:0;s:13:"markerMinZoom";s:1:"4";s:13:"markerMaxZoom";s:1:"0";}s:15:"markerclusterer";a:3:{s:8:"filename";s:25:"markerclusterer_packed.js";s:8:"gridSize";s:2:"60";s:7:"maxZoom";s:2:"17";}s:9:"clusterer";a:6:{s:8:"filename";s:13:"Clusterer2.js";s:6:"marker";s:7:"cluster";s:13:"max_nocluster";s:3:"150";s:11:"cluster_min";s:1:"5";s:9:"max_lines";s:2:"10";s:10:"popup_mode";s:4:"orig";}s:13:"clustermarker";a:7:{s:8:"filename";s:16:"ClusterMarker.js";s:13:"borderPadding";s:3:"256";s:17:"clusteringEnabled";i:1;s:17:"clusterMarkerIcon";s:0:"";s:18:"clusterMarkerTitle";s:0:"";s:13:"fitMapMaxZoom";s:1:"0";s:16:"intersectPadding";s:1:"0";}}'),
('gmap_marker_file', 's:1:"1";'),
('gmap_mm_type', 's:4:"gmap";'),
('gmap_taxonomy_vocabs', 'a:0:{}'),
('googlemap_api_key', 's:86:"ABQIAAAAgzqMW6aHhoMvTDxKU7xc_hRjspgdgKc5z8Nn3NuMde6yToj8ExTpAbtd9y8ko2dn9S0Xnyyini2chg";'),
('image_toolkit', 's:2:"gd";'),
('install_profile', 's:12:"demo_profile";'),
('install_task', 's:4:"done";'),
('install_time', 'i:1305115346;'),
('javascript_parsed', 'a:47:{i:0;s:14:"misc/drupal.js";i:1;s:64:"sites/all/modules/jquery_update/replace/jquery/1.7/jquery.min.js";i:2;s:19:"misc/jquery.once.js";i:3;s:45:"sites/all/themes/theme822/js/theme822.core.js";i:4;s:45:"sites/all/themes/theme822/js/jquery.loader.js";i:5;s:54:"sites/all/themes/theme822/js/jquery.debouncedresize.js";i:6;s:49:"sites/all/themes/theme822/js/jquery.mobilemenu.js";i:7;s:81:"sites/all/modules/jquery_update/replace/ui/ui/minified/jquery.effects.core.min.js";i:8;s:47:"sites/all/modules/back_to_top/js/back_to_top.js";i:9;s:51:"sites/all/libraries/colorbox/jquery.colorbox-min.js";i:10;s:41:"sites/all/modules/colorbox/js/colorbox.js";i:11;s:58:"sites/all/modules/getlocations/js/getlocations_colorbox.js";i:12;s:37:"sites/all/modules/panels/js/panels.js";i:13;s:39:"sites/all/modules/dismiss/js/dismiss.js";i:14;s:55:"sites/all/modules/views_slideshow/js/views_slideshow.js";i:15;s:43:"sites/all/libraries/easing/jquery.easing.js";i:16;s:55:"sites/all/libraries/flexslider/jquery.flexslider-min.js";i:17;s:57:"sites/all/modules/flexslider/assets/js/flexslider.load.js";i:18;s:36:"sites/all/modules/addthis/addthis.js";i:19;s:32:"modules/contextual/contextual.js";i:20;s:42:"sites/all/modules/admin_menu/admin_menu.js";i:21;s:69:"sites/all/modules/admin_menu/admin_menu_toolbar/admin_menu_toolbar.js";i:22;s:19:"misc/tableheader.js";i:23;s:22:"modules/block/block.js";i:24;s:68:"sites/all/modules/jquery_update/replace/ui/external/jquery.cookie.js";i:25;s:17:"misc/tabledrag.js";i:26;s:60:"sites/all/libraries/superfish/jquery.hoverIntent.minified.js";i:27;s:46:"sites/all/libraries/superfish/sftouchscreen.js";i:28;s:42:"sites/all/libraries/superfish/supersubs.js";i:29;s:42:"sites/all/libraries/superfish/superfish.js";i:30;s:40:"sites/all/modules/superfish/superfish.js";i:31;s:56:"sites/all/libraries/jquery.isotope/jquery.isotope.min.js";i:32;s:48:"sites/all/modules/views_isotope/views_isotope.js";i:33;s:34:"sites/all/modules/views/js/base.js";i:34;s:16:"misc/progress.js";i:35;s:12:"misc/ajax.js";i:36;s:63:"sites/all/modules/jquery_update/replace/misc/jquery.form.min.js";i:37;s:39:"sites/all/modules/views/js/ajax_view.js";i:38;s:46:"sites/all/modules/views/js/views-contextual.js";i:39;s:42:"sites/all/modules/getlocations/js/icons.js";i:40;s:56:"sites/default/files/getlocations/getlocations_markers.js";i:41;s:47:"sites/all/modules/getlocations/js/infobubble.js";i:42;s:56:"sites/all/modules/getlocations/js/infobubble_extended.js";i:43;s:49:"sites/all/modules/getlocations/js/getlocations.js";i:44;s:16:"misc/textarea.js";i:45;s:36:"sites/all/modules/demo/demo.admin.js";i:46;s:20:"misc/autocomplete.js";}'),
('jquery_update_compression_type', 's:3:"min";'),
('jquery_update_jquery_admin_version', 's:0:"";'),
('jquery_update_jquery_cdn', 's:4:"none";'),
('jquery_update_jquery_version', 's:3:"1.7";'),
('language_content_type_carousel', 's:1:"0";'),
('language_content_type_employee', 's:1:"0";'),
('language_content_type_faq', 's:1:"0";'),
('language_content_type_maps', 's:1:"0";'),
('language_content_type_partners', 's:1:"0";'),
('language_content_type_popular_services', 's:1:"0";'),
('language_content_type_portfolio', 's:1:"0";'),
('language_content_type_services', 's:1:"0";'),
('language_content_type_slider', 's:1:"0";'),
('language_content_type_testimonials', 's:1:"0";'),
('language_count', 'i:1;'),
('language_negotiation_language', 'a:0:{}'),
('language_negotiation_language_content', 'a:1:{s:16:"locale-interface";a:2:{s:9:"callbacks";a:1:{s:8:"language";s:30:"locale_language_from_interface";}s:4:"file";s:19:"includes/locale.inc";}}'),
('language_negotiation_language_url', 'a:2:{s:10:"locale-url";a:2:{s:9:"callbacks";a:3:{s:8:"language";s:24:"locale_language_from_url";s:8:"switcher";s:28:"locale_language_switcher_url";s:11:"url_rewrite";s:31:"locale_language_url_rewrite_url";}s:4:"file";s:19:"includes/locale.inc";}s:19:"locale-url-fallback";a:2:{s:9:"callbacks";a:1:{s:8:"language";s:28:"locale_language_url_fallback";}s:4:"file";s:19:"includes/locale.inc";}}'),
('language_types', 'a:3:{s:8:"language";b:1;s:16:"language_content";b:0;s:12:"language_url";b:0;}'),
('maintenance_mode', 'b:0;'),
('menu_expanded', 'a:0:{}'),
('menu_masks', 'a:36:{i:0;i:501;i:1;i:493;i:2;i:250;i:3;i:247;i:4;i:246;i:5;i:245;i:6;i:126;i:7;i:125;i:8;i:124;i:9;i:123;i:10;i:122;i:11;i:121;i:12;i:117;i:13;i:63;i:14;i:62;i:15;i:61;i:16;i:60;i:17;i:59;i:18;i:58;i:19;i:44;i:20;i:31;i:21;i:30;i:22;i:29;i:23;i:24;i:24;i:21;i:25;i:15;i:26;i:14;i:27;i:13;i:28;i:12;i:29;i:11;i:30;i:7;i:31;i:6;i:32;i:5;i:33;i:3;i:34;i:2;i:35;i:1;}'),
('menu_options_carousel', 'a:0:{}'),
('menu_options_employee', 'a:0:{}'),
('menu_options_faq', 'a:1:{i:0;s:9:"main-menu";}'),
('menu_options_maps', 'a:1:{i:0;s:9:"main-menu";}'),
('menu_options_partners', 'a:0:{}'),
('menu_options_popular_services', 'a:1:{i:0;s:9:"main-menu";}'),
('menu_options_portfolio', 'a:0:{}'),
('menu_options_services', 'a:0:{}'),
('menu_options_slider', 'a:1:{i:0;s:9:"main-menu";}'),
('menu_options_testimonials', 'a:1:{i:0;s:9:"main-menu";}'),
('menu_parent_carousel', 's:11:"main-menu:0";'),
('menu_parent_employee', 's:11:"main-menu:0";'),
('menu_parent_faq', 's:11:"main-menu:0";'),
('menu_parent_maps', 's:11:"main-menu:0";'),
('menu_parent_partners', 's:11:"main-menu:0";'),
('menu_parent_popular_services', 's:11:"main-menu:0";'),
('menu_parent_portfolio', 's:11:"main-menu:0";'),
('menu_parent_services', 's:11:"main-menu:0";'),
('menu_parent_slider', 's:11:"main-menu:0";'),
('menu_parent_testimonials', 's:11:"main-menu:0";'),
('node_admin_theme', 'i:1;'),
('node_cron_last', 's:10:"1378992232";'),
('node_options_book', 'a:1:{i:0;s:6:"status";}'),
('node_options_carousel', 'a:1:{i:0;s:6:"status";}'),
('node_options_employee', 'a:1:{i:0;s:6:"status";}'),
('node_options_faq', 'a:1:{i:0;s:6:"status";}'),
('node_options_forum', 'a:1:{i:0;s:6:"status";}'),
('node_options_maps', 'a:1:{i:0;s:6:"status";}'),
('node_options_page', 'a:1:{i:0;s:6:"status";}'),
('node_options_partners', 'a:1:{i:0;s:6:"status";}'),
('node_options_popular_services', 'a:1:{i:0;s:6:"status";}'),
('node_options_portfolio', 'a:1:{i:0;s:6:"status";}'),
('node_options_services', 'a:1:{i:0;s:6:"status";}'),
('node_options_slider', 'a:1:{i:0;s:6:"status";}'),
('node_options_testimonials', 'a:1:{i:0;s:6:"status";}'),
('node_preview_employee', 's:1:"1";'),
('node_preview_faq', 's:1:"1";'),
('node_preview_maps', 's:1:"1";'),
('node_preview_partners', 's:1:"1";'),
('node_preview_popular_services', 's:1:"1";'),
('node_preview_portfolio', 's:1:"1";'),
('node_preview_services', 's:1:"1";'),
('node_preview_slider', 's:1:"1";'),
('node_preview_testimonials', 's:1:"1";'),
('node_submitted_carousel', 'i:0;'),
('node_submitted_employee', 'i:0;'),
('node_submitted_faq', 'i:0;'),
('node_submitted_maps', 'i:0;'),
('node_submitted_page', 'b:0;'),
('node_submitted_partners', 'i:0;'),
('node_submitted_popular_services', 'i:1;'),
('node_submitted_portfolio', 'i:0;'),
('node_submitted_services', 'i:1;'),
('node_submitted_slider', 'i:0;'),
('node_submitted_testimonials', 'i:1;'),
('node_type_faq', 'a:1:{i:0;s:6:"status";}'),
('path_alias_whitelist', 'a:0:{}'),
('quotes_author_bio', 's:1:"0";'),
('quotes_author_link', 's:1:"1";'),
('quotes_block_citation', 'b:0;'),
('quotes_edit_link', 's:1:"1";'),
('quotes_format', 's:9:"full_html";'),
('quotes_leader', 's:7:"&mdash;";'),
('quotes_per_page', 's:1:"3";'),
('quotes_quick_nav', 's:1:"1";'),
('quotes_quick_nav_original', 'b:1;'),
('quotes_showlink', 's:1:"1";'),
('quotes_show_myquotes', 's:1:"1";'),
('quotes_show_myquotes_original', 'b:1;'),
('quotes_user_recent', 'b:0;'),
('save_continue_carousel', 's:19:"Save and add fields";'),
('save_continue_employee', 's:19:"Save and add fields";'),
('save_continue_maps', 's:19:"Save and add fields";'),
('save_continue_partners', 's:19:"Save and add fields";'),
('save_continue_popular_services', 's:19:"Save and add fields";'),
('save_continue_portfolio', 's:19:"Save and add fields";'),
('save_continue_services', 's:19:"Save and add fields";'),
('save_continue_slider', 's:19:"Save and add fields";'),
('save_continue_testimonials', 's:19:"Save and add fields";'),
('scroll_to_top_bg_color_hover', 's:7:"#777777";'),
('scroll_to_top_bg_color_out', 's:7:"#CCCCCC";'),
('scroll_to_top_display_text', 'i:1;'),
('scroll_to_top_enable_admin_theme', 'i:0;'),
('scroll_to_top_position', 's:1:"1";'),
('site_403', 's:0:"";'),
('site_404', 's:8:"page-404";'),
('site_default_country', 's:0:"";'),
('site_frontpage', 's:4:"node";'),
('site_mail', 's:15:"admin@admin.com";'),
('site_name', 's:8:"Intermex";'),
('site_slogan', 's:0:"";'),
('social_share_block', 'i:0;'),
('social_share_label', 's:8:"Share to";'),
('social_share_max_desc_length', 's:2:"50";'),
('social_share_new_window', 'i:1;'),
('social_share_node_types', 'a:14:{s:4:"blog";s:4:"blog";s:7:"article";s:7:"article";s:8:"employee";s:8:"employee";s:4:"page";s:4:"page";s:8:"partners";s:8:"partners";s:9:"portfolio";s:9:"portfolio";s:6:"slider";s:6:"slider";s:3:"faq";i:0;s:4:"poll";i:0;s:5:"forum";i:0;s:5:"panel";i:0;s:4:"book";i:0;s:4:"maps";i:0;s:8:"services";i:0;}'),
('social_share_sites', 'a:10:{s:8:"facebook";s:8:"facebook";s:7:"twitter";s:7:"twitter";s:10:"googleplus";s:10:"googleplus";s:7:"myspace";s:7:"myspace";s:7:"msnlive";s:7:"msnlive";s:5:"yahoo";s:5:"yahoo";s:8:"linkedin";s:8:"linkedin";s:5:"orkut";s:5:"orkut";s:4:"digg";s:4:"digg";s:9:"delicious";s:9:"delicious";}'),
('social_share_teaser', 'i:0;'),
('social_share_twitter_truncate', 'i:0;'),
('social_share_weight', 's:1:"1";'),
('statistics_day_timestamp', 'i:1308671857;'),
('superfish_arrow_1', 'i:0;'),
('superfish_bgf_1', 'i:0;'),
('superfish_delay_1', 's:3:"800";'),
('superfish_depth_1', 's:2:"-1";'),
('superfish_dfirstlast_1', 'i:0;'),
('superfish_dzebra_1', 'i:0;'),
('superfish_expanded_1', 'i:0;'),
('superfish_firstlast_1', 'i:1;'),
('superfish_hhldescription_1', 'i:0;'),
('superfish_hid_1', 'i:1;'),
('superfish_hlclass_1', 's:0:"";'),
('superfish_hldescription_1', 'i:0;'),
('superfish_hldexclude_1', 's:0:"";'),
('superfish_hldmenus_1', 's:0:"";'),
('superfish_itemcounter_1', 'i:1;'),
('superfish_itemcount_1', 'i:1;'),
('superfish_itemdepth_1', 'i:1;'),
('superfish_liclass_1', 's:0:"";'),
('superfish_maxwidth_1', 's:2:"27";'),
('superfish_mcdepth_1', 's:1:"1";'),
('superfish_mcexclude_1', 's:0:"";'),
('superfish_mclevels_1', 's:1:"1";'),
('superfish_menu_1', 's:11:"main-menu:0";'),
('superfish_minwidth_1', 's:2:"12";'),
('superfish_multicolumn_1', 'i:0;'),
('superfish_name_1', 's:0:"";'),
('superfish_number', 's:1:"1";'),
('superfish_pathclass_1', 's:12:"active-trail";'),
('superfish_pathcss_1', 's:0:"";'),
('superfish_pathlevels_1', 's:1:"1";'),
('superfish_shadow_1', 'i:0;'),
('superfish_slide_1', 's:4:"none";'),
('superfish_slp', 's:344:"sites/all/libraries/superfish/jquery.hoverIntent.minified.js\r\nsites/all/libraries/superfish/jquery.bgiframe.min.js\r\nsites/all/libraries/superfish/superfish.js\r\nsites/all/libraries/superfish/supersubs.js\r\nsites/all/libraries/superfish/supposition.js\r\nsites/all/libraries/superfish/sftouchscreen.js\r\nsites/all/libraries/superfish/sfsmallscreen.js";'),
('superfish_smallasa_1', 'i:0;'),
('superfish_smallbp_1', 's:3:"768";'),
('superfish_smallchc_1', 'i:0;'),
('superfish_smallcmc_1', 'i:0;'),
('superfish_smallech_1', 's:0:"";'),
('superfish_smallecm_1', 's:0:"";'),
('superfish_smallich_1', 's:0:"";'),
('superfish_smallicm_1', 's:0:"";'),
('superfish_smallset_1', 's:0:"";'),
('superfish_smallual_1', 's:0:"";'),
('superfish_smalluam_1', 's:1:"0";'),
('superfish_smallua_1', 's:1:"0";'),
('superfish_small_1', 's:1:"0";'),
('superfish_speed_1', 's:4:"fast";'),
('superfish_spp_1', 'i:0;'),
('superfish_style_1', 's:4:"none";'),
('superfish_supersubs_1', 'i:1;'),
('superfish_touchbp_1', 's:3:"768";'),
('superfish_touchual_1', 's:19:"iPhone*Android*iPad";'),
('superfish_touchuam_1', 's:1:"0";'),
('superfish_touchua_1', 's:1:"1";'),
('superfish_touch_1', 's:1:"3";'),
('superfish_type_1', 's:10:"horizontal";'),
('superfish_ulclass_1', 's:0:"";'),
('superfish_use_item_theme_1', 'i:1;'),
('superfish_use_link_theme_1', 'i:1;'),
('superfish_wraphlt_1', 's:0:"";'),
('superfish_wraphl_1', 's:0:"";'),
('superfish_wrapmul_1', 's:0:"";'),
('superfish_wrapul_1', 's:0:"";'),
('superfish_zebra_1', 'i:1;'),
('tagadelic_block_tags_1', 's:2:"12";'),
('tagadelic_block_tags_2', 's:2:"12";'),
('tagadelic_block_tags_3', 's:2:"12";'),
('theme_alpha_alpha_css', 'a:3:{s:15:"alpha-reset.css";a:5:{s:4:"name";s:5:"Reset";s:11:"description";s:78:"Created by <a href="http://meyerweb.com/eric/tools/css/reset/">Eric Meyer</a>.";s:4:"file";s:15:"alpha-reset.css";s:4:"path";s:48:"sites/all/themes/omega/alpha/css/alpha-reset.css";s:7:"options";a:2:{s:6:"weight";s:3:"-20";s:5:"group";i:100;}}s:16:"alpha-mobile.css";a:5:{s:4:"name";s:6:"Mobile";s:11:"description";s:37:"Default stylesheet for mobile styles.";s:4:"file";s:16:"alpha-mobile.css";s:4:"path";s:49:"sites/all/themes/omega/alpha/css/alpha-mobile.css";s:7:"options";a:2:{s:6:"weight";s:3:"-20";s:5:"group";i:100;}}s:15:"alpha-alpha.css";a:5:{s:4:"name";s:5:"Alpha";s:11:"description";s:51:"Default styles & resets for Alpha/Omega base theme.";s:4:"file";s:15:"alpha-alpha.css";s:4:"path";s:48:"sites/all/themes/omega/alpha/css/alpha-alpha.css";s:7:"options";a:2:{s:6:"weight";s:3:"-20";s:5:"group";i:100;}}}'),
('theme_alpha_alpha_grids', 'a:2:{s:13:"alpha_default";a:4:{s:4:"name";s:15:"Default (960px)";s:4:"path";s:51:"sites/all/themes/omega/alpha/css/grid/alpha_default";s:7:"layouts";a:4:{s:5:"fluid";a:2:{s:4:"name";s:5:"Fluid";s:8:"attached";a:0:{}}s:6:"narrow";a:2:{s:4:"name";s:6:"Narrow";s:8:"attached";a:0:{}}s:6:"normal";a:2:{s:4:"name";s:6:"Normal";s:8:"attached";a:0:{}}s:4:"wide";a:2:{s:4:"name";s:4:"Wide";s:8:"attached";a:0:{}}}s:7:"columns";a:3:{i:12;s:10:"12 Columns";i:16;s:10:"16 Columns";i:24;s:10:"24 Columns";}}s:11:"alpha_fluid";a:4:{s:4:"name";s:5:"Fluid";s:4:"path";s:49:"sites/all/themes/omega/alpha/css/grid/alpha_fluid";s:7:"layouts";a:1:{s:6:"normal";a:2:{s:4:"name";s:6:"Normal";s:8:"attached";a:0:{}}}s:7:"columns";a:3:{i:12;s:10:"12 Columns";i:16;s:10:"16 Columns";i:24;s:10:"24 Columns";}}}'),
('theme_alpha_alpha_libraries', 'a:0:{}'),
('theme_alpha_alpha_registry', 'a:2:{s:10:"preprocess";a:4:{s:5:"block";a:1:{i:0;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:5:"block";s:5:"theme";s:5:"alpha";s:4:"path";s:87:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/alpha/preprocess/preprocess-block.inc";s:8:"function";s:28:"alpha_alpha_preprocess_block";}}s:4:"html";a:1:{i:0;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:4:"html";s:5:"theme";s:5:"alpha";s:4:"path";s:86:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/alpha/preprocess/preprocess-html.inc";s:8:"function";s:27:"alpha_alpha_preprocess_html";}}s:4:"page";a:1:{i:0;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:4:"page";s:5:"theme";s:5:"alpha";s:4:"path";s:86:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/alpha/preprocess/preprocess-page.inc";s:8:"function";s:27:"alpha_alpha_preprocess_page";}}s:6:"region";a:1:{i:0;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:6:"region";s:5:"theme";s:5:"alpha";s:4:"path";s:88:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/alpha/preprocess/preprocess-region.inc";s:8:"function";s:29:"alpha_alpha_preprocess_region";}}}s:7:"process";a:1:{s:4:"page";a:1:{i:0;a:5:{s:4:"type";s:7:"process";s:4:"hook";s:4:"page";s:5:"theme";s:5:"alpha";s:4:"path";s:80:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/alpha/process/process-page.inc";s:8:"function";s:24:"alpha_alpha_process_page";}}}}'),
('theme_basic_settings', 'a:22:{s:11:"toggle_logo";i:1;s:11:"toggle_name";i:1;s:13:"toggle_slogan";i:1;s:24:"toggle_node_user_picture";i:1;s:27:"toggle_comment_user_picture";i:1;s:14:"toggle_favicon";i:1;s:16:"toggle_main_menu";i:1;s:21:"toggle_secondary_menu";i:1;s:12:"default_logo";i:1;s:9:"logo_path";s:0:"";s:11:"logo_upload";s:0:"";s:15:"default_favicon";i:1;s:12:"favicon_path";s:0:"";s:14:"favicon_upload";s:0:"";s:10:"basic_tabs";i:1;s:16:"basic_breadcrumb";s:3:"yes";s:26:"basic_breadcrumb_separator";s:2:"»";s:21:"basic_breadcrumb_home";i:0;s:25:"basic_breadcrumb_trailing";i:0;s:22:"basic_breadcrumb_title";i:0;s:14:"wireframe_mode";i:1;s:14:"clear_registry";i:0;}'),
('theme_default', 's:8:"theme822";'),
('theme_fusion_core_settings', 'a:27:{s:11:"toggle_logo";i:1;s:11:"toggle_name";i:1;s:13:"toggle_slogan";i:1;s:24:"toggle_node_user_picture";i:1;s:27:"toggle_comment_user_picture";i:1;s:14:"toggle_favicon";i:1;s:12:"default_logo";i:1;s:9:"logo_path";s:0:"";s:11:"logo_upload";s:0:"";s:15:"default_favicon";i:1;s:12:"favicon_path";s:0:"";s:14:"favicon_upload";s:0:"";s:10:"theme_grid";s:10:"grid16-960";s:16:"fluid_grid_width";s:8:"fluid-85";s:14:"sidebar_layout";s:14:"sidebars-split";s:19:"sidebar_first_width";s:1:"3";s:20:"sidebar_second_width";s:1:"3";s:10:"theme_font";s:18:"font-family-myriad";s:15:"theme_font_size";s:12:"font-size-13";s:18:"breadcrumb_display";i:1;s:14:"search_snippet";i:1;s:16:"search_info_type";i:1;s:16:"search_info_user";i:1;s:16:"search_info_date";i:1;s:19:"search_info_comment";i:1;s:18:"search_info_upload";i:1;s:9:"grid_mask";i:1;}'),
('theme_marinelli_banner_settings', 'a:6:{i:1;a:7:{s:10:"image_path";s:21:"public://banner/1.jpg";s:11:"image_thumb";s:27:"public://banner/thumb/1.jpg";s:11:"image_title";s:13:"Title image 1";s:17:"image_description";s:23:"Description for image 1";s:9:"image_url";s:7:"<front>";s:15:"image_published";b:1;s:16:"image_visibility";s:1:"*";}i:2;a:7:{s:10:"image_path";s:21:"public://banner/2.jpg";s:11:"image_thumb";s:27:"public://banner/thumb/2.jpg";s:11:"image_title";s:13:"Title image 2";s:17:"image_description";s:23:"Description for image 2";s:9:"image_url";s:7:"<front>";s:15:"image_published";b:1;s:16:"image_visibility";s:1:"*";}i:3;a:7:{s:10:"image_path";s:21:"public://banner/3.jpg";s:11:"image_thumb";s:27:"public://banner/thumb/3.jpg";s:11:"image_title";s:13:"Title image 3";s:17:"image_description";s:23:"Description for image 3";s:9:"image_url";s:7:"<front>";s:15:"image_published";b:1;s:16:"image_visibility";s:1:"*";}i:4;a:7:{s:10:"image_path";s:21:"public://banner/4.jpg";s:11:"image_thumb";s:27:"public://banner/thumb/4.jpg";s:11:"image_title";s:13:"Title image 4";s:17:"image_description";s:23:"Description for image 4";s:9:"image_url";s:7:"<front>";s:15:"image_published";b:1;s:16:"image_visibility";s:1:"*";}i:5;a:7:{s:10:"image_path";s:21:"public://banner/5.jpg";s:11:"image_thumb";s:27:"public://banner/thumb/5.jpg";s:11:"image_title";s:13:"Title image 5";s:17:"image_description";s:23:"Description for image 5";s:9:"image_url";s:7:"<front>";s:15:"image_published";b:1;s:16:"image_visibility";s:1:"*";}i:6;a:7:{s:10:"image_path";s:21:"public://banner/6.jpg";s:11:"image_thumb";s:27:"public://banner/thumb/6.jpg";s:11:"image_title";s:13:"Title image 6";s:17:"image_description";s:23:"Description for image 6";s:9:"image_url";s:7:"<front>";s:15:"image_published";b:1;s:16:"image_visibility";s:1:"*";}}'),
('theme_marinelli_first_install', 'b:0;'),
('theme_omega_alpha_css', 'a:8:{s:15:"alpha-reset.css";a:5:{s:4:"name";s:5:"Reset";s:11:"description";s:78:"Created by <a href="http://meyerweb.com/eric/tools/css/reset/">Eric Meyer</a>.";s:4:"file";s:15:"alpha-reset.css";s:4:"path";s:48:"sites/all/themes/omega/alpha/css/alpha-reset.css";s:7:"options";a:2:{s:6:"weight";s:3:"-20";s:5:"group";i:100;}}s:16:"alpha-mobile.css";a:5:{s:4:"name";s:6:"Mobile";s:11:"description";s:37:"Default stylesheet for mobile styles.";s:4:"file";s:16:"alpha-mobile.css";s:4:"path";s:49:"sites/all/themes/omega/alpha/css/alpha-mobile.css";s:7:"options";a:2:{s:6:"weight";s:3:"-20";s:5:"group";i:100;}}s:15:"alpha-alpha.css";a:5:{s:4:"name";s:5:"Alpha";s:11:"description";s:51:"Default styles & resets for Alpha/Omega base theme.";s:4:"file";s:15:"alpha-alpha.css";s:4:"path";s:48:"sites/all/themes/omega/alpha/css/alpha-alpha.css";s:7:"options";a:2:{s:6:"weight";s:3:"-20";s:5:"group";i:100;}}s:14:"omega-text.css";a:5:{s:4:"name";s:11:"Text Styles";s:11:"description";s:30:"Default text styles for Omega.";s:4:"file";s:14:"omega-text.css";s:4:"path";s:47:"sites/all/themes/omega/omega/css/omega-text.css";s:7:"options";a:2:{s:6:"weight";s:3:"-10";s:5:"group";i:100;}}s:18:"omega-branding.css";a:5:{s:4:"name";s:15:"Branding Styles";s:11:"description";s:52:"Provides positioning for the logo, title and slogan.";s:4:"file";s:18:"omega-branding.css";s:4:"path";s:51:"sites/all/themes/omega/omega/css/omega-branding.css";s:7:"options";a:2:{s:6:"weight";s:3:"-10";s:5:"group";i:100;}}s:14:"omega-menu.css";a:5:{s:4:"name";s:11:"Menu Styles";s:11:"description";s:66:"Provides positoning and basic CSS for primary and secondary menus.";s:4:"file";s:14:"omega-menu.css";s:4:"path";s:47:"sites/all/themes/omega/omega/css/omega-menu.css";s:7:"options";a:2:{s:6:"weight";s:3:"-10";s:5:"group";i:100;}}s:15:"omega-forms.css";a:5:{s:4:"name";s:11:"Form Styles";s:11:"description";s:27:"Provides basic form styles.";s:4:"file";s:15:"omega-forms.css";s:4:"path";s:48:"sites/all/themes/omega/omega/css/omega-forms.css";s:7:"options";a:2:{s:6:"weight";s:3:"-10";s:5:"group";i:100;}}s:17:"omega-visuals.css";a:5:{s:4:"name";s:12:"Omega Styles";s:11:"description";s:53:"Custom visual styles for Omega. (pagers, menus, etc.)";s:4:"file";s:17:"omega-visuals.css";s:4:"path";s:50:"sites/all/themes/omega/omega/css/omega-visuals.css";s:7:"options";a:2:{s:6:"weight";s:3:"-10";s:5:"group";i:100;}}}'),
('theme_omega_alpha_grids', 'a:2:{s:13:"alpha_default";a:4:{s:4:"name";s:15:"Default (960px)";s:4:"path";s:51:"sites/all/themes/omega/alpha/css/grid/alpha_default";s:7:"layouts";a:4:{s:5:"fluid";a:2:{s:4:"name";s:5:"Fluid";s:8:"attached";a:0:{}}s:6:"narrow";a:2:{s:4:"name";s:6:"Narrow";s:8:"attached";a:0:{}}s:6:"normal";a:2:{s:4:"name";s:6:"Normal";s:8:"attached";a:0:{}}s:4:"wide";a:2:{s:4:"name";s:4:"Wide";s:8:"attached";a:0:{}}}s:7:"columns";a:3:{i:12;s:10:"12 Columns";i:16;s:10:"16 Columns";i:24;s:10:"24 Columns";}}s:11:"alpha_fluid";a:4:{s:4:"name";s:5:"Fluid";s:4:"path";s:49:"sites/all/themes/omega/alpha/css/grid/alpha_fluid";s:7:"layouts";a:1:{s:6:"normal";a:2:{s:4:"name";s:6:"Normal";s:8:"attached";a:0:{}}}s:7:"columns";a:3:{i:12;s:10:"12 Columns";i:16;s:10:"16 Columns";i:24;s:10:"24 Columns";}}}');
INSERT INTO `variable` VALUES
('theme_omega_alpha_libraries', 'a:3:{s:15:"omega_formalize";a:4:{s:4:"name";s:9:"Formalize";s:11:"description";s:159:"Formalize is a framework by <a href="http://formalize.me/" title="Formalize">Nathan Smith</a> for neat looking cross-browser forms with extended functionality.";s:3:"css";a:1:{i:0;a:2:{s:4:"path";s:46:"sites/all/themes/omega/omega/css/formalize.css";s:7:"options";a:2:{s:6:"weight";s:3:"-20";s:5:"group";i:100;}}}s:2:"js";a:1:{i:0;a:2:{s:4:"path";s:51:"sites/all/themes/omega/omega/js/jquery.formalize.js";s:7:"options";a:2:{s:6:"weight";s:3:"-20";s:5:"group";i:100;}}}}s:18:"omega_mediaqueries";a:3:{s:4:"name";s:13:"Media queries";s:11:"description";s:78:"Provides a tiny JavaScript library that can be used in your custom JavaScript.";s:2:"js";a:1:{i:0;a:2:{s:4:"path";s:53:"sites/all/themes/omega/omega/js/omega-mediaqueries.js";s:7:"options";a:2:{s:6:"weight";s:3:"-19";s:5:"group";i:100;}}}}s:18:"omega_equalheights";a:3:{s:4:"name";s:13:"Equal heights";s:11:"description";s:221:"Allows you to force all regions of a zone or all blocks of a region to be of equal size. <span class="marker">This library reveals a corresponding checkbox on every region and zone configuration panel if activated.</span>";s:2:"js";a:2:{i:0;a:2:{s:4:"path";s:54:"sites/all/themes/omega/omega/js/jquery.equalheights.js";s:7:"options";a:2:{s:6:"weight";s:3:"-18";s:5:"group";i:100;}}i:1;a:2:{s:4:"path";s:53:"sites/all/themes/omega/omega/js/omega-equalheights.js";s:7:"options";a:2:{s:6:"weight";s:3:"-18";s:5:"group";i:100;}}}}}'),
('theme_omega_alpha_registry', 'a:2:{s:10:"preprocess";a:7:{s:5:"block";a:2:{i:0;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:5:"block";s:5:"theme";s:5:"omega";s:4:"path";s:87:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/alpha/preprocess/preprocess-block.inc";s:8:"function";s:28:"alpha_alpha_preprocess_block";}i:1;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:5:"block";s:5:"theme";s:5:"omega";s:4:"path";s:87:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/omega/preprocess/preprocess-block.inc";s:8:"function";s:28:"omega_alpha_preprocess_block";}}s:7:"comment";a:1:{i:0;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:7:"comment";s:5:"theme";s:5:"omega";s:4:"path";s:89:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/omega/preprocess/preprocess-comment.inc";s:8:"function";s:30:"omega_alpha_preprocess_comment";}}s:4:"html";a:2:{i:0;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:4:"html";s:5:"theme";s:5:"omega";s:4:"path";s:86:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/alpha/preprocess/preprocess-html.inc";s:8:"function";s:27:"alpha_alpha_preprocess_html";}i:1;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:4:"html";s:5:"theme";s:5:"omega";s:4:"path";s:86:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/omega/preprocess/preprocess-html.inc";s:8:"function";s:27:"omega_alpha_preprocess_html";}}s:4:"node";a:1:{i:0;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:4:"node";s:5:"theme";s:5:"omega";s:4:"path";s:86:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/omega/preprocess/preprocess-node.inc";s:8:"function";s:27:"omega_alpha_preprocess_node";}}s:6:"region";a:2:{i:0;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:6:"region";s:5:"theme";s:5:"omega";s:4:"path";s:88:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/alpha/preprocess/preprocess-region.inc";s:8:"function";s:29:"alpha_alpha_preprocess_region";}i:1;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:6:"region";s:5:"theme";s:5:"omega";s:4:"path";s:88:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/omega/preprocess/preprocess-region.inc";s:8:"function";s:29:"omega_alpha_preprocess_region";}}s:4:"zone";a:1:{i:0;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:4:"zone";s:5:"theme";s:5:"omega";s:4:"path";s:86:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/omega/preprocess/preprocess-zone.inc";s:8:"function";s:27:"omega_alpha_preprocess_zone";}}s:4:"page";a:1:{i:0;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:4:"page";s:5:"theme";s:5:"omega";s:4:"path";s:86:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/alpha/preprocess/preprocess-page.inc";s:8:"function";s:27:"alpha_alpha_preprocess_page";}}}s:7:"process";a:3:{s:6:"region";a:1:{i:0;a:5:{s:4:"type";s:7:"process";s:4:"hook";s:6:"region";s:5:"theme";s:5:"omega";s:4:"path";s:82:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/omega/process/process-region.inc";s:8:"function";s:26:"omega_alpha_process_region";}}s:4:"zone";a:1:{i:0;a:5:{s:4:"type";s:7:"process";s:4:"hook";s:4:"zone";s:5:"theme";s:5:"omega";s:4:"path";s:80:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/omega/process/process-zone.inc";s:8:"function";s:24:"omega_alpha_process_zone";}}s:4:"page";a:1:{i:0;a:5:{s:4:"type";s:7:"process";s:4:"hook";s:4:"page";s:5:"theme";s:5:"omega";s:4:"path";s:80:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/alpha/process/process-page.inc";s:8:"function";s:24:"alpha_alpha_process_page";}}}}'),
('theme_theme813_settings', 'a:19:{s:11:"toggle_logo";i:1;s:11:"toggle_name";i:0;s:13:"toggle_slogan";i:0;s:24:"toggle_node_user_picture";i:0;s:27:"toggle_comment_user_picture";i:1;s:32:"toggle_comment_user_verification";i:1;s:14:"toggle_favicon";i:1;s:16:"toggle_main_menu";i:1;s:21:"toggle_secondary_menu";i:1;s:12:"default_logo";i:1;s:9:"logo_path";s:0:"";s:11:"logo_upload";s:0:"";s:15:"default_favicon";i:1;s:12:"favicon_path";s:0:"";s:14:"favicon_upload";s:0:"";s:27:"theme813_breadcrumb_display";s:2:"no";s:33:"theme813_breadcrumb_hideonlyfront";i:1;s:29:"theme813_breadcrumb_showtitle";i:0;s:29:"theme813_breadcrumb_separator";s:2:"»";}'),
('theme_theme822_settings', 'a:19:{s:11:"toggle_logo";i:1;s:11:"toggle_name";i:0;s:13:"toggle_slogan";i:0;s:24:"toggle_node_user_picture";i:0;s:27:"toggle_comment_user_picture";i:1;s:32:"toggle_comment_user_verification";i:1;s:14:"toggle_favicon";i:1;s:16:"toggle_main_menu";i:1;s:21:"toggle_secondary_menu";i:1;s:12:"default_logo";i:1;s:9:"logo_path";s:0:"";s:11:"logo_upload";s:0:"";s:15:"default_favicon";i:1;s:12:"favicon_path";s:0:"";s:14:"favicon_upload";s:0:"";s:27:"theme822_breadcrumb_display";s:2:"no";s:33:"theme822_breadcrumb_hideonlyfront";i:1;s:29:"theme822_breadcrumb_showtitle";i:0;s:29:"theme822_breadcrumb_separator";s:2:"»";}'),
('theme_tm_framefork_alpha_css', 'a:9:{s:15:"alpha-reset.css";a:5:{s:4:"name";s:5:"Reset";s:11:"description";s:78:"Created by <a href="http://meyerweb.com/eric/tools/css/reset/">Eric Meyer</a>.";s:4:"file";s:15:"alpha-reset.css";s:4:"path";s:48:"sites/all/themes/omega/alpha/css/alpha-reset.css";s:7:"options";a:2:{s:6:"weight";s:3:"-20";s:5:"group";i:100;}}s:16:"alpha-mobile.css";a:5:{s:4:"name";s:6:"Mobile";s:11:"description";s:37:"Default stylesheet for mobile styles.";s:4:"file";s:16:"alpha-mobile.css";s:4:"path";s:49:"sites/all/themes/omega/alpha/css/alpha-mobile.css";s:7:"options";a:2:{s:6:"weight";s:3:"-20";s:5:"group";i:100;}}s:15:"alpha-alpha.css";a:5:{s:4:"name";s:5:"Alpha";s:11:"description";s:51:"Default styles & resets for Alpha/Omega base theme.";s:4:"file";s:15:"alpha-alpha.css";s:4:"path";s:48:"sites/all/themes/omega/alpha/css/alpha-alpha.css";s:7:"options";a:2:{s:6:"weight";s:3:"-20";s:5:"group";i:100;}}s:14:"omega-text.css";a:5:{s:4:"name";s:11:"Text Styles";s:11:"description";s:30:"Default text styles for Omega.";s:4:"file";s:14:"omega-text.css";s:4:"path";s:47:"sites/all/themes/omega/omega/css/omega-text.css";s:7:"options";a:2:{s:6:"weight";s:3:"-10";s:5:"group";i:100;}}s:18:"omega-branding.css";a:5:{s:4:"name";s:15:"Branding Styles";s:11:"description";s:52:"Provides positioning for the logo, title and slogan.";s:4:"file";s:18:"omega-branding.css";s:4:"path";s:51:"sites/all/themes/omega/omega/css/omega-branding.css";s:7:"options";a:2:{s:6:"weight";s:3:"-10";s:5:"group";i:100;}}s:14:"omega-menu.css";a:5:{s:4:"name";s:11:"Menu Styles";s:11:"description";s:66:"Provides positoning and basic CSS for primary and secondary menus.";s:4:"file";s:14:"omega-menu.css";s:4:"path";s:47:"sites/all/themes/omega/omega/css/omega-menu.css";s:7:"options";a:2:{s:6:"weight";s:3:"-10";s:5:"group";i:100;}}s:15:"omega-forms.css";a:5:{s:4:"name";s:11:"Form Styles";s:11:"description";s:27:"Provides basic form styles.";s:4:"file";s:15:"omega-forms.css";s:4:"path";s:48:"sites/all/themes/omega/omega/css/omega-forms.css";s:7:"options";a:2:{s:6:"weight";s:3:"-10";s:5:"group";i:100;}}s:17:"omega-visuals.css";a:5:{s:4:"name";s:12:"Omega Styles";s:11:"description";s:53:"Custom visual styles for Omega. (pagers, menus, etc.)";s:4:"file";s:17:"omega-visuals.css";s:4:"path";s:50:"sites/all/themes/omega/omega/css/omega-visuals.css";s:7:"options";a:2:{s:6:"weight";s:3:"-10";s:5:"group";i:100;}}s:10:"global.css";a:5:{s:4:"name";s:25:"Your custom global styles";s:11:"description";s:65:"This file holds all the globally active custom CSS of your theme.";s:4:"file";s:10:"global.css";s:4:"path";s:44:"sites/all/themes/tm_framefork/css/global.css";s:7:"options";a:2:{s:6:"weight";s:2:"10";s:5:"group";i:100;}}}'),
('theme_tm_framefork_alpha_grids', 'a:2:{s:13:"alpha_default";a:4:{s:4:"name";s:15:"Default (960px)";s:4:"path";s:51:"sites/all/themes/omega/alpha/css/grid/alpha_default";s:7:"layouts";a:4:{s:5:"fluid";a:2:{s:4:"name";s:5:"Fluid";s:8:"attached";a:0:{}}s:6:"narrow";a:2:{s:4:"name";s:6:"Narrow";s:8:"attached";a:0:{}}s:6:"normal";a:2:{s:4:"name";s:6:"Normal";s:8:"attached";a:0:{}}s:4:"wide";a:2:{s:4:"name";s:4:"Wide";s:8:"attached";a:0:{}}}s:7:"columns";a:3:{i:12;s:10:"12 Columns";i:16;s:10:"16 Columns";i:24;s:10:"24 Columns";}}s:11:"alpha_fluid";a:4:{s:4:"name";s:5:"Fluid";s:4:"path";s:49:"sites/all/themes/omega/alpha/css/grid/alpha_fluid";s:7:"layouts";a:1:{s:6:"normal";a:2:{s:4:"name";s:6:"Normal";s:8:"attached";a:0:{}}}s:7:"columns";a:3:{i:12;s:10:"12 Columns";i:16;s:10:"16 Columns";i:24;s:10:"24 Columns";}}}'),
('theme_tm_framefork_alpha_libraries', 'a:3:{s:15:"omega_formalize";a:4:{s:4:"name";s:9:"Formalize";s:11:"description";s:159:"Formalize is a framework by <a href="http://formalize.me/" title="Formalize">Nathan Smith</a> for neat looking cross-browser forms with extended functionality.";s:3:"css";a:1:{i:0;a:2:{s:4:"path";s:46:"sites/all/themes/omega/omega/css/formalize.css";s:7:"options";a:2:{s:6:"weight";s:3:"-20";s:5:"group";i:100;}}}s:2:"js";a:1:{i:0;a:2:{s:4:"path";s:51:"sites/all/themes/omega/omega/js/jquery.formalize.js";s:7:"options";a:2:{s:6:"weight";s:3:"-20";s:5:"group";i:100;}}}}s:18:"omega_mediaqueries";a:3:{s:4:"name";s:13:"Media queries";s:11:"description";s:78:"Provides a tiny JavaScript library that can be used in your custom JavaScript.";s:2:"js";a:1:{i:0;a:2:{s:4:"path";s:53:"sites/all/themes/omega/omega/js/omega-mediaqueries.js";s:7:"options";a:2:{s:6:"weight";s:3:"-19";s:5:"group";i:100;}}}}s:18:"omega_equalheights";a:3:{s:4:"name";s:13:"Equal heights";s:11:"description";s:221:"Allows you to force all regions of a zone or all blocks of a region to be of equal size. <span class="marker">This library reveals a corresponding checkbox on every region and zone configuration panel if activated.</span>";s:2:"js";a:2:{i:0;a:2:{s:4:"path";s:54:"sites/all/themes/omega/omega/js/jquery.equalheights.js";s:7:"options";a:2:{s:6:"weight";s:3:"-18";s:5:"group";i:100;}}i:1;a:2:{s:4:"path";s:53:"sites/all/themes/omega/omega/js/omega-equalheights.js";s:7:"options";a:2:{s:6:"weight";s:3:"-18";s:5:"group";i:100;}}}}}'),
('theme_tm_framefork_alpha_registry', 'a:2:{s:10:"preprocess";a:7:{s:5:"block";a:2:{i:0;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:5:"block";s:5:"theme";s:12:"tm_framefork";s:4:"path";s:87:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/alpha/preprocess/preprocess-block.inc";s:8:"function";s:28:"alpha_alpha_preprocess_block";}i:1;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:5:"block";s:5:"theme";s:12:"tm_framefork";s:4:"path";s:87:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/omega/preprocess/preprocess-block.inc";s:8:"function";s:28:"omega_alpha_preprocess_block";}}s:7:"comment";a:1:{i:0;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:7:"comment";s:5:"theme";s:12:"tm_framefork";s:4:"path";s:89:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/omega/preprocess/preprocess-comment.inc";s:8:"function";s:30:"omega_alpha_preprocess_comment";}}s:4:"html";a:2:{i:0;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:4:"html";s:5:"theme";s:12:"tm_framefork";s:4:"path";s:86:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/alpha/preprocess/preprocess-html.inc";s:8:"function";s:27:"alpha_alpha_preprocess_html";}i:1;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:4:"html";s:5:"theme";s:12:"tm_framefork";s:4:"path";s:86:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/omega/preprocess/preprocess-html.inc";s:8:"function";s:27:"omega_alpha_preprocess_html";}}s:4:"node";a:1:{i:0;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:4:"node";s:5:"theme";s:12:"tm_framefork";s:4:"path";s:86:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/omega/preprocess/preprocess-node.inc";s:8:"function";s:27:"omega_alpha_preprocess_node";}}s:6:"region";a:2:{i:0;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:6:"region";s:5:"theme";s:12:"tm_framefork";s:4:"path";s:88:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/alpha/preprocess/preprocess-region.inc";s:8:"function";s:29:"alpha_alpha_preprocess_region";}i:1;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:6:"region";s:5:"theme";s:12:"tm_framefork";s:4:"path";s:88:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/omega/preprocess/preprocess-region.inc";s:8:"function";s:29:"omega_alpha_preprocess_region";}}s:4:"zone";a:1:{i:0;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:4:"zone";s:5:"theme";s:12:"tm_framefork";s:4:"path";s:86:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/omega/preprocess/preprocess-zone.inc";s:8:"function";s:27:"omega_alpha_preprocess_zone";}}s:4:"page";a:1:{i:0;a:5:{s:4:"type";s:10:"preprocess";s:4:"hook";s:4:"page";s:5:"theme";s:12:"tm_framefork";s:4:"path";s:86:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/alpha/preprocess/preprocess-page.inc";s:8:"function";s:27:"alpha_alpha_preprocess_page";}}}s:7:"process";a:3:{s:6:"region";a:1:{i:0;a:5:{s:4:"type";s:7:"process";s:4:"hook";s:6:"region";s:5:"theme";s:12:"tm_framefork";s:4:"path";s:82:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/omega/process/process-region.inc";s:8:"function";s:26:"omega_alpha_process_region";}}s:4:"zone";a:1:{i:0;a:5:{s:4:"type";s:7:"process";s:4:"hook";s:4:"zone";s:5:"theme";s:12:"tm_framefork";s:4:"path";s:80:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/omega/process/process-zone.inc";s:8:"function";s:24:"omega_alpha_process_zone";}}s:4:"page";a:1:{i:0;a:5:{s:4:"type";s:7:"process";s:4:"hook";s:4:"page";s:5:"theme";s:12:"tm_framefork";s:4:"path";s:80:"C:\\xampp\\htdocs\\drupal-7.4/sites/all/themes/omega/alpha/process/process-page.inc";s:8:"function";s:24:"alpha_alpha_process_page";}}}}'),
('theme_tm_framefork_settings', 'a:298:{s:11:"toggle_logo";i:1;s:11:"toggle_name";i:1;s:13:"toggle_slogan";i:1;s:24:"toggle_node_user_picture";i:1;s:27:"toggle_comment_user_picture";i:1;s:32:"toggle_comment_user_verification";i:1;s:14:"toggle_favicon";i:1;s:16:"toggle_main_menu";i:1;s:21:"toggle_secondary_menu";i:1;s:12:"default_logo";i:1;s:9:"logo_path";s:0:"";s:11:"logo_upload";s:0:"";s:15:"default_favicon";i:1;s:12:"favicon_path";s:0:"";s:14:"favicon_upload";s:0:"";s:10:"alpha_grid";s:13:"alpha_default";s:16:"alpha_responsive";i:1;s:14:"alpha_viewport";i:1;s:28:"alpha_viewport_initial_scale";s:1:"3";s:24:"alpha_viewport_min_scale";s:1:"6";s:24:"alpha_viewport_max_scale";s:3:"8.5";s:29:"alpha_viewport_user_scaleable";i:0;s:27:"alpha_primary_alpha_default";s:5:"fluid";s:44:"alpha_layouts_alpha_default_fluid_responsive";i:1;s:40:"alpha_layouts_alpha_default_fluid_weight";s:1:"0";s:39:"alpha_layouts_alpha_default_fluid_media";s:134:"all and (min-width: 740px) and (min-device-width: 740px), (max-device-width: 800px) and (min-width: 740px) and (orientation:landscape)";s:45:"alpha_layouts_alpha_default_narrow_responsive";i:1;s:41:"alpha_layouts_alpha_default_narrow_weight";s:1:"1";s:40:"alpha_layouts_alpha_default_narrow_media";s:134:"all and (min-width: 740px) and (min-device-width: 740px), (max-device-width: 800px) and (min-width: 740px) and (orientation:landscape)";s:45:"alpha_layouts_alpha_default_normal_responsive";i:1;s:41:"alpha_layouts_alpha_default_normal_weight";s:1:"2";s:40:"alpha_layouts_alpha_default_normal_media";s:144:"all and (min-width: 980px) and (min-device-width: 980px), all and (max-device-width: 1024px) and (min-width: 1024px) and (orientation:landscape)";s:43:"alpha_layouts_alpha_default_wide_responsive";i:1;s:39:"alpha_layouts_alpha_default_wide_weight";s:1:"3";s:38:"alpha_layouts_alpha_default_wide_media";s:27:"all and (min-width: 1220px)";s:25:"alpha_primary_alpha_fluid";s:6:"normal";s:43:"alpha_layouts_alpha_fluid_normal_responsive";i:0;s:39:"alpha_layouts_alpha_fluid_normal_weight";s:1:"0";s:38:"alpha_layouts_alpha_fluid_normal_media";s:134:"all and (min-width: 740px) and (min-device-width: 740px), (max-device-width: 800px) and (min-width: 740px) and (orientation:landscape)";s:15:"alpha_libraries";a:3:{s:15:"omega_formalize";s:15:"omega_formalize";s:18:"omega_mediaqueries";s:18:"omega_mediaqueries";s:18:"omega_equalheights";s:18:"omega_equalheights";}s:9:"alpha_css";a:9:{s:15:"alpha-reset.css";s:15:"alpha-reset.css";s:16:"alpha-mobile.css";s:16:"alpha-mobile.css";s:15:"alpha-alpha.css";s:15:"alpha-alpha.css";s:14:"omega-text.css";s:14:"omega-text.css";s:18:"omega-branding.css";s:18:"omega-branding.css";s:14:"omega-menu.css";s:14:"omega-menu.css";s:15:"omega-forms.css";s:15:"omega-forms.css";s:17:"omega-visuals.css";s:17:"omega-visuals.css";s:10:"global.css";i:0;}s:13:"alpha_exclude";a:32:{s:33:"modules/aggregator/aggregator.css";i:0;s:21:"modules/book/book.css";i:0;s:27:"modules/comment/comment.css";i:0;s:29:"modules/field/theme/field.css";i:0;s:23:"modules/forum/forum.css";i:0;s:21:"modules/node/node.css";i:0;s:21:"modules/poll/poll.css";i:0;s:25:"modules/search/search.css";i:0;s:21:"modules/user/user.css";i:0;s:22:"misc/vertical-tabs.css";i:0;s:23:"modules/block/block.css";i:0;s:23:"modules/dblog/dblog.css";i:0;s:21:"modules/file/file.css";i:0;s:25:"modules/filter/filter.css";i:0;s:21:"modules/help/help.css";i:0;s:21:"modules/menu/menu.css";i:0;s:25:"modules/openid/openid.css";i:0;s:27:"modules/profile/profile.css";i:0;s:33:"modules/statistics/statistics.css";i:0;s:25:"modules/syslog/syslog.css";i:0;s:24:"modules/system/admin.css";i:0;s:30:"modules/system/maintenance.css";i:0;s:25:"modules/system/system.css";i:0;s:31:"modules/system/system.admin.css";i:0;s:30:"modules/system/system.base.css";i:0;s:37:"modules/system/system.maintenance.css";i:0;s:31:"modules/system/system.menus.css";i:0;s:34:"modules/system/system.messages.css";i:0;s:31:"modules/system/system.theme.css";i:0;s:29:"modules/taxonomy/taxonomy.css";i:0;s:27:"modules/tracker/tracker.css";i:0;s:25:"modules/update/update.css";i:0;}s:24:"alpha_debug_block_toggle";i:0;s:24:"alpha_debug_block_active";i:0;s:23:"alpha_debug_grid_toggle";i:1;s:23:"alpha_debug_grid_active";i:1;s:22:"alpha_debug_grid_roles";a:3:{i:1;s:1:"1";i:2;s:1:"2";i:3;s:1:"3";}s:21:"alpha_toggle_messages";i:1;s:25:"alpha_toggle_action_links";i:1;s:17:"alpha_toggle_tabs";i:1;s:23:"alpha_toggle_breadcrumb";i:1;s:23:"alpha_toggle_page_title";i:1;s:23:"alpha_toggle_feed_icons";i:1;s:18:"alpha_hidden_title";i:0;s:22:"alpha_hidden_site_name";i:0;s:24:"alpha_hidden_site_slogan";i:0;s:23:"alpha_zone_user_wrapper";i:1;s:21:"alpha_zone_user_force";i:0;s:21:"alpha_zone_user_order";i:0;s:23:"alpha_zone_user_section";s:6:"header";s:22:"alpha_zone_user_weight";s:1:"1";s:23:"alpha_zone_user_columns";s:2:"12";s:23:"alpha_zone_user_primary";N;s:19:"alpha_zone_user_css";s:0:"";s:27:"alpha_zone_user_wrapper_css";s:0:"";s:28:"alpha_zone_user_equal_height";i:0;s:29:"alpha_region_user_first_force";i:0;s:28:"alpha_region_user_first_zone";s:4:"user";s:30:"alpha_region_user_first_prefix";s:1:"0";s:31:"alpha_region_user_first_columns";s:1:"8";s:30:"alpha_region_user_first_suffix";s:1:"0";s:30:"alpha_region_user_first_weight";s:1:"1";s:32:"alpha_region_user_first_position";s:1:"1";s:27:"alpha_region_user_first_css";s:0:"";s:36:"alpha_region_user_first_equal_height";i:0;s:30:"alpha_region_user_second_force";i:0;s:29:"alpha_region_user_second_zone";s:4:"user";s:31:"alpha_region_user_second_prefix";s:1:"0";s:32:"alpha_region_user_second_columns";s:1:"4";s:31:"alpha_region_user_second_suffix";s:1:"0";s:31:"alpha_region_user_second_weight";s:1:"2";s:33:"alpha_region_user_second_position";s:1:"2";s:28:"alpha_region_user_second_css";s:0:"";s:37:"alpha_region_user_second_equal_height";i:0;s:27:"alpha_zone_branding_wrapper";i:1;s:25:"alpha_zone_branding_force";i:0;s:25:"alpha_zone_branding_order";i:0;s:27:"alpha_zone_branding_section";s:6:"header";s:26:"alpha_zone_branding_weight";s:1:"2";s:27:"alpha_zone_branding_columns";s:2:"12";s:27:"alpha_zone_branding_primary";N;s:23:"alpha_zone_branding_css";s:0:"";s:31:"alpha_zone_branding_wrapper_css";s:0:"";s:32:"alpha_zone_branding_equal_height";i:0;s:27:"alpha_region_branding_force";i:1;s:26:"alpha_region_branding_zone";s:8:"branding";s:28:"alpha_region_branding_prefix";s:1:"0";s:29:"alpha_region_branding_columns";s:2:"12";s:28:"alpha_region_branding_suffix";s:1:"0";s:28:"alpha_region_branding_weight";s:1:"1";s:30:"alpha_region_branding_position";s:1:"1";s:25:"alpha_region_branding_css";s:0:"";s:34:"alpha_region_branding_equal_height";i:0;s:23:"alpha_zone_menu_wrapper";i:1;s:21:"alpha_zone_menu_force";i:0;s:21:"alpha_zone_menu_order";i:0;s:23:"alpha_zone_menu_section";s:6:"header";s:22:"alpha_zone_menu_weight";s:1:"3";s:23:"alpha_zone_menu_columns";s:2:"12";s:23:"alpha_zone_menu_primary";N;s:19:"alpha_zone_menu_css";s:0:"";s:27:"alpha_zone_menu_wrapper_css";s:0:"";s:28:"alpha_zone_menu_equal_height";i:0;s:23:"alpha_region_menu_force";i:1;s:22:"alpha_region_menu_zone";s:4:"menu";s:24:"alpha_region_menu_prefix";s:1:"0";s:25:"alpha_region_menu_columns";s:2:"12";s:24:"alpha_region_menu_suffix";s:1:"0";s:24:"alpha_region_menu_weight";s:1:"1";s:26:"alpha_region_menu_position";s:1:"1";s:21:"alpha_region_menu_css";s:0:"";s:30:"alpha_region_menu_equal_height";i:0;s:25:"alpha_zone_header_wrapper";i:1;s:23:"alpha_zone_header_force";i:0;s:23:"alpha_zone_header_order";i:0;s:25:"alpha_zone_header_section";s:6:"header";s:24:"alpha_zone_header_weight";s:1:"4";s:25:"alpha_zone_header_columns";s:2:"12";s:25:"alpha_zone_header_primary";N;s:21:"alpha_zone_header_css";s:0:"";s:29:"alpha_zone_header_wrapper_css";s:0:"";s:30:"alpha_zone_header_equal_height";i:0;s:31:"alpha_region_header_first_force";i:0;s:30:"alpha_region_header_first_zone";s:6:"header";s:32:"alpha_region_header_first_prefix";s:1:"0";s:33:"alpha_region_header_first_columns";s:1:"6";s:32:"alpha_region_header_first_suffix";s:1:"0";s:32:"alpha_region_header_first_weight";s:1:"1";s:34:"alpha_region_header_first_position";s:1:"1";s:29:"alpha_region_header_first_css";s:0:"";s:38:"alpha_region_header_first_equal_height";i:0;s:32:"alpha_region_header_second_force";i:0;s:31:"alpha_region_header_second_zone";s:6:"header";s:33:"alpha_region_header_second_prefix";s:1:"0";s:34:"alpha_region_header_second_columns";s:1:"6";s:33:"alpha_region_header_second_suffix";s:1:"0";s:33:"alpha_region_header_second_weight";s:1:"2";s:35:"alpha_region_header_second_position";s:1:"2";s:30:"alpha_region_header_second_css";s:0:"";s:39:"alpha_region_header_second_equal_height";i:0;s:26:"alpha_zone_preface_wrapper";i:1;s:24:"alpha_zone_preface_force";i:0;s:24:"alpha_zone_preface_order";i:0;s:26:"alpha_zone_preface_section";s:7:"content";s:25:"alpha_zone_preface_weight";s:1:"1";s:26:"alpha_zone_preface_columns";s:2:"12";s:26:"alpha_zone_preface_primary";N;s:22:"alpha_zone_preface_css";s:0:"";s:30:"alpha_zone_preface_wrapper_css";s:0:"";s:31:"alpha_zone_preface_equal_height";i:0;s:32:"alpha_region_preface_first_force";i:0;s:31:"alpha_region_preface_first_zone";s:7:"preface";s:33:"alpha_region_preface_first_prefix";s:1:"0";s:34:"alpha_region_preface_first_columns";s:1:"4";s:33:"alpha_region_preface_first_suffix";s:1:"0";s:33:"alpha_region_preface_first_weight";s:1:"1";s:35:"alpha_region_preface_first_position";s:1:"1";s:30:"alpha_region_preface_first_css";s:0:"";s:39:"alpha_region_preface_first_equal_height";i:0;s:33:"alpha_region_preface_second_force";i:0;s:32:"alpha_region_preface_second_zone";s:7:"preface";s:34:"alpha_region_preface_second_prefix";s:1:"0";s:35:"alpha_region_preface_second_columns";s:1:"4";s:34:"alpha_region_preface_second_suffix";s:1:"0";s:34:"alpha_region_preface_second_weight";s:1:"2";s:36:"alpha_region_preface_second_position";s:1:"2";s:31:"alpha_region_preface_second_css";s:0:"";s:40:"alpha_region_preface_second_equal_height";i:0;s:32:"alpha_region_preface_third_force";i:0;s:31:"alpha_region_preface_third_zone";s:7:"preface";s:33:"alpha_region_preface_third_prefix";s:1:"0";s:34:"alpha_region_preface_third_columns";s:1:"4";s:33:"alpha_region_preface_third_suffix";s:1:"0";s:33:"alpha_region_preface_third_weight";s:1:"3";s:35:"alpha_region_preface_third_position";s:1:"3";s:30:"alpha_region_preface_third_css";s:0:"";s:39:"alpha_region_preface_third_equal_height";i:0;s:26:"alpha_zone_content_wrapper";i:1;s:24:"alpha_zone_content_force";i:1;s:24:"alpha_zone_content_order";i:1;s:26:"alpha_zone_content_section";s:7:"content";s:25:"alpha_zone_content_weight";s:1:"2";s:26:"alpha_zone_content_columns";s:2:"12";s:26:"alpha_zone_content_primary";s:7:"content";s:22:"alpha_zone_content_css";s:0:"";s:30:"alpha_zone_content_wrapper_css";s:0:"";s:31:"alpha_zone_content_equal_height";i:1;s:26:"alpha_region_content_force";i:0;s:25:"alpha_region_content_zone";s:7:"content";s:27:"alpha_region_content_prefix";s:1:"0";s:28:"alpha_region_content_columns";s:1:"6";s:27:"alpha_region_content_suffix";s:1:"0";s:27:"alpha_region_content_weight";s:1:"1";s:29:"alpha_region_content_position";s:1:"2";s:24:"alpha_region_content_css";s:0:"";s:33:"alpha_region_content_equal_height";i:0;s:32:"alpha_region_sidebar_first_force";i:0;s:31:"alpha_region_sidebar_first_zone";s:7:"content";s:33:"alpha_region_sidebar_first_prefix";s:1:"0";s:34:"alpha_region_sidebar_first_columns";s:1:"3";s:33:"alpha_region_sidebar_first_suffix";s:1:"0";s:33:"alpha_region_sidebar_first_weight";s:1:"2";s:35:"alpha_region_sidebar_first_position";s:1:"1";s:30:"alpha_region_sidebar_first_css";s:0:"";s:39:"alpha_region_sidebar_first_equal_height";i:0;s:33:"alpha_region_sidebar_second_force";i:0;s:32:"alpha_region_sidebar_second_zone";s:7:"content";s:34:"alpha_region_sidebar_second_prefix";s:1:"0";s:35:"alpha_region_sidebar_second_columns";s:1:"3";s:34:"alpha_region_sidebar_second_suffix";s:1:"0";s:34:"alpha_region_sidebar_second_weight";s:1:"3";s:36:"alpha_region_sidebar_second_position";s:1:"3";s:31:"alpha_region_sidebar_second_css";s:0:"";s:40:"alpha_region_sidebar_second_equal_height";i:0;s:29:"alpha_zone_postscript_wrapper";i:1;s:27:"alpha_zone_postscript_force";i:0;s:27:"alpha_zone_postscript_order";i:0;s:29:"alpha_zone_postscript_section";s:7:"content";s:28:"alpha_zone_postscript_weight";s:1:"3";s:29:"alpha_zone_postscript_columns";s:2:"12";s:29:"alpha_zone_postscript_primary";N;s:25:"alpha_zone_postscript_css";s:0:"";s:33:"alpha_zone_postscript_wrapper_css";s:0:"";s:34:"alpha_zone_postscript_equal_height";i:0;s:35:"alpha_region_postscript_first_force";i:0;s:34:"alpha_region_postscript_first_zone";s:10:"postscript";s:36:"alpha_region_postscript_first_prefix";s:1:"0";s:37:"alpha_region_postscript_first_columns";s:1:"3";s:36:"alpha_region_postscript_first_suffix";s:1:"0";s:36:"alpha_region_postscript_first_weight";s:1:"1";s:38:"alpha_region_postscript_first_position";s:1:"1";s:33:"alpha_region_postscript_first_css";s:0:"";s:42:"alpha_region_postscript_first_equal_height";i:0;s:36:"alpha_region_postscript_second_force";i:0;s:35:"alpha_region_postscript_second_zone";s:10:"postscript";s:37:"alpha_region_postscript_second_prefix";s:1:"0";s:38:"alpha_region_postscript_second_columns";s:1:"3";s:37:"alpha_region_postscript_second_suffix";s:1:"0";s:37:"alpha_region_postscript_second_weight";s:1:"2";s:39:"alpha_region_postscript_second_position";s:1:"2";s:34:"alpha_region_postscript_second_css";s:0:"";s:43:"alpha_region_postscript_second_equal_height";i:0;s:35:"alpha_region_postscript_third_force";i:0;s:34:"alpha_region_postscript_third_zone";s:10:"postscript";s:36:"alpha_region_postscript_third_prefix";s:1:"0";s:37:"alpha_region_postscript_third_columns";s:1:"3";s:36:"alpha_region_postscript_third_suffix";s:1:"0";s:36:"alpha_region_postscript_third_weight";s:1:"3";s:38:"alpha_region_postscript_third_position";s:1:"3";s:33:"alpha_region_postscript_third_css";s:0:"";s:42:"alpha_region_postscript_third_equal_height";i:0;s:36:"alpha_region_postscript_fourth_force";i:0;s:35:"alpha_region_postscript_fourth_zone";s:10:"postscript";s:37:"alpha_region_postscript_fourth_prefix";s:1:"0";s:38:"alpha_region_postscript_fourth_columns";s:1:"3";s:37:"alpha_region_postscript_fourth_suffix";s:1:"0";s:37:"alpha_region_postscript_fourth_weight";s:1:"4";s:39:"alpha_region_postscript_fourth_position";s:1:"4";s:34:"alpha_region_postscript_fourth_css";s:0:"";s:43:"alpha_region_postscript_fourth_equal_height";i:0;s:25:"alpha_zone_footer_wrapper";i:1;s:23:"alpha_zone_footer_force";i:0;s:23:"alpha_zone_footer_order";i:0;s:25:"alpha_zone_footer_section";s:6:"footer";s:24:"alpha_zone_footer_weight";s:1:"1";s:25:"alpha_zone_footer_columns";s:2:"12";s:25:"alpha_zone_footer_primary";N;s:21:"alpha_zone_footer_css";s:0:"";s:29:"alpha_zone_footer_wrapper_css";s:0:"";s:30:"alpha_zone_footer_equal_height";i:0;s:31:"alpha_region_footer_first_force";i:0;s:30:"alpha_region_footer_first_zone";s:6:"footer";s:32:"alpha_region_footer_first_prefix";s:1:"0";s:33:"alpha_region_footer_first_columns";s:2:"12";s:32:"alpha_region_footer_first_suffix";s:1:"0";s:32:"alpha_region_footer_first_weight";s:1:"1";s:34:"alpha_region_footer_first_position";s:1:"1";s:29:"alpha_region_footer_first_css";s:0:"";s:38:"alpha_region_footer_first_equal_height";i:0;s:32:"alpha_region_footer_second_force";i:0;s:31:"alpha_region_footer_second_zone";s:6:"footer";s:33:"alpha_region_footer_second_prefix";s:1:"0";s:34:"alpha_region_footer_second_columns";s:2:"12";s:33:"alpha_region_footer_second_suffix";s:1:"0";s:33:"alpha_region_footer_second_weight";s:1:"2";s:35:"alpha_region_footer_second_position";s:1:"2";s:30:"alpha_region_footer_second_css";s:0:"";s:39:"alpha_region_footer_second_equal_height";i:0;}'),
('theme_zentropy_settings', 'a:20:{s:11:"toggle_logo";i:1;s:11:"toggle_name";i:1;s:13:"toggle_slogan";i:1;s:24:"toggle_node_user_picture";i:0;s:27:"toggle_comment_user_picture";i:1;s:32:"toggle_comment_user_verification";i:1;s:14:"toggle_favicon";i:1;s:16:"toggle_main_menu";i:1;s:21:"toggle_secondary_menu";i:1;s:12:"default_logo";i:1;s:9:"logo_path";s:0:"";s:11:"logo_upload";s:0:"";s:15:"default_favicon";i:1;s:12:"favicon_path";s:0:"";s:14:"favicon_upload";s:0:"";s:18:"breadcrumb_display";s:3:"yes";s:20:"breadcrumb_separator";s:5:" › ";s:15:"breadcrumb_home";i:1;s:19:"breadcrumb_trailing";i:0;s:16:"breadcrumb_title";i:0;}'),
('tipsy', 'a:2:{s:12:"drupal_forms";a:2:{s:5:"forms";i:0;s:7:"options";a:7:{s:4:"fade";i:1;s:7:"gravity";s:6:"autoWE";s:7:"delayIn";s:1:"0";s:8:"delayOut";s:1:"0";s:7:"trigger";s:5:"focus";s:7:"opacity";s:3:"0.8";s:6:"offset";s:1:"0";}}s:16:"custom_selectors";a:1:{i:0;a:2:{s:8:"selector";s:13:".tipsy, #logo";s:7:"options";a:9:{s:4:"fade";i:1;s:7:"gravity";s:1:"w";s:7:"trigger";s:5:"hover";s:7:"delayIn";s:1:"1";s:8:"delayOut";s:1:"0";s:7:"opacity";s:3:"0.8";s:6:"offset";s:1:"0";s:4:"html";i:1;s:15:"tooltip_content";a:2:{s:6:"source";s:9:"attribute";s:8:"selector";s:5:"title";}}}}}'),
('update_last_check', 'i:1378992417;'),
('update_notify_emails', 'a:1:{i:0;s:15:"admin@admin.com";}'),
('user_admin_role', 's:1:"3";'),
('user_block_whois_new_count', 's:1:"5";'),
('user_cancel_method', 's:17:"user_cancel_block";'),
('user_email_verification', 'i:1;'),
('user_mail_cancel_confirm_body', 's:381:"[user:name],\r\n\r\nA request to cancel your account has been made at [site:name].\r\n\r\nYou may now cancel your account on [site:url-brief] by clicking this link or copying and pasting it into your browser:\r\n\r\n[user:cancel-url]\r\n\r\nNOTE: The cancellation of your account is not reversible.\r\n\r\nThis link expires in one day and nothing will happen if it is not used.\r\n\r\n--  [site:name] team";'),
('user_mail_cancel_confirm_subject', 's:59:"Account cancellation request for [user:name] at [site:name]";'),
('user_mail_password_reset_body', 's:407:"[user:name],\r\n\r\nA request to reset the password for your account has been made at [site:name].\r\n\r\nYou may now log in by clicking this link or copying and pasting it to your browser:\r\n\r\n[user:one-time-login-url]\r\n\r\nThis link can only be used once to log in and will lead you to a page where you can set your password. It expires after one day and nothing will happen if it''s not used.\r\n\r\n--  [site:name] team";'),
('user_mail_password_reset_subject', 's:60:"Replacement login information for [user:name] at [site:name]";'),
('user_mail_register_admin_created_body', 's:476:"[user:name],\r\n\r\nA site administrator at [site:name] has created an account for you. You may now log in by clicking this link or copying and pasting it to your browser:\r\n\r\n[user:one-time-login-url]\r\n\r\nThis link can only be used once to log in and will lead you to a page where you can set your password.\r\n\r\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\r\n\r\nusername: [user:name]\r\npassword: Your password\r\n\r\n--  [site:name] team";'),
('user_mail_register_admin_created_subject', 's:58:"An administrator created an account for you at [site:name]";'),
('user_mail_register_no_approval_required_body', 's:450:"[user:name],\r\n\r\nThank you for registering at [site:name]. You may now log in by clicking this link or copying and pasting it to your browser:\r\n\r\n[user:one-time-login-url]\r\n\r\nThis link can only be used once to log in and will lead you to a page where you can set your password.\r\n\r\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\r\n\r\nusername: [user:name]\r\npassword: Your password\r\n\r\n--  [site:name] team";'),
('user_mail_register_no_approval_required_subject', 's:46:"Account details for [user:name] at [site:name]";'),
('user_mail_register_pending_approval_body', 's:287:"[user:name],\r\n\r\nThank you for registering at [site:name]. Your application for an account is currently pending approval. Once it has been approved, you will receive another e-mail containing information about how to log in, set your password, and other details.\r\n\r\n\r\n--  [site:name] team";'),
('user_mail_register_pending_approval_subject', 's:71:"Account details for [user:name] at [site:name] (pending admin approval)";'),
('user_mail_status_activated_body', 's:461:"[user:name],\r\n\r\nYour account at [site:name] has been activated.\r\n\r\nYou may now log in by clicking this link or copying and pasting it into your browser:\r\n\r\n[user:one-time-login-url]\r\n\r\nThis link can only be used once to log in and will lead you to a page where you can set your password.\r\n\r\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\r\n\r\nusername: [user:name]\r\npassword: Your password\r\n\r\n--  [site:name] team";'),
('user_mail_status_activated_notify', 'i:1;'),
('user_mail_status_activated_subject', 's:57:"Account details for [user:name] at [site:name] (approved)";'),
('user_mail_status_blocked_body', 's:85:"[user:name],\r\n\r\nYour account on [site:name] has been blocked.\r\n\r\n--  [site:name] team";'),
('user_mail_status_blocked_notify', 'i:0;'),
('user_mail_status_blocked_subject', 's:56:"Account details for [user:name] at [site:name] (blocked)";'),
('user_mail_status_canceled_body', 's:86:"[user:name],\r\n\r\nYour account on [site:name] has been canceled.\r\n\r\n--  [site:name] team";'),
('user_mail_status_canceled_notify', 'i:0;'),
('user_mail_status_canceled_subject', 's:57:"Account details for [user:name] at [site:name] (canceled)";'),
('user_pictures', 'i:1;'),
('user_picture_default', 's:30:"sites/default/files/avatar.png";'),
('user_picture_dimensions', 's:9:"1024x1024";'),
('user_picture_file_size', 's:3:"800";'),
('user_picture_guidelines', 's:0:"";'),
('user_picture_path', 's:8:"pictures";'),
('user_picture_style', 's:9:"thumbnail";'),
('user_register', 's:1:"0";'),
('user_signatures', 'i:0;'),
('views_defaults', 'a:2:{s:15:"comments_recent";b:0;s:7:"archive";b:0;}');
/*!40000 ALTER TABLE variable ENABLE KEYS */;

--
-- Table structure for table 'views_display'
--

CREATE TABLE IF NOT EXISTS `views_display` (
  `vid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The view this display is attached to.',
  `id` varchar(64) NOT NULL DEFAULT '' COMMENT 'An identifier for this display; usually generated from the display_plugin, so should be something like page or page_1 or block_2, etc.',
  `display_title` varchar(64) NOT NULL DEFAULT '' COMMENT 'The title of the display, viewable by the administrator.',
  `display_plugin` varchar(64) NOT NULL DEFAULT '' COMMENT 'The type of the display. Usually page, block or embed, but is pluggable so may be other things.',
  `position` int(11) DEFAULT '0' COMMENT 'The order in which this display is loaded.',
  `display_options` longtext COMMENT 'A serialized array of options for this display; it contains options that are generally only pertinent to that display plugin type.',
  PRIMARY KEY (`vid`,`id`),
  KEY `vid` (`vid`,`position`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores information about each display attached to a view.';

--
-- Dumping data for table 'views_display'
--

/*!40000 ALTER TABLE views_display DISABLE KEYS */;
INSERT INTO `views_display` VALUES
('2', 'default', 'Master', 'default', '1', 'a:17:{s:6:"access";a:1:{s:4:"type";s:4:"perm";}s:5:"cache";a:1:{s:4:"type";s:4:"none";}s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:12:"exposed_form";a:1:{s:4:"type";s:5:"basic";}s:5:"pager";a:2:{s:4:"type";s:4:"some";s:7:"options";a:2:{s:14:"items_per_page";s:1:"0";s:6:"offset";s:1:"0";}}s:12:"style_plugin";s:21:"semanticviews_default";s:10:"row_plugin";s:6:"fields";s:6:"fields";a:5:{s:21:"field_portfolio_image";a:34:{s:2:"id";s:21:"field_portfolio_image";s:5:"table";s:32:"field_data_field_portfolio_image";s:5:"field";s:21:"field_portfolio_image";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:0;s:17:"click_sort_column";s:3:"fid";s:4:"type";s:8:"colorbox";s:8:"settings";a:6:{s:19:"colorbox_node_style";s:16:"portfolio_4_cols";s:20:"colorbox_image_style";s:0:"";s:16:"colorbox_gallery";s:4:"page";s:23:"colorbox_gallery_custom";s:0:"";s:16:"colorbox_caption";s:4:"auto";s:23:"colorbox_caption_custom";s:0:"";}s:12:"group_column";s:3:"fid";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}s:5:"title";a:8:{s:2:"id";s:5:"title";s:5:"table";s:4:"node";s:5:"field";s:5:"title";s:5:"label";s:0:"";s:5:"alter";a:8:{s:10:"alter_text";i:0;s:9:"make_link";i:0;s:8:"absolute";i:0;s:4:"trim";i:0;s:13:"word_boundary";i:0;s:8:"ellipsis";i:0;s:10:"strip_tags";i:0;s:4:"html";i:0;}s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:12:"link_to_node";i:1;}s:4:"body";a:34:{s:2:"id";s:4:"body";s:5:"table";s:15:"field_data_body";s:5:"field";s:4:"body";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:2:"50";s:13:"word_boundary";i:0;s:8:"ellipsis";i:0;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:1;s:4:"trim";i:1;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:0;s:17:"click_sort_column";s:5:"value";s:4:"type";s:12:"text_default";s:8:"settings";a:0:{}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}s:9:"view_node";a:22:{s:2:"id";s:9:"view_node";s:5:"table";s:17:"views_entity_node";s:5:"field";s:9:"view_node";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";b:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:3:"div";s:21:"element_wrapper_class";s:6:"button";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:4:"text";s:4:"More";}s:24:"field_portfolio_category";a:34:{s:2:"id";s:24:"field_portfolio_category";s:5:"table";s:35:"field_data_field_portfolio_category";s:5:"field";s:24:"field_portfolio_category";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:3:"div";s:13:"element_class";s:14:"isotope-filter";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:0;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:17:"click_sort_column";s:3:"tid";s:4:"type";s:29:"taxonomy_term_reference_plain";s:8:"settings";a:0:{}s:12:"group_column";s:3:"tid";s:13:"group_columns";a:0:{}s:10:"group_rows";i:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";s:1:"0";s:14:"delta_reversed";i:0;s:16:"delta_first_last";i:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}}s:7:"filters";a:3:{s:6:"status";a:6:{s:5:"value";i:1;s:5:"table";s:4:"node";s:5:"field";s:6:"status";s:2:"id";s:6:"status";s:6:"expose";a:1:{s:8:"operator";b:0;}s:5:"group";i:1;}s:3:"tid";a:19:{s:2:"id";s:3:"tid";s:5:"table";s:14:"taxonomy_index";s:5:"field";s:3:"tid";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:8:"operator";s:2:"or";s:5:"value";s:0:"";s:5:"group";i:1;s:7:"exposed";b:0;s:6:"expose";a:11:{s:11:"operator_id";b:0;s:5:"label";s:0:"";s:11:"description";s:0:"";s:12:"use_operator";b:0;s:8:"operator";s:0:"";s:10:"identifier";s:0:"";s:8:"required";b:0;s:8:"remember";b:0;s:8:"multiple";b:0;s:14:"remember_roles";a:1:{i:2;i:2;}s:6:"reduce";b:0;}s:10:"is_grouped";b:0;s:10:"group_info";a:10:{s:5:"label";s:0:"";s:11:"description";s:0:"";s:10:"identifier";s:0:"";s:8:"optional";b:1;s:6:"widget";s:6:"select";s:8:"multiple";b:0;s:8:"remember";i:0;s:13:"default_group";s:3:"All";s:22:"default_group_multiple";a:0:{}s:11:"group_items";a:0:{}}s:17:"reduce_duplicates";i:0;s:4:"type";s:9:"textfield";s:5:"limit";b:1;s:10:"vocabulary";s:20:"portfolio_categories";s:9:"hierarchy";i:0;s:13:"error_message";b:1;}s:4:"type";a:5:{s:2:"id";s:4:"type";s:5:"table";s:4:"node";s:5:"field";s:4:"type";s:5:"value";a:1:{s:9:"portfolio";s:9:"portfolio";}s:5:"group";i:1;}}s:5:"sorts";a:1:{s:7:"created";a:4:{s:2:"id";s:7:"created";s:5:"table";s:4:"node";s:5:"field";s:7:"created";s:5:"order";s:4:"DESC";}}s:5:"title";s:15:"Portfolio 2 col";s:8:"use_ajax";b:1;s:6:"header";a:1:{s:4:"view";a:10:{s:2:"id";s:4:"view";s:5:"table";s:5:"views";s:5:"field";s:4:"view";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:5:"empty";i:0;s:14:"view_to_insert";s:24:"portfolio_filter:default";s:17:"inherit_arguments";i:0;}}s:13:"relationships";a:0:{}s:9:"css_class";s:14:"portfolio-grid";s:13:"style_options";a:0:{}s:13:"filter_groups";a:2:{s:8:"operator";s:3:"AND";s:6:"groups";a:1:{i:1;s:3:"AND";}}}'),
('2', 'page', 'Page', 'page', '2', 'a:10:{s:4:"path";s:11:"portfolio-4";s:4:"menu";a:7:{s:4:"type";s:6:"normal";s:5:"title";s:11:"Portfolio 4";s:11:"description";s:0:"";s:4:"name";s:9:"main-menu";s:6:"weight";s:1:"0";s:7:"context";i:0;s:19:"context_only_inline";i:0;}s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:5:"title";s:11:"Catalogue 4";s:8:"defaults";a:7:{s:5:"title";b:0;s:12:"style_plugin";b:0;s:13:"style_options";b:0;s:10:"row_plugin";b:0;s:11:"row_options";b:0;s:5:"pager";b:1;s:13:"pager_options";b:1;}s:8:"link_url";N;s:12:"style_plugin";s:7:"isotope";s:13:"style_options";a:3:{s:4:"type";s:2:"ul";s:13:"wrapper_class";s:9:"item-list";s:5:"class";s:0:"";}s:10:"row_plugin";s:6:"fields";s:11:"row_options";a:0:{}}'),
('2', 'page_1', 'Page', 'page', '5', 'a:11:{s:4:"path";s:9:"portfolio";s:4:"menu";a:7:{s:4:"type";s:6:"normal";s:5:"title";s:9:"Portfolio";s:11:"description";s:0:"";s:4:"name";s:9:"main-menu";s:6:"weight";s:1:"0";s:7:"context";i:0;s:19:"context_only_inline";i:0;}s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:6:"fields";a:5:{s:21:"field_portfolio_image";a:34:{s:2:"id";s:21:"field_portfolio_image";s:5:"table";s:32:"field_data_field_portfolio_image";s:5:"field";s:21:"field_portfolio_image";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:0;s:17:"click_sort_column";s:3:"fid";s:4:"type";s:8:"colorbox";s:8:"settings";a:6:{s:19:"colorbox_node_style";s:16:"portfolio_3_cols";s:20:"colorbox_image_style";s:0:"";s:16:"colorbox_gallery";s:4:"page";s:23:"colorbox_gallery_custom";s:0:"";s:16:"colorbox_caption";s:4:"auto";s:23:"colorbox_caption_custom";s:0:"";}s:12:"group_column";s:3:"fid";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}s:5:"title";a:8:{s:2:"id";s:5:"title";s:5:"table";s:4:"node";s:5:"field";s:5:"title";s:5:"label";s:0:"";s:5:"alter";a:8:{s:10:"alter_text";i:0;s:9:"make_link";i:0;s:8:"absolute";i:0;s:4:"trim";i:0;s:13:"word_boundary";i:0;s:8:"ellipsis";i:0;s:10:"strip_tags";i:0;s:4:"html";i:0;}s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:12:"link_to_node";i:1;}s:4:"body";a:34:{s:2:"id";s:4:"body";s:5:"table";s:15:"field_data_body";s:5:"field";s:4:"body";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:2:"90";s:13:"word_boundary";i:0;s:8:"ellipsis";i:0;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:1;s:4:"trim";i:1;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:0;s:17:"click_sort_column";s:5:"value";s:4:"type";s:12:"text_default";s:8:"settings";a:0:{}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}s:9:"view_node";a:22:{s:2:"id";s:9:"view_node";s:5:"table";s:17:"views_entity_node";s:5:"field";s:9:"view_node";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";b:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:3:"div";s:21:"element_wrapper_class";s:6:"button";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:4:"text";s:4:"More";}s:24:"field_portfolio_category";a:34:{s:2:"id";s:24:"field_portfolio_category";s:5:"table";s:35:"field_data_field_portfolio_category";s:5:"field";s:24:"field_portfolio_category";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:3:"div";s:13:"element_class";s:14:"isotope-filter";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:0;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:17:"click_sort_column";s:3:"tid";s:4:"type";s:29:"taxonomy_term_reference_plain";s:8:"settings";a:0:{}s:12:"group_column";s:3:"tid";s:13:"group_columns";a:0:{}s:10:"group_rows";i:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";s:1:"0";s:14:"delta_reversed";i:0;s:16:"delta_first_last";i:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}}s:8:"defaults";a:8:{s:6:"fields";b:0;s:5:"title";b:0;s:12:"style_plugin";b:0;s:13:"style_options";b:0;s:10:"row_plugin";b:0;s:11:"row_options";b:0;s:5:"pager";b:1;s:13:"pager_options";b:1;}s:8:"link_url";N;s:5:"title";s:9:"Catalogue";s:12:"style_plugin";s:7:"isotope";s:13:"style_options";a:3:{s:4:"type";s:2:"ul";s:13:"wrapper_class";s:9:"item-list";s:5:"class";s:0:"";}s:10:"row_plugin";s:6:"fields";s:11:"row_options";a:0:{}}'),
('2', 'page_2', 'Page', 'page', '3', 'a:11:{s:4:"path";s:11:"portfolio-2";s:4:"menu";a:7:{s:4:"type";s:6:"normal";s:5:"title";s:11:"Portfolio 2";s:11:"description";s:0:"";s:4:"name";s:9:"main-menu";s:6:"weight";s:1:"0";s:7:"context";i:0;s:19:"context_only_inline";i:0;}s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:6:"fields";a:5:{s:21:"field_portfolio_image";a:34:{s:2:"id";s:21:"field_portfolio_image";s:5:"table";s:32:"field_data_field_portfolio_image";s:5:"field";s:21:"field_portfolio_image";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:23:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:0;s:17:"click_sort_column";s:3:"fid";s:4:"type";s:8:"colorbox";s:8:"settings";a:5:{s:19:"colorbox_node_style";s:16:"portfolio_2_cols";s:20:"colorbox_image_style";s:0:"";s:16:"colorbox_gallery";s:4:"page";s:23:"colorbox_gallery_custom";s:0:"";s:16:"colorbox_caption";s:4:"auto";}s:12:"group_column";s:3:"fid";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}s:5:"title";a:8:{s:2:"id";s:5:"title";s:5:"table";s:4:"node";s:5:"field";s:5:"title";s:5:"label";s:0:"";s:5:"alter";a:8:{s:10:"alter_text";i:0;s:9:"make_link";i:0;s:8:"absolute";i:0;s:4:"trim";i:0;s:13:"word_boundary";i:0;s:8:"ellipsis";i:0;s:10:"strip_tags";i:0;s:4:"html";i:0;}s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:12:"link_to_node";i:1;}s:4:"body";a:34:{s:2:"id";s:4:"body";s:5:"table";s:15:"field_data_body";s:5:"field";s:4:"body";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:3:"210";s:13:"word_boundary";i:0;s:8:"ellipsis";i:0;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:1;s:4:"trim";i:1;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:0;s:17:"click_sort_column";s:5:"value";s:4:"type";s:12:"text_default";s:8:"settings";a:0:{}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}s:9:"view_node";a:22:{s:2:"id";s:9:"view_node";s:5:"table";s:17:"views_entity_node";s:5:"field";s:9:"view_node";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";b:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:3:"div";s:21:"element_wrapper_class";s:6:"button";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:4:"text";s:4:"More";}s:24:"field_portfolio_category";a:34:{s:2:"id";s:24:"field_portfolio_category";s:5:"table";s:35:"field_data_field_portfolio_category";s:5:"field";s:24:"field_portfolio_category";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:3:"div";s:13:"element_class";s:14:"isotope-filter";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:0;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:17:"click_sort_column";s:3:"tid";s:4:"type";s:28:"taxonomy_term_reference_link";s:8:"settings";a:0:{}s:12:"group_column";s:3:"tid";s:13:"group_columns";a:0:{}s:10:"group_rows";i:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";s:1:"0";s:14:"delta_reversed";i:0;s:16:"delta_first_last";i:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}}s:8:"defaults";a:8:{s:6:"fields";b:0;s:5:"title";b:0;s:12:"style_plugin";b:0;s:13:"style_options";b:0;s:10:"row_plugin";b:0;s:11:"row_options";b:0;s:5:"pager";b:1;s:13:"pager_options";b:1;}s:8:"link_url";N;s:5:"title";s:11:"Catalogue 2";s:12:"style_plugin";s:7:"isotope";s:13:"style_options";a:3:{s:4:"type";s:2:"ul";s:13:"wrapper_class";s:9:"item-list";s:5:"class";s:0:"";}s:10:"row_plugin";s:6:"fields";s:11:"row_options";a:0:{}}'),
('2', 'page_3', 'Page', 'page', '4', 'a:11:{s:4:"path";s:11:"portfolio-3";s:4:"menu";a:7:{s:4:"type";s:6:"normal";s:5:"title";s:11:"Portfolio 3";s:11:"description";s:0:"";s:4:"name";s:9:"main-menu";s:6:"weight";s:1:"0";s:7:"context";i:0;s:19:"context_only_inline";i:0;}s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:6:"fields";a:5:{s:21:"field_portfolio_image";a:34:{s:2:"id";s:21:"field_portfolio_image";s:5:"table";s:32:"field_data_field_portfolio_image";s:5:"field";s:21:"field_portfolio_image";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:23:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:0;s:17:"click_sort_column";s:3:"fid";s:4:"type";s:8:"colorbox";s:8:"settings";a:5:{s:19:"colorbox_node_style";s:16:"portfolio_3_cols";s:20:"colorbox_image_style";s:0:"";s:16:"colorbox_gallery";s:4:"page";s:23:"colorbox_gallery_custom";s:0:"";s:16:"colorbox_caption";s:4:"auto";}s:12:"group_column";s:3:"fid";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}s:5:"title";a:8:{s:2:"id";s:5:"title";s:5:"table";s:4:"node";s:5:"field";s:5:"title";s:5:"label";s:0:"";s:5:"alter";a:8:{s:10:"alter_text";i:0;s:9:"make_link";i:0;s:8:"absolute";i:0;s:4:"trim";i:0;s:13:"word_boundary";i:0;s:8:"ellipsis";i:0;s:10:"strip_tags";i:0;s:4:"html";i:0;}s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:12:"link_to_node";i:1;}s:4:"body";a:34:{s:2:"id";s:4:"body";s:5:"table";s:15:"field_data_body";s:5:"field";s:4:"body";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:2:"90";s:13:"word_boundary";i:0;s:8:"ellipsis";i:0;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:1;s:4:"trim";i:1;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:0;s:17:"click_sort_column";s:5:"value";s:4:"type";s:12:"text_default";s:8:"settings";a:0:{}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}s:9:"view_node";a:22:{s:2:"id";s:9:"view_node";s:5:"table";s:17:"views_entity_node";s:5:"field";s:9:"view_node";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";b:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:3:"div";s:21:"element_wrapper_class";s:6:"button";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:4:"text";s:4:"More";}s:24:"field_portfolio_category";a:34:{s:2:"id";s:24:"field_portfolio_category";s:5:"table";s:35:"field_data_field_portfolio_category";s:5:"field";s:24:"field_portfolio_category";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:3:"div";s:13:"element_class";s:14:"isotope-filter";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:0;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:17:"click_sort_column";s:3:"tid";s:4:"type";s:29:"taxonomy_term_reference_plain";s:8:"settings";a:0:{}s:12:"group_column";s:3:"tid";s:13:"group_columns";a:0:{}s:10:"group_rows";i:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";s:1:"0";s:14:"delta_reversed";i:0;s:16:"delta_first_last";i:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}}s:8:"defaults";a:8:{s:6:"fields";b:0;s:5:"title";b:0;s:12:"style_plugin";b:0;s:13:"style_options";b:0;s:10:"row_plugin";b:0;s:11:"row_options";b:0;s:5:"pager";b:1;s:13:"pager_options";b:1;}s:8:"link_url";N;s:5:"title";s:11:"Catalogue 3";s:12:"style_plugin";s:7:"isotope";s:13:"style_options";a:3:{s:4:"type";s:2:"ul";s:13:"wrapper_class";s:9:"item-list";s:5:"class";s:0:"";}s:10:"row_plugin";s:6:"fields";s:11:"row_options";a:0:{}}'),
('4', 'block', 'Block', 'block', '3', 'a:3:{s:9:"arguments";a:1:{s:18:"created_year_month";a:13:{s:2:"id";s:18:"created_year_month";s:5:"table";s:4:"node";s:5:"field";s:18:"created_year_month";s:14:"default_action";s:11:"summary asc";s:12:"style_plugin";s:15:"default_summary";s:13:"style_options";a:3:{s:5:"count";i:1;s:8:"override";i:0;s:14:"items_per_page";s:2:"30";}s:8:"wildcard";s:3:"all";s:21:"wildcard_substitution";s:3:"All";s:5:"title";s:2:"%1";s:12:"relationship";s:4:"none";s:13:"validate_type";s:4:"none";s:13:"validate_fail";s:9:"not found";s:21:"default_argument_type";s:5:"fixed";}}s:8:"defaults";a:1:{s:9:"arguments";b:0;}s:17:"block_description";s:7:"Archive";}'),
('4', 'default', 'Master', 'default', '1', 'a:15:{s:5:"title";s:15:"Monthly archive";s:8:"defaults";a:10:{s:5:"title";b:0;s:5:"sorts";b:0;s:9:"arguments";b:0;s:7:"filters";b:0;s:13:"filter_groups";b:0;s:6:"access";b:0;s:12:"style_plugin";b:0;s:13:"style_options";b:0;s:10:"row_plugin";b:0;s:11:"row_options";b:0;}s:5:"sorts";a:1:{s:7:"created";a:6:{s:2:"id";s:7:"created";s:5:"table";s:4:"node";s:5:"field";s:7:"created";s:5:"order";s:4:"DESC";s:11:"granularity";s:6:"second";s:12:"relationship";s:4:"none";}}s:9:"arguments";a:1:{s:18:"created_year_month";a:13:{s:2:"id";s:18:"created_year_month";s:5:"table";s:4:"node";s:5:"field";s:18:"created_year_month";s:14:"default_action";s:12:"summary desc";s:12:"style_plugin";s:15:"default_summary";s:13:"style_options";a:3:{s:5:"count";i:1;s:8:"override";i:1;s:14:"items_per_page";s:2:"30";}s:8:"wildcard";s:3:"all";s:21:"wildcard_substitution";s:3:"All";s:5:"title";s:2:"%1";s:12:"relationship";s:4:"none";s:13:"validate_type";s:4:"none";s:13:"validate_fail";s:9:"not found";s:21:"default_argument_type";s:5:"fixed";}}s:7:"filters";a:1:{s:6:"status";a:9:{s:2:"id";s:6:"status";s:5:"table";s:4:"node";s:5:"field";s:6:"status";s:8:"operator";s:1:"=";s:5:"value";i:1;s:5:"group";i:0;s:7:"exposed";b:0;s:6:"expose";a:2:{s:8:"operator";b:0;s:5:"label";s:0:"";}s:12:"relationship";s:4:"none";}}s:13:"filter_groups";a:2:{s:8:"operator";s:3:"AND";s:6:"groups";a:1:{i:0;s:3:"AND";}}s:6:"access";a:3:{s:4:"type";s:4:"none";s:4:"role";a:0:{}s:4:"perm";s:0:"";}s:9:"use_pager";N;s:12:"style_plugin";s:7:"default";s:13:"style_options";a:0:{}s:10:"row_plugin";s:4:"node";s:11:"row_options";a:2:{s:6:"teaser";b:1;s:5:"links";b:1;}s:14:"items_per_page";N;s:6:"offset";N;s:5:"pager";a:2:{s:4:"type";s:4:"full";s:7:"options";a:2:{s:6:"offset";i:0;s:14:"items_per_page";i:10;}}}'),
('4', 'page', 'Page', 'page', '2', 'a:3:{s:4:"path";s:7:"archive";s:4:"menu";a:3:{s:4:"type";s:4:"none";s:5:"title";s:0:"";s:6:"weight";i:0;}s:11:"tab_options";a:3:{s:4:"type";s:4:"none";s:5:"title";s:0:"";s:6:"weight";i:0;}}'),
('5', 'block', 'Block', 'block', '2', 'a:0:{}'),
('5', 'default', 'Master', 'default', '1', 'a:11:{s:6:"access";a:1:{s:4:"type";s:4:"perm";}s:5:"cache";a:1:{s:4:"type";s:4:"none";}s:5:"query";a:1:{s:4:"type";s:11:"views_query";}s:12:"exposed_form";a:1:{s:4:"type";s:5:"basic";}s:5:"pager";a:2:{s:4:"type";s:4:"some";s:7:"options";a:2:{s:14:"items_per_page";s:1:"3";s:6:"offset";s:1:"0";}}s:12:"style_plugin";s:7:"default";s:10:"row_plugin";s:6:"fields";s:6:"fields";a:3:{s:20:"field_employee_photo";a:32:{s:2:"id";s:20:"field_employee_photo";s:5:"table";s:31:"field_data_field_employee_photo";s:5:"field";s:20:"field_employee_photo";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:21:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:4:"trim";i:0;s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:10:"strip_tags";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";i:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:17:"click_sort_column";s:3:"fid";s:4:"type";s:5:"image";s:8:"settings";a:2:{s:11:"image_style";s:14:"our_team_80x80";s:10:"image_link";s:0:"";}s:12:"group_column";s:3:"fid";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}s:5:"title";a:8:{s:2:"id";s:5:"title";s:5:"table";s:4:"node";s:5:"field";s:5:"title";s:5:"label";s:0:"";s:5:"alter";a:8:{s:10:"alter_text";i:0;s:9:"make_link";i:0;s:8:"absolute";i:0;s:4:"trim";i:0;s:13:"word_boundary";i:0;s:8:"ellipsis";i:0;s:10:"strip_tags";i:0;s:4:"html";i:0;}s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:12:"link_to_node";i:1;}s:4:"body";a:32:{s:2:"id";s:4:"body";s:5:"table";s:15:"field_data_body";s:5:"field";s:4:"body";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:21:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:4:"trim";i:1;s:5:"nl2br";i:0;s:10:"max_length";s:2:"60";s:13:"word_boundary";i:0;s:8:"ellipsis";i:1;s:10:"strip_tags";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";i:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:17:"click_sort_column";s:5:"value";s:4:"type";s:10:"text_plain";s:8:"settings";a:0:{}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}}s:7:"filters";a:2:{s:6:"status";a:6:{s:5:"value";i:1;s:5:"table";s:4:"node";s:5:"field";s:6:"status";s:2:"id";s:6:"status";s:6:"expose";a:1:{s:8:"operator";b:0;}s:5:"group";i:0;}s:4:"type";a:4:{s:2:"id";s:4:"type";s:5:"table";s:4:"node";s:5:"field";s:4:"type";s:5:"value";a:1:{s:8:"employee";s:8:"employee";}}}s:5:"sorts";a:1:{s:7:"created";a:4:{s:2:"id";s:7:"created";s:5:"table";s:4:"node";s:5:"field";s:7:"created";s:5:"order";s:4:"DESC";}}s:5:"title";s:8:"Our team";}'),
('6', 'attachment_1', 'Attachment - Questions Top', 'attachment', '6', 'a:13:{s:7:"enabled";b:0;s:8:"defaults";a:7:{s:8:"use_more";b:0;s:12:"link_display";b:0;s:12:"style_plugin";b:0;s:13:"style_options";b:0;s:10:"row_plugin";b:0;s:11:"row_options";b:0;s:6:"fields";b:0;}s:15:"use_more_always";b:1;s:13:"use_more_text";s:13:"View all FAQs";s:12:"link_display";s:6:"page_1";s:5:"pager";a:2:{s:4:"type";s:4:"none";s:7:"options";a:1:{s:6:"offset";s:1:"0";}}s:12:"style_plugin";s:4:"list";s:10:"row_plugin";s:6:"fields";s:11:"row_options";a:2:{s:10:"hide_empty";i:0;s:22:"default_field_elements";i:1;}s:6:"fields";a:2:{s:3:"nid";a:12:{s:2:"id";s:3:"nid";s:5:"table";s:4:"node";s:5:"field";s:3:"nid";s:5:"label";s:0:"";s:7:"exclude";b:1;s:5:"alter";a:12:{s:10:"alter_text";i:0;s:9:"make_link";i:0;s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:15:"trim_whitespace";i:0;s:5:"nl2br";i:0;s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:10:"strip_tags";i:0;s:4:"trim";i:0;s:4:"html";i:0;}s:19:"element_label_colon";b:0;s:23:"element_default_classes";i:1;s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:0;s:12:"link_to_node";i:0;}s:5:"title";a:11:{s:2:"id";s:5:"title";s:5:"table";s:4:"node";s:5:"field";s:5:"title";s:5:"label";s:0:"";s:5:"alter";a:13:{s:10:"alter_text";i:0;s:9:"make_link";i:1;s:4:"path";s:24:"faq-questions-top#n[nid]";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:15:"trim_whitespace";i:0;s:5:"nl2br";i:0;s:13:"word_boundary";i:0;s:8:"ellipsis";i:0;s:10:"strip_tags";i:0;s:4:"trim";i:0;s:4:"html";i:0;}s:19:"element_label_colon";b:0;s:23:"element_default_classes";i:1;s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:0;s:12:"link_to_node";i:0;}}s:8:"displays";a:5:{s:6:"page_1";s:6:"page_1";s:7:"default";i:0;s:4:"page";i:0;s:5:"block";i:0;s:7:"block_1";i:0;}s:23:"inherit_exposed_filters";i:1;s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}}'),
('6', 'default', 'Master', 'default', '1', 'a:14:{s:5:"title";s:3:"FAQ";s:8:"use_more";i:1;s:15:"use_more_always";b:0;s:13:"use_more_text";s:13:"View all FAQs";s:6:"access";a:1:{s:4:"type";s:4:"perm";}s:5:"cache";a:1:{s:4:"type";s:4:"none";}s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:1:{s:13:"query_comment";b:0;}}s:12:"exposed_form";a:1:{s:4:"type";s:5:"basic";}s:5:"pager";a:2:{s:4:"type";s:4:"full";s:7:"options";a:1:{s:14:"items_per_page";s:2:"10";}}s:12:"style_plugin";s:7:"default";s:10:"row_plugin";s:4:"node";s:6:"fields";a:1:{s:5:"title";a:8:{s:2:"id";s:5:"title";s:5:"table";s:4:"node";s:5:"field";s:5:"title";s:5:"label";s:0:"";s:5:"alter";a:8:{s:10:"alter_text";i:0;s:9:"make_link";i:0;s:8:"absolute";i:0;s:13:"word_boundary";i:0;s:8:"ellipsis";i:0;s:10:"strip_tags";i:0;s:4:"trim";i:0;s:4:"html";i:0;}s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:12:"link_to_node";i:1;}}s:5:"sorts";a:2:{s:6:"sticky";a:4:{s:2:"id";s:6:"sticky";s:5:"table";s:4:"node";s:5:"field";s:6:"sticky";s:5:"order";s:4:"DESC";}s:7:"created";a:4:{s:2:"id";s:7:"created";s:5:"table";s:4:"node";s:5:"field";s:7:"created";s:5:"order";s:4:"DESC";}}s:7:"filters";a:2:{s:6:"status";a:6:{s:2:"id";s:6:"status";s:5:"table";s:4:"node";s:5:"field";s:6:"status";s:5:"value";i:1;s:5:"group";i:0;s:6:"expose";a:1:{s:8:"operator";b:0;}}s:4:"type";a:4:{s:2:"id";s:4:"type";s:5:"table";s:4:"node";s:5:"field";s:4:"type";s:5:"value";a:1:{s:3:"faq";s:3:"faq";}}}}'),
('6', 'faq_random', 'Block - Random FAQs', 'block', '3', 'a:13:{s:8:"defaults";a:8:{s:5:"title";b:0;s:8:"use_more";b:0;s:5:"pager";b:0;s:12:"style_plugin";b:0;s:13:"style_options";b:0;s:10:"row_plugin";b:0;s:11:"row_options";b:0;s:5:"sorts";b:0;}s:5:"title";s:11:"Random FAQs";s:8:"use_more";b:1;s:15:"use_more_always";b:1;s:13:"use_more_text";s:13:"View all FAQs";s:5:"pager";a:2:{s:4:"type";s:4:"some";s:7:"options";a:2:{s:14:"items_per_page";s:1:"5";s:6:"offset";s:1:"0";}}s:12:"style_plugin";s:4:"list";s:10:"row_plugin";s:6:"fields";s:11:"row_options";a:2:{s:10:"hide_empty";i:0;s:22:"default_field_elements";i:1;}s:5:"sorts";a:1:{s:6:"random";a:3:{s:2:"id";s:6:"random";s:5:"table";s:5:"views";s:5:"field";s:6:"random";}}s:17:"block_description";s:11:"Random FAQs";s:7:"enabled";b:0;s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}}'),
('6', 'faq_recent', 'Block - Recent FAQs', 'block', '2', 'a:11:{s:8:"defaults";a:7:{s:5:"title";b:0;s:8:"use_more";b:0;s:5:"pager";b:0;s:12:"style_plugin";b:0;s:13:"style_options";b:0;s:10:"row_plugin";b:0;s:11:"row_options";b:0;}s:5:"title";s:11:"Recent FAQs";s:8:"use_more";b:1;s:15:"use_more_always";b:1;s:13:"use_more_text";s:13:"View all FAQs";s:5:"pager";a:2:{s:4:"type";s:4:"some";s:7:"options";a:2:{s:14:"items_per_page";s:1:"5";s:6:"offset";s:1:"0";}}s:12:"style_plugin";s:4:"list";s:10:"row_plugin";s:6:"fields";s:17:"block_description";s:11:"Recent FAQs";s:7:"enabled";b:0;s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}}'),
('6', 'page', 'Page - Questions Inline', 'page', '4', 'a:6:{s:7:"enabled";b:0;s:8:"defaults";a:2:{s:7:"filters";b:0;s:13:"filter_groups";b:0;}s:7:"filters";a:2:{s:6:"status";a:6:{s:2:"id";s:6:"status";s:5:"table";s:4:"node";s:5:"field";s:6:"status";s:5:"value";i:1;s:5:"group";i:0;s:6:"expose";a:1:{s:8:"operator";b:0;}}s:4:"type";a:4:{s:2:"id";s:4:"type";s:5:"table";s:4:"node";s:5:"field";s:4:"type";s:5:"value";a:1:{s:3:"faq";s:3:"faq";}}}s:4:"path";s:20:"faq-questions-inline";s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:13:"filter_groups";a:2:{s:8:"operator";s:3:"AND";s:6:"groups";a:1:{i:1;s:3:"AND";}}}'),
('6', 'page_1', 'Page - Questions Top', 'page', '5', 'a:12:{s:7:"enabled";b:1;s:8:"defaults";a:8:{s:5:"pager";b:0;s:12:"style_plugin";b:0;s:13:"style_options";b:0;s:10:"row_plugin";b:0;s:11:"row_options";b:0;s:6:"fields";b:0;s:7:"filters";b:0;s:13:"filter_groups";b:0;}s:5:"pager";a:2:{s:4:"type";s:4:"none";s:7:"options";a:1:{s:6:"offset";s:1:"0";}}s:12:"style_plugin";s:7:"default";s:10:"row_plugin";s:6:"fields";s:11:"row_options";a:2:{s:10:"hide_empty";i:0;s:22:"default_field_elements";i:1;}s:6:"fields";a:3:{s:3:"nid";a:12:{s:2:"id";s:3:"nid";s:5:"table";s:4:"node";s:5:"field";s:3:"nid";s:5:"label";s:0:"";s:7:"exclude";b:1;s:5:"alter";a:12:{s:10:"alter_text";i:0;s:9:"make_link";i:0;s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:15:"trim_whitespace";i:0;s:5:"nl2br";i:0;s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:10:"strip_tags";i:0;s:4:"trim";i:0;s:4:"html";i:0;}s:19:"element_label_colon";b:0;s:23:"element_default_classes";i:1;s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:0;s:12:"link_to_node";i:0;}s:5:"title";a:22:{s:2:"id";s:5:"title";s:5:"table";s:4:"node";s:5:"field";s:5:"title";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:1;s:4:"text";s:16:"<h3>[title]</h3>";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:0;s:8:"ellipsis";i:0;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:0;s:12:"link_to_node";i:0;}s:4:"body";a:11:{s:2:"id";s:4:"body";s:5:"table";s:15:"field_data_body";s:5:"field";s:4:"body";s:5:"label";s:0:"";s:5:"alter";a:12:{s:10:"alter_text";i:0;s:9:"make_link";i:0;s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:15:"trim_whitespace";i:0;s:5:"nl2br";i:0;s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:10:"strip_tags";i:0;s:4:"trim";i:0;s:4:"html";i:0;}s:19:"element_label_colon";b:0;s:23:"element_default_classes";i:1;s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:0;s:17:"field_api_classes";i:0;}}s:7:"filters";a:2:{s:6:"status";a:6:{s:2:"id";s:6:"status";s:5:"table";s:4:"node";s:5:"field";s:6:"status";s:5:"value";i:1;s:5:"group";i:0;s:6:"expose";a:1:{s:8:"operator";b:0;}}s:4:"type";a:4:{s:2:"id";s:4:"type";s:5:"table";s:4:"node";s:5:"field";s:4:"type";s:5:"value";a:1:{s:3:"faq";s:3:"faq";}}}s:4:"path";s:17:"faq-questions-top";s:4:"menu";a:5:{s:4:"type";s:6:"normal";s:5:"title";s:3:"FAQ";s:11:"description";s:0:"";s:4:"name";s:9:"user-menu";s:6:"weight";s:1:"0";}s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:13:"filter_groups";a:2:{s:8:"operator";s:3:"AND";s:6:"groups";a:1:{i:1;s:3:"AND";}}}'),
('6', 'page_2', 'Page - New Page', 'page', '7', 'a:10:{s:7:"enabled";b:0;s:8:"defaults";a:7:{s:12:"style_plugin";b:0;s:13:"style_options";b:0;s:10:"row_plugin";b:0;s:11:"row_options";b:0;s:6:"fields";b:0;s:7:"filters";b:0;s:13:"filter_groups";b:0;}s:12:"style_plugin";s:4:"list";s:10:"row_plugin";s:6:"fields";s:11:"row_options";a:2:{s:10:"hide_empty";i:0;s:22:"default_field_elements";i:1;}s:6:"fields";a:1:{s:5:"title";a:8:{s:2:"id";s:5:"title";s:5:"table";s:4:"node";s:5:"field";s:5:"title";s:5:"label";s:0:"";s:5:"alter";a:8:{s:10:"alter_text";i:0;s:9:"make_link";i:0;s:8:"absolute";i:0;s:13:"word_boundary";i:0;s:8:"ellipsis";i:0;s:10:"strip_tags";i:0;s:4:"trim";i:0;s:4:"html";i:0;}s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:12:"link_to_node";i:1;}}s:7:"filters";a:2:{s:6:"status";a:6:{s:2:"id";s:6:"status";s:5:"table";s:4:"node";s:5:"field";s:6:"status";s:5:"value";i:1;s:5:"group";i:0;s:6:"expose";a:1:{s:8:"operator";b:0;}}s:4:"type";a:4:{s:2:"id";s:4:"type";s:5:"table";s:4:"node";s:5:"field";s:4:"type";s:5:"value";a:1:{s:3:"faq";s:3:"faq";}}}s:4:"path";s:12:"faq-new-page";s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:13:"filter_groups";a:2:{s:8:"operator";s:3:"AND";s:6:"groups";a:1:{i:1;s:3:"AND";}}}'),
('6', 'page_3', 'Page - Categories Inline - New Page', 'page', '8', 'a:11:{s:7:"enabled";b:0;s:8:"defaults";a:7:{s:12:"style_plugin";b:0;s:13:"style_options";b:0;s:10:"row_plugin";b:0;s:11:"row_options";b:0;s:6:"fields";b:0;s:7:"filters";b:0;s:13:"filter_groups";b:0;}s:12:"style_plugin";s:4:"list";s:13:"style_options";a:1:{s:8:"grouping";s:14:"field_category";}s:10:"row_plugin";s:6:"fields";s:11:"row_options";a:2:{s:10:"hide_empty";i:0;s:22:"default_field_elements";i:1;}s:6:"fields";a:1:{s:5:"title";a:8:{s:2:"id";s:5:"title";s:5:"table";s:4:"node";s:5:"field";s:5:"title";s:5:"label";s:0:"";s:5:"alter";a:8:{s:10:"alter_text";i:0;s:9:"make_link";i:0;s:8:"absolute";i:0;s:13:"word_boundary";i:0;s:8:"ellipsis";i:0;s:10:"strip_tags";i:0;s:4:"trim";i:0;s:4:"html";i:0;}s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:12:"link_to_node";i:1;}}s:7:"filters";a:2:{s:6:"status";a:6:{s:2:"id";s:6:"status";s:5:"table";s:4:"node";s:5:"field";s:6:"status";s:5:"value";i:1;s:5:"group";i:0;s:6:"expose";a:1:{s:8:"operator";b:0;}}s:4:"type";a:4:{s:2:"id";s:4:"type";s:5:"table";s:4:"node";s:5:"field";s:4:"type";s:5:"value";a:1:{s:3:"faq";s:3:"faq";}}}s:4:"path";s:30:"faq-categories-inline-new-page";s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:13:"filter_groups";a:2:{s:8:"operator";s:3:"AND";s:6:"groups";a:1:{i:1;s:3:"AND";}}}'),
('8', 'block', 'Block', 'block', '2', 'a:2:{s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:5:"field";a:1:{s:5:"title";a:1:{s:12:"link_to_node";i:1;}}}');
INSERT INTO `views_display` VALUES
('8', 'default', 'Master', 'default', '1', 'a:12:{s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:6:"access";a:1:{s:4:"type";s:4:"perm";}s:5:"cache";a:1:{s:4:"type";s:4:"none";}s:12:"exposed_form";a:1:{s:4:"type";s:5:"basic";}s:5:"pager";a:2:{s:4:"type";s:4:"some";s:7:"options";a:2:{s:14:"items_per_page";s:1:"5";s:6:"offset";s:1:"0";}}s:12:"style_plugin";s:10:"flexslider";s:10:"row_plugin";s:6:"fields";s:6:"fields";a:5:{s:17:"field_slide_image";a:34:{s:2:"id";s:17:"field_slide_image";s:5:"table";s:28:"field_data_field_slide_image";s:5:"field";s:17:"field_slide_image";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:17:"click_sort_column";s:3:"fid";s:4:"type";s:5:"image";s:8:"settings";a:2:{s:11:"image_style";s:0:"";s:10:"image_link";s:0:"";}s:12:"group_column";s:0:"";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}s:5:"title";a:22:{s:2:"id";s:5:"title";s:5:"table";s:4:"node";s:5:"field";s:5:"title";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:1;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:12:"link_to_node";i:1;}s:4:"body";a:34:{s:2:"id";s:4:"body";s:5:"table";s:15:"field_data_body";s:5:"field";s:4:"body";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:1;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:0;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:23:"text_summary_or_trimmed";s:8:"settings";a:1:{s:11:"trim_length";s:3:"600";}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}s:6:"body_1";a:34:{s:2:"id";s:6:"body_1";s:5:"table";s:15:"field_data_body";s:5:"field";s:4:"body";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:1;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:3:"140";s:13:"word_boundary";i:1;s:8:"ellipsis";i:0;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:1;s:4:"trim";i:1;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:0;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:12:"text_default";s:8:"settings";a:0:{}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}s:7:"nothing";a:21:{s:2:"id";s:7:"nothing";s:5:"table";s:5:"views";s:5:"field";s:7:"nothing";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";b:1;s:4:"text";s:117:"<div class="slide-title">[title]</div>\n<div class="slide-summary">[body]</div>\n<div class="slide-text">[body_1]</div>";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:3:"div";s:13:"element_class";s:20:"slider_caption_inner";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:3:"div";s:21:"element_wrapper_class";s:14:"slider_caption";s:23:"element_default_classes";i:0;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:0;}}s:7:"filters";a:2:{s:6:"status";a:6:{s:5:"value";i:1;s:5:"table";s:4:"node";s:5:"field";s:6:"status";s:2:"id";s:6:"status";s:6:"expose";a:1:{s:8:"operator";b:0;}s:5:"group";i:1;}s:4:"type";a:4:{s:2:"id";s:4:"type";s:5:"table";s:4:"node";s:5:"field";s:4:"type";s:5:"value";a:1:{s:6:"slider";s:6:"slider";}}}s:5:"sorts";a:1:{s:7:"created";a:4:{s:2:"id";s:7:"created";s:5:"table";s:4:"node";s:5:"field";s:7:"created";s:5:"order";s:4:"DESC";}}s:5:"title";s:0:"";s:13:"style_options";a:1:{s:9:"optionset";s:7:"default";}}'),
('9', 'block', 'Block', 'block', '2', 'a:1:{s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}}'),
('9', 'default', 'Master', 'default', '1', 'a:11:{s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:6:"access";a:1:{s:4:"type";s:4:"perm";}s:5:"cache";a:1:{s:4:"type";s:4:"none";}s:12:"exposed_form";a:1:{s:4:"type";s:5:"basic";}s:5:"pager";a:2:{s:4:"type";s:4:"some";s:7:"options";a:1:{s:14:"items_per_page";s:2:"10";}}s:12:"style_plugin";s:4:"list";s:10:"row_plugin";s:6:"fields";s:6:"fields";a:1:{s:4:"name";a:23:{s:2:"id";s:4:"name";s:5:"table";s:18:"taxonomy_term_data";s:5:"field";s:4:"name";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:0;s:8:"ellipsis";i:0;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:1:"0";s:13:"element_class";s:0:"";s:18:"element_label_type";s:1:"0";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:0;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:16:"link_to_taxonomy";i:1;s:14:"convert_spaces";i:0;}}s:7:"filters";a:1:{s:12:"machine_name";a:4:{s:2:"id";s:12:"machine_name";s:5:"table";s:19:"taxonomy_vocabulary";s:5:"field";s:12:"machine_name";s:5:"value";a:1:{s:13:"blog_cetogory";s:13:"blog_cetogory";}}}s:5:"sorts";a:0:{}s:5:"title";s:10:"Categories";}'),
('10', 'block', 'Block', 'block', '2', 'a:1:{s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}}'),
('10', 'default', 'Master', 'default', '1', 'a:12:{s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:6:"access";a:1:{s:4:"type";s:4:"perm";}s:5:"cache";a:1:{s:4:"type";s:4:"none";}s:12:"exposed_form";a:1:{s:4:"type";s:5:"basic";}s:5:"pager";a:2:{s:4:"type";s:4:"none";s:7:"options";a:1:{s:14:"items_per_page";s:1:"0";}}s:12:"style_plugin";s:20:"isotope_filter_block";s:10:"row_plugin";s:6:"fields";s:6:"fields";a:1:{s:4:"name";a:23:{s:2:"id";s:4:"name";s:5:"table";s:18:"taxonomy_term_data";s:5:"field";s:4:"name";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:0;s:8:"ellipsis";i:0;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:0;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:16:"link_to_taxonomy";i:0;s:14:"convert_spaces";i:0;}}s:7:"filters";a:1:{s:12:"machine_name";a:4:{s:2:"id";s:12:"machine_name";s:5:"table";s:19:"taxonomy_vocabulary";s:5:"field";s:12:"machine_name";s:5:"value";a:1:{s:20:"portfolio_categories";s:20:"portfolio_categories";}}}s:5:"sorts";a:1:{s:6:"weight";a:9:{s:2:"id";s:6:"weight";s:5:"table";s:18:"taxonomy_term_data";s:5:"field";s:6:"weight";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"order";s:3:"ASC";s:7:"exposed";b:0;s:6:"expose";a:1:{s:5:"label";s:0:"";}}}s:5:"title";s:16:"Portfolio filter";s:11:"row_options";a:4:{s:22:"default_field_elements";i:0;s:6:"inline";a:0:{}s:9:"separator";s:0:"";s:10:"hide_empty";i:0;}}'),
('11', 'block', 'Block', 'block', '2', 'a:2:{s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:5:"field";a:1:{s:5:"title";a:1:{s:12:"link_to_node";i:1;}}}'),
('11', 'default', 'Master', 'default', '1', 'a:12:{s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:6:"access";a:1:{s:4:"type";s:4:"perm";}s:5:"cache";a:1:{s:4:"type";s:4:"none";}s:12:"exposed_form";a:1:{s:4:"type";s:5:"basic";}s:5:"pager";a:2:{s:4:"type";s:4:"some";s:7:"options";a:1:{s:14:"items_per_page";s:1:"3";}}s:12:"style_plugin";s:21:"semanticviews_default";s:10:"row_plugin";s:6:"fields";s:6:"fields";a:6:{s:7:"counter";a:22:{s:2:"id";s:7:"counter";s:5:"table";s:5:"views";s:5:"field";s:7:"counter";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:1;s:5:"alter";a:26:{s:10:"alter_text";i:1;s:4:"text";s:10:"0[counter]";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:3:"div";s:21:"element_wrapper_class";s:7:"counter";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:13:"counter_start";s:1:"1";}s:5:"title";a:22:{s:2:"id";s:5:"title";s:5:"table";s:4:"node";s:5:"field";s:5:"title";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:1;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:0;s:8:"ellipsis";i:0;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:3:"div";s:21:"element_wrapper_class";s:8:"title-30";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:12:"link_to_node";i:1;}s:6:"body_1";a:34:{s:2:"id";s:6:"body_1";s:5:"table";s:15:"field_data_body";s:5:"field";s:4:"body";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:1;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:3:"div";s:21:"element_wrapper_class";s:7:"summary";s:23:"element_default_classes";i:0;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:23:"text_summary_or_trimmed";s:8:"settings";a:1:{s:11:"trim_length";s:3:"600";}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}s:7:"nothing";a:21:{s:2:"id";s:7:"nothing";s:5:"table";s:5:"views";s:5:"field";s:7:"nothing";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";b:1;s:4:"text";s:210:"<div class="extra srvice-header">\n	<div class="counter img-left">[counter]</div>\n	<div class="extra">\n		<div class="views-field-title title-30">[title]</div>\n		<div class="summary">[body_1]</div>\n	</div>\n</div>";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:0;}s:4:"body";a:34:{s:2:"id";s:4:"body";s:5:"table";s:15:"field_data_body";s:5:"field";s:4:"body";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:3:"200";s:13:"word_boundary";i:1;s:8:"ellipsis";i:0;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:1;s:4:"trim";i:1;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:12:"text_default";s:8:"settings";a:0:{}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}s:9:"view_node";a:22:{s:2:"id";s:9:"view_node";s:5:"table";s:17:"views_entity_node";s:5:"field";s:9:"view_node";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";b:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:3:"div";s:21:"element_wrapper_class";s:6:"button";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:4:"text";s:9:"Read more";}}s:7:"filters";a:2:{s:6:"status";a:6:{s:5:"value";i:1;s:5:"table";s:4:"node";s:5:"field";s:6:"status";s:2:"id";s:6:"status";s:6:"expose";a:1:{s:8:"operator";b:0;}s:5:"group";i:1;}s:4:"type";a:4:{s:2:"id";s:4:"type";s:5:"table";s:4:"node";s:5:"field";s:4:"type";s:5:"value";a:1:{s:8:"services";s:8:"services";}}}s:5:"sorts";a:1:{s:7:"created";a:4:{s:2:"id";s:7:"created";s:5:"table";s:4:"node";s:5:"field";s:7:"created";s:5:"order";s:4:"DESC";}}s:5:"title";s:0:"";s:13:"style_options";a:4:{s:8:"grouping";a:0:{}s:5:"group";a:2:{s:12:"element_type";s:2:"h3";s:5:"class";s:5:"title";}s:4:"list";a:2:{s:12:"element_type";s:0:"";s:5:"class";s:0:"";}s:3:"row";a:6:{s:12:"element_type";s:3:"div";s:5:"class";s:16:"grid-4 views-row";s:14:"last_every_nth";s:1:"3";s:11:"first_class";s:5:"alpha";s:10:"last_class";s:5:"omega";s:16:"striping_classes";s:8:"odd even";}}}'),
('12', 'block', 'Block', 'block', '2', 'a:2:{s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:5:"field";a:1:{s:5:"title";a:1:{s:12:"link_to_node";i:1;}}}'),
('12', 'default', 'Master', 'default', '1', 'a:11:{s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:6:"access";a:1:{s:4:"type";s:4:"perm";}s:5:"cache";a:1:{s:4:"type";s:4:"none";}s:12:"exposed_form";a:1:{s:4:"type";s:5:"basic";}s:5:"pager";a:2:{s:4:"type";s:4:"some";s:7:"options";a:1:{s:14:"items_per_page";s:1:"6";}}s:12:"style_plugin";s:7:"default";s:10:"row_plugin";s:6:"fields";s:6:"fields";a:1:{s:5:"title";a:8:{s:2:"id";s:5:"title";s:5:"table";s:4:"node";s:5:"field";s:5:"title";s:5:"label";s:0:"";s:5:"alter";a:8:{s:10:"alter_text";i:0;s:9:"make_link";i:0;s:8:"absolute";i:0;s:4:"trim";i:0;s:13:"word_boundary";i:0;s:8:"ellipsis";i:0;s:10:"strip_tags";i:0;s:4:"html";i:0;}s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:12:"link_to_node";i:1;}}s:7:"filters";a:2:{s:6:"status";a:6:{s:5:"value";i:1;s:5:"table";s:4:"node";s:5:"field";s:6:"status";s:2:"id";s:6:"status";s:6:"expose";a:1:{s:8:"operator";b:0;}s:5:"group";i:1;}s:4:"type";a:4:{s:2:"id";s:4:"type";s:5:"table";s:4:"node";s:5:"field";s:4:"type";s:5:"value";a:1:{s:9:"portfolio";s:9:"portfolio";}}}s:5:"sorts";a:1:{s:7:"created";a:4:{s:2:"id";s:7:"created";s:5:"table";s:4:"node";s:5:"field";s:7:"created";s:5:"order";s:4:"DESC";}}s:5:"title";s:13:"Design Trends";}'),
('13', 'block', 'Block', 'block', '2', 'a:2:{s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:5:"field";a:1:{s:5:"title";a:1:{s:12:"link_to_node";i:1;}}}'),
('13', 'default', 'Master', 'default', '1', 'a:12:{s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:6:"access";a:1:{s:4:"type";s:4:"perm";}s:5:"cache";a:1:{s:4:"type";s:4:"none";}s:12:"exposed_form";a:1:{s:4:"type";s:5:"basic";}s:5:"pager";a:2:{s:4:"type";s:4:"some";s:7:"options";a:1:{s:14:"items_per_page";s:1:"6";}}s:12:"style_plugin";s:21:"semanticviews_default";s:10:"row_plugin";s:6:"fields";s:6:"fields";a:3:{s:28:"field_popular_services_image";a:34:{s:2:"id";s:28:"field_popular_services_image";s:5:"table";s:39:"field_data_field_popular_services_image";s:5:"field";s:28:"field_popular_services_image";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:3:"div";s:21:"element_wrapper_class";s:24:"img-indent opacity-hover";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:17:"click_sort_column";s:3:"fid";s:4:"type";s:5:"image";s:8:"settings";a:2:{s:11:"image_style";s:7:"324x267";s:10:"image_link";s:7:"content";}s:12:"group_column";s:0:"";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}s:5:"title";a:22:{s:2:"id";s:5:"title";s:5:"table";s:4:"node";s:5:"field";s:5:"title";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:0;s:8:"ellipsis";i:0;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:3:"div";s:21:"element_wrapper_class";s:12:"title-indent";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:12:"link_to_node";i:1;}s:4:"body";a:34:{s:2:"id";s:4:"body";s:5:"table";s:15:"field_data_body";s:5:"field";s:4:"body";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:3:"120";s:13:"word_boundary";i:1;s:8:"ellipsis";i:0;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:1;s:4:"trim";i:1;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:0;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:12:"text_default";s:8:"settings";a:0:{}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}}s:7:"filters";a:2:{s:6:"status";a:6:{s:5:"value";i:1;s:5:"table";s:4:"node";s:5:"field";s:6:"status";s:2:"id";s:6:"status";s:6:"expose";a:1:{s:8:"operator";b:0;}s:5:"group";i:1;}s:4:"type";a:4:{s:2:"id";s:4:"type";s:5:"table";s:4:"node";s:5:"field";s:4:"type";s:5:"value";a:1:{s:16:"popular_services";s:16:"popular_services";}}}s:5:"sorts";a:1:{s:7:"created";a:4:{s:2:"id";s:7:"created";s:5:"table";s:4:"node";s:5:"field";s:7:"created";s:5:"order";s:4:"DESC";}}s:5:"title";s:16:"Popular services";s:13:"style_options";a:4:{s:8:"grouping";a:0:{}s:5:"group";a:2:{s:12:"element_type";s:2:"h3";s:5:"class";s:5:"title";}s:4:"list";a:2:{s:12:"element_type";s:0:"";s:5:"class";s:0:"";}s:3:"row";a:6:{s:12:"element_type";s:3:"div";s:5:"class";s:16:"grid-4 views-row";s:14:"last_every_nth";s:1:"3";s:11:"first_class";s:5:"alpha";s:10:"last_class";s:5:"omega";s:16:"striping_classes";s:8:"odd even";}}}'),
('14', 'block', 'Block', 'block', '2', 'a:2:{s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:5:"field";a:1:{s:5:"title";a:1:{s:12:"link_to_node";i:1;}}}'),
('14', 'default', 'Master', 'default', '1', 'a:12:{s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:6:"access";a:1:{s:4:"type";s:4:"perm";}s:5:"cache";a:1:{s:4:"type";s:4:"none";}s:12:"exposed_form";a:1:{s:4:"type";s:5:"basic";}s:5:"pager";a:2:{s:4:"type";s:4:"some";s:7:"options";a:1:{s:14:"items_per_page";s:1:"3";}}s:12:"style_plugin";s:7:"default";s:10:"row_plugin";s:6:"fields";s:6:"fields";a:6:{s:7:"created";a:24:{s:2:"id";s:7:"created";s:5:"table";s:4:"node";s:5:"field";s:7:"created";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:1;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:11:"date_format";s:6:"custom";s:18:"custom_date_format";s:1:"d";s:8:"timezone";s:0:"";}s:9:"created_1";a:24:{s:2:"id";s:9:"created_1";s:5:"table";s:4:"node";s:5:"field";s:7:"created";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:1;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:11:"date_format";s:6:"custom";s:18:"custom_date_format";s:1:"M";s:8:"timezone";s:0:"";}s:5:"title";a:22:{s:2:"id";s:5:"title";s:5:"table";s:4:"node";s:5:"field";s:5:"title";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:1;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:0;s:8:"ellipsis";i:0;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:12:"link_to_node";i:1;}s:4:"body";a:34:{s:2:"id";s:4:"body";s:5:"table";s:15:"field_data_body";s:5:"field";s:4:"body";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:1;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:2:"50";s:13:"word_boundary";i:1;s:8:"ellipsis";i:0;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:1;s:4:"trim";i:1;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:0;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:23:"text_summary_or_trimmed";s:8:"settings";a:1:{s:11:"trim_length";s:3:"600";}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}s:6:"body_1";a:34:{s:2:"id";s:6:"body_1";s:5:"table";s:15:"field_data_body";s:5:"field";s:4:"body";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:1;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:2:"70";s:13:"word_boundary";i:1;s:8:"ellipsis";i:0;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:1;s:4:"trim";i:1;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:0;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:12:"text_default";s:8:"settings";a:0:{}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}s:7:"nothing";a:21:{s:2:"id";s:7:"nothing";s:5:"table";s:5:"views";s:5:"field";s:7:"nothing";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";b:1;s:4:"text";s:258:"<div class="post-date img-left">\n	<div class="day">[created]</div>\n	<div class="month">[created_1]</div>\n</div>\n<div class="extra">\n	<div class="views-field-title">[title]</div>\n	<div class="summary summary-regular ">[body]</div>\n	<div>[body_1]</div>\n</div>\n";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:0;}}s:7:"filters";a:2:{s:6:"status";a:6:{s:5:"value";i:1;s:5:"table";s:4:"node";s:5:"field";s:6:"status";s:2:"id";s:6:"status";s:6:"expose";a:1:{s:8:"operator";b:0;}s:5:"group";i:1;}s:4:"type";a:4:{s:2:"id";s:4:"type";s:5:"table";s:4:"node";s:5:"field";s:4:"type";s:5:"value";a:1:{s:4:"blog";s:4:"blog";}}}s:5:"sorts";a:1:{s:7:"created";a:4:{s:2:"id";s:7:"created";s:5:"table";s:4:"node";s:5:"field";s:7:"created";s:5:"order";s:4:"DESC";}}s:5:"title";s:11:"Latest News";s:9:"css_class";s:14:"views-clearfix";}'),
('15', 'block', 'Block', 'block', '2', 'a:2:{s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:5:"field";a:1:{s:5:"title";a:1:{s:12:"link_to_node";i:1;}}}'),
('15', 'default', 'Master', 'default', '1', 'a:12:{s:5:"query";a:2:{s:4:"type";s:11:"views_query";s:7:"options";a:0:{}}s:6:"access";a:1:{s:4:"type";s:4:"perm";}s:5:"cache";a:1:{s:4:"type";s:4:"none";}s:12:"exposed_form";a:1:{s:4:"type";s:5:"basic";}s:5:"pager";a:2:{s:4:"type";s:4:"some";s:7:"options";a:1:{s:14:"items_per_page";s:1:"2";}}s:12:"style_plugin";s:7:"default";s:10:"row_plugin";s:6:"fields";s:6:"fields";a:5:{s:7:"picture";a:23:{s:2:"id";s:7:"picture";s:5:"table";s:5:"users";s:5:"field";s:7:"picture";s:12:"relationship";s:3:"uid";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:1;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:21:"link_photo_to_profile";i:1;s:11:"image_style";s:0:"";}s:4:"body";a:34:{s:2:"id";s:4:"body";s:5:"table";s:15:"field_data_body";s:5:"field";s:4:"body";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:1;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:3:"130";s:13:"word_boundary";i:1;s:8:"ellipsis";i:0;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:1;s:4:"trim";i:1;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:12:"text_default";s:8:"settings";a:0:{}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}s:4:"name";a:25:{s:2:"id";s:4:"name";s:5:"table";s:5:"users";s:5:"field";s:4:"name";s:12:"relationship";s:3:"uid";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:1;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:12:"link_to_user";i:1;s:19:"overwrite_anonymous";i:0;s:14:"anonymous_text";s:0:"";s:15:"format_username";i:1;}s:27:"field_testimonials_position";a:34:{s:2:"id";s:27:"field_testimonials_position";s:5:"table";s:38:"field_data_field_testimonials_position";s:5:"field";s:27:"field_testimonials_position";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:1;s:5:"alter";a:26:{s:10:"alter_text";i:0;s:4:"text";s:0:"";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:0:"";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:0:"";s:21:"element_wrapper_class";s:0:"";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:1;s:17:"click_sort_column";s:5:"value";s:4:"type";s:12:"text_default";s:8:"settings";a:0:{}s:12:"group_column";s:5:"value";s:13:"group_columns";a:0:{}s:10:"group_rows";b:1;s:11:"delta_limit";s:3:"all";s:12:"delta_offset";i:0;s:14:"delta_reversed";b:0;s:16:"delta_first_last";b:0;s:10:"multi_type";s:9:"separator";s:9:"separator";s:2:", ";s:17:"field_api_classes";i:0;}s:7:"nothing";a:21:{s:2:"id";s:7:"nothing";s:5:"table";s:5:"views";s:5:"field";s:7:"nothing";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:0:"";s:7:"exclude";i:0;s:5:"alter";a:26:{s:10:"alter_text";b:1;s:4:"text";s:224:"<div class="extra">\n	<div class="img-left">[picture]</div>\n	<div class="extra">\n		<div class="testimonials-text">" [body] "</div>\n		<div class="testimonials-author">[name] / [field_testimonials_position]</div>\n	</div>\n</div>";s:9:"make_link";i:0;s:4:"path";s:0:"";s:8:"absolute";i:0;s:8:"external";i:0;s:14:"replace_spaces";i:0;s:9:"path_case";s:4:"none";s:15:"trim_whitespace";i:0;s:3:"alt";s:0:"";s:3:"rel";s:0:"";s:10:"link_class";s:0:"";s:6:"prefix";s:0:"";s:6:"suffix";s:0:"";s:6:"target";s:0:"";s:5:"nl2br";i:0;s:10:"max_length";s:0:"";s:13:"word_boundary";i:1;s:8:"ellipsis";i:1;s:9:"more_link";i:0;s:14:"more_link_text";s:0:"";s:14:"more_link_path";s:0:"";s:10:"strip_tags";i:0;s:4:"trim";i:0;s:13:"preserve_tags";s:0:"";s:4:"html";i:0;}s:12:"element_type";s:1:"0";s:13:"element_class";s:0:"";s:18:"element_label_type";s:0:"";s:19:"element_label_class";s:0:"";s:19:"element_label_colon";b:0;s:20:"element_wrapper_type";s:3:"div";s:21:"element_wrapper_class";s:18:"testimonials-block";s:23:"element_default_classes";i:1;s:5:"empty";s:0:"";s:10:"hide_empty";i:0;s:10:"empty_zero";i:0;s:16:"hide_alter_empty";i:0;}}s:7:"filters";a:2:{s:6:"status";a:6:{s:5:"value";i:1;s:5:"table";s:4:"node";s:5:"field";s:6:"status";s:2:"id";s:6:"status";s:6:"expose";a:1:{s:8:"operator";b:0;}s:5:"group";i:1;}s:4:"type";a:4:{s:2:"id";s:4:"type";s:5:"table";s:4:"node";s:5:"field";s:4:"type";s:5:"value";a:1:{s:12:"testimonials";s:12:"testimonials";}}}s:5:"sorts";a:1:{s:7:"created";a:10:{s:2:"id";s:7:"created";s:5:"table";s:4:"node";s:5:"field";s:7:"created";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"order";s:3:"ASC";s:7:"exposed";b:0;s:6:"expose";a:1:{s:5:"label";s:0:"";}s:11:"granularity";s:6:"second";}}s:5:"title";s:12:"Testimonials";s:13:"relationships";a:1:{s:3:"uid";a:8:{s:2:"id";s:3:"uid";s:5:"table";s:4:"node";s:5:"field";s:3:"uid";s:12:"relationship";s:4:"none";s:10:"group_type";s:5:"group";s:7:"ui_name";s:0:"";s:5:"label";s:6:"author";s:8:"required";i:0;}}}');
/*!40000 ALTER TABLE views_display ENABLE KEYS */;

--
-- Table structure for table 'views_view'
--

CREATE TABLE IF NOT EXISTS `views_view` (
  `vid` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'The view ID of the field, defined by the database.',
  `name` varchar(128) NOT NULL DEFAULT '' COMMENT 'The unique name of the view. This is the primary field views are loaded from, and is used so that views may be internal and not necessarily in the database. May only be alphanumeric characters plus underscores.',
  `description` varchar(255) DEFAULT '' COMMENT 'A description of the view for the admin interface.',
  `tag` varchar(255) DEFAULT '' COMMENT 'A tag used to group/sort views in the admin interface',
  `base_table` varchar(64) NOT NULL DEFAULT '' COMMENT 'What table this view is based on, such as node, user, comment, or term.',
  `human_name` varchar(255) DEFAULT '' COMMENT 'A human readable name used to be displayed in the admin interface',
  `core` int(11) DEFAULT '0' COMMENT 'Stores the drupal core version of the view.',
  PRIMARY KEY (`vid`),
  UNIQUE KEY `name` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores the general data for a view.';

--
-- Dumping data for table 'views_view'
--

/*!40000 ALTER TABLE views_view DISABLE KEYS */;
INSERT INTO `views_view` VALUES
('2', 'portfolio', '', 'default', 'node', 'Portfolio', '7'),
('4', 'archive', 'Display a list of months that link to content for that month.', 'default', 'node', 'Archive', '0'),
('5', 'our_team', '', 'default', 'node', 'Our team', '7'),
('6', 'faq', 'FAQ listings', 'default', 'node', 'FAQ', '7'),
('8', 'slider', '', 'default', 'node', 'Slider', '7'),
('9', 'categories', '', 'default', 'taxonomy_term_data', 'Categories', '7'),
('10', 'portfolio_filter', '', 'default', 'taxonomy_term_data', 'Portfolio filter', '7'),
('11', 'services', '', 'default', 'node', 'Services', '7'),
('12', 'areas_of_practice', '', 'default', 'node', 'Areas of Practice', '7'),
('13', 'popular_services', '', 'default', 'node', 'Popular services', '7'),
('14', 'latest_news', '', 'default', 'node', 'Latest News', '7'),
('15', 'testimonials', '', 'default', 'node', 'Testimonials', '7');
/*!40000 ALTER TABLE views_view ENABLE KEYS */;

--
-- Table structure for table 'watchdog'
--

CREATE TABLE IF NOT EXISTS `watchdog` (
  `wid` int(11) NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique watchdog event ID.',
  `uid` int(11) NOT NULL DEFAULT '0' COMMENT 'The users.uid of the user who triggered the event.',
  `type` varchar(64) NOT NULL DEFAULT '' COMMENT 'Type of log message, for example `user` or `page not found.`',
  `message` longtext NOT NULL COMMENT 'Text of log message to be passed into the t() function.',
  `variables` longblob NOT NULL COMMENT 'Serialized array of variables that match the message string and that is passed into the t() function.',
  `severity` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT 'The severity level of the event; ranges from 0 (Emergency) to 7 (Debug)',
  `link` varchar(255) DEFAULT '' COMMENT 'Link to view the result of the event.',
  `location` text NOT NULL COMMENT 'URL of the origin of the event.',
  `referer` text COMMENT 'URL of referring page.',
  `hostname` varchar(128) NOT NULL DEFAULT '' COMMENT 'Hostname of the user who triggered the event.',
  `timestamp` int(11) NOT NULL DEFAULT '0' COMMENT 'Unix timestamp of when event occurred.',
  PRIMARY KEY (`wid`),
  KEY `type` (`type`),
  KEY `uid` (`uid`),
  KEY `severity` (`severity`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Table that contains logs of all system events.';

--
-- Table structure for table 'wysiwyg'
--

CREATE TABLE IF NOT EXISTS `wysiwyg` (
  `format` varchar(255) NOT NULL COMMENT 'The filter_format.format of the text format.',
  `editor` varchar(128) NOT NULL DEFAULT '' COMMENT 'Internal name of the editor attached to the text format.',
  `settings` text COMMENT 'Configuration settings for the editor.',
  PRIMARY KEY (`format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores Wysiwyg profiles.';

--
-- Dumping data for table 'wysiwyg'
--

/*!40000 ALTER TABLE wysiwyg DISABLE KEYS */;
INSERT INTO `wysiwyg` VALUES
('filtered_html', 'tinymce', 'a:20:{s:7:"default";i:1;s:11:"user_choose";i:0;s:11:"show_toggle";i:1;s:5:"theme";s:8:"advanced";s:8:"language";s:2:"en";s:7:"buttons";a:3:{s:7:"default";a:22:{s:4:"bold";i:1;s:6:"italic";i:1;s:9:"underline";i:1;s:11:"justifyleft";i:1;s:13:"justifycenter";i:1;s:12:"justifyright";i:1;s:11:"justifyfull";i:1;s:7:"bullist";i:1;s:7:"numlist";i:1;s:4:"undo";i:1;s:4:"redo";i:1;s:4:"link";i:1;s:6:"unlink";i:1;s:5:"image";i:1;s:9:"forecolor";i:1;s:9:"backcolor";i:1;s:10:"blockquote";i:1;s:4:"code";i:1;s:3:"cut";i:1;s:4:"copy";i:1;s:5:"paste";i:1;s:12:"removeformat";i:1;}s:8:"advimage";a:1:{s:8:"advimage";i:1;}s:4:"font";a:1:{s:14:"fontsizeselect";i:1;}}s:11:"toolbar_loc";s:3:"top";s:13:"toolbar_align";s:4:"left";s:8:"path_loc";s:6:"bottom";s:8:"resizing";i:1;s:11:"verify_html";i:1;s:12:"preformatted";i:0;s:22:"convert_fonts_to_spans";i:1;s:17:"remove_linebreaks";i:1;s:23:"apply_source_formatting";i:0;s:27:"paste_auto_cleanup_on_paste";i:0;s:13:"block_formats";s:32:"p,address,pre,h2,h3,h4,h5,h6,div";s:11:"css_setting";s:5:"theme";s:8:"css_path";s:0:"";s:11:"css_classes";s:0:"";}'),
('full_html', '', NULL),
('gmap', '', NULL),
('php_code', '', NULL),
('plain_text', '', NULL);
/*!40000 ALTER TABLE wysiwyg ENABLE KEYS */;

--
-- Table structure for table 'wysiwyg_user'
--

CREATE TABLE IF NOT EXISTS `wysiwyg_user` (
  `uid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT 'The users.uid of the user.',
  `format` varchar(255) DEFAULT NULL COMMENT 'The filter_format.format of the text format.',
  `status` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether the format is enabled by default.',
  KEY `uid` (`uid`),
  KEY `format` (`format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Stores user preferences for wysiwyg profiles.';

--
-- Dumping data for table 'wysiwyg_user'
--

/*!40000 ALTER TABLE wysiwyg_user DISABLE KEYS */;
/*!40000 ALTER TABLE wysiwyg_user ENABLE KEYS */;

SET FOREIGN_KEY_CHECKS = 1;
SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT;
SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS;
SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION;

